/*---------------------------------------------------------------------------*/
/*   Copyright (C)       Endress+Hauser (2002). All Rights Reserved          */
/*                                                                           */
/*   Product:            SIMATIC PDM                                         */
/*                                                                           */
/*   Device:             ECHO LEVEL DEVICE Micropilot PA for Profibus        */
/*   Function:           Device Description Implementation for FMR2xx        */
/*   Description:        Device Description                                  */
/*   Filename:           MPM_P3.ddl                                          */
/*   Dictionary:         EHPA__MicropilotM_P3_00.dct                         */
/*                                                                           */
/*   Manufactor:         Endress & Hauser GmbH & Co.                         */
/*                       Hauptstrasse 1                                      */
/*                       D-79689 Maulburg                                    */
/*                       Tel:07622/28-0                                      */
/*                                                                           */
/*   Author:             Stefan Mller, Julien Messer                        */
/*                       Interpro GmbH                                       */
/*                       CH-4144 Arlesheim                                   */
/*                                                                           */
/*  $Revision:            2.0$                                               */
/*  $Date:                23.09.02$                                          */
/*  Obere Revision fr QVCS, untere fr DD, unten die aktuelle angeben       */
/*  Revision:2.0                                                             */
/*  Date:25.09.2002                                                          */
/*---------------------------------------------------------------------------*/

/******************************************************************************/
/* Defines                                                                    */
/******************************************************************************/
#define ENABLE_IDENTCHECK

#define  DEVICE_TYPE                    "FMR 2XX"
#define  DEFAULT_VALUE_phys_device_id   "FMR 2XX"
#define  DEFAULT_VALUE_phys_software_rev        "1.0"
#define  DEFAULT_MANUFACTURER_ID        17
#define  CHECK_PROFILE_REV      0x300
#define  CHECK_DEVICE_TYPE "FMR 2XX"

// Note: only the following releases are allowed (see MPM_IDENT01.inc).
// All the build version (01.01.XX) are allowed.
#define  CHECK_SOFTWARE_VERSION "01.01"
#define  CHECK_SOFTWARE_VERSION02 "01.02"

#ifndef ID_FC_ERROR
#define ID_FC_ERROR                     3000
#endif


#define  YT1_LABEL      "|en|measured value|de|Messwert|fr|Valeur de mesure|es|Messwert|it|Valore di misura|nl|gemeten waarde"
#define  YT1_VALUE      parMeasuredValue
#define  YT1_LRV        MEASVAL_LOWER_LIMIT
#define  YT1_URV        MEASVAL_UPPER_LIMIT

#define  YT2_LABEL      "|en|measured level|de|gemess. Fuellst.|fr|niveau mesure|es|gemess. Fuellst.|it|Livello mis.|nl|gemeten niveau"
#define  YT2_VALUE      parMeasuredLevel
#define  YT2_LRV        MEASLEV_LOWER_LIMIT
#define  YT2_URV        MEASLEV_UPPER_LIMIT

#define  YT3_LABEL      "|en|measured dist.|de|gemessene Dist.|fr|distance mesuree|es|gemessene Dist.|it|Distanza mis.|nl|meetafstand"
#define  YT3_VALUE      parMeasuredDistance
#define  YT3_LRV        MEASDIS_LOWER_LIMIT
#define  YT3_URV        MEASDIS_UPPER_LIMIT

#define  YT4_LABEL      "|en|echo quality|de|Echoqualitaet|fr|Qualite echo|es|Echoqualitaet|it|Qualit eco|nl|echokwaliteit"
#define  YT4_VALUE      parEchoQuality
#define  YT4_LRV        ECHQUAL_LOWER_LIMIT
#define  YT4_URV        ECHQUAL_UPPER_LIMIT


/*
#define  YT1_LABEL      [func_out_value]
#define  YT1_HELP       [func_ai_out_value_help]
#define  YT1_VALUE      func1_AI_out_value
#define  YT1_LRV        func1_AI_out_lower_range_value
#define  YT1_URV        func1_AI_out_upper_range_value
*/
#define  FUNC1_TITLE    [menu_dialog_display_output]
#define  DECIMAL_POINT_7_SUPPORTED
#define  DECIMAL_POINT_STANDARD_SUPPORTED

/******************************************************************************/
/* Includes                                                                    */
/******************************************************************************/

#include "SIPAST_CommError.inc"
#include "SIPAST_Macros_300.inc"

// #include "SIPAST.inc"
#include "MPM_IDENT01_Rev2.inc"      // Copied and modified from SIPASTIDENT01.inc
                                // (This DDL supports more than one software release)
                                // Replaced from "SIPAST.inc"

#include "SI_YT.inc"

#include "SIPASTPB_300.inc"
#include "SIPASTAI_300.inc"
#include "SI_FileM.inc"
#include "SI_HlpM.inc"
#include "SI_OptM.inc"


/***********************************************************************/
/* HANDLING CONDITIONS                                                 */
/***********************************************************************/
#define  Val012	parOperationCode==33999||parOperationCode==33998||parOperationCode==33200||parOperationCode==33300||parOperationCode==33123
#define  Val013	(parSoftwareVersion > 1)
#define  Dlc000	Val013
#define  Val015	((Val012) && (parSoftwareVersion == 1))
#define  Val016	((Val012) && (parSoftwareVersion > 1))
#define  Dlc001	Val015
#define  Dlc002	Val016
#define  Hnd000	(parOperationCode == 2457)||\
			(parOperationCode == 33300)||\
			(parOperationCode == 33123)
#define  Hnd001	((parOperationCode == 2457)||\
			 (parOperationCode == 33300)||\
			 (parOperationCode == 33123))\
			 &&\
			((parLevelUllageMode == 0)||\
			 (parLevelUllageMode == 2))
#define  Hnd002	parOperationMode != 1
#define  Hnd003	(parOperationCode == 33300)||\
			(parOperationCode == 33123)
#define  Hnd004	((parOperationCode == 2457)||\
			(parOperationCode == 33300)||\
			(parOperationCode == 33123))\
			&&\
			(parLinearisation == 240)&&\
			((parLevelUllageMode == 0)||\
			(parLevelUllageMode == 2))
#define  Hnd005	((parOperationCode == 2457)||\
			(parOperationCode == 33300)||\
			(parOperationCode == 33123))\
			&&\
			((parLinearisation == 240)||\
			(parLinearisation == 241))\
			&&\
			((parLevelUllageMode == 0)||\
			(parLevelUllageMode == 2))
#define  Hnd006	((parOperationCode == 2457)||\
			(parOperationCode == 33300)||\
			(parOperationCode == 33123))\
			&&\
			((parLinearisation == 0)||\
			(parLinearisation == 20)||\
			(parLinearisation == 242))\
			&&\
			((parLevelUllageMode == 0)||\
			(parLevelUllageMode == 2))
#define  Hnd007	((parOperationCode == 2457)||\
			(parOperationCode == 33300)||\
			(parOperationCode == 33123))\
			&&\
			(parLinearisation == 20)\
			&&\
			((parLevelUllageMode == 0)||\
			(parLevelUllageMode == 2))
#define  Val000	parFormatDisplay_ft==0
#define  Hnd008	parOperationCode == 33123
#define  Ped000	((preDistanceUnit == 1018 && parDistanceUnit == 1010) ||\
			(preDistanceUnit == 1018 && parDistanceUnit == 1013) ||\
			(preDistanceUnit == 1019 && parDistanceUnit == 1010) ||\
			(preDistanceUnit == 1019 && parDistanceUnit == 1013))
#define  Ped001	((preDistanceUnit == 1010 && parDistanceUnit == 1018) ||\
			(preDistanceUnit == 1010 && parDistanceUnit == 1019) ||\
			(preDistanceUnit == 1013 && parDistanceUnit == 1018) ||\
			(preDistanceUnit == 1013 && parDistanceUnit == 1019))
#define  Hnd009	((parOperationCode ==33998)||\
			(parOperationCode == 33200)||\
			(parOperationCode == 33300)||\
			(parOperationCode == 33123)||\
			(parOperationCode == 2457))
#define  Val001	parTankShape==3||parTankShape==2
#define  Val002	parReactionLostEcho==2
#define  Val003	(parLevelUllageMode==0||parLevelUllageMode==2)&&(parLinearisation==240||parLinearisation==241||parLinearisation==1)
#define  Val004	parLinearisation==240||parLinearisation==1
#define  Val005	parLinearisation==240||parLinearisation==241||parLinearisation==1
#define  Val006	parLinearisation==20||parLinearisation==0
#define  Val007	parLinearisation==20
#define  Val008	parCheckDistance==0||parCheckDistance==1||parCheckDistance==240
#define  Val009	parSimulation==1
#define  Val010	parLinearisation==241
#define  Val011	parSimulation==2
#define  Hnd010	((parOperationCode == 33300)||\
			(parOperationCode == 33123)||\
			(parOperationCode == 2457)\
			) &&\
			(parCheckDistance == 240)
#define  Val014	((parLevelUllageMode == 0) || (parLevelUllageMode == 2))\
	&& ((parLinearisation == 0) || (parLinearisation == 20))
#define  Hnd011	((parOperationCode == 33300)||\
			(parOperationCode == 33123)||\
			(parOperationCode == 2457))
#define  Hnd012	((parOperationCode != 33998) && (parOperationCode != 33999))


/******************************************************************************/
/* UNIT RELATIONS                                                             */
/******************************************************************************/


UNIT DistUnitRel
{
        parDistanceUnit:
                                parAbsMaxMessDist,
                                parEmptyCalibration,
                                parFullCalibration ,
                                //parTubeDiameter,
                                parCylinderVessel,
                                parPresMapRange,
                                parRangeFactoryMap,
                                parLevelWithinSafetyDistance,
                                parMeasuredDistance,
                                parInputLevelManual,
                                parInputLevelHalfAutomatic,
                                parSuppressionDistance,
                                parOffsetOfMeasuredDistance,
                                parBlockingDistance,
                                parSimulationValueLevel,
//                              parMeasuredDistance,
                                MEASLEV_LOWER_LIMIT,
                                MEASLEV_UPPER_LIMIT,
                                MEASDIS_LOWER_LIMIT,
                                MEASDIS_UPPER_LIMIT,
                                parMeasuredLevel
}


UNIT CustUnitRel
{
        parCustomerUnit:
                                parMaxVolume,
                                parMeasuredValue,
                                parInputVolume,
                                MEASVAL_UPPER_LIMIT,
                                MEASVAL_LOWER_LIMIT,
                                MEASLEV_LOWER_LIMIT,
                                MEASLEV_UPPER_LIMIT,
                                ECHQUAL_LOWER_LIMIT,
                                ECHQUAL_UPPER_LIMIT,
                                parSimulationValueVolume
}

/*******************************************************************************/
/*    Members                                                                  */
/*******************************************************************************/

COLLECTION OF VARIABLE collectionTag
{
        MEMBERS
        {
                parTagMPM, phys_tag_desc, "|en|tag no.|de|Messstelle|fr|N Repere|es|Messstelle|it|Tag n|nl|tag nummer";
        }
}

/*******************************************************************************/
/*    Standard Methods                                                         */
/*******************************************************************************/

METHOD method_set
{
	LABEL       [transfer];
	HELP        [transfer_help];
	DEFINITION
	{
	}
}

METHOD uploadVariablesPreWriteActions
{
        LABEL "Download of the Operation Code before uploading the variables" ;
        DEFINITION
        {
                ReadCommand(read_parOperationCode);
                ReadCommand(read_phys_software_rev);
                if (parShowAccess == 0)
                {
                        ACKNOWLEDGE("|en|No variables have been uploaded|de|Es wurde keine Variablen geschrieben");
                }
        }
}

METHOD downloadVariablesPreReadActions
{
        LABEL "downloadVariablesPreReadActions" ;
        DEFINITION
        {
                ReadCommand(read_parOperationCode);
                ReadCommand(read_parDistanceUnit);
                ReadCommand(read_phys_software_rev);
        }
}


METHOD std_NodeAddress
{
	LABEL		[menu_Device_NodeAddress];
	DEFINITION
	{
	}
}

METHOD std_LoadinDevice
{
	LABEL		[menu_Device_LoadinDevice];
	DEFINITION
	{
	}
}

METHOD std_LoadinPC
{
	LABEL		[menu_Device_LoadinPC];
	DEFINITION
	{
	}
}

METHOD std_Funktionsleiste
{
	LABEL		[menu_View_Toolbar];
	DEFINITION
	{
	}
}

METHOD std_Statuszeile
{
	LABEL		[menu_View_Statusbar];
	DEFINITION
	{
	}
}


METHOD std_Update
{
	LABEL		[menu_View_Update];
	DEFINITION
	{
	}
}


METHOD assignDistanceUnit
{
        preDistanceUnit = parDistanceUnit;
}


METHOD nonMetricToMetricUnits
{
        DEFINITION
        {
                fassign(parTubeDiameter, fvar_value(parTubeDiameter)*25.4);
                fassign(parUnfilteredDistance, fvar_value(parUnfilteredDistance)*25.4);
                fassign(parHystereseWidth, fvar_value(parHystereseWidth)*25.4);
                fassign(parEchoLostRampUp, fvar_value(parEchoLostRampUp)*25.4);
                fassign(parEchoLostRampDown, fvar_value(parEchoLostRampDown)*25.4);
                fassign(parUnfilteredDistanceRaw, fvar_value(parUnfilteredDistanceRaw)*25.4);
                fassign(parFefDistanceNear, fvar_value(parFefDistanceNear)*25.4);
                fassign(parFefDistanceFar, fvar_value(parFefDistanceFar)*25.4);
                fassign(parMinLevelBottomDetection, fvar_value(parMinLevelBottomDetection)*25.4);
                fassign(parLevelSpeed, fvar_value(parLevelSpeed)*25.4);
                fassign(parZeroDistance, fvar_value(parZeroDistance)*25.4);
                fassign(parInactiveLength, fvar_value(parInactiveLength)*25.4);
                fassign(parTotalLength, fvar_value(parTotalLength)*25.4);
                fassign(parPositionOfReferencePulse, fvar_value(parPositionOfReferencePulse)*25.4);
                fassign(parMaxDeltaPlausibilityFunction, fvar_value(parMaxDeltaPlausibilityFunction)*25.4);
                fassign(parUpperAreaPlausibilityFunction, fvar_value(parUpperAreaPlausibilityFunction)*25.4);
        }
}

METHOD metricToNonMetricUnits
{
        DEFINITION
        {
                fassign(parTubeDiameter, fvar_value(parTubeDiameter)/25.4);
                fassign(parUnfilteredDistance, fvar_value(parUnfilteredDistance)/25.4);
                fassign(parHystereseWidth, fvar_value(parHystereseWidth)/25.4);
                fassign(parEchoLostRampUp, fvar_value(parEchoLostRampUp)/25.4);
                fassign(parEchoLostRampDown, fvar_value(parEchoLostRampDown)/25.4);
                fassign(parUnfilteredDistanceRaw, fvar_value(parUnfilteredDistanceRaw)/25.4);
                fassign(parFefDistanceNear, fvar_value(parFefDistanceNear)/25.4);
                fassign(parFefDistanceFar, fvar_value(parFefDistanceFar)/25.4);
                fassign(parMinLevelBottomDetection, fvar_value(parMinLevelBottomDetection)/25.4);
                fassign(parLevelSpeed, fvar_value(parLevelSpeed)/25.4);
                fassign(parZeroDistance, fvar_value(parZeroDistance)/25.4);
                fassign(parInactiveLength, fvar_value(parInactiveLength)/25.4);
                fassign(parTotalLength, fvar_value(parTotalLength)/25.4);
                fassign(parPositionOfReferencePulse, fvar_value(parPositionOfReferencePulse)/25.4);
                fassign(parMaxDeltaPlausibilityFunction, fvar_value(parMaxDeltaPlausibilityFunction)/25.4);
                fassign(parUpperAreaPlausibilityFunction, fvar_value(parUpperAreaPlausibilityFunction)/25.4);
        }
}

METHOD preOperationCodeModified
{
        LABEL "Copy value of preOperationCode onto parOperationCode" ;
        DEFINITION
        {
                parOperationCode  = preOperationCode;
        }
}

METHOD updateParShowAccess
{
        LABEL "Update parShowAccess after preOperationCode gets modified" ;
        DEFINITION
        {
                switch (parOperationCode)
                {
                        case 33200:
                        {
                                parShowAccess = 2;
                                parWriteLocking = 0;    //Yes
                        }; break;
                        case 33300:
                        {
                                parShowAccess = 3;
                                parWriteLocking = 1;    //No
                        }; break;
                        case 2457:
                        {
                                parShowAccess = 4;
                                parWriteLocking = 1;    //No
                        }; break;
                        case 33998:
                        {
                                parShowAccess = 5;
                                parWriteLocking = 0;    //Yes
                        }; break;
                        case 33999:
                        {
                                parShowAccess = 7;
                                parWriteLocking = 1;    //Yes
                        }; break;
                        case 33123:
                        {
                                parShowAccess = 6;
                                parWriteLocking = 1;    //No
                        }; break;
                        default:
                        {
                                parShowAccess = 0;      // 0
                                parWriteLocking = 0;    //Yes
                        }; break;
                }
        }
}

METHOD setAbsMax
{
        DEFINITION
        {
                iassign(parMaxAbs, 1);
        }
}

METHOD synchronizeParProcessConditionToParOutputDamping
{
        DEFINITION
        {
                switch (parProcessCondition)
                {
                        default:
                        case 0: // standard
                        case 2: // unruhig
                        case 3: // Rhrwerk
                        {
                                parOutputDamping = 3;
                        }; break;
                        case 1: // ruhig
                        {
                                parOutputDamping = 10;
                        }; break;
                        case 4: // schnell
                        case 5: // test (no filter)
                        {
                                parOutputDamping = 0;
                        }; break;
                }
        }
}

METHOD setUnitToBus
{
        LABEL "|en|set unit to bus|de|Setze Einh. Out";
        DEFINITION
        {
                WriteCommand(write_parPASetUnitToBus);
        }
}

METHOD PostReadId_phys_software_rev
{
        LABEL "PostReadId_phys_software_rev" ;  // See also "PostReadPhys_software_rev"
        DEFINITION
        {
                char myString[16];
                myString = id_phys_software_rev;
                myString[5] = 0;        // Remove Build version
                if (myString == CHECK_SOFTWARE_VERSION)
                {
                        parSoftwareVersion = 1;
                }
                else if (myString == CHECK_SOFTWARE_VERSION02)
                {
                        parSoftwareVersion = 2;
                }
                else
                {
                        parSoftwareVersion = 0;
                }
        }
}

METHOD PostReadPhys_software_rev
{
        LABEL "PostReadPhys_software_rev" ;     // See also "PostReadId_phys_software_rev"
        DEFINITION
        {
                char myString[16];
                myString = phys_software_rev;
                myString[5] = 0;        // Remove Build version
                if (myString == CHECK_SOFTWARE_VERSION)
                {
                        parSoftwareVersion = 1;
                }
                else if (myString == CHECK_SOFTWARE_VERSION02)
                {
                        parSoftwareVersion = 2;
                }
                else
                {
                        parSoftwareVersion = 0;
                }
        }
}

BLOCK transducer_block_1
{
	TYPE	TRANSDUCER;
	NUMBER	1;
}


MENU upload_variables { 
	LABEL "|en|Upload variables";
	PRE_WRITE_ACTIONS {
		uploadVariablesPreWriteActions
	}
	ITEMS { 
		IF ( Hnd000 ) { 
			parDistanceUnit,
			parAcknowledgeAlarm,
			parOffsetOfMeasuredDistance
		}
		IF ( Hnd009 ) {
			parLanguage
		}
		IF ( Hnd000 ) {
			parPAIdentNumberSelector,
			parPA2ndCyclicValue,
			parPASelectMainValue
			IF ( Val000 ) {
				parNoOfDecimals
			}
			parTankShape,
			parDielectricConstant,
			parProcessCondition,
			parEmptyCalibration,
			parFullCalibration,
			parFormatDisplay_ft,
			parOutputOnAlarm,
			parReactionLostEcho
			IF ( Val001 ) {
				parTubeDiameter
			}
			IF ( Val002 ) {
				parRampInPercentPerMin
			}
			parDelayTimeOnLostEcho,
			parLevelWithinSafetyDistance,
			parInSafetyDistance,
			parOutputDamping,
			parBlockingDistance,
			parBackToHome
			IF ( Val000 ) {
				parSeparationCharacter
			}
			parClearLastError,
			parTagNumber
		}
		IF ( Hnd011 ) {
			func1_AI_pv_lower_range_value,
			func1_AI_out_lower_range_value,
			func1_AI_lo_lo_lim,
			phys_descriptor,
			func1_AI_pv_upper_range_value,
			func1_AI_out_upper_range_value,
			func1_AI_lo_lim,
			phys_message,
			func1_AI_out_unit,
			func1_AI_hi_lim,
			func1_AI_pv_ftime,
			func1_AI_hi_hi_lim,
			phys_install_date,
			func1_AI_out_decimal_point,
			func1_AI_alarm_hys,
			func1_AI_FSafeType,
			func1_AI_FSafeValue
		}
		IF ( Hnd000 ) { 
			phys_tag_desc
		}

		IF ( Hnd000 ) {

			IF ( Val013 ) { 
				parAntennaExtensionLength
			}
		}
	}
}
MENU download_variables { 
	LABEL [menu_load_to_PC] ; 
	PRE_READ_ACTIONS {
		downloadVariablesPreReadActions
	}
	ITEMS {
		parOperationCode,
		parDistanceUnit,
		parCustomerUnit,
		parAbsMaxMessDist,
		parLinearisation,
		parMeasuredLevel,
		parInputLevelHalfAutomatic,
		parMeasuredValue,
		parNoOfDecimals,
		parTankShape,
		parFullCalibration,
		parDielectricConstant,
		parProcessCondition,
		parEmptyCalibration,
		parOperationMode,
		parFormatDisplay_ft,
		parOutputOnAlarm,
		parReactionLostEcho,
		parTubeDiameter,
		parRampInPercentPerMin,
		parLevelUllageMode,
		parDelayTimeOnLostEcho,
		parLevelWithinSafetyDistance,
		parInSafetyDistance,
		parAcknowledgeAlarm,
		parTableNumber,
		parInputLevelManual,
		parInputVolume,
		parMaxVolume,
		parCylinderVessel,
		parCheckDistance,
		parSuppressionDistance,
		parStartMappingRecord,
		parPresMapRange,
		parCustTankMap,
		parEchoQuality,
		parOffsetOfMeasuredDistance,
		parOutputDamping,
		parBlockingDistance,
		parSimulation,
		parSimulationValueLevel,
		parLanguage,
		parBackToHome,
		parSeparationCharacter,
		parActualError,
		parLastError,
		parClearLastError,
		parMeasuredDistance,
		parApplicationParameter,
		parTagNumber,
		parProtSoftVersionString,
		parSerialNumber,
		parDownloadMode,
		parPADeviceBusAddress,
		parPAIdentNumberSelector,
		parPASetUnitToBus,
		parPAAIOutValue,
		parPAAIOutStatus,
		parPA2ndCyclicValue,
		parPASelectMainValue,
		parPADisplayValue,
		parPAProfileRevision,
		parSimulationValueVolume,
		parCurrentAmplitude,
		parAmplitudeOverSuppression,
		parAmplitudeOverFAC,
		parUnfilteredDistance,
		parCalcEdgeParameter,
		parCurrentFirstEchoFactor,
		parDeviceName,
		parOrderCode,
		parMamFilterLength,
		parMamFilterBorder,
		parLowPassFilter,
		parHystereseWidth,
		parEchoLostRampUp,
		parEchoLostRampDown,
		parUnfilteredDistanceRaw,
		parHKStatistik,
		parFilterBreite,
		parEnvelopeEnergy,
		parMappingAdder,
		parMappingWidth,
		parMappingAverage,
		parFactoryTdt,
		parFacAdder,
		parFACWidth,
		parRangeFactoryMap,
		parFactoryMappingValid,
		parCustomerMappingValid,
		parEdgeDetectionMode,
		parEdgeParameter,
		parFirstEchoFactor,
		parFefThreshold,
		parFefNearFactor,
		parFefDistanceNear,
		parFefDistanceFar,
		parFefEdge,
		parDishBottomDetection,
		parAmplLevelBottomDetection,
		parMinLevelBottomDetection,
		parLevelSpeed,
		parHfModul,
		parZeroDistance,
		parAntennaType,
		parInactiveLength,
		parTotalLength,
		parPositionOfReferencePulse
		IF ( Dlc001 ) { 
			parAmplOfReferencePulse
		}
		parPlausibilityFunction,
		parMaxDeltaPlausibilityFunction,
		parUpperAreaPlausibilityFunction,
		parDisplayVersion,
		parCalculatedCycleTime,
		parSwVersion,
		parParamVersion,
		parErrorStateOfAlgorithm,
		parStateOfAlgorithm,
		parReset,
		parDaaIndex1,
		parDaaIndex2,
		parDaaRdWrValue,
		phys_device_man_id,
		func1_AI_pv_lower_range_value,
		func1_AI_out_lower_range_value,
		func1_AI_lo_lo_lim,
		phys_device_certification,
		phys_descriptor,
		phys_device_ser_num,
		func1_AI_pv_upper_range_value,
		func1_AI_out_upper_range_value,
		func1_AI_lo_lim,
		phys_message,
		func1_AI_out_unit,
		func1_AI_hi_lim,
		phys_hardware_rev,
		func1_AI_pv_ftime,
		func1_AI_hi_hi_lim,
		phys_install_date,
		func1_AI_out_decimal_point,
		func1_AI_alarm_hys,
		phys_st_rev,
		func1_AI_FSafeType,
		func1_AI_FSafeValue,
		phys_tag_desc
		IF ( Dlc000 ) { 
			parAntennaExtensionLength,
			parMaxEchoSN,
			parEditRangeMaxSampleDist
		}
		IF ( Dlc002 ) { 
			parAmplOfReferencePulse02
		}

	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parMeasuredValue {
	LABEL 	"|en|measured value|de|Messwert|fr|Valeur de mesure|es|Messwert|it|Valore di misura|nl|gemeten waarde" ;
	CLASS 	DYNAMIC ; 
	HANDLING  READ ;
	TYPE 	FLOAT	{
        DISPLAY_FORMAT

        IF (parNoOfDecimals == 0)
        {
            "9.0f";
        }
        ELSE
        {
            IF ( parNoOfDecimals == 1 )
            {
                "9.1f";
            }
            ELSE
            {
                IF ( parNoOfDecimals == 2 )
                {
                    "9.2f";
                }
                ELSE
                {
                    IF ( parNoOfDecimals == 3 )
                    {
                        "9.3f";
                    }
                        ELSE
                       {
                        "9.3f";
                       }
                    }
                }
            }
        }
} 



COMMAND read_parMeasuredValue { 
	BLOCK 	transducer_block_1 ;
	INDEX 	8 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parMeasuredValue
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parNoOfDecimals {
	LABEL 	"|en|no.of decimals|de|Nachkommast.|fr|decimales|es|Nachkommast.|it|decimali|nl|aantal decim." ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val000)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	{ DEFAULT_VALUE 2;  { 0 ,"|en|x"}, { 1 ,"|en|x.x"}, { 2 ,"|en|x.xx"}, { 3 ,"|en|x.xxx"}  }
} 



COMMAND read_parNoOfDecimals { 
	BLOCK 	transducer_block_1 ;
	INDEX 	73 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parNoOfDecimals
		} 
	} 
} 

COMMAND write_parNoOfDecimals { 
	BLOCK 	transducer_block_1 ;
	INDEX 	73 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parNoOfDecimals
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parTankShape {
	LABEL 	"|en|tank shape|de|Tankgeometrie|fr|Forme reservoir|es|Tankgeometrie|it|Forma serbatoio|nl|Tankvorm" ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	{
		{ 0 ,"|en|dome ceiling|de|Kloepperdeckel|fr|Toit bombe|es|techo bveda|it|tetto bombato|nl|dome plafond"},
		{ 20 ,"|en|horizontal cyl|de|zyl.liegend|fr|cyl. horizont.|es|cilind. horiz.|it|cilind. orizz.|nl|horizont. cyl."},
		{ 2 ,"|en|bypass|de|Bypass|fr|Bypass|es|bypass|it|bypass|nl|by-pass"},
		{ 3 ,"|en|stilling well|de|Schwallrohr|fr|Tube de mesure|es|tubo tranquil.|it|tubo di calma|nl|duikpyp"},
		{ 4 ,"|en|flat ceiling|de|Flachdeckel|fr|Toit plat|es|techo plano|it|tetto piatto|nl|vlak plafond"},
		{ 5 ,"|en|sphere|de|Kugeltank|fr|Spherique|es|esfera|it|sfera|nl|sferisch"}
}
} 



COMMAND read_parTankShape { 
	BLOCK 	transducer_block_1 ;
	INDEX 	10 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parTankShape
		} 
	} 
} 

COMMAND write_parTankShape { 
	BLOCK 	transducer_block_1 ;
	INDEX 	10 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parTankShape
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parOperationCode {
	LABEL 	"|en|unlock parameter|de|Freigabecode|fr|code operation|es|Freigabecode|it|Modo operativo|nl|startcode" ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd002)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE  UNSIGNED_INTEGER (2)  {
		DISPLAY_FORMAT	"5.1u" ;
		EDIT_FORMAT	"5.1u" ;
		MIN_VALUE 	0 ;
		MAX_VALUE	33999 ;
		DEFAULT_VALUE	2457 ;
		INITIAL_VALUE	2457 ;
	}
	POST_READ_ACTIONS  { 
		updateParShowAccess
	}
} 



COMMAND read_parOperationCode { 
	BLOCK 	transducer_block_1 ;
	INDEX 	102 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parOperationCode
		} 
	} 
} 

COMMAND write_parOperationCode { 
	BLOCK 	transducer_block_1 ;
	INDEX 	102 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parOperationCode
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parDielectricConstant {
	LABEL 	"|en|medium property|de|Medium Eigensch.|fr|charact.du prod|es|Medium Eigensch.|it|caratt.del prod.|nl|produktconstante" ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	{  { 0 ,"|en|unknown|de|unbekannt|fr|inconnu|es|desconocido|it|sconosciuta|nl|onbekend"}, { 1 ,"|en|DC:< 1.9"}, { 2 ,"|en|DC:1.9 ... 4"}, { 3 ,"|en|DC:4 ... 10"}, { 4 ,"|en|DC:> 10"}  }
} 



COMMAND read_parDielectricConstant { 
	BLOCK 	transducer_block_1 ;
	INDEX 	11 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parDielectricConstant
		} 
	} 
} 

COMMAND write_parDielectricConstant { 
	BLOCK 	transducer_block_1 ;
	INDEX 	11 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parDielectricConstant
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parProcessCondition {
	LABEL 	"|en|process cond.|de|Messbedingungen|fr|Cond. process|es|Messbedingungen|it|condiz. Processo|nl|proces conditier" ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	{  
	{ 0 ,"|en|standard|de|Standard|fr|standard|es|estndar|it|standard|nl|standaard"}, 
	{ 1 ,"|en|calm surface|de|Oberfl. ruhig|fr|Surface calme|es|sup. calmada|it|superf.calma|nl|rustig"}, 
	{ 2 ,"|en|turb. surface|de|Oberfl.unruhig|fr|Surface agitee|es|sup. turbul.|it|superf.turbol.|nl|onrustig"}, 
	{ 3 ,"|en|add. agitator|de|zus. Ruehrwerk|fr|supp.Agitateur|es|adic. agitador|it|supp.agitatore|nl|plus roerwerk"}, 
	{ 4 ,"|en|fast change|de|schnelle aender|fr|Variat. rapide|es|camb. rpidos|it|cambiam.veloci|nl|snelle variat."}, 
	{ 5 ,"|en|test:no filter|de|Test:Filt. aus|fr|Test:pas filt.|es|test:no filtro|it|test:no filtro|nl|test:no filter"}  
}
	POST_EDIT_ACTIONS  { 
		synchronizeParProcessConditionToParOutputDamping
	}
} 



COMMAND read_parProcessCondition { 
	BLOCK 	transducer_block_1 ;
	INDEX 	12 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parProcessCondition
		} 
	} 
} 

COMMAND write_parProcessCondition { 
	BLOCK 	transducer_block_1 ;
	INDEX 	12 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parProcessCondition
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parEmptyCalibration {
	LABEL 	"|en|empty calibr.|de|Abgleich leer|fr|Etalonnage vide|es|Abgleich leer|it|calibr.di vuoto|nl|leegafregeling" ;
	HELP 	"|en|distance processconn. to min. level|de|Abstand Flanschzu min.Fuellstand|fr|Distance brideau niveau min.|es|dimetro internocon, al nivel mnimo|it|distanza min livellodalla flangia|nl|afstand van de flenstot het min. niveau" ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "m";
					CASE 1018:   "ft";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "mm";
				}
	TYPE 	FLOAT	        {
                                        EDIT_FORMAT "9.3f";
                                        DISPLAY_FORMAT "9.3f";
                                        MIN_VALUE 0.0;
                                        MAX_VALUE
                                        IF (parMaxAbs) {
                                                parAbsMaxMessDist;
                                        }
                                        ELSE {
                                                SELECT (parDistanceUnit)
                                                {
                                                        CASE 1010: 22.0;
                                                        CASE 1018: 72.178;
                                                        CASE 1019: 866.142;
                                                        CASE 1013: 22000.0;
                                                        DEFAULT: 22.0;
                                                }
                                        }
                                        DEFAULT_VALUE
                                        IF (parMaxAbs) {
                                                parAbsMaxMessDist;
                                        }
                                        ELSE {
                                                SELECT (parDistanceUnit)
                                                {
                                                        CASE 1010: 22.0;
                                                        CASE 1018: 72.178;
                                                        CASE 1019: 866.142;
                                                        CASE 1013: 22000.0;
                                                        DEFAULT: 22.0;
                                                }
                                        }
                                }
	POST_READ_ACTIONS  { 
		setAbsMax
	}
} 



COMMAND read_parEmptyCalibration { 
	BLOCK 	transducer_block_1 ;
	INDEX 	13 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parEmptyCalibration
		} 
	} 
} 

COMMAND write_parEmptyCalibration { 
	BLOCK 	transducer_block_1 ;
	INDEX 	13 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parEmptyCalibration
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parDistanceUnit {
	LABEL 	"|en|distance unit|de|Laengeneinheit|fr|unite longueur|es|Laengeneinheit|it|Unit distanza|nl|lengte-eenheid" ;
	CLASS 	DYNAMIC ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED(2)	{ DEFAULT_VALUE 1010;  { 1010 ,"|en|m"}, { 1018 ,"|en|ft"}, { 1019 ,"|en|inch"}, { 1013 ,"|en|mm"}  }
	POST_EDIT_ACTIONS  { 
		IF (Ped000) { nonMetricToMetricUnits } IF (Ped001) { metricToNonMetricUnits } assignDistanceUnit
	}
} 



COMMAND read_parDistanceUnit { 
	BLOCK 	transducer_block_1 ;
	INDEX 	113 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parDistanceUnit
		} 
	} 
} 

COMMAND write_parDistanceUnit { 
	BLOCK 	transducer_block_1 ;
	INDEX 	113 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parDistanceUnit
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parFullCalibration {
	LABEL 	"|en|full calibr.|de|Abgleich voll|fr|Etalonnage plein|es|Abgleich voll|it|calibr.di pieno|nl|volafregeling" ;
	HELP 	"|en|span|de|Messspanne|fr|Gamme de mesure|es|campo de medida|it|campo di misura|nl|meetbereik" ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "m";
					CASE 1018:   "ft";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "mm";
				}
	TYPE 	FLOAT	{
					EDIT_FORMAT "9.3f";
					DISPLAY_FORMAT "9.3f";
					MIN_VALUE 0.0;
					MAX_VALUE
					IF (parMaxAbs) {
						parAbsMaxMessDist;
					}
					ELSE {
						SELECT (parDistanceUnit) {
							CASE 1010: 22.0;
							CASE 1018: 72.178;
							CASE 1019: 866.142;
							CASE 1013: 22000.0;
							DEFAULT: 22.0;
						}
					}
					DEFAULT_VALUE
					IF (parMaxAbs) {
						parAbsMaxMessDist;
					}
					ELSE {
						SELECT (parDistanceUnit) {
							CASE 1010: 22.0;
							CASE 1018: 72.178;
							CASE 1019: 866.142;
							CASE 1013: 22000.0;
							DEFAULT: 22.0;
						}
					}
				}

} 



COMMAND read_parFullCalibration { 
	BLOCK 	transducer_block_1 ;
	INDEX 	14 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parFullCalibration
		} 
	} 
} 

COMMAND write_parFullCalibration { 
	BLOCK 	transducer_block_1 ;
	INDEX 	14 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parFullCalibration
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parOperationMode {
	LABEL 	"|en|overspill prot.|de|berfuellsicherung.|fr|anti-debordement|es|ueberfuellsicher.|it|prot. antiracim|nl|overvulbewaking" ;
	CLASS 	CONTAINED ; 
	HANDLING  READ & WRITE ;
	TYPE 	ENUMERATED	{  { 0 ,"|en|standard|de|Standard|fr|standard|es|estndar|it|standard|nl|standaard"}, { 1 ,"|en|german WHG|de|WHG|fr|WHG|es|alemana WHG|it|WHG tedesco|nl|duitse WHG"}  }
} 



COMMAND read_parOperationMode { 
	BLOCK 	transducer_block_1 ;
	INDEX 	26 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parOperationMode
		} 
	} 
} 

COMMAND write_parOperationMode { 
	BLOCK 	transducer_block_1 ;
	INDEX 	26 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parOperationMode
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parFormatDisplay_ft {
	LABEL 	"|en|format display|de|Anzeigeformat|fr|format affichage|es|Anzeigeformat|it|formato display|nl|aanwijsformaat" ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	{ DEFAULT_VALUE 0; { 0 ,"|en|decimal|de|dezimal|fr|decimal|es|decimal|it|decimale|nl|decimaal"}, { 1 ,"|en|1/16''"}  }
} 



COMMAND read_parFormatDisplay_ft { 
	BLOCK 	transducer_block_1 ;
	INDEX 	72 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parFormatDisplay_ft
		} 
	} 
} 

COMMAND write_parFormatDisplay_ft { 
	BLOCK 	transducer_block_1 ;
	INDEX 	72 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parFormatDisplay_ft
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parOutputOnAlarm {
	LABEL 	"|en|output on alarm|de|Ausg. b. Alarm|fr|Sortie si alarme|es|Ausg. b. Alarm|it|Comp. in allarme|nl|uitg. bij alarm" ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	{  	 DEFAULT_VALUE 1;
        {0, "MIN"},
        {1, "MAX"}, 
        {2, "hold"}     
}
} 



COMMAND read_parOutputOnAlarm { 
	BLOCK 	transducer_block_1 ;
	INDEX 	18 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parOutputOnAlarm
		} 
	} 
} 

COMMAND write_parOutputOnAlarm { 
	BLOCK 	transducer_block_1 ;
	INDEX 	18 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parOutputOnAlarm
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parReactionLostEcho {
	LABEL 	"|en|outp. echo loss|de|Ausg.Echoverlust|fr|Sort. perte echo|es|Ausg.Echoverlust|it|in caso manc.eco|nl|uitg.echoverlies" ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	{  DEFAULT_VALUE 1; { 0 ,"|en|alarm|de|Alarm|fr|Alarme|es|alarma|it|allarme|nl|Alarm"}, { 1 ,"|en|hold|de|Halten|fr|Maintien|es|Mantener|it|Ultimo valore|nl|Hold"}, { 2 ,"|en|ramp %/min|de|Rampe %/min|fr|Rampe %/min|es|rampa %/min|it|rampa %/min|nl|Steilh. %/min"}  }
} 



COMMAND read_parReactionLostEcho { 
	BLOCK 	transducer_block_1 ;
	INDEX 	20 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parReactionLostEcho
		} 
	} 
} 

COMMAND write_parReactionLostEcho { 
	BLOCK 	transducer_block_1 ;
	INDEX 	20 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parReactionLostEcho
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parTubeDiameter {
	LABEL 	"|en|pipe diameter|de|Rohrdurchmesser|fr|Diametre du tube|es|Rohrdurchmesser|it|diametro tubo|nl|diam. by-pass" ;
	HELP 	"|en|inner diameter ofbypass/stilling well|de|InnendurchmesserBypass/Schwallrohr|fr|Diametre interieurdu tube/by-pass|es|dimetro internobypass/tubo tranq.|it|diametro internodel tubo guida|nl|inwendige diam. vanby-pass / duikpijp" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val001)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "mm";
					CASE 1018:   "inch";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "mm";
				}
	TYPE 	FLOAT	{
                   EDIT_FORMAT "9.3f";
					DISPLAY_FORMAT "9.3f";
					MIN_VALUE
					SELECT (parDistanceUnit)
					{
						CASE 1010 :    1.000;
						CASE 1018 :    0.039;
						CASE 1019 :    0.039;
						CASE 1013 :    1.000;
						DEFAULT:       1.000;
					};
					MAX_VALUE
					SELECT (parDistanceUnit)
					{
						CASE 1010 :  10000.000;
						CASE 1018 :    393.701;
						CASE 1019 :    393.701;
						CASE 1013 :  10000.000;
						DEFAULT:     10000.000;
					};
					DEFAULT_VALUE
					SELECT (parDistanceUnit)
					{
						CASE 1010 :    204.425;
						CASE 1018 :      8.048;
						CASE 1019 :      8.048;
						CASE 1013 :    204.425;
						DEFAULT:       204.425;
					};
				}
} 



COMMAND read_parTubeDiameter { 
	BLOCK 	transducer_block_1 ;
	INDEX 	15 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parTubeDiameter
		} 
	} 
} 

COMMAND write_parTubeDiameter { 
	BLOCK 	transducer_block_1 ;
	INDEX 	15 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parTubeDiameter
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parRampInPercentPerMin {
	LABEL 	"|en|ramp %span/min|de|Rampe %MB/min|fr|Rampe %GM/min|es|Rampe %MB/min|it|rampa %campo/min|nl|steilh.span%/min" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val002)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  "|en|%/min" ;
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"10.3f" ;
		EDIT_FORMAT	"10.3f" ;
		MIN_VALUE 	-99999.0 ;
		MAX_VALUE	99999.0 ;
		DEFAULT_VALUE	0.0 ;
	}
} 



COMMAND read_parRampInPercentPerMin { 
	BLOCK 	transducer_block_1 ;
	INDEX 	21 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parRampInPercentPerMin
		} 
	} 
} 

COMMAND write_parRampInPercentPerMin { 
	BLOCK 	transducer_block_1 ;
	INDEX 	21 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parRampInPercentPerMin
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parLevelUllageMode {
	LABEL 	"|en|level/ullage|de|Fuellst./Restvol.|fr|Niv./Vol. resid.|es|Fuellst./Restvol.|it|livello/vol vuot|nl|niveau/restvol." ;
	CLASS 	DYNAMIC ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	{  DEFAULT_VALUE 0; 
	{ 0 ,"|en|level CU|de|Fuellst. TE|fr|niveau  UT|es|nivel unid us.|it|livello UI|nl|niveau T.E.."}, 
	{ 1 ,"|en|level DU|de|Fuellst m/ft/in|fr|niveau m/ft/in|es|nivel m/p/pulg|it|livel. m/ft/in|nl|niveau m/ft/in"}, 
	{ 2 ,"|en|ullage CU|de|Restvol. TE|fr|vol. resid. UT|es|unidades usu.|it|vol vuoto UI|nl|restvol. T.E."}, 
	{ 3 ,"|en|ullage DU|de|Restvo.m/ft/in|fr|vo.res.m/ft/in|es|unida m/p/pulg|it|vol vu.m/ft/in|nl|restv. m/ft/in"}  
}
} 



COMMAND read_parLevelUllageMode { 
	BLOCK 	transducer_block_1 ;
	INDEX 	38 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parLevelUllageMode
		} 
	} 
} 

COMMAND write_parLevelUllageMode { 
	BLOCK 	transducer_block_1 ;
	INDEX 	38 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parLevelUllageMode
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parLinearisation {
	LABEL 	"|en|linearisation|de|Linearisierung|fr|Linearisation|es|Linearisierung|it|Linearizzazione|nl|linearisatie" ;
	CLASS 	DYNAMIC ; 
	HANDLING  IF (Hnd001)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	{ DEFAULT_VALUE 0; 
	{ 0 ,"|en|linear|de|linear|fr|lineaire|es|lineal|it|Lineare|nl|lineair"}, 
	{ 20 ,"|en|horizontal cyl|de|zyl.liegend|fr|cyl. horizont.|es|cilind. horiz.|it|cilind. orizz.|nl|horizont. cyl."}, 
	{ 240 ,"|en|manual|de|manuell|fr|manuel|es|manual|it|manuale|nl|handmatig"}, 
	{ 241 ,"|en|semi-automatic|de|halbautomat.|fr|semi-automat.|es|semiautomatico|it|semi-auto.|nl|half-automat."}, 
	{ 1 ,"|en|table on|de|Tabelle ein|fr|tableau actif|es|tabla on|it|tab. attivata|nl|tabel aan"}, 
	{ 242 ,"|en|clear table|de|Loesche Tabelle|fr|effac. tableau|es|borrar tabla|it|cancella tab.|nl|tabel wissen"}  
}
} 



COMMAND read_parLinearisation { 
	BLOCK 	transducer_block_1 ;
	INDEX 	39 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parLinearisation
		} 
	} 
} 

COMMAND write_parLinearisation { 
	BLOCK 	transducer_block_1 ;
	INDEX 	39 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parLinearisation
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parDelayTimeOnLostEcho {
	LABEL 	"|en|delay time|de|Verzoegerung|fr|Temporisation|es|Verzoegerung|it|Tempo di ritardo|nl|vertragingstijd" ;
	HELP 	"|en|in case of echo lossmax. 4000 sec.|de|Zeit bei Echoverlustmax. 4000 sec.|fr|si perte echomax. 4000 sec.|es|en caso de perd. ecomx. 4000 segundos|it|se manca ecomax. 4000 sec.|nl|i.g.v. echoverliesmax. 4000 s." ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  "|en|s" ;
	TYPE  UNSIGNED_INTEGER (2)  {
		DISPLAY_FORMAT	"4.1u" ;
		EDIT_FORMAT	"4.1u" ;
		MIN_VALUE 	0 ;
		MAX_VALUE	4000 ;
		DEFAULT_VALUE	30 ;
	}
} 



COMMAND read_parDelayTimeOnLostEcho { 
	BLOCK 	transducer_block_1 ;
	INDEX 	22 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parDelayTimeOnLostEcho
		} 
	} 
} 

COMMAND write_parDelayTimeOnLostEcho { 
	BLOCK 	transducer_block_1 ;
	INDEX 	22 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parDelayTimeOnLostEcho
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parLevelWithinSafetyDistance {
	LABEL 	"|en|safety distance|de|Sicherheitsabst.|fr|Dist. securite|es|Sicherheitsabst.|it|dist. di sicur.|nl|veiligheidsafst." ;
	HELP 	"|en|from antenna tip/lower edge of horn|de|ab Antennenspitze/Hornkante|fr|sous antenne/extremite antenne|es|desde extremo antenadesde extr. trompeta|it|dall'antenna/bordo inf. antenna|nl|vanaf antennetip/onderkant hoornant." ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "m";
					CASE 1018:   "ft";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "mm";
				}
	TYPE 	FLOAT	{
					EDIT_FORMAT "9.3f";
					DISPLAY_FORMAT "9.3f";
					MIN_VALUE 0.0;
					MAX_VALUE
					IF (parMaxAbs) {
						parAbsMaxMessDist;
					}
					ELSE {
						SELECT (parDistanceUnit)
						{
							CASE 1010: 22.0;
							CASE 1018: 72.178;
							CASE 1019: 866.142;
							CASE 1013: 22000.0;
							DEFAULT: 22.0;
						}
					}
					DEFAULT_VALUE
					SELECT (parDistanceUnit)
					{
						CASE 1010 :  0.100;
						CASE 1018 :  0.328;
						CASE 1019 :  3.937;
						CASE 1013 :  100.000;
						DEFAULT:  0.100;
					};
				}
	POST_READ_ACTIONS  { 
		setAbsMax
	}
} 



COMMAND read_parLevelWithinSafetyDistance { 
	BLOCK 	transducer_block_1 ;
	INDEX 	23 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parLevelWithinSafetyDistance
		} 
	} 
} 

COMMAND write_parLevelWithinSafetyDistance { 
	BLOCK 	transducer_block_1 ;
	INDEX 	23 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parLevelWithinSafetyDistance
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parInSafetyDistance {
	LABEL 	"|en|in safety dist.|de|im Sicherh.abst.|fr|dans dist.secur.|es|im Sicherh.abst.|it|in dist.di sicur|nl|op veiligh.afst." ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	{  DEFAULT_VALUE 1; { 0 ,"|en|alarm|de|Alarm|fr|Alarme|es|alarma|it|allarme|nl|Alarm"}, { 1 ,"|en|warning|de|Warnung|fr|Avertissement|es|aviso|it|avviso|nl|Waarschuwing"}, { 2 ,"|en|self holding|de|Selbsthaltung|fr|Maintien|es|mantener|it|autoritenuto|nl|Hold"}  }
} 



COMMAND read_parInSafetyDistance { 
	BLOCK 	transducer_block_1 ;
	INDEX 	24 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parInSafetyDistance
		} 
	} 
} 

COMMAND write_parInSafetyDistance { 
	BLOCK 	transducer_block_1 ;
	INDEX 	24 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parInSafetyDistance
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parAcknowledgeAlarm {
	LABEL 	"|en|ackn. alarm|de|Reset Selbsthalt|fr|Supp.auto maint.|es|Reset Selbsthalt|it|ripristina|nl|reset alarm" ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	{  DEFAULT_VALUE 0; { 0 ,"|en|no|de|nein|fr|non|es|no|it|no|nl|nee"}, { 1 ,"|en|yes|de|ja|fr|oui|es|si|it|si|nl|ja"}  }
} 



COMMAND read_parAcknowledgeAlarm { 
	BLOCK 	transducer_block_1 ;
	INDEX 	25 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parAcknowledgeAlarm
		} 
	} 
} 

COMMAND write_parAcknowledgeAlarm { 
	BLOCK 	transducer_block_1 ;
	INDEX 	25 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parAcknowledgeAlarm
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parCustomerUnit {
	LABEL 	"|en|customer unit|de|Kundeneinheit|fr|Unite utilisat.|es|Kundeneinheit|it|Unit di misura|nl|klanteenheid" ;
	CLASS 	DYNAMIC ; 
	HANDLING  IF (Hnd001)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED(2)	        {	  DEFAULT_VALUE 1342;
                {1342,"%"},
                {1038,"l "},
                {1041,"hl"},
                {1034,"m"},
                {1035,"dm"},
                {1036,"cm"},
                {1043,"ft"},
                {1048,"us_gal"},
                {1049,"i_gal"},
                {1088,"kg"},
                {1092,"t"},
                {1094,"lb"},
                {1095,"ton"},
                {1010,"m"},
                {1018,"ft"},
                {1013,"mm"},
                {1019,"inch"},
                {1997, "none"}
        }
} 



COMMAND read_parCustomerUnit { 
	BLOCK 	transducer_block_1 ;
	INDEX 	40 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parCustomerUnit
		} 
	} 
} 

COMMAND write_parCustomerUnit { 
	BLOCK 	transducer_block_1 ;
	INDEX 	40 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parCustomerUnit
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parTableNumber {
	LABEL 	"|en|table no.|de|Tabellen Nummer|fr|numero tableau|es|Tabellen Nummer|it|N tabella|nl|tabel nummer" ;
	HELP 	"|en|volume xx custunitlevel xx m/ft|de|Volumen xx Kd.EinFuellstand xx m/ft|fr|Volume xx u.util.Niveau xx m/ft|es|volum xx unid usunivel xx m/pies|it|Volume xx un.ing.Livello xx un.ing.|nl|vol.klanteenh.niveau xx m/ft" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val003)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ & WRITE ;
	TYPE  UNSIGNED_INTEGER (1)  {
		DISPLAY_FORMAT	"2.1u" ;
		EDIT_FORMAT	"2.1u" ;
		MIN_VALUE 	1 ;
		MAX_VALUE	32 ;
		DEFAULT_VALUE	1 ;
	}
} 



COMMAND read_parTableNumber { 
	BLOCK 	transducer_block_1 ;
	INDEX 	41 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parTableNumber
		} 
	} 
} 

COMMAND write_parTableNumber { 
	BLOCK 	transducer_block_1 ;
	INDEX 	41 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parTableNumber
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parInputLevelManual {
	LABEL 	"|en|input level|de|Eingabe Fuellst.|fr|entree niveau|es|Eingabe Fuellst.|it|Dato livello|nl|invoer niveau" ;
	HELP 	"|en|volume xx custunittable no. X|de|Volumen xx Kd.Ein Tabellennummer x|fr|Volume xx u.util.numero tableau x|es|vol xx unid,usunmero en la tabla x|it|Volume xx un.ing.Tabella n x|nl|vol.klanteenh.tabelnummer" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val004)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd004)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "m";
					CASE 1018:   "ft";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "mm";
				}
	TYPE 	FLOAT	{
					EDIT_FORMAT "9.3f";
					DISPLAY_FORMAT "9.3f";
					MIN_VALUE 0.0;
					MAX_VALUE
					IF (parMaxAbs) {
                                                parAbsMaxMessDist;
					}
					ELSE {
						SELECT (parDistanceUnit)
						{
							CASE 1010: 22.0;
							CASE 1018: 72.178;
							CASE 1019: 866.142;
							CASE 1013: 22000.0;
							DEFAULT: 22.0;
						}
					}
					DEFAULT_VALUE 0.0;
				}
	POST_READ_ACTIONS  { 
		setAbsMax
	}
} 



COMMAND read_parInputLevelManual { 
	BLOCK 	transducer_block_1 ;
	INDEX 	119 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parInputLevelManual
		} 
	} 
} 

COMMAND write_parInputLevelManual { 
	BLOCK 	transducer_block_1 ;
	INDEX 	119 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parInputLevelManual
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parInputVolume {
	LABEL 	"|en|input volume|de|Eingabe Volumen|fr|entree volume|es|Eingabe Volumen|it|Dato volume|nl|invoer volume" ;
	HELP 	"|en|level xx m/fttable no. X|de|Fuellstand xx m/ftTabellennummer x|fr|Niveau xx m/ftnumero tableau x|es|nivel xx en m/pnmero en la tabla x|it|Livello xx m/ftTabella n X|nl|niveau xx m/fttabelnummer X" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val005)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd005)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"10.3f" ;
		EDIT_FORMAT	"10.3f" ;
		MIN_VALUE 	-99999.0 ;
		MAX_VALUE	99999.0 ;
		DEFAULT_VALUE	0 ;
	}
} 



COMMAND read_parInputVolume { 
	BLOCK 	transducer_block_1 ;
	INDEX 	43 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parInputVolume
		} 
	} 
} 

COMMAND write_parInputVolume { 
	BLOCK 	transducer_block_1 ;
	INDEX 	43 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parInputVolume
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parMaxVolume {
	LABEL 	"|en|max. scale|de|Endwert Messber.|fr|Gamme mes. max.|es|Endwert Messber.|it|max.valore|nl|eindw.meetbereik" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val006)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd006)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"10.3f" ;
		EDIT_FORMAT	"10.3f" ;
		MIN_VALUE 	-99999.0 ;
		MAX_VALUE	99999.0 ;
		DEFAULT_VALUE	100.0 ;
	}
} 



COMMAND read_parMaxVolume { 
	BLOCK 	transducer_block_1 ;
	INDEX 	44 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parMaxVolume
		} 
	} 
} 

COMMAND write_parMaxVolume { 
	BLOCK 	transducer_block_1 ;
	INDEX 	44 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parMaxVolume
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parCylinderVessel {
	LABEL 	"|en|diameter vessel|de|Zyl.-durchmesser|fr|diametre cuve|es|Zyl.-durchmesser|it|Diam. Serbatoio|nl|tankdiameter" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val007)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd007)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "m";
					CASE 1018:   "ft";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "m";
				}
	TYPE 	FLOAT	{
					EDIT_FORMAT "9.3f";
					DISPLAY_FORMAT "9.3f";
					MIN_VALUE 0.0;
					MAX_VALUE
					IF (parMaxAbs) {
                                                parAbsMaxMessDist;
					}
					ELSE {
						SELECT (parDistanceUnit)
						{
							CASE 1010: 22.0;
							CASE 1018: 72.178;
							CASE 1019: 866.142;
							CASE 1013: 22000.0;
							DEFAULT: 22.0;
						}
					}
					DEFAULT_VALUE
					SELECT (parDistanceUnit)
					{
						CASE 1010 :  9.000;
						CASE 1018 :  29.528;
						CASE 1019 :  354.331;
						CASE 1013 :  9000.000;
						DEFAULT:  9.000;
					};
				}
} 



COMMAND read_parCylinderVessel { 
	BLOCK 	transducer_block_1 ;
	INDEX 	45 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parCylinderVessel
		} 
	} 
} 

COMMAND write_parCylinderVessel { 
	BLOCK 	transducer_block_1 ;
	INDEX 	45 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parCylinderVessel
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parCheckDistance {
	LABEL 	"|en|check distance|de|Distanz pruefen|fr|verifier dist.|es|Distanz pruefen|it|Controll. dist.|nl|check afstand" ;
	CLASS 	DYNAMIC ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	{ DEFAULT_VALUE 3; 
	{ 0 ,"|en|distance = ok|de|Distanz = ok|fr|distance = ok|es|distancia = ok|it|distanza = ok|nl|afstand = ok"}, 
	{ 1 ,"|en|dist.too small|de|Dist. zu klein|fr|dis.trop petit|es|dist. muy pequ|it|dist.trop.picc|nl|afst. te klein"}, 
	{ 2 ,"|en|dist. too big|de|Dist. zu gross|fr|dis.trop grand|es|dist.muy grand|it|dist.trop.gran|nl|afst. te groot"}, 
	{ 3 ,"|en|dist. unknown|de|Dist.unbekannt|fr|dist. inconnue|es|dist.desconoc.|it|dist. sconosc.|nl|afst.niet  bek"}, 
	{ 240 ,"|en|manual|de|manuell|fr|manuel|es|manual|it|manuale|nl|handmatig"}  
}
} 



COMMAND read_parCheckDistance { 
	BLOCK 	transducer_block_1 ;
	INDEX 	49 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parCheckDistance
		} 
	} 
} 

COMMAND write_parCheckDistance { 
	BLOCK 	transducer_block_1 ;
	INDEX 	49 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parCheckDistance
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parSuppressionDistance {
	LABEL 	"|en|range of mapping|de|Bereich Ausblend|fr|Plage suppress.|es|Bereich Ausblend|it|dist. mappa man.|nl|bereik uitwaard." ;
	HELP 	"|en|input ofmapping range|de|Eingabe desAusbl.bereiches|fr|entree plagede suppression|es|introducirrango mapeado|it|dato distanzafino a mappa|nl|invoer van hetuitwaard. bereik" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  IF (Val008)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd010)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "m";
					CASE 1018:   "ft";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "mm";
				}
	TYPE 	FLOAT	{
					EDIT_FORMAT "9.3f";
					DISPLAY_FORMAT "9.3f";
					MIN_VALUE 0.0;
					MAX_VALUE
					IF (parMaxAbs) {
                                                parAbsMaxMessDist;
					}
					ELSE {
						SELECT (parDistanceUnit)
						{
							CASE 1010: 22.0;
							CASE 1018: 72.178;
							CASE 1019: 866.142;
							CASE 1013: 22000.0;
							DEFAULT: 22.0;
						}
					}
					DEFAULT_VALUE 0.0;
				}
	POST_READ_ACTIONS  { 
		setAbsMax
	}
} 



COMMAND read_parSuppressionDistance { 
	BLOCK 	transducer_block_1 ;
	INDEX 	50 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parSuppressionDistance
		} 
	} 
} 

COMMAND write_parSuppressionDistance { 
	BLOCK 	transducer_block_1 ;
	INDEX 	50 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parSuppressionDistance
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parStartMappingRecord {
	LABEL 	"|en|start mapping|de|Starte Ausblend.|fr|Lancer mapping|es|Starte Ausblend.|it|avvico mappatura|nl|start mapping" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  IF (Val008)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	{  { 0 ,"|en|off|de|aus|fr|inactif|es|desconectado|it|disattivato|nl|uit"}, { 1 ,"|en|on|de|an|fr|actif|es|conectado|it|attivato|nl|aan"}  }
} 



COMMAND read_parStartMappingRecord { 
	BLOCK 	transducer_block_1 ;
	INDEX 	51 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parStartMappingRecord
		} 
	} 
} 

COMMAND write_parStartMappingRecord { 
	BLOCK 	transducer_block_1 ;
	INDEX 	51 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parStartMappingRecord
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parPresMapRange {
	LABEL 	"|en|pres. map dist.|de|akt. Ausbl.dist.|fr|dist. suppr.act.|es|akt. Ausbl.dist.|it|dist. mappa att.|nl|act. afst. uitw." ;
	CLASS 	DYNAMIC ; 
	HANDLING  READ ;
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "m";
					CASE 1018:   "ft";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "mm";
				}
	TYPE 	FLOAT	{
					EDIT_FORMAT "9.3f";
					DISPLAY_FORMAT "9.3f";
					MIN_VALUE 0.0;
					MAX_VALUE
					IF (parMaxAbs) {
                                                parAbsMaxMessDist;
					}
					ELSE {
						SELECT (parDistanceUnit)
						{
							CASE 1010: 22.0;
							CASE 1018: 72.178;
							CASE 1019: 866.142;
							CASE 1013: 22000.0;
							DEFAULT: 22.0;
						}
					}
				}
} 



COMMAND read_parPresMapRange { 
	BLOCK 	transducer_block_1 ;
	INDEX 	52 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parPresMapRange
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parCustTankMap {
	LABEL 	"|en|cust. tank map|de|Ausblendung|fr|suppression|es|Ausblendung|it|Mappa cliente|nl|klant tank map" ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED(1)	{  { 0 ,"|en|not active"}, { 1 ,"|en|active"}, { 2 ,"|en|reset|de|loeschen|fr|reset|es|borrar|it|reset|nl|reset"}  }
} 



COMMAND read_parCustTankMap { 
	BLOCK 	transducer_block_1 ;
	INDEX 	53 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parCustTankMap
		} 
	} 
} 

COMMAND write_parCustTankMap { 
	BLOCK 	transducer_block_1 ;
	INDEX 	53 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parCustTankMap
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parEchoQuality {
	LABEL 	"|en|echo quality|de|Echoqualitaet|fr|Qualite echo|es|Echoqualitaet|it|Qualit eco|nl|echokwaliteit" ;
	CLASS 	DYNAMIC ; 
	HANDLING  READ ;
	CONSTANT_UNIT  "|en|dB" ;
	TYPE  UNSIGNED_INTEGER (1)  {
		DISPLAY_FORMAT	"3.1u" ;
		EDIT_FORMAT	"3.1u" ;
	}
} 



COMMAND read_parEchoQuality { 
	BLOCK 	transducer_block_1 ;
	INDEX 	54 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parEchoQuality
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parOffsetOfMeasuredDistance {
	LABEL 	"|en|offset|de|Fuellhoehenkorrektur|fr|Correct. Niveau|es|Fuellhoehenkorrekt|it|offset|nl|offset" ;
	HELP 	"|en|will be added to themeasured level|de|wird zum gemessennenFuellstand addiert|fr|sera additionneau niveau mesure|es|sera aadidoal luivel medido|it|sara addizionataal livello misurato|nl|zal werd. toegevoegdan de gemeten waarde" ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "m";
					CASE 1018:   "ft";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "mm";
				}
	TYPE 	FLOAT	{
					EDIT_FORMAT "10.3f";
					DISPLAY_FORMAT "10.3f";
					MIN_VALUE
					IF (parMaxAbs) {
                                                (-1.0)*parAbsMaxMessDist;
					}
					ELSE {
						SELECT (parDistanceUnit)
						{
							CASE 1010: -22.0;
							CASE 1018: -72.178;
							CASE 1019: -866.142;
							CASE 1013: -22000.0;
							DEFAULT: -22.0;
						}
					}
					MAX_VALUE
					IF (parMaxAbs) {
                                                parAbsMaxMessDist;
					}
					ELSE {
						SELECT (parDistanceUnit)
						{
							CASE 1010: 22.0;
							CASE 1018: 72.178;
							CASE 1019: 866.142;
							CASE 1013: 22000.0;
							DEFAULT: 22.0;
						}
					}
					DEFAULT_VALUE 0.0;
				}
} 



COMMAND read_parOffsetOfMeasuredDistance { 
	BLOCK 	transducer_block_1 ;
	INDEX 	55 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parOffsetOfMeasuredDistance
		} 
	} 
} 

COMMAND write_parOffsetOfMeasuredDistance { 
	BLOCK 	transducer_block_1 ;
	INDEX 	55 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parOffsetOfMeasuredDistance
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parOutputDamping {
	LABEL 	"|en|output damping|de|Integrationszeit|fr|temps integrat.|es|Integrationszeit|it|Tempo integraz.|nl|uitgangsdemping" ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  "|en|s" ;
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"5.1f" ;
		EDIT_FORMAT	"5.1f" ;
		MIN_VALUE 	0.0 ;
		MAX_VALUE	255.0 ;
		DEFAULT_VALUE	3.0 ;
	}
} 



COMMAND read_parOutputDamping { 
	BLOCK 	transducer_block_1 ;
	INDEX 	56 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parOutputDamping
		} 
	} 
} 

COMMAND write_parOutputDamping { 
	BLOCK 	transducer_block_1 ;
	INDEX 	56 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parOutputDamping
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parBlockingDistance {
	LABEL 	"|en|blocking dist.|de|Blockdistanz|fr|distance blocage|es|Blockdistanz|it|Dist. di blocco|nl|blokafstand" ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "m";
					CASE 1018:   "ft";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "mm";
				}
	TYPE 	FLOAT	{
					EDIT_FORMAT "9.3f";
					DISPLAY_FORMAT "9.3f";
					MIN_VALUE 0.0;
					MAX_VALUE
					IF (parMaxAbs) {
                                                parAbsMaxMessDist;
					}
					ELSE {
						SELECT (parDistanceUnit)
						{
							CASE 1010: 22.0;
							CASE 1018: 72.178;
							CASE 1019: 866.142;
							CASE 1013: 22000.0;
							DEFAULT: 22.0;
						}
					}
					DEFAULT_VALUE
					SELECT (parDistanceUnit)
					{
						CASE 1010 :  0.500;
						CASE 1018 :  1.640;
						CASE 1019 :  19.685;
						CASE 1013 :  500.000;
						DEFAULT:  0.500;
					};

				}
	POST_READ_ACTIONS  { 
		setAbsMax
	}
} 



COMMAND read_parBlockingDistance { 
	BLOCK 	transducer_block_1 ;
	INDEX 	57 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parBlockingDistance
		} 
	} 
} 

COMMAND write_parBlockingDistance { 
	BLOCK 	transducer_block_1 ;
	INDEX 	57 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parBlockingDistance
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parSimulation {
	LABEL 	"|en|simulation|de|Simulation|fr|simulation|es|Simulation|it|simulazione|nl|simulatie" ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	{ DEFAULT_VALUE 0; { 0 ,"|en|sim. off|de|Sim. aus|fr|simul. inact.|es|sim, conectada|it|sim. disattiva|nl|sim. off"}, { 1 ,"|en|sim. level|de|Sim. Fuellstand|fr|simul. niveau|es|sim, nivel|it|sim. livello|nl|sim. level"}, { 2 ,"|en|sim. volume|de|Sim. Volumen|fr|simul. volume|es|sim, volumen|it|sim. volume|nl|sim. volume"}  }
} 



COMMAND read_parSimulation { 
	BLOCK 	transducer_block_1 ;
	INDEX 	63 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parSimulation
		} 
	} 
} 

COMMAND write_parSimulation { 
	BLOCK 	transducer_block_1 ;
	INDEX 	63 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parSimulation
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parSimulationValueLevel {
	LABEL 	"|en|simulation value|de|Simulationswert|fr|valeur simulat.|es|Simulationswert|it|Val. di simul.|nl|simulatiewaarde" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val009)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "m";
					CASE 1018:   "ft";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "mm";
				}
	TYPE 	FLOAT	{
					EDIT_FORMAT "9.3f";
					DISPLAY_FORMAT "9.3f";
					MIN_VALUE
					SELECT (parDistanceUnit)
					{
						CASE 1010 :  -2.000;
						CASE 1018 :  -6.562;
						CASE 1019 :  -78.740;
						CASE 1013 :  -2000.000;
						DEFAULT:  -2000.000;
					};
					MAX_VALUE
					IF (parMaxAbs) {
                                                parAbsMaxMessDist;
					}
					ELSE {
						SELECT (parDistanceUnit)
						{
							CASE 1010: 22.0;
							CASE 1018: 72.178;
							CASE 1019: 866.142;
							CASE 1013: 22000.0;
							DEFAULT: 22.0;
						}
					}
				}
	POST_READ_ACTIONS  { 
		setAbsMax
	}
} 



COMMAND read_parSimulationValueLevel { 
	BLOCK 	transducer_block_1 ;
	INDEX 	120 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parSimulationValueLevel
		} 
	} 
} 

COMMAND write_parSimulationValueLevel { 
	BLOCK 	transducer_block_1 ;
	INDEX 	120 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parSimulationValueLevel
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parLanguage {
	LABEL 	"|en|language|de|Sprache|fr|Langage|es|Sprache|it|Lingua|nl|taal" ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd009)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	{ DEFAULT_VALUE 0;  { 0 ,"|en|English"}, { 1 ,"|en|Deutsch"}, { 2 ,"|en|Franais"}  /*, { 4 ,"|en|Italiano"}, { 3 ,"|en|Espaol"}, { 5 ,"|en|Nederlands"} */ }
} 



COMMAND read_parLanguage { 
	BLOCK 	transducer_block_1 ;
	INDEX 	70 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parLanguage
		} 
	} 
} 

COMMAND write_parLanguage { 
	BLOCK 	transducer_block_1 ;
	INDEX 	70 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parLanguage
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parBackToHome {
	LABEL 	"|en|back to home|de|Zur Startseite|fr|Retour  Home|es|Zur Startseite|it|Vai a men princ|nl|Home" ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  "|en|s" ;
	TYPE  INTEGER (2)  {
		DISPLAY_FORMAT	"4.1i" ;
		EDIT_FORMAT	"4.1i" ;
		MIN_VALUE 	3 ;
		MAX_VALUE	9999 ;
		DEFAULT_VALUE	100 ;
	}
} 



COMMAND read_parBackToHome { 
	BLOCK 	transducer_block_1 ;
	INDEX 	71 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parBackToHome
		} 
	} 
} 

COMMAND write_parBackToHome { 
	BLOCK 	transducer_block_1 ;
	INDEX 	71 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parBackToHome
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parSeparationCharacter {
	LABEL 	"|en|sep. character|de|Trennungszeichen|fr|Signe separation|es|Trennungszeichen|it|segni separaz.|nl|scheidingsteken" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val000)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	{ DEFAULT_VALUE 0; { 0 ,"|en|."}, { 1 ,"|en|,"}  }
} 



COMMAND read_parSeparationCharacter { 
	BLOCK 	transducer_block_1 ;
	INDEX 	74 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parSeparationCharacter
		} 
	} 
} 

COMMAND write_parSeparationCharacter { 
	BLOCK 	transducer_block_1 ;
	INDEX 	74 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parSeparationCharacter
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parActualError {
	LABEL 	"|en|present error|de|aktueller Fehler|fr|defaut actuel|es|aktueller Fehler|it|errore attuale|nl|actuele fout" ;
	HELP 	[error_code_help] ;
	CLASS 	DYNAMIC ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED (2)	{
    {0, "|en|system ok"},
    {101, "|en|A101 checksum error general reset & new calibr.required|de|A101 Prfsummenfehler Totalreset & Neu- abgl. erfordert|fr|A101 erreur somme test reset gnral nouvel talonn.|it|A101 errore check sum ripristino totale nuova calibraz.  "},
    {102, "|en|A102 checksum error general reset & new calibr.required|de|A102 Prfsummenfehler Totalreset & Neu- abgl. erfordert|fr|A102 erreur somme test reset gnral nouvel talonn.|it|A102 errore check sum ripristino totale nuova calibraz.  "},
    {103, "|en|W103 initialising - please wait |de|W103 Initialisierung - bitte warten |fr|W103 initialisation en cours-attendre |it|W103 inizializzazione in corso-attendere   "},
    {106, "|en|A106 downloading please wait |de|A106 Download luft - bitte warten |fr|A106 download en cours-attendre |it|A106 download in corso-attendere   "},
    {110, "|en|A110 checksum error general reset & new calibr.required|de|A110 Prfsummenfehler Totalreset & Neu- abgl. erfordert|fr|A110 erreur somme test reset gnral nouvel talonn.|it|A110 errore di check sum riprist. totale nuova calibr.  "},
    {111, "|en|A111 electronics defect  |de|A111 Elektronik defekt  |fr|A111 dfaut lectronique  |it|A111 Guasto elettron.    "},
    {113, "|en|A113 electronics defect  |de|A113 Elektronik defekt  |fr|A113 dfaut lectronique  |it|A113 Guasto elettron.    "},
    {114, "|en|A114 electronics defect  |de|A114 Elektronik defekt  |fr|A114 dfaut lectronique  |it|A114 Guasto elettron.    "},
    {115, "|en|A115 electronics defect  |de|A115 Elektronik defekt  |fr|A115 dfaut lectronique  |it|A115 Guasto elettron.    "},
    {116, "|en|A116 download error repeat download |de|A116 Downloadfehler Download wiederholen |fr|A116 erreur download rpter download |it|A116 Errore download ripetere download   "},
    {121, "|en|A121 electronics defect  |de|A121 Elektronik defekt  |fr|A121 dfaut lectronique  |it|A121 Guasto elettron.    "},
    {152, "|en|A152 checksum error general reset & new calibr.required|de|A152 Prfsummenfehler Totalreset & Neu- abgl. erfordert|fr|A152 erreur somme test reset gnral nouvel talonn.|it|A152 errore check sum ripristino totale nuova calibraz.  "},
    {153, "|en|W153 initialising - please wait |de|W153 Initialisierung - bitte warten |fr|W153 initialisation en cours-attendre |it|W153 inizializzazione in corso-attendere   "},
    {155, "|en|A155 electronics defect  |de|A155 Elektronik defekt  |fr|A155 dfaut lectronique  |it|A155 Guasto elettron.    "},
    {160, "|en|A160 checksum error general reset & new calibr.required|de|A160 Prfsummenfehler Totalreset & Neu- abgl. erfordert|fr|A160 erreur somme test reset gnral nouvel talonn.|it|A160 errore check sum ripristino totale nuova calibraz.  "},
    {164, "|en|A164 electronics defect  |de|A164 Elektronik defekt  |fr|A164 dfaut lectronique  |it|A164 Guasto elettron.    "},
    {171, "|en|A171 electronics defect  |de|A171 Elektronik defekt  |fr|A171 dfaut lectronique  |it|A171 Guasto elettron.    "},
    {231, "|en|A231 sensor 1 defect check connection |de|A231 Sensor 1 defekt Prfe Verbindung |fr|A231 dfaut sonde 1 vrifier connexion |it|A231 Sens.1 guasto controll. conness.   "},
    {270, "|en|A270 custody switch undef check position |de|A270 Schalter undefiniert berprfe Position |fr|A270 commutateur indfini vrifier position |it|A270 Interr. non def. contr. posizione   "},
    {271, "|en|W271 reduced accuracy check installation |de|W271 reduz. Genauigkeit Installation prfen |fr|W271 prcision rduit vrifier installat. |it|W271 precis. ridotto controll. Installaz.   "},
    {272, "|en|A272 electronics defect amplifier |de|A272 Elektronik defekt Verstrker |fr|A272 dfaut lectron. amplificateur |it|A272 guasto elettron. amplificatore   "},
    {273, "|en|W273 reduced accuracy  |de|W273 reduz. Genauigkeit  |fr|W273 prcision rduit  |it|W273 precis. ridotto    "},
    {274, "|en|W274 reduced accuracy check pipe diameter |de|W274 reduz. Genauigkeit Prfe Rohr- durchmesser|fr|W274 prcision rduit vr. diamtre du tube|it|W274 precis. ridotto controll. diametro del tubo guida  "},
    {275, "|en|W275 electronics defect factory settings |de|W275 Elektronik defekt Werksabgleich |fr|W275 dfaut lectron. calibration usine |it|W275 dfaut lectron. calibrazione di fabbrica  "},
    {511, "|en|W511 no factory cali- bration ch1 |de|W511 kein Werksabgl. vorhanden K1 |fr|W511 pas de rglage usine disponible voie 1 |it|W511 assenza calibr. di fabbrica C1   "},
    {512, "|en|W512 recording of mapping please wait |de|W512 Aufnahme Ausblendung - warten |fr|W512 suppressionen cours attendre |it|W512 registr. mappatura in corso-attendere   "},
    {601, "|en|W601 linearisation ch1 curve not monotone |de|W601 Linearisierung K1 Kurve nicht monoton |fr|W601 linarisation voie 1 courbe non monotone |it|W601 Linearizzazione C1 curva non monotona   "},
    {611, "|en|W611 less than 2 linea- risation points for channel 1|de|W611 Linearisierungspkt. Anzahl <2 (K1) |fr|W611 linarisation voie 1 moins de 2 points |it|W611 N punti linearizz. minori di 2 (C1)   "},
    {621, "|en|W621 simulation ch. 1 on |de|W621 Simulation K1 eingeschaltet |fr|W621 simulation voie 1 active |it|W621 Simulazione C1 attiva   "},
    {641, "|en|E641 no usable echo channel 1 check calibr.|de|E641 kein auswertbares Echo K1 Abgleich prfen|fr|E641 pas d'cho valuable en voie 1 vrifier calib.|it|E641 mancanza eco per elabor. C1 controll. cali.  "},
    {651, "|en|E651 level in safety distance - risk of overspill|de|E651 Sicherheitsabst. erreicht berfllgefahr|fr|E651 distance de scurit atteinte danger dbord.|it|E651 Raggiunta distanza di sicurezza Pericolo tracim  "},
    {671, "|en|A671 linearisation ch1 not complete, not usable|de|A671 Linearisation Ch1 nicht vollstndig, unbrauchbar|fr|A671 linaristion voie incomplte, inutilisable|it|A671 linearizzaz. C1 non completa, non utilizzabile  "},
    {681, "|en|W681 current ch1 out of range |de|W681 Strom Ch1 ausserhalb des Messbereichs |fr|W681 courant voie hors gamme |it|W681 usc. corr. C1 fuori range   "}}
} 



COMMAND read_parActualError { 
	BLOCK 	transducer_block_1 ;
	INDEX 	98 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parActualError
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parLastError {
	LABEL 	"|en|previous error|de|letzter Fehler|fr|dernier defaut|es|letzter Fehler|it|ultimo errore|nl|vorige fout" ;
	HELP 	[error_code_help] ;
	CLASS 	DYNAMIC ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED (2)	{
    {0, "|en|system ok"},
    {101, "|en|A101 checksum error general reset & new calibr.required|de|A101 Prfsummenfehler Totalreset & Neu- abgl. erfordert|fr|A101 erreur somme test reset gnral nouvel talonn.|it|A101 errore check sum ripristino totale nuova calibraz.  "},
    {102, "|en|A102 checksum error general reset & new calibr.required|de|A102 Prfsummenfehler Totalreset & Neu- abgl. erfordert|fr|A102 erreur somme test reset gnral nouvel talonn.|it|A102 errore check sum ripristino totale nuova calibraz.  "},
    {103, "|en|W103 initialising - please wait |de|W103 Initialisierung - bitte warten |fr|W103 initialisation en cours-attendre |it|W103 inizializzazione in corso-attendere   "},
    {106, "|en|A106 downloading please wait |de|A106 Download luft - bitte warten |fr|A106 download en cours-attendre |it|A106 download in corso-attendere   "},
    {110, "|en|A110 checksum error general reset & new calibr.required|de|A110 Prfsummenfehler Totalreset & Neu- abgl. erfordert|fr|A110 erreur somme test reset gnral nouvel talonn.|it|A110 errore di check sum riprist. totale nuova calibr.  "},
    {111, "|en|A111 electronics defect  |de|A111 Elektronik defekt  |fr|A111 dfaut lectronique  |it|A111 Guasto elettron.    "},
    {113, "|en|A113 electronics defect  |de|A113 Elektronik defekt  |fr|A113 dfaut lectronique  |it|A113 Guasto elettron.    "},
    {114, "|en|A114 electronics defect  |de|A114 Elektronik defekt  |fr|A114 dfaut lectronique  |it|A114 Guasto elettron.    "},
    {115, "|en|A115 electronics defect  |de|A115 Elektronik defekt  |fr|A115 dfaut lectronique  |it|A115 Guasto elettron.    "},
    {116, "|en|A116 download error repeat download |de|A116 Downloadfehler Download wiederholen |fr|A116 erreur download rpter download |it|A116 Errore download ripetere download   "},
    {121, "|en|A121 electronics defect  |de|A121 Elektronik defekt  |fr|A121 dfaut lectronique  |it|A121 Guasto elettron.    "},
    {152, "|en|A152 checksum error general reset & new calibr.required|de|A152 Prfsummenfehler Totalreset & Neu- abgl. erfordert|fr|A152 erreur somme test reset gnral nouvel talonn.|it|A152 errore check sum ripristino totale nuova calibraz.  "},
    {153, "|en|W153 initialising - please wait |de|W153 Initialisierung - bitte warten |fr|W153 initialisation en cours-attendre |it|W153 inizializzazione in corso-attendere   "},
    {155, "|en|A155 electronics defect  |de|A155 Elektronik defekt  |fr|A155 dfaut lectronique  |it|A155 Guasto elettron.    "},
    {160, "|en|A160 checksum error general reset & new calibr.required|de|A160 Prfsummenfehler Totalreset & Neu- abgl. erfordert|fr|A160 erreur somme test reset gnral nouvel talonn.|it|A160 errore check sum ripristino totale nuova calibraz.  "},
    {164, "|en|A164 electronics defect  |de|A164 Elektronik defekt  |fr|A164 dfaut lectronique  |it|A164 Guasto elettron.    "},
    {171, "|en|A171 electronics defect  |de|A171 Elektronik defekt  |fr|A171 dfaut lectronique  |it|A171 Guasto elettron.    "},
    {231, "|en|A231 sensor 1 defect check connection |de|A231 Sensor 1 defekt Prfe Verbindung |fr|A231 dfaut sonde 1 vrifier connexion |it|A231 Sens.1 guasto controll. conness.   "},
    {270, "|en|A270 custody switch undef check position |de|A270 Schalter undefiniert berprfe Position |fr|A270 commutateur indfini vrifier position |it|A270 Interr. non def. contr. posizione   "},
    {271, "|en|W271 reduced accuracy check installation |de|W271 reduz. Genauigkeit Installation prfen |fr|W271 prcision rduit vrifier installat. |it|W271 precis. ridotto controll. Installaz.   "},
    {272, "|en|A272 electronics defect amplifier |de|A272 Elektronik defekt Verstrker |fr|A272 dfaut lectron. amplificateur |it|A272 guasto elettron. amplificatore   "},
    {273, "|en|W273 reduced accuracy  |de|W273 reduz. Genauigkeit  |fr|W273 prcision rduit  |it|W273 precis. ridotto    "},
    {274, "|en|W274 reduced accuracy check pipe diameter |de|W274 reduz. Genauigkeit Prfe Rohr- durchmesser|fr|W274 prcision rduit vr. diamtre du tube|it|W274 precis. ridotto controll. diametro del tubo guida  "},
    {275, "|en|W275 electronics defect factory settings |de|W275 Elektronik defekt Werksabgleich |fr|W275 dfaut lectron. calibration usine |it|W275 dfaut lectron. calibrazione di fabbrica  "},
    {511, "|en|W511 no factory cali- bration ch1 |de|W511 kein Werksabgl. vorhanden K1 |fr|W511 pas de rglage usine disponible voie 1 |it|W511 assenza calibr. di fabbrica C1   "},
    {512, "|en|W512 recording of mapping please wait |de|W512 Aufnahme Ausblendung - warten |fr|W512 suppressionen cours attendre |it|W512 registr. mappatura in corso-attendere   "},
    {601, "|en|W601 linearisation ch1 curve not monotone |de|W601 Linearisierung K1 Kurve nicht monoton |fr|W601 linarisation voie 1 courbe non monotone |it|W601 Linearizzazione C1 curva non monotona   "},
    {611, "|en|W611 less than 2 linea- risation points for channel 1|de|W611 Linearisierungspkt. Anzahl <2 (K1) |fr|W611 linarisation voie 1 moins de 2 points |it|W611 N punti linearizz. minori di 2 (C1)   "},
    {621, "|en|W621 simulation ch. 1 on |de|W621 Simulation K1 eingeschaltet |fr|W621 simulation voie 1 active |it|W621 Simulazione C1 attiva   "},
    {641, "|en|E641 no usable echo channel 1 check calibr.|de|E641 kein auswertbares Echo K1 Abgleich prfen|fr|E641 pas d'cho valuable en voie 1 vrifier calib.|it|E641 mancanza eco per elabor. C1 controll. cali.  "},
    {651, "|en|E651 level in safety distance - risk of overspill|de|E651 Sicherheitsabst. erreicht berfllgefahr|fr|E651 distance de scurit atteinte danger dbord.|it|E651 Raggiunta distanza di sicurezza Pericolo tracim  "},
    {671, "|en|A671 linearisation ch1 not complete, not usable|de|A671 Linearisation Ch1 nicht vollstndig, unbrauchbar|fr|A671 linaristion voie incomplte, inutilisable|it|A671 linearizzaz. C1 non completa, non utilizzabile  "},
    {681, "|en|W681 current ch1 out of range |de|W681 Strom Ch1 ausserhalb des Messbereichs |fr|W681 courant voie hors gamme |it|W681 usc. corr. C1 fuori range   "}}
} 



COMMAND read_parLastError { 
	BLOCK 	transducer_block_1 ;
	INDEX 	99 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parLastError
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parClearLastError {
	LABEL 	"|en|clear last error|de|Loesche let.Fehl.|fr|eff. der. defaut|es|Loesche let.Fehl.|it|canc.ult. err.|nl|wis laatste fout" ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	{ DEFAULT_VALUE 0; { 0 ,"|en|keep|de|beibehalten|fr|garder|es|mantener|it|mantieni|nl|houden"}, { 1 ,"|en|erase|de|loeschen|fr|effacer|es|borrar|it|cancella|nl|wissen"}  }
} 



COMMAND read_parClearLastError { 
	BLOCK 	transducer_block_1 ;
	INDEX 	100 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parClearLastError
		} 
	} 
} 

COMMAND write_parClearLastError { 
	BLOCK 	transducer_block_1 ;
	INDEX 	100 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parClearLastError
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parMeasuredDistance {
	LABEL 	"|en|measured dist.|de|gemessene Dist.|fr|distance mesuree|es|gemessene Dist.|it|Distanza mis.|nl|meetafstand" ;
	CLASS 	DYNAMIC ; 
	HANDLING  READ ;
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"6.3f" ;
		EDIT_FORMAT	"6.3f" ;
	}
} 



COMMAND read_parMeasuredDistance { 
	BLOCK 	transducer_block_1 ;
	INDEX 	103 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parMeasuredDistance
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parMeasuredLevel {
	LABEL 	"|en|measured level|de|gemess. Fuellst.|fr|niveau mesure|es|gemess. Fuellst.|it|Livello mis.|nl|gemeten niveau" ;
	CLASS 	DYNAMIC ; 
	HANDLING  READ ;
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"6.3f" ;
		EDIT_FORMAT	"6.3f" ;
	}
} 



COMMAND read_parMeasuredLevel { 
	BLOCK 	transducer_block_1 ;
	INDEX 	104 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parMeasuredLevel
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parApplicationParameter {
	LABEL 	"|en|application par.|de|Anwendungsparam.|fr|par. d'applicat.|es|Anwendungsparam.|it|par. applicaz.|nl|toepassing par." ;
	CLASS 	CONTAINED ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED	{ DEFAULT_VALUE 0;   { 0 ,"|en|modified|de|geaendert|fr|modifie|es|modificato|it|modificato|nl|veranderet"}, { 1 ,"|en|not modified|de|nicht geaendert|fr|non modifie|es|non modificato|it|non modificato|nl|niet verander."}  }
} 



COMMAND read_parApplicationParameter { 
	BLOCK 	transducer_block_1 ;
	INDEX 	106 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parApplicationParameter
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parTagNumber {
	LABEL 	"|en|tag no.|de|Messstelle|fr|N Repere|es|Messstelle|it|Tag n|nl|tag nummer" ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE  ASCII (32) ;
} 



COMMAND read_parTagNumber { 
	BLOCK 	transducer_block_1 ;
	INDEX 	108 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parTagNumber
		} 
	} 
} 

COMMAND write_parTagNumber { 
	BLOCK 	transducer_block_1 ;
	INDEX 	108 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parTagNumber
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parProtSoftVersionString {
	LABEL 	"|en|protocol+sw-no.|de|Protokoll+SW-Nr.|fr|protoc. +nsw|es|Protokoll+SW-Nr.|it|protocol.+sw ver|nl|protoc.en SW.nr." ;
	CLASS 	CONTAINED ; 
	HANDLING  READ ;
	TYPE  ASCII (16)  {
		DEFAULT_VALUE	"V01.01.0x (PA)" ;
	}
} 



COMMAND read_parProtSoftVersionString { 
	BLOCK 	transducer_block_1 ;
	INDEX 	110 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parProtSoftVersionString
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parSerialNumber {
	LABEL 	"|en|serial no.|de|Seriennummer|fr|numero de serie|es|Seriennummer|it|Num. di serie|nl|serienummer" ;
	CLASS 	CONTAINED ; 
	HANDLING  READ ;
	TYPE  ASCII (16) ;
} 



COMMAND read_parSerialNumber { 
	BLOCK 	transducer_block_1 ;
	INDEX 	112 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parSerialNumber
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parDownloadMode {
	LABEL 	"|en|download mode|de|Download Mode|fr|mode download|es|Download Mode|it|modo download|nl|download keuze" ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	{ DEFAULT_VALUE 0; { 0 ,"|en|parameter only|de|nur Parameter|fr|seul. param.|es|slo parmet.|it|solo parametro|nl|alleen param."}, { 1 ,"|en|param+cust.map|de|Param+Ausblen.|fr|param.+ suppr.|es|par.+mapeado|it|param+map.cl.|nl|param.+select."}, { 2 ,"|en|mapping only|de|Ausblendung|fr|suppression|es|slo mapeado|it|solo mappatura|nl|alleen select."}  }
} 



COMMAND read_parDownloadMode { 
	BLOCK 	transducer_block_1 ;
	INDEX 	116 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parDownloadMode
		} 
	} 
} 

COMMAND write_parDownloadMode { 
	BLOCK 	transducer_block_1 ;
	INDEX 	116 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parDownloadMode
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parPADeviceBusAddress {
	LABEL 	"|en|instrument addr.|de|Gerteadresse" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  TRUE ;
	HANDLING  READ ;
	TYPE  UNSIGNED_INTEGER(1) ;
} 



COMMAND read_parPADeviceBusAddress { 
	BLOCK 	transducer_block_1 ;
	INDEX 	58 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parPADeviceBusAddress
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parPAIdentNumberSelector {
	LABEL 	"|en|ident number|de|Ident. Nr." ;
	CLASS 	CONTAINED ; 
	VALIDITY  TRUE ;
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED(1)	        {
		   DEFAULT_VALUE 1;
                {0,[phys_ident_number_PROFILE]},
                {1,[phys_ident_number_MANUFACURER]}
        }
} 



COMMAND read_parPAIdentNumberSelector { 
	BLOCK 	transducer_block_1 ;
	INDEX 	59 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parPAIdentNumberSelector
		} 
	} 
} 

COMMAND write_parPAIdentNumberSelector { 
	BLOCK 	transducer_block_1 ;
	INDEX 	59 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parPAIdentNumberSelector
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parPASetUnitToBus {
	LABEL 	"|en|set unit to bus|de|Setze Einh. Out" ;
	CLASS 	CONTAINED ; 
	VALIDITY  TRUE ;
	HANDLING  READ & WRITE ;
	TYPE 	ENUMERATED (1)	{ DEFAULT_VALUE 0; {0,"|en|confirm|de|besttigen"}}
} 



COMMAND read_parPASetUnitToBus { 
	BLOCK 	transducer_block_1 ;
	INDEX 	60 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parPASetUnitToBus
		} 
	} 
} 

COMMAND write_parPASetUnitToBus { 
	BLOCK 	transducer_block_1 ;
	INDEX 	60 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parPASetUnitToBus
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parPAAIOutValue {
	LABEL 	"|en|out value|de|Out Wert" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  TRUE ;
	HANDLING  READ ;
	TYPE  FLOAT ;
} 



COMMAND read_parPAAIOutValue { 
	BLOCK 	transducer_block_1 ;
	INDEX 	61 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parPAAIOutValue
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parPAAIOutStatus {
	LABEL 	"|en|out status|de|Out Status" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  TRUE ;
	HANDLING  READ ;
	TYPE  UNSIGNED_INTEGER(1) ;
} 



COMMAND read_parPAAIOutStatus { 
	BLOCK 	transducer_block_1 ;
	INDEX 	62 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parPAAIOutStatus
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parPA2ndCyclicValue {
	LABEL 	"|en|2nd cyclic value|de|2. zykl. Wert" ;
	CLASS 	CONTAINED ; 
	VALIDITY  TRUE ;
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	  {
    DEFAULT_VALUE 0;
    { 0,  "|en|height/dist.|de|Hhe/Distanz"  }
  }
} 



COMMAND read_parPA2ndCyclicValue { 
	BLOCK 	transducer_block_1 ;
	INDEX 	65 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parPA2ndCyclicValue
		} 
	} 
} 

COMMAND write_parPA2ndCyclicValue { 
	BLOCK 	transducer_block_1 ;
	INDEX 	65 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parPA2ndCyclicValue
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parPASelectMainValue {
	LABEL 	"|en|select V0H0|de|Zuordnung Anzei." ;
	CLASS 	CONTAINED ; 
	VALIDITY  TRUE ;
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED(1)	        {
                {0,[enum_eh_meas]},
                {1,[enum_eh_display]}
        }
} 



COMMAND read_parPASelectMainValue { 
	BLOCK 	transducer_block_1 ;
	INDEX 	66 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parPASelectMainValue
		} 
	} 
} 

COMMAND write_parPASelectMainValue { 
	BLOCK 	transducer_block_1 ;
	INDEX 	66 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parPASelectMainValue
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parPADisplayValue {
	LABEL 	"Display value" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  TRUE ;
	HANDLING  READ ;
	TYPE  FLOAT ;
} 



COMMAND read_parPADisplayValue { 
	BLOCK 	transducer_block_1 ;
	INDEX 	67 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parPADisplayValue
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parPAProfileRevision {
	LABEL 	"Profile Version" ;
	CLASS 	CONTAINED ; 
	VALIDITY  TRUE ;
	HANDLING  READ ;
	TYPE  ASCII (16)  {
		DEFAULT_VALUE	"3.0" ;
	}
} 



COMMAND read_parPAProfileRevision { 
	SLOT 	1 ;
	INDEX 	113 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parPAProfileRevision
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parInputLevelHalfAutomatic {
	LABEL 	"|en|input level|de|Eingabe Fuellst.|fr|entree niveau|es|Eingabe Fuellst.|it|Dato livello|nl|invoer niveau" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val010)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ ;
	TYPE  FLOAT ;
} 



COMMAND read_parInputLevelHalfAutomatic { 
	BLOCK 	transducer_block_1 ;
	INDEX 	118 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parInputLevelHalfAutomatic
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parSimulationValueVolume {
	LABEL 	"|en|sim. value volume|de|Simulationsvolumen" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val011)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ & WRITE ;
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "m";
					CASE 1018:   "ft";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "mm";
				}
	TYPE 	FLOAT	{
	EDIT_FORMAT "9.3f";
	DISPLAY_FORMAT "9.3f";
	MIN_VALUE
	IF ((parLevelUllageMode == 0) || (parLevelUllageMode == 2))
	{
		-99999.0;
	}
	ELSE
	{
		IF ((parLevelUllageMode == 1) || (parLevelUllageMode == 3))
		{
			SELECT (parDistanceUnit)
			{
				CASE 1010 :  -2.000;
				CASE 1018 :  -6.562;
				CASE 1019 :  -78.740;
				CASE 1013 :  -2000.000;
				DEFAULT:  -2.000;
			}
		}
	}
	MAX_VALUE
	IF ((parLevelUllageMode == 0) || (parLevelUllageMode == 2))
	{
		99999.0;
	}
	ELSE
	{
		IF ((parLevelUllageMode == 1) || (parLevelUllageMode == 3))
		{
			IF (parMaxAbs) {
				parAbsMaxMessDist;
			}
			ELSE {
				SELECT (parDistanceUnit)
				{
					CASE 1010: 22.0;
					CASE 1018: 72.178;
					CASE 1019: 866.142;
					CASE 1013: 22000.0;
					DEFAULT: 22.0;
				}
			}
		}
	}
}
} 



COMMAND read_parSimulationValueVolume { 
	BLOCK 	transducer_block_1 ;
	INDEX 	121 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parSimulationValueVolume
		} 
	} 
} 

COMMAND write_parSimulationValueVolume { 
	BLOCK 	transducer_block_1 ;
	INDEX 	121 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parSimulationValueVolume
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  preDistanceUnit {
	LABEL 	" " ;
	CLASS 	LOCAL ; 
	HANDLING  READ & WRITE ;
	TYPE  UNSIGNED_INTEGER (2)  {
		DEFAULT_VALUE	1010 ;
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parAbsMaxMessDist {
	LABEL 	"|en|max. meas. dist." ;
	CLASS 	DYNAMIC ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ ;
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "m";
					CASE 1018:   "ft";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "mm";
				}
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"9.3f" ;
		EDIT_FORMAT	"9.3f" ;
		DEFAULT_VALUE	22.0 ;
	}
	POST_READ_ACTIONS  { 
		setAbsMax
	}
} 



COMMAND read_parAbsMaxMessDist { 
	SLOT 	2 ;
	INDEX 	75 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parAbsMaxMessDist
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parCurrentAmplitude {
	LABEL 	"|en|pres. amplitude" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ ;
	CONSTANT_UNIT  "|en|dB" ;
	TYPE  INTEGER (1)  {
		DISPLAY_FORMAT	"3.1i" ;
		EDIT_FORMAT	"3.1i" ;
		DEFAULT_VALUE	0 ;
	}
} 



COMMAND read_parCurrentAmplitude { 
	SLOT 	2 ;
	INDEX 	0 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parCurrentAmplitude
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parAmplitudeOverSuppression {
	LABEL 	"|en|ampl. over map." ;
	CLASS 	DYNAMIC ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ ;
	CONSTANT_UNIT  "|en|dB" ;
	TYPE  INTEGER (1)  {
		DISPLAY_FORMAT	"3.1i" ;
		EDIT_FORMAT	"3.1i" ;
		DEFAULT_VALUE	0 ;
	}
} 



COMMAND read_parAmplitudeOverSuppression { 
	SLOT 	2 ;
	INDEX 	1 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parAmplitudeOverSuppression
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parAmplitudeOverFAC {
	LABEL 	"|en|ampl. over FAC" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ ;
	CONSTANT_UNIT  "|en|dB" ;
	TYPE  INTEGER (1)  {
		DISPLAY_FORMAT	"4.1i" ;
		EDIT_FORMAT	"4.1i" ;
		DEFAULT_VALUE	0 ;
	}
} 



COMMAND read_parAmplitudeOverFAC { 
	SLOT 	2 ;
	INDEX 	2 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parAmplitudeOverFAC
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parUnfilteredDistance {
	LABEL 	"|en|unfilt. distance" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ ;
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "mm";
					CASE 1018:   "inch";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "mm";
				}
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"8.2f" ;
		EDIT_FORMAT	"8.2f" ;
		DEFAULT_VALUE	0 ;
	}
} 



COMMAND read_parUnfilteredDistance { 
	SLOT 	2 ;
	INDEX 	3 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parUnfilteredDistance
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parCalcEdgeParameter {
	LABEL 	"|en|pres. edge param" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ ;
	CONSTANT_UNIT  "|en|dB" ;
	TYPE  UNSIGNED_INTEGER (1)  {
		DISPLAY_FORMAT	"4.1u" ;
		EDIT_FORMAT	"4.1u" ;
		DEFAULT_VALUE	0 ;
	}
} 



COMMAND read_parCalcEdgeParameter { 
	SLOT 	2 ;
	INDEX 	4 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parCalcEdgeParameter
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parCurrentFirstEchoFactor {
	LABEL 	"|en|present FEF" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ ;
	CONSTANT_UNIT  "|en|dB" ;
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"5.2f" ;
		EDIT_FORMAT	"5.2f" ;
		DEFAULT_VALUE	0 ;
	}
} 



COMMAND read_parCurrentFirstEchoFactor { 
	SLOT 	2 ;
	INDEX 	5 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parCurrentFirstEchoFactor
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parDeviceName {
	LABEL 	"|en|device name" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE  ASCII (16)  {
		DEFAULT_VALUE	"FMR 23x" ;
	}
} 



COMMAND read_parDeviceName { 
	SLOT 	2 ;
	INDEX 	7 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parDeviceName
		} 
	} 
} 

COMMAND write_parDeviceName { 
	SLOT 	2 ;
	INDEX 	7 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parDeviceName
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parOrderCode {
	LABEL 	"|en|order code" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE  ASCII (16)  {
	}
} 



COMMAND read_parOrderCode { 
	SLOT 	2 ;
	INDEX 	8 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parOrderCode
		} 
	} 
} 

COMMAND write_parOrderCode { 
	SLOT 	2 ;
	INDEX 	8 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parOrderCode
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parMamFilterLength {
	LABEL 	"|en|MAM filt. length" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE  UNSIGNED_INTEGER (1)  {
		DISPLAY_FORMAT	"2.1u" ;
		EDIT_FORMAT	"2.1u" ;
		MIN_VALUE 	1 ;
		MAX_VALUE	32 ;
		DEFAULT_VALUE	20 ;
	}
} 



COMMAND read_parMamFilterLength { 
	SLOT 	2 ;
	INDEX 	9 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parMamFilterLength
		} 
	} 
} 

COMMAND write_parMamFilterLength { 
	SLOT 	2 ;
	INDEX 	9 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parMamFilterLength
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parMamFilterBorder {
	LABEL 	"|en|MAM filt. border" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE  UNSIGNED_INTEGER (1)  {
		DISPLAY_FORMAT	"2.1u" ;
		EDIT_FORMAT	"2.1u" ;
		MIN_VALUE 	0 ;
		MAX_VALUE	15 ;
		DEFAULT_VALUE	3 ;
	}
} 



COMMAND read_parMamFilterBorder { 
	SLOT 	2 ;
	INDEX 	10 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parMamFilterBorder
		} 
	} 
} 

COMMAND write_parMamFilterBorder { 
	SLOT 	2 ;
	INDEX 	10 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parMamFilterBorder
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parLowPassFilter {
	LABEL 	"|en|low pass filter" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  "|en|s" ;
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"5.1f" ;
		EDIT_FORMAT	"5.1f" ;
		MIN_VALUE 	0.0 ;
		MAX_VALUE	255.0 ;
		DEFAULT_VALUE	5.0 ;
	}
} 



COMMAND read_parLowPassFilter { 
	SLOT 	2 ;
	INDEX 	11 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parLowPassFilter
		} 
	} 
} 

COMMAND write_parLowPassFilter { 
	SLOT 	2 ;
	INDEX 	11 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parLowPassFilter
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parHystereseWidth {
	LABEL 	"|en|hysterese width" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "mm";
					CASE 1018:   "inch";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "mm";
				}
	TYPE 	FLOAT	{
					EDIT_FORMAT "8.3f";
					DISPLAY_FORMAT "8.3f";
					MIN_VALUE 0.0;
					MAX_VALUE
					SELECT (parDistanceUnit)
					{
						CASE 1010: 1000.000;
						CASE 1018:   39.370;
						CASE 1019:   39.370;
						CASE 1013: 1000.000;
						DEFAULT:   1000.000;
					}
					DEFAULT_VALUE 0.0;
				}
} 



COMMAND read_parHystereseWidth { 
	SLOT 	2 ;
	INDEX 	12 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parHystereseWidth
		} 
	} 
} 

COMMAND write_parHystereseWidth { 
	SLOT 	2 ;
	INDEX 	12 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parHystereseWidth
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parEchoLostRampUp {
	LABEL 	"|en|echo lost up" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "mm/s";
					CASE 1018:   "inch/s";
					CASE 1019:   "inch/s";
					CASE 1013:   "mm/s";
					DEFAULT:  "mm/s";
				}
	TYPE 	FLOAT	{
					EDIT_FORMAT "9.3f";
					DISPLAY_FORMAT "9.3f";
					MIN_VALUE 0.0;
					MAX_VALUE
					IF (parMaxAbs) {
                                                parAbsMaxMessDist;
					}
					ELSE {
						SELECT (parDistanceUnit)
						{
							CASE 1010: 22000.0;
							CASE 1018: 866.142;
							CASE 1019: 866.142;
							CASE 1013: 22000.0;
							DEFAULT: 22000.0;
						}
					}
					DEFAULT_VALUE 0.0;
				}
} 



COMMAND read_parEchoLostRampUp { 
	SLOT 	2 ;
	INDEX 	13 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parEchoLostRampUp
		} 
	} 
} 

COMMAND write_parEchoLostRampUp { 
	SLOT 	2 ;
	INDEX 	13 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parEchoLostRampUp
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parEchoLostRampDown {
	LABEL 	"|en|echo lost down" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "mm/s";
					CASE 1018:   "inch/s";
					CASE 1019:   "inch/s";
					CASE 1013:   "mm/s";
					DEFAULT:  "mm/s";
				}
	TYPE 	FLOAT	{
					EDIT_FORMAT "9.3f";
					DISPLAY_FORMAT "9.3f";
					MIN_VALUE 0.0;
					MAX_VALUE
					IF (parMaxAbs) {
                                                parAbsMaxMessDist;
					}
					ELSE {
						SELECT (parDistanceUnit)
						{
							CASE 1010: 22000.0;
							CASE 1018: 866.142;
							CASE 1019: 866.142;
							CASE 1013: 22000.0;
							DEFAULT: 22000.0;
						}
					}
					DEFAULT_VALUE 0.0;
				}
} 



COMMAND read_parEchoLostRampDown { 
	SLOT 	2 ;
	INDEX 	14 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parEchoLostRampDown
		} 
	} 
} 

COMMAND write_parEchoLostRampDown { 
	SLOT 	2 ;
	INDEX 	14 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parEchoLostRampDown
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parUnfilteredDistanceRaw {
	LABEL 	"|en|unflt. dist. raw" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ ;
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "mm";
					CASE 1018:   "inch";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "mm";
				}
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"9.3f" ;
		EDIT_FORMAT	"9.3f" ;
	}
} 



COMMAND read_parUnfilteredDistanceRaw { 
	SLOT 	2 ;
	INDEX 	15 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parUnfilteredDistanceRaw
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parHKStatistik {
	LABEL 	"|en|env. statistics" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE  UNSIGNED_INTEGER (1)  {
		DISPLAY_FORMAT	"3.1u" ;
		EDIT_FORMAT	"3.1u" ;
		MIN_VALUE 	0 ;
		MAX_VALUE	255 ;
	}
} 



COMMAND read_parHKStatistik { 
	SLOT 	2 ;
	INDEX 	18 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parHKStatistik
		} 
	} 
} 

COMMAND write_parHKStatistik { 
	SLOT 	2 ;
	INDEX 	18 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parHKStatistik
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parFilterBreite {
	LABEL 	"|en|env. smoothing" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE  UNSIGNED_INTEGER (1)  {
		DISPLAY_FORMAT	"2.1u" ;
		EDIT_FORMAT	"2.1u" ;
		MIN_VALUE 	0 ;
		MAX_VALUE	77 ;
	}
} 



COMMAND read_parFilterBreite { 
	SLOT 	2 ;
	INDEX 	19 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parFilterBreite
		} 
	} 
} 

COMMAND write_parFilterBreite { 
	SLOT 	2 ;
	INDEX 	19 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parFilterBreite
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parEnvelopeEnergy {
	LABEL 	"|en|envel. energy" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ ;
	CONSTANT_UNIT  "|en|dB" ;
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"9.3f" ;
		EDIT_FORMAT	"9.3f" ;
	}
} 



COMMAND read_parEnvelopeEnergy { 
	SLOT 	2 ;
	INDEX 	26 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parEnvelopeEnergy
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parMappingAdder {
	LABEL 	"|en|mapping adder" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  "|en|dB" ;
	TYPE  UNSIGNED_INTEGER (1)  {
		DISPLAY_FORMAT	"3.1u" ;
		EDIT_FORMAT	"3.1u" ;
		MIN_VALUE 	0 ;
		MAX_VALUE	255 ;
		DEFAULT_VALUE	5 ;
	}
} 



COMMAND read_parMappingAdder { 
	SLOT 	2 ;
	INDEX 	27 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parMappingAdder
		} 
	} 
} 

COMMAND write_parMappingAdder { 
	SLOT 	2 ;
	INDEX 	27 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parMappingAdder
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parMappingWidth {
	LABEL 	"|en|mapping scanrate" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE  UNSIGNED_INTEGER (1)  {
		DISPLAY_FORMAT	"3.1u" ;
		EDIT_FORMAT	"3.1u" ;
		MIN_VALUE 	1 ;
		MAX_VALUE	255 ;
		DEFAULT_VALUE	6 ;
	}
} 



COMMAND read_parMappingWidth { 
	SLOT 	2 ;
	INDEX 	28 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parMappingWidth
		} 
	} 
} 

COMMAND write_parMappingWidth { 
	SLOT 	2 ;
	INDEX 	28 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parMappingWidth
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parMappingAverage {
	LABEL 	"|en|mapping average" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE  UNSIGNED_INTEGER (1)  {
		DISPLAY_FORMAT	"3.1u" ;
		EDIT_FORMAT	"3.1u" ;
		MIN_VALUE 	0 ;
		MAX_VALUE	255 ;
		DEFAULT_VALUE	6 ;
	}
} 



COMMAND read_parMappingAverage { 
	SLOT 	2 ;
	INDEX 	29 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parMappingAverage
		} 
	} 
} 

COMMAND write_parMappingAverage { 
	SLOT 	2 ;
	INDEX 	29 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parMappingAverage
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parFactoryTdt {
	LABEL 	"|en|fact. map. valid" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	{ DEFAULT_VALUE 0; { 0 ,"|en|off|de|aus|fr|inactif|es|desconectado|it|disattivato|nl|uit"}, { 1 ,"|en|on|de|an|fr|actif|es|conectado|it|attivato|nl|aan"}, { 2 ,"|en|reset|de|loeschen|fr|reset|es|borrar|it|reset|nl|reset"}  }
} 



COMMAND read_parFactoryTdt { 
	SLOT 	2 ;
	INDEX 	30 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parFactoryTdt
		} 
	} 
} 

COMMAND write_parFactoryTdt { 
	SLOT 	2 ;
	INDEX 	30 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parFactoryTdt
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parFacAdder {
	LABEL 	"|en|FAC adder" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  "|en|dB" ;
	TYPE  UNSIGNED_INTEGER (1)  {
		DISPLAY_FORMAT	"3.1u" ;
		EDIT_FORMAT	"3.1u" ;
		MIN_VALUE 	0 ;
		MAX_VALUE	255 ;
	}
} 



COMMAND read_parFacAdder { 
	SLOT 	2 ;
	INDEX 	31 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parFacAdder
		} 
	} 
} 

COMMAND write_parFacAdder { 
	SLOT 	2 ;
	INDEX 	31 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parFacAdder
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parFACWidth {
	LABEL 	"|en|FAC scan rate" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE  UNSIGNED_INTEGER (1)  {
		DISPLAY_FORMAT	"3.1u" ;
		EDIT_FORMAT	"3.1u" ;
		MIN_VALUE 	1 ;
		MAX_VALUE	255 ;
	}
} 



COMMAND read_parFACWidth { 
	SLOT 	2 ;
	INDEX 	32 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parFACWidth
		} 
	} 
} 

COMMAND write_parFACWidth { 
	SLOT 	2 ;
	INDEX 	32 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parFACWidth
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parRangeFactoryMap {
	LABEL 	"|en|range fact. map" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ ;
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "m";
					CASE 1018:   "ft";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "mm";
				}
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"9.3f" ;
		EDIT_FORMAT	"9.3f" ;
	}
} 



COMMAND read_parRangeFactoryMap { 
	SLOT 	2 ;
	INDEX 	33 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parRangeFactoryMap
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parFactoryMappingValid {
	LABEL 	"|en|fact. map. valid" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ ;
	TYPE 	ENUMERATED	{  { 0 ,"|en|not active"}, { 1 ,"|en|active"}  }
} 



COMMAND read_parFactoryMappingValid { 
	SLOT 	2 ;
	INDEX 	34 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parFactoryMappingValid
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parCustomerMappingValid {
	LABEL 	"|en|cust. map. valid" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ ;
	TYPE 	ENUMERATED	{  { 0 ,"|en|not active"}, { 1 ,"|en|active"}  }
} 



COMMAND read_parCustomerMappingValid { 
	SLOT 	2 ;
	INDEX 	35 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parCustomerMappingValid
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parEdgeDetectionMode {
	LABEL 	"|en|edge detec. mode" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	{ DEFAULT_VALUE 0; { 0 ,"|en|front of echo"}, { 1 ,"|en|behind echo"}, { 2 ,"|en|middle of echo"}  }
} 



COMMAND read_parEdgeDetectionMode { 
	SLOT 	2 ;
	INDEX 	36 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parEdgeDetectionMode
		} 
	} 
} 

COMMAND write_parEdgeDetectionMode { 
	SLOT 	2 ;
	INDEX 	36 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parEdgeDetectionMode
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parEdgeParameter {
	LABEL 	"|en|edge parameter" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  "|en|dB" ;
	TYPE  UNSIGNED_INTEGER (1)  {
		DISPLAY_FORMAT	"3.1u" ;
		EDIT_FORMAT	"3.1u" ;
		MIN_VALUE 	0 ;
		MAX_VALUE	255 ;
		DEFAULT_VALUE	4 ;
	}
} 



COMMAND read_parEdgeParameter { 
	SLOT 	2 ;
	INDEX 	37 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parEdgeParameter
		} 
	} 
} 

COMMAND write_parEdgeParameter { 
	SLOT 	2 ;
	INDEX 	37 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parEdgeParameter
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parFirstEchoFactor {
	LABEL 	"|en|First Echo Fact." ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  "|en|dB" ;
	TYPE  UNSIGNED_INTEGER (1)  {
		DISPLAY_FORMAT	"3.1u" ;
		EDIT_FORMAT	"3.1u" ;
		MIN_VALUE 	0 ;
		MAX_VALUE	255 ;
		DEFAULT_VALUE	20 ;
	}
} 



COMMAND read_parFirstEchoFactor { 
	SLOT 	2 ;
	INDEX 	45 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parFirstEchoFactor
		} 
	} 
} 

COMMAND write_parFirstEchoFactor { 
	SLOT 	2 ;
	INDEX 	45 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parFirstEchoFactor
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parFefThreshold {
	LABEL 	"|en|FEF threshold" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  "|en|dB" ;
	TYPE  UNSIGNED_INTEGER (1)  {
		DISPLAY_FORMAT	"3.1u" ;
		EDIT_FORMAT	"3.1u" ;
		MIN_VALUE 	0 ;
		MAX_VALUE	255 ;
		DEFAULT_VALUE	0 ;
	}
} 



COMMAND read_parFefThreshold { 
	SLOT 	2 ;
	INDEX 	46 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parFefThreshold
		} 
	} 
} 

COMMAND write_parFefThreshold { 
	SLOT 	2 ;
	INDEX 	46 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parFefThreshold
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parFefNearFactor {
	LABEL 	"|en|FEF at near dist" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  "|en|dB" ;
	TYPE  UNSIGNED_INTEGER (1)  {
		DISPLAY_FORMAT	"3.1u" ;
		EDIT_FORMAT	"3.1u" ;
		MIN_VALUE 	0 ;
		MAX_VALUE	255 ;
		DEFAULT_VALUE	0 ;
	}
} 



COMMAND read_parFefNearFactor { 
	SLOT 	2 ;
	INDEX 	47 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parFefNearFactor
		} 
	} 
} 

COMMAND write_parFefNearFactor { 
	SLOT 	2 ;
	INDEX 	47 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parFefNearFactor
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parFefDistanceNear {
	LABEL 	"|en|FEF dist. near" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "mm";
					CASE 1018:   "inch";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "mm";
				}
	TYPE 	FLOAT	{
				EDIT_FORMAT "9.3f";
				DISPLAY_FORMAT "9.3f";
				MIN_VALUE	  0.0;
				MAX_VALUE
				IF (parMaxAbs) {
					parAbsMaxMessDist;
				}
				ELSE
				{
					SELECT (parDistanceUnit)
					{
						CASE 1010: 22000.0;
						CASE 1018: 866.142;
						CASE 1019: 866.142;
						CASE 1013: 22000.0;
						DEFAULT: 22000.0;
					}
				}
				DEFAULT_VALUE 0.0;
			}
} 



COMMAND read_parFefDistanceNear { 
	SLOT 	2 ;
	INDEX 	48 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parFefDistanceNear
		} 
	} 
} 

COMMAND write_parFefDistanceNear { 
	SLOT 	2 ;
	INDEX 	48 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parFefDistanceNear
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parFefDistanceFar {
	LABEL 	"|en|FEF dist. far" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "mm";
					CASE 1018:   "inch";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "mm";
				}
	TYPE 	FLOAT	{
				EDIT_FORMAT "9.3f";
				DISPLAY_FORMAT "9.3f";
				MIN_VALUE	  0.0;
				MAX_VALUE
				IF (parMaxAbs) {
					parAbsMaxMessDist;
				}
				ELSE
				{
					SELECT (parDistanceUnit)
					{
						CASE 1010: 22000.0;
						CASE 1018: 866.142;
						CASE 1019: 866.142;
						CASE 1013: 22000.0;
						DEFAULT: 22000.0;
					}
				}
				DEFAULT_VALUE 0.0;
			}
} 



COMMAND read_parFefDistanceFar { 
	SLOT 	2 ;
	INDEX 	49 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parFefDistanceFar
		} 
	} 
} 

COMMAND write_parFefDistanceFar { 
	SLOT 	2 ;
	INDEX 	49 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parFefDistanceFar
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parFefEdge {
	LABEL 	"|en|FEF edge" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  "|en|dB" ;
	TYPE  UNSIGNED_INTEGER (1)  {
		DISPLAY_FORMAT	"3.1u" ;
		EDIT_FORMAT	"3.1u" ;
		MIN_VALUE 	0 ;
		MAX_VALUE	255 ;
		DEFAULT_VALUE	20 ;
	}
} 



COMMAND read_parFefEdge { 
	SLOT 	2 ;
	INDEX 	50 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parFefEdge
		} 
	} 
} 

COMMAND write_parFefEdge { 
	SLOT 	2 ;
	INDEX 	50 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parFefEdge
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parDishBottomDetection {
	LABEL 	"|en|Tank Bottom Det." ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	{  DEFAULT_VALUE 1; { 0 ,"|en|off|de|aus|fr|inactif|es|desconectado|it|disattivato|nl|uit"}, { 1 ,"|en|on|de|an|fr|actif|es|conectado|it|attivato|nl|aan"}  }
} 



COMMAND read_parDishBottomDetection { 
	SLOT 	2 ;
	INDEX 	54 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parDishBottomDetection
		} 
	} 
} 

COMMAND write_parDishBottomDetection { 
	SLOT 	2 ;
	INDEX 	54 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parDishBottomDetection
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parAmplLevelBottomDetection {
	LABEL 	"|en|min. ampl. TBD" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  "|en|dB" ;
	TYPE  UNSIGNED_INTEGER (1)  {
		DISPLAY_FORMAT	"3.1u" ;
		EDIT_FORMAT	"3.1u" ;
		MIN_VALUE 	0 ;
		MAX_VALUE	255 ;
		DEFAULT_VALUE	70 ;
	}
} 



COMMAND read_parAmplLevelBottomDetection { 
	SLOT 	2 ;
	INDEX 	55 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parAmplLevelBottomDetection
		} 
	} 
} 

COMMAND write_parAmplLevelBottomDetection { 
	SLOT 	2 ;
	INDEX 	55 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parAmplLevelBottomDetection
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parMinLevelBottomDetection {
	LABEL 	"|en|max. level TBD" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "mm";
					CASE 1018:   "inch";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "mm";
				}
	TYPE 	FLOAT	{
				EDIT_FORMAT "9.3f";
				DISPLAY_FORMAT "9.3f";
				MIN_VALUE	  0.0;
				DEFAULT_VALUE
					SELECT (parDistanceUnit)
					{
						CASE 1010:     500.000;
						CASE 1018:      19.685;
						CASE 1019:      19.685;
						CASE 1013:     500.000;
						DEFAULT:       500.000;
					};

			}
} 



COMMAND read_parMinLevelBottomDetection { 
	SLOT 	2 ;
	INDEX 	56 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parMinLevelBottomDetection
		} 
	} 
} 

COMMAND write_parMinLevelBottomDetection { 
	SLOT 	2 ;
	INDEX 	56 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parMinLevelBottomDetection
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parLevelSpeed {
	LABEL 	"|en|fill/drain speed" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ ;
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "mm/s";
					CASE 1018:   "inch/s";
					CASE 1019:   "inch/s";
					CASE 1013:   "mm/s";
					DEFAULT:  "mm/s";
				}
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"9.3f" ;
		EDIT_FORMAT	"9.3f" ;
	}
} 



COMMAND read_parLevelSpeed { 
	SLOT 	2 ;
	INDEX 	62 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parLevelSpeed
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parHfModul {
	LABEL 	"|en|HF modul" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	{ DEFAULT_VALUE 1; { 0 ,"|en|P II.1"}, { 1 ,"|en|P II.2"}, { 2 ,"|en|P III.1"}, { 3 ,"|en|P III.2"}  }
} 



COMMAND read_parHfModul { 
	SLOT 	2 ;
	INDEX 	63 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parHfModul
		} 
	} 
} 

COMMAND write_parHfModul { 
	SLOT 	2 ;
	INDEX 	63 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parHfModul
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parZeroDistance {
	LABEL 	"|en|zero distance" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "mm";
					CASE 1018:   "inch";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "mm";
				}
	TYPE 	FLOAT	{
				EDIT_FORMAT "8.3f";
				DISPLAY_FORMAT "8.3f";
				MIN_VALUE	  0.0;
				MAX_VALUE
				SELECT (parDistanceUnit)
				{
					CASE 1010:   5000.000;
					CASE 1018:    196.850;
					CASE 1019:    196.850;
					CASE 1013:   5000.000;
					DEFAULT:     5000.000;
				};
				DEFAULT_VALUE
				SELECT (parDistanceUnit)
				{
					CASE 1010:   700.000;
					CASE 1018:    27.559;
					CASE 1019:    27.559;
					CASE 1013:   700.000;
					DEFAULT:     700.000;
				};

			}
} 



COMMAND read_parZeroDistance { 
	SLOT 	2 ;
	INDEX 	64 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parZeroDistance
		} 
	} 
} 

COMMAND write_parZeroDistance { 
	SLOT 	2 ;
	INDEX 	64 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parZeroDistance
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parAntennaType {
	LABEL 	"|en|antenna type" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	{ DEFAULT_VALUE 1;  { 0 ,"|en|rod aerial"}, { 1 ,"|en|horn aerial"}, { 2 ,"|en|dish antenna"}, { 3 ,"|en|planar antenna"}  }
} 



COMMAND read_parAntennaType { 
	SLOT 	2 ;
	INDEX 	72 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parAntennaType
		} 
	} 
} 

COMMAND write_parAntennaType { 
	SLOT 	2 ;
	INDEX 	72 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parAntennaType
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parInactiveLength {
	LABEL 	"|en|inactive length" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "mm";
					CASE 1018:   "inch";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "mm";
				}
	TYPE 	FLOAT	{
				EDIT_FORMAT "9.3f";
				DISPLAY_FORMAT "9.3f";
				MIN_VALUE
				SELECT (parDistanceUnit)
				{
					CASE 1010:   -5000.000;
					CASE 1018:    -196.850;
					CASE 1019:    -196.850;
					CASE 1013:   -5000.000;
					DEFAULT:     -5000.000;
				};
				MAX_VALUE
				SELECT (parDistanceUnit)
				{
					CASE 1010:   5000.000;
					CASE 1018:    196.850;
					CASE 1019:    196.850;
					CASE 1013:   5000.000;
					DEFAULT:     5000.000;
				};
				DEFAULT_VALUE 0.000;
			}
} 



COMMAND read_parInactiveLength { 
	SLOT 	2 ;
	INDEX 	73 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parInactiveLength
		} 
	} 
} 

COMMAND write_parInactiveLength { 
	SLOT 	2 ;
	INDEX 	73 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parInactiveLength
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parTotalLength {
	LABEL 	"|en|total length" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "mm";
					CASE 1018:   "inch";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "mm";
				}
	TYPE 	FLOAT	{
				EDIT_FORMAT "9.3f";
				DISPLAY_FORMAT "9.3f";
				MIN_VALUE
				SELECT (parDistanceUnit)
				{
					CASE 1010:   -5000.000;
					CASE 1018:    -196.850;
					CASE 1019:    -196.850;
					CASE 1013:   -5000.000;
					DEFAULT:     -5000.000;
				};
				MAX_VALUE
				SELECT (parDistanceUnit)
				{
					CASE 1010:   5000.000;
					CASE 1018:    196.850;
					CASE 1019:    196.850;
					CASE 1013:   5000.000;
					DEFAULT:     5000.000;
				};
				DEFAULT_VALUE 0.000;
			}
} 



COMMAND read_parTotalLength { 
	SLOT 	2 ;
	INDEX 	74 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parTotalLength
		} 
	} 
} 

COMMAND write_parTotalLength { 
	SLOT 	2 ;
	INDEX 	74 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parTotalLength
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parPositionOfReferencePulse {
	LABEL 	"|en|pos. ref. pulse" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ ;
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "mm";
					CASE 1018:   "inch";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "mm";
				}
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"8.3f" ;
		EDIT_FORMAT	"8.3f" ;
	}
} 



COMMAND read_parPositionOfReferencePulse { 
	SLOT 	2 ;
	INDEX 	79 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parPositionOfReferencePulse
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parAmplOfReferencePulse {
	LABEL 	"|en|ampl. ref. pulse" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  IF (Val015)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ ;
	CONSTANT_UNIT  "|en|dB" ;
	TYPE  INTEGER (1)  {
		DISPLAY_FORMAT	"4.1i" ;
		EDIT_FORMAT	"4.1i" ;
	}
} 



COMMAND read_parAmplOfReferencePulse { 
	SLOT 	2 ;
	INDEX 	80 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parAmplOfReferencePulse
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parPlausibilityFunction {
	LABEL 	"|en|Plausib.Function" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	{  DEFAULT_VALUE 0; { 0 ,"|en|off|de|aus|fr|inactif|es|desconectado|it|disattivato|nl|uit"}, { 1 ,"|en|on|de|an|fr|actif|es|conectado|it|attivato|nl|aan"}  }
} 



COMMAND read_parPlausibilityFunction { 
	SLOT 	2 ;
	INDEX 	108 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parPlausibilityFunction
		} 
	} 
} 

COMMAND write_parPlausibilityFunction { 
	SLOT 	2 ;
	INDEX 	108 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parPlausibilityFunction
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parMaxDeltaPlausibilityFunction {
	LABEL 	"|en|PF maximum delta" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "mm";
					CASE 1018:   "inch";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "mm";
				}
	TYPE 	FLOAT	{
				EDIT_FORMAT "9.3f";
				DISPLAY_FORMAT "9.3f";
				MIN_VALUE   0.0;
				MAX_VALUE
				SELECT (parDistanceUnit)
				{
					CASE 1010:   5000.000;
					CASE 1018:    196.850;
					CASE 1019:    196.850;
					CASE 1013:   5000.000;
					DEFAULT:     5000.000;
				};
				DEFAULT_VALUE
				SELECT (parDistanceUnit)
				{
					CASE 1010:   500.000;
					CASE 1018:    19.685;
					CASE 1019:    19.685;
					CASE 1013:   500.000;
					DEFAULT:     500.000;
				};
			}
} 



COMMAND read_parMaxDeltaPlausibilityFunction { 
	SLOT 	2 ;
	INDEX 	109 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parMaxDeltaPlausibilityFunction
		} 
	} 
} 

COMMAND write_parMaxDeltaPlausibilityFunction { 
	SLOT 	2 ;
	INDEX 	109 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parMaxDeltaPlausibilityFunction
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parUpperAreaPlausibilityFunction {
	LABEL 	"|en|PF upper area" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd003)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "mm";
					CASE 1018:   "inch";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "mm";
				}
	TYPE 	FLOAT	{
				EDIT_FORMAT "9.3f";
				DISPLAY_FORMAT "9.3f";
				MIN_VALUE   0.0;
				MAX_VALUE
				SELECT (parDistanceUnit)
				{
					CASE 1010:   5000.000;
					CASE 1018:    196.850;
					CASE 1019:    196.850;
					CASE 1013:   5000.000;
					DEFAULT:     5000.000;
				};
				DEFAULT_VALUE
				SELECT (parDistanceUnit)
				{
					CASE 1010:   350.000;
					CASE 1018:    13.780;
					CASE 1019:    13.780;
					CASE 1013:   350.000;
					DEFAULT:     350.000;
				};
			}
} 



COMMAND read_parUpperAreaPlausibilityFunction { 
	SLOT 	2 ;
	INDEX 	110 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parUpperAreaPlausibilityFunction
		} 
	} 
} 

COMMAND write_parUpperAreaPlausibilityFunction { 
	SLOT 	2 ;
	INDEX 	110 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parUpperAreaPlausibilityFunction
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parDisplayVersion {
	LABEL 	"|en|display version" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ ;
	TYPE  ASCII (32)  {
	}
} 



COMMAND read_parDisplayVersion { 
	SLOT 	2 ;
	INDEX 	112 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parDisplayVersion
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parCalculatedCycleTime {
	LABEL 	"|en|calc. cycle time" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ ;
	CONSTANT_UNIT  "|en|ms" ;
	TYPE  UNSIGNED_INTEGER (2) ;
} 



COMMAND read_parCalculatedCycleTime { 
	SLOT 	2 ;
	INDEX 	113 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parCalculatedCycleTime
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parSwVersion {
	LABEL 	"|en|sw. vers. appl." ;
	CLASS 	DYNAMIC ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ ;
	TYPE  UNSIGNED_INTEGER (2) ;
} 



COMMAND read_parSwVersion { 
	SLOT 	2 ;
	INDEX 	115 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parSwVersion
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parParamVersion {
	LABEL 	"|en|para. vers. appl" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ ;
	TYPE  UNSIGNED_INTEGER (2) ;
} 



COMMAND read_parParamVersion { 
	SLOT 	2 ;
	INDEX 	116 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parParamVersion
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parErrorStateOfAlgorithm {
	LABEL 	"|en|err. state alg." ;
	CLASS 	DYNAMIC ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ ;
	TYPE  UNSIGNED_INTEGER (4) ;
} 



COMMAND read_parErrorStateOfAlgorithm { 
	SLOT 	2 ;
	INDEX 	141 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parErrorStateOfAlgorithm
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parStateOfAlgorithm {
	LABEL 	"|en|state algorithm" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ ;
	TYPE  UNSIGNED_INTEGER (4) ;
} 



COMMAND read_parStateOfAlgorithm { 
	SLOT 	2 ;
	INDEX 	142 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parStateOfAlgorithm
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parReset {
	LABEL 	"|en|reset|de|Ruecksetzen|fr|Remise  zero|es|Ruecksetzen|it|reset|nl|reset" ;
	HELP 	"|en|for reset codesee manual|de|Zur Codeeingabesiehe Betriebsanl.|fr|pour code r..z.voir mise en serv.|es|cdigo de borradover manual|it|per codice resetvedi manuale|nl|voor resetcodezie handboek" ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE  UNSIGNED_INTEGER (2)  {
		DISPLAY_FORMAT	"5.1u" ;
		EDIT_FORMAT	"5.1u" ;
		MIN_VALUE 	0 ;
		MAX_VALUE	65535 ;
		DEFAULT_VALUE	0 ;
	}
} 



COMMAND read_parReset { 
	SLOT 	1 ;
	INDEX 	231 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parReset
		} 
	} 
} 

COMMAND write_parReset { 
	SLOT 	1 ;
	INDEX 	231 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parReset
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parDaaIndex1 {
	LABEL 	"|en|Debug index 1" ;
	CLASS 	IF  (parOperationCode == 33123)
    {
        INPUT;
    }
    ELSE
    {
        COMPUTATION & DYNAMIC;
    } ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd008)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE  UNSIGNED_INTEGER (1)  {
		DISPLAY_FORMAT	"3.1u" ;
		EDIT_FORMAT	"3.1u" ;
		MIN_VALUE 	0 ;
		MAX_VALUE	255 ;
		DEFAULT_VALUE	0 ;
	}
} 



COMMAND read_parDaaIndex1 { 
	SLOT 	2 ;
	INDEX 	135 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parDaaIndex1
		} 
	} 
} 

COMMAND write_parDaaIndex1 { 
	SLOT 	2 ;
	INDEX 	135 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parDaaIndex1
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parDaaIndex2 {
	LABEL 	"|en|Debug index 2" ;
	CLASS 	IF  (Hnd008)
    {
        INPUT;
    }
    ELSE
    {
        COMPUTATION & DYNAMIC;
    } ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd008)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE  UNSIGNED_INTEGER (1)  {
		DISPLAY_FORMAT	"3.1u" ;
		EDIT_FORMAT	"3,1u" ;
		MIN_VALUE 	0 ;
		MAX_VALUE	255 ;
		DEFAULT_VALUE	0 ;
	}
} 



COMMAND read_parDaaIndex2 { 
	SLOT 	2 ;
	INDEX 	136 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parDaaIndex2
		} 
	} 
} 

COMMAND write_parDaaIndex2 { 
	SLOT 	2 ;
	INDEX 	136 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parDaaIndex2
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parDaaRdWrValue {
	LABEL 	"|en|Debug value" ;
	CLASS 	IF  (Hnd008)
    {
        INPUT;
    }
    ELSE
    {
        COMPUTATION & DYNAMIC;
    } ; 
	VALIDITY  IF (Val012)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd008)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"10.1f" ;
		EDIT_FORMAT	"10.1f" ;
		MIN_VALUE 	-9999999.0 ;
		MAX_VALUE	9999999.0 ;
		DEFAULT_VALUE	0 ;
	}
} 



COMMAND read_parDaaRdWrValue { 
	SLOT 	2 ;
	INDEX 	137 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parDaaRdWrValue
		} 
	} 
} 

COMMAND write_parDaaRdWrValue { 
	SLOT 	2 ;
	INDEX 	137 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parDaaRdWrValue
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parMaxAbs {
	LABEL 	" " ;
	CLASS 	LOCAL ; 
	HANDLING  READ & WRITE ;
	TYPE  UNSIGNED_INTEGER (1)  {
		DEFAULT_VALUE	0 ;
		INITIAL_VALUE	0 ;
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parReadDevice {
	LABEL 	" " ;
	CLASS 	LOCAL ; 
	HANDLING  READ & WRITE ;
	TYPE  UNSIGNED_INTEGER (1)  {
		DEFAULT_VALUE	0 ;
		INITIAL_VALUE	0 ;
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  MEASVAL_LOWER_LIMIT {
	LABEL 	" " ;
	CLASS 	LOCAL ; 
	VALIDITY  TRUE ;
	HANDLING  READ ;
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"7.3f" ;
		EDIT_FORMAT	"7.3f" ;
		DEFAULT_VALUE	0.0 ;
		INITIAL_VALUE	0.0 ;
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  MEASVAL_UPPER_LIMIT {
	LABEL 	" " ;
	CLASS 	LOCAL ; 
	VALIDITY  TRUE ;
	HANDLING  READ ;
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"7.3f" ;
		EDIT_FORMAT	"7.3f" ;
		DEFAULT_VALUE	100.0 ;
		INITIAL_VALUE	100.0 ;
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  MEASLEV_LOWER_LIMIT {
	LABEL 	" " ;
	CLASS 	LOCAL ; 
	VALIDITY  TRUE ;
	HANDLING  READ ;
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"7.3f" ;
		EDIT_FORMAT	"7.3f" ;
		DEFAULT_VALUE	0.0 ;
		INITIAL_VALUE	0.0 ;
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  MEASLEV_UPPER_LIMIT {
	LABEL 	" " ;
	CLASS 	LOCAL ; 
	VALIDITY  TRUE ;
	HANDLING  READ ;
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"7.3f" ;
		EDIT_FORMAT	"7.3f" ;
		DEFAULT_VALUE	100.0 ;
		INITIAL_VALUE	100.0 ;
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  MEASDIS_LOWER_LIMIT {
	LABEL 	" " ;
	CLASS 	LOCAL ; 
	VALIDITY  TRUE ;
	HANDLING  READ ;
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"7.3f" ;
		EDIT_FORMAT	"7.3f" ;
		DEFAULT_VALUE	0.0 ;
		INITIAL_VALUE	0.0 ;
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  MEASDIS_UPPER_LIMIT {
	LABEL 	" " ;
	CLASS 	LOCAL ; 
	VALIDITY  TRUE ;
	HANDLING  READ ;
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"7.3f" ;
		EDIT_FORMAT	"7.3f" ;
		DEFAULT_VALUE	100.0 ;
		INITIAL_VALUE	100.0 ;
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  ECHQUAL_LOWER_LIMIT {
	LABEL 	" " ;
	CLASS 	LOCAL ; 
	VALIDITY  TRUE ;
	HANDLING  READ ;
	CONSTANT_UNIT  "|en|mV|de|mV|fr|mV|it|mV" ;
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"7.3f" ;
		EDIT_FORMAT	"7.3f" ;
		DEFAULT_VALUE	0.0 ;
		INITIAL_VALUE	0.0 ;
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  ECHQUAL_UPPER_LIMIT {
	LABEL 	" " ;
	CLASS 	LOCAL ; 
	VALIDITY  TRUE ;
	HANDLING  READ ;
	CONSTANT_UNIT  "|en|mV|de|mV|fr|mV|it|mV" ;
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"7.3f" ;
		EDIT_FORMAT	"7.3f" ;
		DEFAULT_VALUE	100.0 ;
		INITIAL_VALUE	100.0 ;
	}
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  trans1_blk_reserve {
	LABEL 	[blk_reserved] ;
	HELP 	[blk_reserved_help] ;
	CLASS 	CONTAINED ; 
	HANDLING  READ ;
	TYPE  UNSIGNED_INTEGER(1) ;
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  trans1_blk_object {
	LABEL 	[blk_block_object] ;
	HELP 	[blk_block_object_help] ;
	CLASS 	CONTAINED ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED(1)	{
		{	3,	[blk_block_object_TRANSDUCER]		}
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  trans1_blk_parent_class {
	LABEL 	[blk_parent_class] ;
	HELP 	[trans_blk_parent_class_help] ;
	CLASS 	CONTAINED ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED(1)	{
		DEFAULT_VALUE	240;
		{	240,	[trans_blk_parent_class_LEVEL]		}
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  trans1_blk_class {
	LABEL 	[blk_class] ;
	HELP 	[trans_blk_class_help] ;
	CLASS 	CONTAINED ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED(1)	{
		DEFAULT_VALUE	252;
		{	1,		[trans_lev_blk_class_HYDRO]	},
		{	2,		[trans_lev_blk_class_ECHO]	},
		{	250,	[not_used] 					},
		{	251,	[none]						},
		{	252,	[unknown]					},
		{	253,	[special]					}
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  trans1_blk_dd_reference {
	LABEL 	[blk_dd_reference] ;
	HELP 	[blk_dd_reference_help] ;
	CLASS 	CONTAINED ; 
	HANDLING  READ ;
	TYPE  UNSIGNED_INTEGER (4) ;
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  trans1_blk_dd_rev {
	LABEL 	[blk_dd_rev] ;
	HELP 	[blk_dd_rev_help] ;
	CLASS 	CONTAINED ; 
	HANDLING  READ ;
	TYPE  UNSIGNED_INTEGER(2) ;
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  trans1_blk_profile {
	LABEL 	[blk_profile] ;
	HELP 	[blk_profile_help] ;
	CLASS 	CONTAINED ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED (2)	{
		{ 0x4001,	[blk_profile_PA_COMPACT_A]	},
		{ 0x4002,	[blk_profile_PA_COMPACT_B]	},
		{ 0x4081,	[blk_profile_PA_SIMPLE_A]	},
		{ 0x4082,	[blk_profile_PA_SIMPLE_B]	}
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  trans1_blk_profile_rev {
	LABEL 	[blk_profile_rev] ;
	HELP 	[blk_profile_rev_help] ;
	CLASS 	CONTAINED ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED (2)	{
		DEFAULT_VALUE	0x025F;
		{	0x025A,	"2.90"	},
		{	0x025B,	"2.91"	},
		{	0x025C,	"2.92"	},
		{	0x025D,	"2.93"	},
		{	0x025E,	"2.94"	},
		{	0x025F,	"2.95"	},
		{	0x0260,	"2.96"	},
		{	0x0261,	"2.97"	},
		{	0x0262,	"2.98"	},
		{	0x0263,	"2.99"	},
		{	0x0300,	"3.0"	}
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  trans1_blk_execution_time {
	LABEL 	[blk_execution_time] ;
	HELP 	[blk_execution_time_help] ;
	CLASS 	CONTAINED ; 
	HANDLING  READ ;
	TYPE  UNSIGNED_INTEGER (1) ;
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  trans1_blk_num_parameters {
	LABEL 	[blk_num_parameters] ;
	HELP 	[blk_num_parameters_help] ;
	CLASS 	CONTAINED ; 
	HANDLING  READ ;
	TYPE  UNSIGNED_INTEGER (2) ;
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  trans1_blk_index_view_1 {
	LABEL 	[blk_index_view_1] ;
	HELP 	[blk_index_view_1_help] ;
	CLASS 	CONTAINED ; 
	HANDLING  READ ;
	TYPE  UNSIGNED_INTEGER (2) ;
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  trans1_blk_num_view_lists {
	LABEL 	[blk_num_view_lists] ;
	HELP 	[blk_num_view_lists_help] ;
	CLASS 	CONTAINED ; 
	HANDLING  READ ;
	TYPE  UNSIGNED_INTEGER (1) ;
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  trans1_st_rev {
	LABEL 	[st_rev] ;
	HELP 	[st_rev_help] ;
	CLASS 	CONTAINED ; 
	HANDLING  READ ;
	TYPE  UNSIGNED_INTEGER (2)  {
		DEFAULT_VALUE	0 ;
	}
} 



COMMAND read_trans1_st_rev { 
	BLOCK 	transducer_block_1 ;
	INDEX 	1 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			trans1_st_rev
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  trans1_tag_desc {
	LABEL 	[tag_desc] ;
	HELP 	[tag_desc_help] ;
	CLASS 	CONTAINED ; 
	HANDLING  READ & WRITE ;
	TYPE  ASCII (32) ;
} 



COMMAND read_trans1_tag_desc { 
	BLOCK 	transducer_block_1 ;
	INDEX 	2 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			trans1_tag_desc
		} 
	} 
} 

COMMAND write_trans1_tag_desc { 
	BLOCK 	transducer_block_1 ;
	INDEX 	2 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			trans1_tag_desc
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  trans1_strategy {
	LABEL 	[strategy] ;
	HELP 	[strategy_help] ;
	CLASS 	CONTAINED ; 
	HANDLING  READ & WRITE ;
	TYPE  UNSIGNED_INTEGER (2)  {
		DEFAULT_VALUE	0 ;
	}
} 



COMMAND read_trans1_strategy { 
	BLOCK 	transducer_block_1 ;
	INDEX 	3 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			trans1_strategy
		} 
	} 
} 

COMMAND write_trans1_strategy { 
	BLOCK 	transducer_block_1 ;
	INDEX 	3 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			trans1_strategy
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  trans1_alert_key {
	LABEL 	[alert_key] ;
	HELP 	[alert_key_help] ;
	CLASS 	CONTAINED ; 
	HANDLING  READ & WRITE ;
	TYPE  UNSIGNED_INTEGER (1)  {
		DEFAULT_VALUE	0 ;
	}
} 



COMMAND read_trans1_alert_key { 
	BLOCK 	transducer_block_1 ;
	INDEX 	4 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			trans1_alert_key
		} 
	} 
} 

COMMAND write_trans1_alert_key { 
	BLOCK 	transducer_block_1 ;
	INDEX 	4 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			trans1_alert_key
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  trans1_target_mode {
	LABEL 	[target_mode] ;
	HELP 	[target_mode_help] ;
	CLASS 	CONTAINED ; 
	HANDLING  READ & WRITE ;
	TYPE 	ENUMERATED (1)	{
		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x20,	[mode_LO]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}

	}
} 



COMMAND read_trans1_target_mode { 
	BLOCK 	transducer_block_1 ;
	INDEX 	5 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			trans1_target_mode
		} 
	} 
} 

COMMAND write_trans1_target_mode { 
	BLOCK 	transducer_block_1 ;
	INDEX 	5 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			trans1_target_mode
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  trans1_actual_mode {
	LABEL 	[actual_mode] ;
	HELP 	[actual_mode_help] ;
	CLASS 	CONTAINED & DYNAMIC ; 
	HANDLING  READ ;
	TYPE 	BIT_ENUMERATED (1)	{
		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x20,	[mode_LO]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}

	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  trans1_permitted_mode {
	LABEL 	[permitted_mode] ;
	HELP 	[permitted_mode_help] ;
	CLASS 	CONTAINED ; 
	HANDLING  READ ;
	TYPE 	BIT_ENUMERATED (1)	{
		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x20,	[mode_LO]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  trans1_normal_mode {
	LABEL 	[normal_mode] ;
	HELP 	[normal_mode_help] ;
	CLASS 	CONTAINED ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED (1)	{
		{	0x02,	[mode_RCAS]				},
		{	0x08,	[mode_AUTO]				},
		{	0x10,	[mode_MAN]				},
		{	0x20,	[mode_LO]				},
		{	0x80,	[mode_OUT_OF_SERVICE]	}
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  trans1_current_state_alarm_sum {
	LABEL 	[current_state_alarm_sum] ;
	HELP 	[current_state_alarm_sum_help] ;
	CLASS 	CONTAINED & DYNAMIC ; 
	HANDLING  READ ;
	TYPE 	BIT_ENUMERATED (2)	{
		DEFAULT_VALUE	0x0000;
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  trans1_unacknowledged_state_alarm_sum {
	LABEL 	[unacknowledged_state_alarm_sum] ;
	HELP 	[unacknowledged_state_alarm_sum_help] ;
	CLASS 	CONTAINED & DYNAMIC ; 
	HANDLING  READ ;
	TYPE 	BIT_ENUMERATED (2)	{
		DEFAULT_VALUE	0x0000;
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  trans1_unreported_state_alarm_sum {
	LABEL 	[unreported_state_alarm_sum] ;
	HELP 	[unreported_state_alarm_sum_help] ;
	CLASS 	CONTAINED & DYNAMIC ; 
	HANDLING  READ ;
	TYPE 	BIT_ENUMERATED (2)	{
		DEFAULT_VALUE	0x0000;
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  trans1_disabled_state_alarm_sum {
	LABEL 	[disabled_state_alarm_sum] ;
	HELP 	[disabled_state_alarm_sum_help] ;
	CLASS 	CONTAINED & DYNAMIC ; 
	HANDLING  READ ;
	TYPE 	BIT_ENUMERATED (2)	{
		DEFAULT_VALUE	0x0000;
		{	0x0000,	[limit_state_NO_ALARM]	},
		{	0x8000,	[limit_state_ST_REV]	}
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 


COMMAND read_trans1_mode { 
	BLOCK 	transducer_block_1 ;
	INDEX 	6 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			trans1_actual_mode, trans1_permitted_mode, trans1_normal_mode
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 


COMMAND read_trans1_blk { 
	BLOCK 	transducer_block_1 ;
	INDEX 	0 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			trans1_blk_reserve, trans1_blk_object, trans1_blk_parent_class, trans1_blk_class, 
trans1_blk_dd_reference, trans1_blk_dd_rev, trans1_blk_profile, trans1_blk_profile_rev,
trans1_blk_execution_time, trans1_blk_num_parameters, trans1_blk_index_view_1, trans1_blk_num_view_lists
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 


COMMAND read_trans1_alarm { 
	BLOCK 	transducer_block_1 ;
	INDEX 	7 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			trans1_current_state_alarm_sum, trans1_unacknowledged_state_alarm_sum, trans1_unreported_state_alarm_sum, trans1_disabled_state_alarm_sum
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  DummySetUnitToBus {
	LABEL 	"|en|set unit to bus|de|Setze Einh. Out" ;
	CLASS 	LOCAL ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED	        {
                DEFAULT_VALUE 0;
                {       0,      [EnumSetUnitToBus] }
        }
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  TitleDiagnosticsReset {
	LABEL 	[LabTitleDiagnosticsReset] ;
	CLASS 	LOCAL ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED	        {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleDiagnosticsReset] }
        }
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  TitleBasicSetup {
	LABEL 	[LabTitleBasicSetup] ;
	CLASS 	LOCAL ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED	        {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleBasicSetup] }
        }
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  TitleSafetySettings {
	LABEL 	[LabTitleSafetySettings] ;
	CLASS 	LOCAL ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED	        {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleSafetySettings] }
        }
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  TitleLinearisation {
	LABEL 	[LabTitleLinearisation] ;
	CLASS 	LOCAL ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED	        {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleLinearisation] }
        }
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  TitleExtendedCalibration {
	LABEL 	[LabTitleExtendedCalibration] ;
	CLASS 	LOCAL ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED	        {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleExtendedCalibration] }
        }
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  TitleProfibusParameter {
	LABEL 	[LabTitleProfibusParameters] ;
	CLASS 	LOCAL ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED	        {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleProfibusParameters] }
        }
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  TitleDisplay {
	LABEL 	[LabTitleDisplay] ;
	CLASS 	LOCAL ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED	        {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleDisplay] }
        }
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  TitleDiagnostics {
	LABEL 	[LabTitleDiagnostics] ;
	CLASS 	LOCAL ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED	        {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleDiagnostics] }
        }
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  TitleSystemParameter {
	LABEL 	[LabTitleSystemParameter] ;
	CLASS 	LOCAL ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED	        {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleSystemParameter] }
        }
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  phys_software_rev {
	LABEL 	[phys_software_revision] ;
	HELP 	[phys_software_revision_help] ;
	CLASS 	CONTAINED ; 
	HANDLING  READ ;
	TYPE  ASCII  {
		DEFAULT_VALUE	"01.01.0x" ;
	}
	POST_READ_ACTIONS  { 
		PostReadPhys_software_rev
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  phys_hardware_rev {
	LABEL 	[phys_hardware_revision] ;
	HELP 	[phys_hardware_revision_help] ;
	CLASS 	CONTAINED ; 
	HANDLING  READ ;
	TYPE  ASCII  {
		DEFAULT_VALUE	"1.0" ;
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  func1_AI_alarm_hys {
	LABEL 	[limit_hysteresis] ;
	HELP 	[limit_hysteresis_help] ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd011)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE  FLOAT  {
		DISPLAY_FORMAT	DEF_DISPLAY_FORMAT_FUNC1_AI(func1_AI_alarm_hys)
	 ;
		MIN_VALUE 	0  ;
		DEFAULT_VALUE	0.5000 ;
	}
	POST_EDIT_ACTIONS  { 
		method_check_func1_AI_alarm_hys
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  func1_AI_pv_upper_range_value {
	LABEL 	[func_pv_scale_upper_value] ;
	HELP 	[func_pv_scale_upper_value_help] ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd011)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE  FLOAT  {
		DEFAULT_VALUE	100 ;
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  func1_AI_out_upper_range_value {
	LABEL 	[func_upper_value] ;
	HELP 	[func_out_scale_upper_value_help] ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd011)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE  FLOAT  {
		DEFAULT_VALUE	100 ;
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parBarLowerRange {
	LABEL 	"Lower range" ;
	CLASS 	LOCAL ; 
	TYPE  FLOAT  {
		DEFAULT_VALUE	0.0 ;
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  preOperationCode {
	LABEL 	"|en|unlock parameter|de|Freigabecode|fr|code operation|es|Freigabecode|it|Modo operativo|nl|startcode" ;
	CLASS 	LOCAL ; 
	HANDLING  IF (Hnd012)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE  UNSIGNED_INTEGER (2)  {
		DISPLAY_FORMAT	"5.1u" ;
		EDIT_FORMAT	"5.1u" ;
		MIN_VALUE 	0 ;
		MAX_VALUE	33300 ;
		DEFAULT_VALUE	2457 ;
		INITIAL_VALUE	2457 ;
	}
	POST_EDIT_ACTIONS  { 
		preOperationCodeModified
	}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parShowAccess {
	LABEL 	"|en|Access rights|de|Zugriff|fr|Droits d'accs" ;
	CLASS 	LOCAL ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED	{  
	DEFAULT_VALUE   4; 
	INITIAL_VALUE   4; 
	{ 0, "|en|Locked|de|Verriegelt|fr|Verrouill"},
	{ 2 ,"|en|Service (View only)|de|Service (nur Ansicht)|fr|Service (Consultation)"}, 
	{ 3 ,"|en|Service|de|Service|fr|Service"},
	{ 4, "|en|Customer|de|Kunde|fr|Client"},
	{ 5, "|en|WHG|de|WHG|fr|WHG"},
	{ 6, "|en|Debug unlock|de|Debug unlock|fr|Debug unlock"},
	{ 7, "|en|Hard lock|de|Hard lock|fr|Hard lock"}
}

} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  TitleOperationCode {
	LABEL 	[LabTitleOperationCode] ;
	CLASS 	LOCAL ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED	        {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleOperationCode] }
        }
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parWriteLocking {
	LABEL 	[phys_write_locking] ;
	HELP 	[phys_write_locking_help] ;
	CLASS 	LOCAL ; 
	TYPE 	ENUMERATED	{  DEFAULT_VALUE   0; 
	{ 0, "|en|On|de|Ein|fr|On"},
	{ 1 ,"|en|Off|de|Aus|fr|Off"}
}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parSoftwareVersion {
	LABEL 	"Software revision" ;
	CLASS 	LOCAL ; 
	HANDLING  READ ;
	TYPE 	ENUMERATED	{  DEFAULT_VALUE   0; 
	{ 0, "Unknown"},
	{ 1, "V01.01.XX"},
	{ 2, "V01.02.XX"}
}
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parAntennaExtensionLength {
	LABEL 	"|en|antenna extens.|de|Antenn. verlng" ;
	HELP 	"|en|length FAR10 - for FMR230 only|de|Lnge FAR10 - nur fr FMR230" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val013)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "m";
					CASE 1018:   "ft";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "m";
				}
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"5.3f" ;
		EDIT_FORMAT	"5.3f" ;
		MIN_VALUE 	0 ;
		MAX_VALUE	SELECT (parDistanceUnit)
{
	CASE 1010: 5.0;
	CASE 1018: 16.404;
	CASE 1019: 866.142;
	CASE 1013: 5000.0;
	DEFAULT: 5.0;
}
		DEFAULT_VALUE	0 ;
		INITIAL_VALUE	0 ;
	}
} 



COMMAND read_parAntennaExtensionLength { 
	SLOT 	1 ;
	INDEX 	247 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parAntennaExtensionLength
		} 
	} 
} 

COMMAND write_parAntennaExtensionLength { 
	SLOT 	1 ;
	INDEX 	247 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parAntennaExtensionLength
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parMaxEchoSN {
	LABEL 	"|en|max.ampl.o.FAC" ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val013)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ ;
	CONSTANT_UNIT  "|en|dB" ;
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"3.0f" ;
		EDIT_FORMAT	"3.0f" ;
		DEFAULT_VALUE	0 ;
	}
} 



COMMAND read_parMaxEchoSN { 
	SLOT 	2 ;
	INDEX 	53 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parMaxEchoSN
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parEditRangeMaxSampleDist {
	LABEL 	"|en|max sample dist." ;
	CLASS 	CONTAINED ; 
	VALIDITY  IF (Val013)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ ;
	CONSTANT_UNIT  SELECT (parDistanceUnit)
				{
					CASE 1010:   "m";
					CASE 1018:   "ft";
					CASE 1019:   "inch";
					CASE 1013:   "mm";
					DEFAULT:  "m";
				}
	TYPE  FLOAT  {
		DISPLAY_FORMAT	"5.3f" ;
		EDIT_FORMAT	"5.3f" ;
	}
} 



COMMAND read_parEditRangeMaxSampleDist { 
	SLOT 	2 ;
	INDEX 	79 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parEditRangeMaxSampleDist
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE  parAmplOfReferencePulse02 {
	LABEL 	"|en|ampl. ref. pulse" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  IF (Val016)
				{ TRUE; }
			ELSE
				{ FALSE; }
	HANDLING  READ ;
	CONSTANT_UNIT  "|en|dB" ;
	TYPE  INTEGER (1)  {
		DISPLAY_FORMAT	"4.1i" ;
		EDIT_FORMAT	"4.1i" ;
	}
} 



COMMAND read_parAmplOfReferencePulse02 { 
	SLOT 	2 ;
	INDEX 	71 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parAmplOfReferencePulse02
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 


/* mnuTblMaintenance */
MENU   Menu_Main_Maintenance {
	LABEL 	[main_menu] ;
	ITEMS { 
		Menu_File,
		Menu_S_Device,
		Menu_S_View,
		Menu_S_Options,
		Menu_Help
	} 
}

MENU   Table_Main_Maintenance {
	LABEL 	"Micropilot M" ;
	ITEMS { 
		EH_S_Matrix,
		Tab_s_PA_Profil
	} 
}


/* mnuTblSpecsMenuMicropilotM */
MENU   Menu_Main_Specialist {
	LABEL 	[main_menu] ;
	ITEMS { 
		Menu_File,
		Menu_S_Device,
		Menu_S_View,
		Menu_S_Options,
		Menu_Help
	} 
}

MENU   Menu_S_Device {
	LABEL 	[menu_Device] ;
	ITEMS { 
		std_NodeAddress,
		SEPARATOR,
		std_LoadinDevice,
		std_LoadinPC,
		SEPARATOR,
		OnlineDialog_Simulation,
		OnlineDialog_Reset,
		OnlineDialog_SetUnitToBus,
		SEPARATOR,
		OnlineDialog_Adjust_BasicSetup,
		OnlineDialog_Adjust_SafetySettings,
		OnlineDialog_Adjust_Linearisation,
		OnlineDialog_Adjust_ExtendedCalibration,
		OnlineDialog_Adjust_ProfibusParam,
		OnlineDialog_Adjust_Display,
		OnlineDialog_Adjust_Diagnostics,
		OnlineDialog_Adjust_SystemParam
		IF (Val012) {
			OnlineDialog_Adjust_Service
		}
		SEPARATOR,
		OnlineDialog_write_locking
	} 
}

MENU   OnlineDialog_Simulation {
	LABEL 	[Online_Simulation] ;
	ITEMS { 
		Page_simulation_input_func1,
		Page_simulation_output_func1,
		Page_Simulation
	} 
}

MENU   Page_Simulation {
	LABEL 	[Online_Simulation_1_3] ;
	ITEMS { 
		parSimulation,
		parSimulationValueLevel,
		parSimulationValueVolume
	} 
}

MENU   OnlineDialog_Reset {
	LABEL 	[Online_Reset] ;
	ITEMS { 
		Page_Reset_1_1
	} 
}

MENU   Page_Reset_1_1 {
	LABEL 	[Online_Reset_1_1] ;
	ITEMS { 
		parReset
	} 
}

MENU   OnlineDialog_SetUnitToBus {
	LABEL 	[Online_SetUnitToBus] ;
	ITEMS { 
		Page_SetUnitToBus_1_1
	} 
}

MENU   Page_SetUnitToBus_1_1 {
	LABEL 	[Online_SetUnitToBus] ;
	ITEMS { 
		setUnitToBus
	} 
}

MENU   OnlineDialog_Adjust_BasicSetup {
	LABEL 	[Online_Adjust_BasicSetup] ;
	ITEMS { 
		page_Basic_Setup_1_4,
		page_Basic_Setup_2_4,
		page_Basic_Setup_3_4,
		page_Basic_Setup_4_4
	} 
}

MENU   page_Basic_Setup_1_4 {
	LABEL 	[Online_Adjust_BasicSetup_1_4] ;
	ITEMS { 
		parProtSoftVersionString,
		parTagNumber,
		parDeviceName,
		parOrderCode
	} 
}

MENU   page_Basic_Setup_2_4 {
	LABEL 	[Online_Adjust_BasicSetup_2_4] ;
	ITEMS { 
		parTankShape,
		parDielectricConstant,
		parProcessCondition,
		parTubeDiameter
	} 
}

MENU   page_Basic_Setup_3_4 {
	LABEL 	[Online_Adjust_BasicSetup_3_4] ;
	ITEMS { 
		parEmptyCalibration,
		parFullCalibration
	} 
}

MENU   page_Basic_Setup_4_4 {
	LABEL 	[Online_Adjust_BasicSetup_4_4] ;
	ITEMS { 
		parMeasuredDistance,
		parCheckDistance,
		parSuppressionDistance,
		parStartMappingRecord,
		parActualError
	} 
}

MENU   OnlineDialog_Adjust_SafetySettings {
	LABEL 	[Online_Adjust_SafetySettings] ;
	ITEMS { 
		page_Safety_Settings_1_4,
		page_Safety_Settings_2_4,
		page_Safety_Settings_3_4,
		page_Safety_Settings_4_4
	} 
}

MENU   page_Safety_Settings_1_4 {
	LABEL 	[Online_Adjust_SafetySettings_1_4] ;
	ITEMS { 
		parOutputOnAlarm
	} 
}

MENU   page_Safety_Settings_2_4 {
	LABEL 	[Online_Adjust_SafetySettings_2_4] ;
	ITEMS { 
		parReactionLostEcho,
		parRampInPercentPerMin,
		parDelayTimeOnLostEcho
	} 
}

MENU   page_Safety_Settings_3_4 {
	LABEL 	[Online_Adjust_SafetySettings_3_4] ;
	ITEMS { 
		parInSafetyDistance,
		parLevelWithinSafetyDistance,
		parAcknowledgeAlarm
	} 
}

MENU   page_Safety_Settings_4_4 {
	LABEL 	[Online_Adjust_SafetySettings_4_4] ;
	ITEMS { 
		parOperationMode
	} 
}

MENU   OnlineDialog_Adjust_Linearisation {
	LABEL 	[Online_Adjust_Linearisation] ;
	ITEMS { 
		page_Linearisation_1_3,
		page_Linearisation_2_3,
		page_Linearisation_3_3
	} 
}

MENU   page_Linearisation_1_3 {
	LABEL 	[Online_Adjust_Linearisation_1_3] ;
	ITEMS { 
		parLevelUllageMode,
		parLinearisation
	} 
}

MENU   page_Linearisation_2_3 {
	LABEL 	[Online_Adjust_Linearisation_2_3] ;
	ITEMS { 
		parCylinderVessel,
		parCustomerUnit,
		parMaxVolume,
		parTableNumber,
		parInputLevelManual,
		parInputLevelHalfAutomatic,
		parInputVolume
	} 
}

MENU   page_Linearisation_3_3 {
	LABEL 	[Online_Adjust_Linearisation_3_3] ;
	ITEMS { 
		parLinearisation,
		parActualError
	} 
}

MENU   OnlineDialog_Adjust_ExtendedCalibration {
	LABEL 	[Online_Adjust_ExtendedCalibration] ;
	ITEMS { 
		page_Extended_Calibration_1_3,
		page_Extended_Calibration_2_3,
		page_Extended_Calibration_3_3
	} 
}

MENU   page_Extended_Calibration_1_3 {
	LABEL 	[Online_Adjust_ExtendedCalibration_1_3] ;
	ITEMS { 
		parMeasuredDistance,
		parCheckDistance,
		parSuppressionDistance,
		parStartMappingRecord,
		parActualError
	} 
}

MENU   page_Extended_Calibration_2_3 {
	LABEL 	[Online_Adjust_ExtendedCalibration_2_3] ;
	ITEMS { 
		parPresMapRange,
		parCustTankMap
	} 
}

MENU   page_Extended_Calibration_3_3 {
	LABEL 	[Online_Adjust_ExtendedCalibration_3_3] ;
	ITEMS { 
		phys_software_rev(HIDDEN),
		parEchoQuality,
		parOffsetOfMeasuredDistance,
		parOutputDamping,
		parBlockingDistance,
		parAntennaExtensionLength
	} 
}

MENU   OnlineDialog_Adjust_ProfibusParam {
	LABEL 	[Online_Adjust_ProfibusParam] ;
	ITEMS { 
		page_Profibus_Param_1_3,
		page_Profibus_Param_2_3,
		page_Profibus_Param_3_3
	} 
}

MENU   page_Profibus_Param_1_3 {
	LABEL 	[Online_Adjust_ProfibusParam_1_3] ;
	ITEMS { 
		parPADeviceBusAddress,
		parPAIdentNumberSelector
	} 
}

MENU   page_Profibus_Param_2_3 {
	LABEL 	[Online_Adjust_ProfibusParam_2_3] ;
	ITEMS { 
		parPAAIOutValue,
		parPAAIOutStatus,
		parPA2ndCyclicValue,
		parPASelectMainValue
	} 
}

MENU   page_Profibus_Param_3_3 {
	LABEL 	[Online_Adjust_ProfibusParam_3_3] ;
	ITEMS { 
		parSimulation,
		parSimulationValueLevel,
		parSimulationValueVolume
	} 
}

MENU   OnlineDialog_Adjust_Display {
	LABEL 	[Online_Adjust_Display] ;
	ITEMS { 
		page_Display_1_1
	} 
}

MENU   page_Display_1_1 {
	LABEL 	[Online_Adjust_Display_1_1] ;
	ITEMS { 
		parLanguage,
		parBackToHome,
		parFormatDisplay_ft,
		parNoOfDecimals,
		parSeparationCharacter
	} 
}

MENU   OnlineDialog_Adjust_Diagnostics {
	LABEL 	[Online_Adjust_Diagnostics] ;
	ITEMS { 
		page_Diagnostics_1_2,
		page_Diagnostics_2_2
	} 
}

MENU   page_Diagnostics_1_2 {
	LABEL 	[Online_Adjust_Diagnostics_1_2] ;
	ITEMS { 
		parActualError,
		parLastError,
		parClearLastError,
		TitleDiagnosticsReset(READ_ONLY),
		parOperationCode
	} 
}

MENU   page_Diagnostics_2_2 {
	LABEL 	[Online_Adjust_Diagnostics_2_2] ;
	ITEMS { 
		parMeasuredLevel,
		parApplicationParameter
	} 
}

MENU   OnlineDialog_Adjust_SystemParam {
	LABEL 	[Online_Adjust_SystemParam] ;
	ITEMS { 
		page_System_Param_1_1
	} 
}

MENU   page_System_Param_1_1 {
	LABEL 	[Online_Adjust_SystemParam_1_1] ;
	ITEMS { 
		parTagNumber,
		parPAProfileRevision,
		parProtSoftVersionString,
		parSerialNumber,
		parDistanceUnit
	} 
}

MENU   OnlineDialog_Adjust_Service {
	LABEL 	"Service" ;
	ITEMS { 
		page_Service_1_11,
		page_Service_2_11,
		page_Service_3_11,
		page_Service_4_11,
		page_Service_5_11,
		page_Service_6_11,
		page_Service_7_11,
		page_Service_8_11,
		page_Service_9_11,
		page_Service_10_11,
		page_Service_11_11
	} 
}

MENU   page_Service_1_11 {
	LABEL 	"Info" ;
	ITEMS { 
		parCurrentAmplitude,
		parAmplitudeOverSuppression,
		parAmplitudeOverFAC,
		parUnfilteredDistance,
		parCalcEdgeParameter,
		parCurrentFirstEchoFactor,
		parDeviceName,
		parOrderCode
	} 
}

MENU   page_Service_2_11 {
	LABEL 	"Distance" ;
	ITEMS { 
		parMamFilterLength,
		parMamFilterBorder,
		parLowPassFilter,
		parHystereseWidth,
		parEchoLostRampUp,
		parEchoLostRampDown,
		parUnfilteredDistanceRaw
	} 
}

MENU   page_Service_3_11 {
	LABEL 	"Envelope" ;
	ITEMS { 
		parHKStatistik,
		parFilterBreite,
		parEnvelopeEnergy
	} 
}

MENU   page_Service_4_11 {
	LABEL 	"Mapping" ;
	ITEMS { 
		parMappingAdder,
		parMappingWidth,
		parMappingAverage,
		parFactoryTdt,
		parFacAdder,
		parFACWidth,
		parRangeFactoryMap,
		parFactoryMappingValid,
		parCustomerMappingValid
	} 
}

MENU   page_Service_5_11 {
	LABEL 	"Edge" ;
	ITEMS { 
		parEdgeDetectionMode,
		parEdgeParameter,
		parCalcEdgeParameter
	} 
}

MENU   page_Service_6_11 {
	LABEL 	"First Echo" ;
	ITEMS { 
		phys_software_rev(HIDDEN),
		parFirstEchoFactor,
		parFefThreshold,
		parFefNearFactor,
		parFefDistanceNear,
		parFefDistanceFar,
		parFefEdge,
		parMaxEchoSN,
		parCurrentFirstEchoFactor
	} 
}

MENU   page_Service_7_11 {
	LABEL 	"Tank Bottom" ;
	ITEMS { 
		parDishBottomDetection,
		parAmplLevelBottomDetection,
		parMinLevelBottomDetection,
		parLevelSpeed
	} 
}

MENU   page_Service_8_11 {
	LABEL 	"Module" ;
	ITEMS { 
		parHfModul,
		parZeroDistance
	} 
}

MENU   page_Service_9_11 {
	LABEL 	"Antenna Table" ;
	ITEMS { 
		phys_software_rev(HIDDEN),
		parAntennaType,
		parInactiveLength,
		parTotalLength,
		parAbsMaxMessDist,
		parPositionOfReferencePulse,
		parAmplOfReferencePulse,
		parAmplOfReferencePulse02,
		parEditRangeMaxSampleDist
	} 
}

MENU   page_Service_10_11 {
	LABEL 	"System 1" ;
	ITEMS { 
		parPlausibilityFunction,
		parMaxDeltaPlausibilityFunction,
		parUpperAreaPlausibilityFunction,
		parCalculatedCycleTime,
		parDisplayVersion,
		parSwVersion,
		parParamVersion
	} 
}

MENU   page_Service_11_11 {
	LABEL 	"Debug" ;
	ITEMS { 
		parDaaIndex1,
		parDaaIndex2,
		parDaaRdWrValue,
		parErrorStateOfAlgorithm
	} 
}

MENU   OnlineDialog_write_locking {
	LABEL 	[phys_write_locking] ;
	ITEMS { 
		page_phys_write_locking_user
	} 
}

MENU   page_phys_write_locking_user {
	LABEL 	[phys_write_locking_user] ;
	ITEMS { 
		parShowAccess,
		parOperationCode,
		parWriteLocking(READ_ONLY),
		method_set
	} 
}

MENU   Menu_S_View {
	LABEL 	[menu_View] ;
	ITEMS { 
		OnlineWindow_display,
        OnlineWindow_yt,
		OnlineWindow_S_alarm_func1,
		OnlineWindow_diagnosis,
		SEPARATOR,
		std_Funktionsleiste,
		std_Statuszeile,
		SEPARATOR,
		std_Update
	} 
}

MENU   OnlineWindow_display {
	LABEL 	[menu_dialog_display] ;
	ITEMS { 
		Page_display_measure,
		Page_display_func1,
		Page_display_value
	} 
}

MENU   Page_display_measure {
	LABEL 	[menu_dialog_display_measure] ;
	ITEMS { 
		IF (Val014) {
			BarVal_measuredValue
		}
		group_1
	} 
}

MENU   BarVal_measuredValue {
	LABEL 	"|en|measured value|de|Messwert|fr|Valeur de mesure|es|Messwert|it|Valore di misura|nl|gemeten waarde" ;
	ITEMS { 
		parMeasuredValue,
		parBarLowerRange,
		parMaxVolume
	} 
}

MENU   group_1 {
	LABEL 	"" ;
	ITEMS { 
		Val_parMeasuredValue,
		Val_parMeasuredDistance,
		Val_parMeasuredLevel,
		SEPARATOR,
		Val_parEchoQuality,
		Val_parActualError
	} 
}

MENU   Val_parMeasuredValue {
	LABEL 	"|en|measured value|de|Messwert|fr|Valeur de mesure|es|Messwert|it|Valore di misura|nl|gemeten waarde" ;
	ITEMS { 
		parMeasuredValue
	} 
}

MENU   Val_parMeasuredDistance {
	LABEL 	"|en|measured dist.|de|gemessene Dist.|fr|distance mesuree|es|gemessene Dist.|it|Distanza mis.|nl|meetafstand" ;
	ITEMS { 
		parMeasuredDistance
	} 
}

MENU   Val_parMeasuredLevel {
	LABEL 	"|en|measured level|de|gemess. Fuellst.|fr|niveau mesure|es|gemess. Fuellst.|it|Livello mis.|nl|gemeten niveau" ;
	ITEMS { 
		parMeasuredLevel
	} 
}

MENU   Val_parEchoQuality {
	LABEL 	"|en|echo quality|de|Echoqualitaet|fr|Qualite echo|es|Echoqualitaet|it|Qualit eco|nl|echokwaliteit" ;
	ITEMS { 
		parEchoQuality
	} 
}

MENU   Val_parActualError {
	LABEL 	"|en|present error|de|aktueller Fehler|fr|defaut actuel|es|aktueller Fehler|it|errore attuale|nl|actuele fout" ;
	ITEMS { 
		parActualError
	} 
}

MENU   Page_display_value {
	LABEL 	"display value" ;
	ITEMS { 
		Val_parPADisplayValue
	} 
}

MENU   Val_parPADisplayValue {
	LABEL 	"display value" ;
	ITEMS { 
		parPADisplayValue
	} 
}

MENU   OnlineWindow_diagnosis {
	LABEL 	[menu_dialog_diagnosis] ;
	ITEMS { 
		Page_diagnosis_general,
		Page_diagnosis_phys_block,
		Page_diagnosis_func1
	} 
}

MENU   Page_diagnosis_general {
	LABEL 	[menu_dialog_general] ;
	ITEMS { 
		parTagNumber,
		phys_device_man_id,
		phys_device_id,
		phys_device_ser_num,
		phys_software_rev,
		phys_hardware_rev,
		phys_install_date,
		phys_diagnosis
	} 
}

MENU   Page_diagnosis_phys_block {
	LABEL 	[blk_block_object_PHYSICAL] ;
	ITEMS { 
		phys_blk_object,
		phys_blk_parent_class,
		phys_blk_class,
		phys_blk_dd_reference,
		phys_blk_dd_rev,
		phys_blk_profile,
		phys_blk_profile_rev,
		phys_st_rev,
		phys_actual_mode
	} 
}


/* mnuTblMainMenuMicropilotM */
MENU   Table_Main_Specialist {
	LABEL 	DEFAULT_VALUE_phys_device_id ;
	ITEMS { 
		EH_S_Matrix
		IF (Hnd011) {
			Tab_s_PA_Profil
		}
		IF (!(Hnd011)) {
			Tab_s_PA_Profil_RO
		}
	} 
}

MENU   EH_S_Matrix {
	LABEL 	[menu_table_EH_Std_Matrix] ;
	ITEMS { 
		var_basic_setup,
		var_safety_settings,
		var_linearisation,
		var_extended_calibration,
		var_profibus_parameter,
		var_display,
		var_diagnostics,
		var_system_parameter
		IF (Val012) {
			var_service
		}
	} 
}

MENU   var_basic_setup {
	LABEL 	[Online_Adjust_BasicSetup] ;
	ITEMS { 
		TitleBasicSetup(READ_ONLY),
		parMeasuredValue,
		parTankShape,
		parDielectricConstant,
		parProcessCondition,
		parEmptyCalibration,
		parFullCalibration,
		parTubeDiameter
	} 
}

MENU   var_safety_settings {
	LABEL 	[Online_Adjust_SafetySettings] ;
	ITEMS { 
		TitleSafetySettings(READ_ONLY),
		parOutputOnAlarm,
		parReactionLostEcho,
		parRampInPercentPerMin,
		parDelayTimeOnLostEcho,
		parInSafetyDistance,
		parLevelWithinSafetyDistance,
		parAcknowledgeAlarm,
		parOperationMode(READ_ONLY)
	} 
}

MENU   var_linearisation {
	LABEL 	[Online_Adjust_Linearisation] ;
	ITEMS { 
		TitleLinearisation(READ_ONLY),
		parLevelUllageMode(READ_ONLY),
		parLinearisation(READ_ONLY),
		parCustomerUnit(READ_ONLY),
		parTableNumber(READ_ONLY),
		parInputLevelManual(READ_ONLY),
		parInputLevelHalfAutomatic(READ_ONLY),
		parInputVolume(READ_ONLY),
		parMaxVolume(READ_ONLY),
		parCylinderVessel(READ_ONLY)
	} 
}

MENU   var_extended_calibration {
	LABEL 	[Online_Adjust_ExtendedCalibration] ;
	ITEMS { 
		phys_software_rev(HIDDEN),
		TitleExtendedCalibration(READ_ONLY),
		parCheckDistance(READ_ONLY),
		parSuppressionDistance(READ_ONLY),
		parStartMappingRecord(READ_ONLY),
		parPresMapRange(READ_ONLY),
		parCustTankMap(READ_ONLY),
		parEchoQuality(READ_ONLY),
		parOffsetOfMeasuredDistance,
		parOutputDamping,
		parBlockingDistance,
		parAntennaExtensionLength
	} 
}

MENU   var_profibus_parameter {
	LABEL 	[Online_Adjust_ProfibusParam] ;
	ITEMS { 
		TitleProfibusParameter(READ_ONLY),
		parPADeviceBusAddress,
		parPAIdentNumberSelector,
		DummySetUnitToBus,
		parPAAIOutValue,
		parPAAIOutStatus,
		parSimulation(READ_ONLY),
		parSimulationValueLevel(READ_ONLY),
		parSimulationValueVolume(READ_ONLY),
		parPA2ndCyclicValue,
		parPASelectMainValue,
		parPADisplayValue
	} 
}

MENU   var_display {
	LABEL 	[Online_Adjust_Display] ;
	ITEMS { 
		TitleDisplay(READ_ONLY),
		parLanguage,
		parBackToHome,
		parFormatDisplay_ft,
		parNoOfDecimals,
		parSeparationCharacter
	} 
}

MENU   var_diagnostics {
	LABEL 	[Online_Adjust_Diagnostics] ;
	ITEMS { 
		TitleDiagnostics(READ_ONLY),
		parActualError(READ_ONLY),
		parLastError(READ_ONLY),
		parClearLastError,
		TitleDiagnosticsReset(READ_ONLY),
		parShowAccess,
		parOperationCode(READ_ONLY),
		parMeasuredDistance(READ_ONLY),
		parMeasuredLevel(READ_ONLY),
		parApplicationParameter(READ_ONLY)
	} 
}

MENU   var_system_parameter {
	LABEL 	[Online_Adjust_SystemParam] ;
	ITEMS { 
		TitleSystemParameter(READ_ONLY),
		collectionTag.parTagMPM,
		parPAProfileRevision,
		parProtSoftVersionString,
		parSerialNumber(READ_ONLY),
		parDistanceUnit
	} 
}

MENU   var_service {
	LABEL 	"Service" ;
	ITEMS { 
		pardService0,
		pardService1,
		pardService2,
		pardService3,
		pardService4,
		pardService5,
		pardService6,
		pardService7,
		pardService8,
		pardService12,
		pardService15
	} 
}

MENU   pardService0 {
	LABEL 	"Info" ;
	ITEMS { 
		parCurrentAmplitude(READ_ONLY),
		parAmplitudeOverSuppression(READ_ONLY),
		parAmplitudeOverFAC(READ_ONLY),
		parUnfilteredDistance(READ_ONLY),
		parCalcEdgeParameter(READ_ONLY),
		parCurrentFirstEchoFactor(READ_ONLY),
		parDeviceName(READ_ONLY),
		parOrderCode(READ_ONLY)
	} 
}

MENU   pardService1 {
	LABEL 	"Distance" ;
	ITEMS { 
		parMamFilterLength(READ_ONLY),
		parMamFilterBorder(READ_ONLY),
		parLowPassFilter(READ_ONLY),
		parHystereseWidth(READ_ONLY),
		parEchoLostRampUp(READ_ONLY),
		parEchoLostRampDown(READ_ONLY),
		parUnfilteredDistanceRaw(READ_ONLY)
	} 
}

MENU   pardService2 {
	LABEL 	"Envelope" ;
	ITEMS { 
		parHKStatistik(READ_ONLY),
		parFilterBreite(READ_ONLY),
		parEnvelopeEnergy(READ_ONLY)
	} 
}

MENU   pardService3 {
	LABEL 	"Mapping" ;
	ITEMS { 
		parMappingAdder(READ_ONLY),
		parMappingWidth(READ_ONLY),
		parMappingAverage(READ_ONLY),
		parFactoryTdt(READ_ONLY),
		parFacAdder(READ_ONLY),
		parFACWidth(READ_ONLY),
		parRangeFactoryMap(READ_ONLY),
		parFactoryMappingValid(READ_ONLY),
		parCustomerMappingValid(READ_ONLY)
	} 
}

MENU   pardService4 {
	LABEL 	"Edge" ;
	ITEMS { 
		parEdgeDetectionMode(READ_ONLY),
		parEdgeParameter(READ_ONLY),
		parCalcEdgeParameter(READ_ONLY)
	} 
}

MENU   pardService5 {
	LABEL 	"First Echo" ;
	ITEMS { 
		phys_software_rev(HIDDEN),
		parFirstEchoFactor(READ_ONLY),
		parFefThreshold(READ_ONLY),
		parFefNearFactor(READ_ONLY),
		parFefDistanceNear(READ_ONLY),
		parFefDistanceFar(READ_ONLY),
		parFefEdge(READ_ONLY),
		parMaxEchoSN(READ_ONLY),
		parCurrentFirstEchoFactor(READ_ONLY)
	} 
}

MENU   pardService6 {
	LABEL 	"Tank Bottom" ;
	ITEMS { 
		parDishBottomDetection(READ_ONLY),
		parAmplLevelBottomDetection(READ_ONLY),
		parMinLevelBottomDetection(READ_ONLY),
		parLevelSpeed(READ_ONLY)
	} 
}

MENU   pardService7 {
	LABEL 	"Module" ;
	ITEMS { 
		parHfModul(READ_ONLY),
		parZeroDistance(READ_ONLY)
	} 
}

MENU   pardService8 {
	LABEL 	"Antenna Table" ;
	ITEMS { 
		phys_software_rev(HIDDEN),
		parAntennaType(READ_ONLY),
		parInactiveLength(READ_ONLY),
		parTotalLength(READ_ONLY),
		parAbsMaxMessDist(READ_ONLY),
		parPositionOfReferencePulse(READ_ONLY),
		parAmplOfReferencePulse(READ_ONLY),
		parAmplOfReferencePulse02(READ_ONLY),
		parEditRangeMaxSampleDist(READ_ONLY)
	} 
}

MENU   pardService12 {
	LABEL 	"System 1" ;
	ITEMS { 
		parPlausibilityFunction(READ_ONLY),
		parMaxDeltaPlausibilityFunction(READ_ONLY),
		parUpperAreaPlausibilityFunction(READ_ONLY),
		parCalculatedCycleTime(READ_ONLY),
		parDisplayVersion(READ_ONLY),
		parSwVersion(READ_ONLY),
		parParamVersion(READ_ONLY)
	} 
}

MENU   pardService15 {
	LABEL 	"Debug" ;
	ITEMS { 
		parDaaIndex1(READ_ONLY),
		parDaaIndex2(READ_ONLY),
		parDaaRdWrValue(READ_ONLY),
		parErrorStateOfAlgorithm,
		parStateOfAlgorithm
	} 
}

MENU   Tab_s_PA_Profil {
	LABEL 	[menu_table_sensor_level_radar] ;
	ITEMS { 
		Tab_s_ident,
		Tab_s_input,
		Tab_s_output,
		Tab_s_certificates
	} 
}

MENU   Tab_s_ident {
	LABEL 	[menu_ident] ;
	ITEMS { 
		Tab_s_ident_opunit,
		Tab_s_ident_device
	} 
}

MENU   Tab_s_ident_opunit {
	LABEL 	[menu_ident_opunit] ;
	ITEMS { 
		phys_tag_desc,
		phys_descriptor,
		phys_message
	} 
}

MENU   Tab_s_ident_device {
	LABEL 	[menu_ident_device] ;
	ITEMS { 
		phys_device_man_id,
		phys_device_ser_num,
		phys_software_rev,
		phys_hardware_rev,
		phys_install_date,
		phys_st_rev
	} 
}

MENU   Tab_s_input {
	LABEL 	[menu_input] ;
	ITEMS { 
		Tab_s_input_measwindow
	} 
}

MENU   Tab_s_input_measwindow {
	LABEL 	[menu_input_measwindow] ;
	ITEMS { 
		func1_AI_pv_lower_range_value,
		func1_AI_pv_upper_range_value
	} 
}

MENU   Tab_s_output {
	LABEL 	[menu_output] ;
	ITEMS { 
		Tab_s_output_signal,
		Tab_s_output_limits,
		Tab_s_func1_FSafe
	} 
}

MENU   Tab_s_output_signal {
	LABEL 	[menu_output_signal] ;
	ITEMS { 
		func1_AI_out_lower_range_value,
		func1_AI_out_upper_range_value,
		func1_AI_out_unit,
		func1_AI_pv_ftime,
		func1_AI_out_decimal_point
	} 
}

MENU   Tab_s_output_limits {
	LABEL 	[menu_output_limits] ;
	ITEMS { 
		func1_AI_lo_lo_lim,
		func1_AI_lo_lim,
		func1_AI_hi_lim,
		func1_AI_hi_hi_lim,
		func1_AI_alarm_hys
	} 
}

MENU   Tab_s_func1_FSafe {
	LABEL 	[menu_fail_safe] ;
	ITEMS { 
		func1_AI_FSafeType,
		func1_AI_FSafeValue
	} 
}

MENU   Tab_s_certificates {
	LABEL 	[menu_certificates] ;
	ITEMS { 
		phys_device_certification
	} 
}

MENU   Tab_s_PA_Profil_RO {
	LABEL 	[menu_table_sensor_level_radar] ;
	ITEMS { 
		Tab_s_ident_RO,
		Tab_s_input_RO,
		Tab_s_output_RO,
		Tab_s_certificates_RO
	} 
}

MENU   Tab_s_ident_RO {
	LABEL 	[menu_ident] ;
	ITEMS { 
		Tab_s_ident_opunit_RO,
		Tab_s_ident_device_RO
	} 
}

MENU   Tab_s_ident_opunit_RO {
	LABEL 	[menu_ident_opunit] ;
	ITEMS { 
		phys_tag_desc,
		phys_descriptor(READ_ONLY),
		phys_message(READ_ONLY)
	} 
}

MENU   Tab_s_ident_device_RO {
	LABEL 	[menu_ident_device] ;
	ITEMS { 
		phys_device_man_id(READ_ONLY),
		phys_device_ser_num(READ_ONLY),
		phys_software_rev(READ_ONLY),
		phys_hardware_rev(READ_ONLY),
		phys_install_date(READ_ONLY),
		phys_st_rev(READ_ONLY)
	} 
}

MENU   Tab_s_input_RO {
	LABEL 	[menu_input] ;
	ITEMS { 
		Tab_s_input_measwindow_RO
	} 
}

MENU   Tab_s_input_measwindow_RO {
	LABEL 	[menu_input_measwindow] ;
	ITEMS { 
		func1_AI_pv_lower_range_value(READ_ONLY),
		func1_AI_pv_upper_range_value(READ_ONLY)
	} 
}

MENU   Tab_s_output_RO {
	LABEL 	[menu_output] ;
	ITEMS { 
		Tab_s_output_signal_RO,
		Tab_s_output_limits_RO,
		Tab_s_func1_FSafe_RO
	} 
}

MENU   Tab_s_output_signal_RO {
	LABEL 	[menu_output_signal] ;
	ITEMS { 
		func1_AI_out_lower_range_value(READ_ONLY),
		func1_AI_out_upper_range_value(READ_ONLY),
		func1_AI_out_unit(READ_ONLY),
		func1_AI_pv_ftime(READ_ONLY),
		func1_AI_out_decimal_point(READ_ONLY)
	} 
}

MENU   Tab_s_output_limits_RO {
	LABEL 	[menu_output_limits] ;
	ITEMS { 
		func1_AI_lo_lo_lim(READ_ONLY),
		func1_AI_lo_lim(READ_ONLY),
		func1_AI_hi_lim(READ_ONLY),
		func1_AI_hi_hi_lim(READ_ONLY),
		func1_AI_alarm_hys(READ_ONLY)
	} 
}

MENU   Tab_s_func1_FSafe_RO {
	LABEL 	[menu_fail_safe] ;
	ITEMS { 
		func1_AI_FSafeType(READ_ONLY),
		func1_AI_FSafeValue(READ_ONLY)
	} 
}

MENU   Tab_s_certificates_RO {
	LABEL 	[menu_certificates] ;
	ITEMS { 
		phys_device_certification(READ_ONLY)
	} 
}


