/******************************************************************************/
/*                                                                            */
/*  Copyright (C)        Endress+Hauser (2008). All Rights Reserved           */
/*                                                                            */
/*  Product:             SIMATIC PDM                                          */
/*                                                                            */
/*  Device:              ECHO LEVEL DEVICE Micropilot M for PA                */
/*  Function:            Device Description Implementation for FMR2xx         */
/*  Description:         Dictionary for PA Device Descriptions                */
/*                                                                            */
/*  Manufacturer:        Endress & Hauser GmbH & Co.                          */
/*   *                   Hauptstrasse 1                                       */
/*   *                   D-79689 Maulburg                                     */
/*   *                   Tel:07622/28-0                                       */
/*                                                                            */
/*  Author:              Daniel Ritter                                        */
/*  		             Yves Dschle	                                      */
/*                                                                            */
/*  Revision:            2.0                                                  */
/*  Date:                10.04.08                                             */
/*                                                                            */
/*                                                                            */
/******************************************************************************/

/*______________________________________________________________________*/
/*----------------------DEVICE & REVISION CODES-------------------------*/

#define SERVICEUNLOCKCODE  33300
#define CUSTOMERUNLOCKCODE  2457
#define CUSTOMERLOCK IF (parOperationCode==CUL) {READ & WRITE;} ELSE {READ;}

#define  CHECK_PROFILE_REV      0x300
#define  CHECK_DEVICE_TYPE "FMR 25X"
#define  CHECK_SOFTWARE_VERSION "01.05.00"
#define  CHECK_SOFTWARE_VERSION01 "01.05.00"
#define FUNC1_TITLE "|en|Function Block 1 - Analog Input 1|de|Funktions Block 1 - Analog Eingang 1"
#define DEFAULT_VALUE_phys_device_id "FMR24x-25x"

 #define ENABLE_IDENTCHECK


#define YT1_VALUE func1_AI_out_value
#define YT1_LABEL YT1_VALUE.LABEL
#define YT1_LRV   MEASVAR_LOWER_LIMIT
#define YT1_URV   MEASVAR_UPPER_LIMIT


/*** Includes ********************************************************************/

#include "\SI_FileM.inc"
#include "\SI_HlpM.inc"
#include "\SI_OptM.inc"
#include "\SI_DevM.inc"
#include "\SI_ViewM.inc"
#include "\SI_YT.inc"


#define  Hnd011	((parOperationCode == 33300)||\
			(parOperationCode == 33123)||\
			(parOperationCode == 2457))
#define ENUM_RBIdentNumberSelector { 0, PA_profile_specific } { 1, PA_manufacturer_specific }
#define PAIdentNumberSelectorLabel "|en|ident number|de|Ident Number|es|numero ident.|fr|Numero ident.|it|Numero ident."
#define PADeviceBusAddressLabel "|en|instrument addr|de|Gerteadresse"
#define PAProfileRevisionLabel "|en|profile version|de|Profile Version"
#define grpProfibusDPGroupLabel "Profibus PA|de|Profibus PA"
#define var_basic_setupParamGroup "|en|basic setup|de|Grundabgleich|fr|Etalonnage base|es|ajustes bsicos|it|Calibrazione base|nl|basisinstelling";
#define var_safety_settingsParamGroup "|en|safety settings|de|Sicherheitseinst.|fr|Rglages scurit|es|ajustes de fb.|it|imp. sicurezza|nl|veiligheidsinst.";
#define var_linearisationParamGroup "|en|linearisation|de|Linearisierung|fr|Linarisation|es|linearizacin|it|Linearizzazione|nl|linearisering";
#define var_extended_calibrationParamGroup "|en|extended calibr.|de|erweit. Abgleich|fr|Etalonnage tendu|es|calib. extendida|it|Altre calibr.|nl|uitgebreide kalib";
#define var_outputParamGroup "|en|output|de|Ausgang|fr|Sortie|es|salida|it|Uscita|nl|uitgang";
#define var_displayParamGroup "|en|display|de|Anzeige|fr|Affichage|es|visualizador|it|Indicatore|nl|display";
#define var_diagnosticsParamGroup "|en|diagnostics|de|Diagnose|fr|Diagnostic|es|diagnsticos|it|Param. operativi|nl|diagnose";
#define var_system_parameterParamGroup "|en|system parameters|de|System Parameter|fr|Paramtre systme|es|parm sistema|it|Param. di sistema|nl|systeemparameter";
#define var_serviceParamGroup "|en|service|de|Service|fr|Service|es|servicio|it|Service|nl|service";
#define pardService0SubParamGroup "|en|info|de|Info|fr|info|es|info|it|info|nl|informatie";
#define pardService1SubParamGroup "|en|distance";
#define pardService2SubParamGroup "|en|envelope";
#define pardService3SubParamGroup "|en|mapping";
#define pardService4SubParamGroup "|en|edge";
#define pardService5SubParamGroup "|en|first echo";
#define pardService6SubParamGroup "|en|tank bottom";
#define pardService7SubParamGroup "|en|module";
#define pardService8SubParamGroup "|en|antenna table";
#define pardService9SubParamGroup "|en|algorithm 1";
#define pardService12SubParamGroup "|en|system 1";
#define pardService13SubParamGroup "|en|system 2";
#define pardService15SubParamGroup "|en|debug";
#define parErrorEnumList ENUMERATED (2) {\
{0, "|en|   |de|   |fr|   |it|     "},\
{102, "|en|A102 checksum error general reset & new calibr.required|de|A102 Prfsummenfehler Totalreset & Neu- abgl. erfordert|fr|A102 erreur somme test reset gnral nouvel talonn.|it|A102 errore check sum ripristino totale nuova calibraz.  "},\
{103, "|en|W103 initialising - please wait |de|W103 Initialisierung - bitte warten |fr|W103 initialisation en cours-attendre |it|W103 inizializzazione in corso-attendere   "},\
{106, "|en|A106 downloading please wait |de|A106 Download luft - bitte warten |fr|A106 download en cours-attendre |it|A106 download in corso-attendere   "},\
{110, "|en|A110 checksum error general reset & new calibr.required|de|A110 Prfsummenfehler Totalreset & Neu- abgl. ntig|fr|A110 erreur somme test reset gnral nouvel talonn.|it|A110 errore di check sum riprist. totale nuova calibr.  "},\
{111, "|en|A111 electronics defect  |de|A111 Elektronik defekt  |fr|A111 dfaut lectronique  |it|A111 Guasto elettron.    "},\
{113, "|en|A113 electronics defect  |de|A113 Elektronik defekt  |fr|A113 dfaut lectronique  |it|A113 Guasto elettron.    "},\
{114, "|en|A114 electronics defect  |de|A114 Elektronik defekt  |fr|A114 dfaut lectronique  |it|A114 Guasto elettron.    "},\
{115, "|en|A115 fault power supply  |de|A115 Fehler Energievers.  |fr|A115 dfaut alimentation  |it|A115 errore alimentazione    "},\
{116, "|en|A116 download error repeat download |de|A116 Downloadfehler Download wiederholen |fr|A116 erreur download rpter download |it|A116 Errore download ripetere download   "},\
{121, "|en|A121 electronics defect  |de|A121 Elektronik defekt  |fr|A121 dfaut lectronique  |it|A121 Guasto elettron.    "},\
{153, "|en|W153 initialising - please wait |de|W153 Initialisierung - bitte warten |fr|W153 initialisation en cours-attendre |it|W153 inizializzazione in corso-attendere   "},\
{155, "|en|A155 electronics defect  |de|A155 Elektronik defekt  |fr|A155 dfaut lectronique  |it|A155 Guasto elettron.    "},\
{160, "|en|A160 checksum error general reset & new calibr.required|de|A160 Prfsummenfehler Totalreset & Neu- abgl. erfordert|fr|A160 erreur somme test reset gnral nouvel talonn.|it|A160 errore check sum ripristino totale nuova calibraz.  "},\
{164, "|en|A164 electronics defect  |de|A164 Elektronik defekt  |fr|A164 dfaut lectronique  |it|A164 Guasto elettron.    "},\
{171, "|en|A171 electronics defect  |de|A171 Elektronik defekt  |fr|A171 dfaut lectronique  |it|A171 Guasto elettron.    "},\
{231, "|en|A231 sensor 1 defect check connection |de|A231 Sensor 1 defekt Prfe Verbindung |fr|A231 dfaut sonde 1 vrifier connexion |it|A231 Sens.1 guasto controll. conness.   "},\
{270, "|en|A270 custody switch undef check position |de|A270 Schalter undefiniert berprfe Position |fr|A270 commutateur indfini vrifier position |it|A270 Interr. non def. contr. posizione   "},\
{271, "|en|W271 reduced accuracy check installation |de|W271 reduz. Genauigkeit Installation prfen |fr|W271 prcision rduit vrifier installat. |it|W271 precis. ridotto controll. Installaz.   "},\
{272, "|en|A272 electronics defect amplifier |de|A272 Elektronik defekt Verstrker |fr|A272 dfaut lectron. amplificateur |it|A272 guasto elettron. amplificatore   "},\
{273, "|en|W273 reduced accuracy  |de|W273 reduz. Genauigkeit  |fr|W273 prcision rduit  |it|W273 precis. ridotto    "},\
{274, "|en|W274 reduced accuracy check pipe diameter |de|W274 reduz. Genauigkeit Prfe Rohr- durchmesser|fr|W274 prcision rduit vr. diamtre du tube|it|W274 precis. ridotto controll. diametro del tubo guida  "},\
{275, "|en|W275 electronics defect factory settings |de|W275 Elektronik defekt Werksabgleich |fr|W275 dfaut lectron. calibration usine |it|W275 dfaut lectron. calibrazione di fabbrica  "},\
{511, "|en|W511 no factory cali- bration ch1 |de|W511 kein Werksabgl. vorhanden K1 |fr|W511 pas de rglage usine disponible voie 1 |it|W511 assenza calibr. di fabbrica C1   "},\
{512, "|en|W512 recording of mapping please wait |de|W512 Aufnahme Ausblendung - warten |fr|W512 suppressionen cours attendre |it|W512 registr. mappatura in corso-attendere   "},\
{601, "|en|W601 linearisation ch1 curve not monotone |de|W601 Linearisierung K1 Kurve nicht monoton |fr|W601 linarisation voie 1 courbe non monotone |it|W601 Linearizzazione C1 curva non monotona   "},\
{611, "|en|W611 less than 2 linea- risation points for channel 1|de|W611 Linearisierungspkt. Anzahl <2 (K1) |fr|W611 linarisation voie 1 moins de 2 points |it|W611 N punti linearizz. minori di 2 (C1)   "},\
{621, "|en|W621 simulation ch. 1 on |de|W621 Simulation K1 eingeschaltet |fr|W621 simulation voie 1 active |it|W621 Simulazione C1 attiva   "},\
{641, "|en|E641 no usable echo channel 1 check calibr.|de|E641 kein auswertbares Echo K1 Abgleich prfen|fr|E641 pas d'cho valuable en voie 1 vrifier calib.|it|E641 mancanza eco per elabor. C1 controll. cali.  "},\
{651, "|en|E651 level in safety distance - risk of overspill|de|E651 Sicherheitsabst. erreicht berfllgefahr|fr|E651 distance de scurit atteinte danger dbord.|it|E651 Raggiunta distanza di sicurezza Pericolo tracim  "},\
{671, "|en|A671 linearisation ch1 not complete, not usable|de|A671 Linearisation Ch1 nicht vollstndig, unbrauchbar|fr|A671 linaristion voie incomplte, inutilisable|it|A671 linearizzaz. C1 non completa, non utilizzabile  "},\
{681, "|en|W681 current ch1 out of range |de|W681 Strom Ch1 ausserhalb des Messbereichs |fr|W681 courant voie hors gamme |it|W681 usc. corr. C1 fuori range   "}}        
#define parMeasuredValueLAH LABEL "|en|measured value|de|Messwert|fr|Valeur de mesure|es|Messwert|it|Valore di misura|nl|gemeten waarde";
#define parMediaTypeLAH LABEL "|en|media type|de|Mediumtyp|fr|Type de produit|es|Mediumtyp|it|tipo di prodotto|nl|Medium type";
#define parMediaTypeEL ENUMERATED {  { 0 ,"|en|liquid|de|Flssigkeit|fr|Liquide|es|lquido|it|liquido|nl|Vloeistof"}, { 1 ,"|en|solid|de|Schttgut|fr|Solide|es|slido|it|solido|nl|Stortgoed"}  }
#define enum_liquidity_V  0 
#define enum_solids_V  1


#define enum_dome_ceiling_V  0 
#define enum_horizontal_cyl_V  20 
#define enum_bypass_V  2 
#define enum_stilling_well_V  3 
#define enum_vertical_cyl_V  4 
#define enum_sphere_V  5
#define parDielectricConstantLAH LABEL "|en|medium property|de|Medium Eigensch.|fr|Caract. prod.|es|Medium Eigensch.|it|caratt.del prod.|nl|produktconstante";
#define parDielectricConstantEL ENUMERATED {  { 0 ,"|en|unknown|de|unbekannt|fr|Inconnu|es|desconocido|it|sconosciuto|nl|Onbekend"}, { 1 ,"|en|DC: < 1.9|de|DK: < 1.9|fr|CD: < 1.9|es|DC: < 1.9|it|DC: < 1.9|nl|DC: < 1.9"}, { 2 ,"|en|DC: 1.9 ... 4|de|DK: 1.9 ... 4|fr|CD: 1.9 ... 4|es|DC: 1.9 ... 4|it|DC: 1.9 ... 4|nl|DC: 1.9 ... 4"}, { 3 ,"|en|DC: 4 ... 10|de|DK: 4 ... 10|fr|CD: 4 ... 10|es|DC: 4 ... 10|it|DC: 4 ... 10|nl|DC: 4 ... 10"}, { 4 ,"|en|DC: > 10|de|DK: > 10|fr|CD: > 10|es|DC: > 10|it|DC: > 10|nl|DC: > 10"}  }

#define enum_unknown_V  0 
#define enum_lower_then_1P9_V  1 
#define enum_between_1P9_4_V  2 
#define enum_between_4_10_V  3 
#define enum_higher_than_10_V  4
#define parProcessConditionLAH LABEL "|en|process cond.|de|Messbedingungen|fr|Cond. process|es|Messbedingungen|it|condiz. Processo|nl|proces conditier";
#define parProcessConditionEL ENUMERATED {  { 0 ,"|en|standard|de|Standard|fr|Standard|es|estndar|it|standard|nl|standaard"}, { 1 ,"|en|calm surface|de|Oberfl. ruhig|fr|Surface calme|es|sup. calmada|it|superf.calma|nl|rustig"}, { 2 ,"|en|turb. surface|de|Oberfl.unruhig|fr|Surface agite|es|sup. turbul.|it|superf.turbol.|nl|onrustig"}, { 3 ,"|en|add. agitator|de|zus. Rhrwerk|fr|Agitateur|es|adic. agitador|it|supp.agitatore|nl|plus roerwerk"}, { 4 ,"|en|fast change|de|schnelle nder|fr|Variat. rapide|es|camb. rpidos|it|cambiam.veloci|nl|snelle variat."}, { 5 ,"|en|test:no filter|de|Test:Filt. aus|fr|Test:pas filt.|es|test:no filtro|it|test:no filtro|nl|test:no filter"}  }

#define enum_standard_V  0 
#define enum_calm_surface_V  1 
#define enum_turb_surface_V  2 
#define enum_agitator_V  3 
#define enum_fast_change_V  4 
#define enum_test_no_filter_V  5
#define parEmptyCalibrationLAH HELP "|en|distance process\nconn. to min. level|de|Abstand Flansch\nzu min.Fllstand|fr|Distance bride\nau niveau min.|es|dimetro interno\ncon, al nivel mnimo|it|distanza min livello\ndalla flangia|nl|afstand van de flens\ntot het min. niveau"; LABEL "|en|empty calibr.|de|Abgleich leer|fr|Etalonnage vide|es|Abgleich leer|it|calibr.di vuoto|nl|leegafregeling";
#define parFullCalibrationLAH HELP "|en|span|de|Messspanne|fr|Gamme de mesure|es|campo de medida|it|campo di misura|nl|meetbereik"; LABEL "|en|full calibr.|de|Abgleich voll|fr|Etalonnage plein|es|Abgleich voll|it|calibr.di pieno|nl|volafregeling";
#define parTubeDiameterLAH HELP "|en|inner diameter of\nbypass/stilling well|de|Innendurchmesser\nBypass/Schwallrohr|fr|Diamtre intrieur\ndu tube/by-pass|es|dimetro interno\nbypass/tubo tranq.|it|diametro interno\ndel tubo guida|nl|inwendige diam. van\nby-pass / duikpijp"; LABEL "|en|pipe diameter|de|Rohrdurchmesser|fr|Diamtre du tube|es|Rohrdurchmesser|it|diametro tubo|nl|diam. by-pass";
#define parVesselSiloLAH LABEL "|en|vessel / silo|de|Behlter / Silo|fr|Cuve / Silo|es|Behlter / Silo|it|forma serbatoio|nl|Opslag vorm";
#define parVesselSiloEL ENUMERATED {  { 0 ,"|en|unknown|de|unbekannt|fr|Inconnu|es|desconocido|it|sconosciuto|nl|Onbekend"}, { 1 ,"|en|metal silo|de|Metallsilo|fr|Silo en mtal|es|dep. metlico|it|metallico|nl|Metalen silo"}, { 2 ,"|en|concrete silo|de|Betonsilo|fr|Silo en bton|es|dep. hormign|it|in cemento|nl|Betonnen silo"}, { 3 ,"|en|bin / bunker|de|Bunker|fr|Bunker|es|tolva|it|cassa/bunker|nl|Bunker"}, { 4 ,"|en|dome|de|Dome|fr|Dme|es|techo bveda|it|tetto bombato|nl|Bol"}, { 5 ,"|en|stockpile|de|offene Halden|fr|Aire stockage|es|almac. Abierto|it|cumulo aperto|nl|Open ruimte"}, { 6 ,"|en|conveyor belt|de|Bandbelegung|fr|Tapis convoy.|es|cinta transp.|it|nastro trasp.|nl|Transport band"}  }

#define enum_unknown_V  0 
#define enum_metalsilo_V  1 
#define enum_concretesilo_V  2 
#define enum_binbunker_V  3 
#define enum_dome_V  4 
#define enum_stockpile_V  5 
#define enum_conveyorbelt_V  6
#define parDielectricConstantLAH LABEL "|en|medium property|de|Medium Eigensch.|fr|Caract. produit|es|Medium Eigensch.|it|caratt.del prod.|nl|produktconstante";
#define parDielectricConstantEL ENUMERATED {  { 0 ,"|en|unknown|de|unbekannt|fr|Inconnu|es|desconocido|it|sconosciuto|nl|Onbekend"}, { 1 ,"|en|DC:1.6 ... 1.9|de|DK:1.6 ... 1.9|fr|CD:1.6 ... 1.9|es|DC:1.6 ... 1.9|it|DC:1.6 ... 1.9|nl|DC:1.6 ... 1.9"}, { 2 ,"|en|DC:1.9 ... 2.5|de|DK:1.9 ... 2.5|fr|CD:1.9 ... 2.5|es|DC:1.9 ... 2.5|it|DC:1.9 ... 2.5|nl|DC:1.9 ... 2.5"}, { 3 ,"|en|DC:2.5 ... 4|de|DK:2.5 ... 4|fr|CD:2.5 ... 4|es|DC:2.5 ... 4|it|DC:2.5 ... 4|nl|DC:2.5 ... 4"}, { 4 ,"|en|DC:4 ... 7|de|DK:4 ... 7|fr|CD:4 ... 7|es|DC:4 ... 7|it|DC:4 ... 7|nl|DC:4 ... 7"}, { 5 ,"|en|DC: > 7|de|DK: > 7|fr|CD: > 7|es|DC: > 7|it|DC: > 7|nl|DC: > 7"}  }

#define enum_unknown_V  0 
#define enum_16_19_DK_V  1 
#define enum_19_25_DK_V  2 
#define enum_25_40_DK_V  3 
#define enum_40_70_DK_V  4 
#define enum_higher_than_7_DK_V  5
#define parProcessConditionLAH LABEL "|en|process cond.|de|Messbedingungen|fr|Cond. process|es|Messbedingungen|it|condiz. Processo|nl|proces conditier";
#define parProcessConditionEL ENUMERATED {  { 0 ,"|en|standard|de|Standard|fr|Standard|es|estndar|it|standard|nl|standaard"}, { 1 ,"|en|fast change|de|schnelle nder|fr|Variat. rapide|es|camb. rpidos|it|cambiam.veloci|nl|snelle variat."}, { 2 ,"|en|slow change|de|langsame nder|fr|Variat. lente|es|cambio lento|it|variaz lente|nl|langzame corr."}, { 3 ,"|en|test:no filter|de|Test:Filt. aus|fr|Test:pas filt.|es|test:no filtro|it|test:no filtro|nl|test:no filter"}  }

#define enum_standard_V  0 
#define enum_fast_change_V  4 
#define enum_slow_change_V  2 
#define enum_test_no_filter_V  5

#define enum_min_neg_10percent_V  1 
#define enum_max_110percent_V  0 
#define enum_hold_V  239 
#define enum_user_specific_V  253
#define parOutputAtErrorLAH LABEL "|en|output on alarm|de|Ausg. b. Alarm|fr|Sortie si alarme|es|Ausg. b. Alarm|it|Comp.in allarme|nl|uitg. bij alarm";
#define parOutputAtErrorU CONSTANT_UNIT "|en|mA";
#define parReactionLostEchoLAH LABEL "|en|outp. echo loss|de|Ausg.Echoverlust|fr|Sort. perte cho|es|Ausg.Echoverlust|it|in caso manc.eco|nl|uitg.echoverlies";
#define parReactionLostEchoEL ENUMERATED {  { 0 ,"|en|alarm|de|Alarm|fr|Alarme|es|alarma|it|allarme|nl|Alarm"}, { 239 ,"|en|hold|de|Halten|fr|Maintien|es|Mantener|it|Ultimo valore|nl|hold"}, { 2 ,"|en|ramp %/min|de|Rampe %/min|fr|Rampe %/mn|es|rampa %/min|it|rampa %/min|nl|Steilh. %/min"}  }


#define enum_alarm_V  0 
#define enum_hold_V  239 
#define enum_ramp_in_percent_per_min_V  2
#define parRampInPercentPerMinLAH LABEL "|en|ramp %span/min|de|Rampe %MB/min|fr|Rampe %GM/mn|es|Rampe %MB/min|it|rampa %campo/min|nl|steilh.span%/min";
#define parRampInPercentPerMinU CONSTANT_UNIT "|en|%/min|de|%/min|fr|%/min|es|%/min|it|%/min|nl|%/min";
#define parDelayTimeOnLostEchoLAH HELP "|en|in case of echo loss|de|Zeit bei Echoverlust|fr|si perte cho|es|en caso de prd. eco|it|se manca eco|nl|i.g.v. echoverlies"; LABEL "|en|delay time|de|Verzgerung|fr|Temporisation|es|Verzgerung|it|Tempo di ritardo|nl|vertragingstijd";
#define parDelayTimeOnLostEchoU CONSTANT_UNIT "|en|s";
#define parLevelWithinSafetyDistanceanceLAH HELP "|en|from antenna tip/\nlower edge of horn|de|ab Antennenspitze/\nHornkante|fr|de l'antenne/\ntrop basse|es|desde extremo antena\ndesde extr. trompeta|it|dall'antenna/\nbordo inf. antenna|nl|vanaf antennetip/\nonderkant hoornant."; LABEL "|en|safety distance|de|Sicherheitsabst.|fr|Dist. scurit|es|Sicherheitsabst.|it|dist. di sicur.|nl|veiligheidsafst.";
#define parInSafetyDistanceLAH LABEL "|en|in safety dist.|de|im Sicherh.abst.|fr|Dans dist.scur.|es|im Sicherh.abst.|it|in dist.di sicur|nl|op veiligh.afst.";
#define parInSafetyDistanceEL ENUMERATED {  { 0 ,"|en|alarm|de|Alarm|fr|Alarme|es|alarma|it|allarme|nl|Alarm"}, { 1 ,"|en|warning|de|Warnung|fr|Avertissement|es|aviso|it|avviso|nl|Waarschuwing"}, { 2 ,"|en|self holding|de|Selbsthaltung|fr|Maintien|es|mantener|it|autoritenuto|nl|Hold"}  }

#define enum_alarm_V  0 
#define enum_warning_V  1 
#define enum_selfholding_V  2
#define parAcknowledgeAlarmLAH LABEL "|en|ackn. alarm|de|Reset Selbsthalt|fr|Supp.auto maint.|es|Reset Selbsthalt|it|ripristina|nl|reset alarm";
#define parAcknowledgeAlarmEL ENUMERATED {  { 0 ,"|en|no|de|nein|fr|non|es|no|it|no|nl|nee"}, { 1 ,"|en|yes|de|ja|fr|oui|es|si|it|si|nl|ja"}  }

#define enum_no_V  0 
#define enum_yes_V  1
#define parOperationModeLAH LABEL "|en|overspill prot.|de|berfllsicher.|fr|Anti-Dbordement|es|berfllsicher.|it|prot. antiracim|nl|overvulbewaking";
#define parOperationModeEL ENUMERATED {  { 0 ,"|en|standard|de|Standard|fr|Standard|es|estndar|it|standard|nl|standaard"}, { 1 ,"|en|german WHG|de|WHG|fr|WHG|es|alemana WHG|it|WHG tedesco|nl|duitse WHG"}  }

#define enum_standard_V  0 
#define enum_level_overspill_V  1
#define parLevelUllageModeLAH LABEL "|en|level/ullage|de|Fllst./Restvol.|fr|Niv./Vol. rsid.|es|Fllst./Restvol.|it|livello/vol vuot|nl|niveau/restvol.";
#define parLevelUllageModeEL ENUMERATED {  { 0 ,"|en|level CU|de|Fllst. TE|fr|Volume UT|es|nivel unid us.|it|livello UI|nl|niveau T.E.."}, { 1 ,"|en|level DU|de|Fllst m/ft/in|fr|Niveau m/ft/in|es|nivel m/p/pulg|it|livel. m/ft/in|nl|niveau m/ft/in"}, { 2 ,"|en|ullage CU|de|Restvol. TE|fr|Niv.restant UT|es|unidades usu.|it|vol vuoto UI|nl|restvol. T.E."}, { 3 ,"|en|ullage DU|de|Restvo.m/ft/in|fr|Niv.rst.m/ft.|es|unida m/p/pulg|it|vol vu.m/ft/in|nl|restv. m/ft/in"}  }

#define enum_lvl_cust_unit_V  0 
#define enum_lvl_m_ft_in_V  1 
#define enum_ullage_CU_V  2 
#define enum_ullage_m_ft_in_V  3
#define parLinearisationLAH LABEL "|en|linearisation|de|Linearisierung|fr|Linarisation|es|Linearisierung|it|Linearizzazione|nl|linearisatie";
#define parLinearisationEL ENUMERATED {  { 0 ,"|en|linear|de|linear|fr|Linaire|es|lineal|it|Lineare|nl|lineair"}, { 20 ,"|en|horizontal cyl|de|zyl.liegend|fr|Cyl. horizont.|es|cilind. horiz.|it|cilind. orizz.|nl|horizont. cyl."}, { 240 ,"|en|manual|de|manuell|fr|Manuelle|es|manual|it|manuale|nl|handmatig"}, { 241 ,"|en|semi-automatic|de|halbautomat.|fr|Semi-automat.|es|semiautomatico|it|semi-auto.|nl|half-automat."}, { 1 ,"|en|table on|de|Tabelle ein|fr|Tableau actif|es|tabla on|it|tab. attivata|nl|tabel aan"}, { 242 ,"|en|clear table|de|Lsche Tabelle|fr|Effac. tableau|es|borrar tabla|it|cancella tab.|nl|tabel wissen"}  }


#define enum_linear_in_percent_V  0 
#define enum_horizontal_cyl_V  20 
#define enum_manual_V  240 
#define enum_semi_automatic_V  241 
#define enum_activate_table_V  1 
#define enum_clear_table_V  242
#define parCustomerUnitLAH LABEL "|en|customer unit|de|Kundeneinheit|fr|Unit utilisat.|es|Kundeneinheit|it|Unit di misura|nl|klanteenheid";



#define enum_percent_V 1342
#define enum_l_V 1038
#define enum_hl_V 1041
#define enum_m_3_V 1034
#define enum_dm_3_V 1035
#define enum_cm_3_V 1036
#define enum_ft_3_V 1043
#define enum_us_gal_V 1048
#define enum_i_gal_V 1049
#define enum_kg_V 1088
#define enum_t_V 1092
#define enum_lb_V 1094
#define enum_ton_V 1095
#define enum_m_V 1010
#define enum_ft_V 1018
#define enum_mm_V 1013
#define enum_none_V 1997

#define parTableNumberLAH LABEL "|en|table no.|de|Tabellen Nummer|fr|Numro tableau|es|Tabellen Nummer|it|N tabella|nl|tabel nummer";
#define parInputLevelHalfAutomaticmaticLAH LABEL "|en|input level|de|Eingabe Fllst.|fr|Entre niveau|es|Eingabe Fllst.|it|Dato livello|nl|invoer niveau";
#define parInputLevelManualLAH LABEL "|en|input level|de|Eingabe Fllst.|fr|Entre niveau|es|Eingabe Fllst.|it|Dato livello|nl|invoer niveau";
#define parInputVolumeLAH LABEL "|en|input volume|de|Eingabe Volumen|fr|entre volume|es|Eingabe Volumen|it|Dato volume|nl|invoer volume";
#define parMaxVolumeLAH LABEL "|en|max. scale|de|Endwert Messber.|fr|Gamme mes. max.|es|Endwert Messber.|it|max.valore|nl|eindw.meetbereik";
#define parCylinderVesselLAH LABEL "|en|diameter vessel|de|Zyl.-durchmesser|fr|Diamtre cuve|es|Zyl.-durchmesser|it|Diam. Serbatoio|nl|tankdiameter";
#define parSelectionLAH LABEL "|en|selection|de|Auswahl|fr|Choix|es|Auswahl|it|Selezione|nl|keuze";
#define parSelectionEL ENUMERATED {  { 0 ,"|en|common|de|Allgemein|fr|Gnral|es|general|it|general|nl|generaal"}, { 1 ,"|en|mapping|de|Ausblendung|fr|Suppression|es|mapa|it|mappatura|nl|uitwaard."}, { 2 ,"|en|extended map.|de|erweit. Ausbl.|fr|suppr. tendu|es|mapa extendida|it|altre mappa.|nl|verdere uitw."}  }

#define enum_common_V  0 
#define enum_mapping_V  1 
#define enum_extended_map_V  2
#define parCheckDistanceLAH LABEL "|en|check distance|de|Distanz prfen|fr|Vrifier dist.|es|Distanz prfen|it|Controll. dist.|nl|check afstand";
#define parCheckDistanceEL ENUMERATED {  { 0 ,"|en|distance = ok|de|Distanz = ok|fr|Distance = ok|es|distancia = ok|it|distanza = ok|nl|afstand = ok"}, { 1 ,"|en|dist.too small|de|Dist. zu klein|fr|Dis.trop petit|es|dist. muy pequ|it|dist.trop.picc|nl|afst. te klein"}, { 2 ,"|en|dist. too big|de|Dist. zu gross|fr|Dis.trop grand|es|dist.muy grand|it|dist.trop.gran|nl|afst. te groot"}, { 3 ,"|en|dist. unknown|de|Dist.unbekannt|fr|Dist. inconnue|es|dist.desconoc.|it|dist. sconosc.|nl|afst.niet  bek"}, { 241 ,"|en|manual|de|manuell|fr|Manuelle|es|manual|it|manuale|nl|handmatig"}  }


#define enum_distance_ok_V  0 
#define enum_dist_too_small_V  1 
#define enum_dist_too_big_V  2 
#define enum_dist_unknown_V  3 
#define enum_manual_V  240
#define parSuppressionDistanceLAH HELP "|en|input of\nmapping range|de|Eingabe des\nAusbl.bereiches|fr|entre plage\nde suppression|es|introducir\nrango mapeado|it|dato distanza\nfino a mappa|nl|invoer van het\nuitwaard. bereik"; LABEL "|en|range of mapping|de|Bereich Ausblend|fr|Plage suppress.|es|Bereich Ausblend|it|dist. mappa man.|nl|bereik uitwaard.";
#define parStartMappingRecordLAH LABEL "|en|start mapping|de|Starte Ausblend.|fr|Lancer mapping|es|Starte Ausblend.|it|avvio mappatura|nl|start mapping";
#define parStartMappingRecordEL ENUMERATED {  { 0 ,"|en|no|de|nein|fr|non|es|no|it|no|nl|nee"}, { 1 ,"|en|yes|de|ja|fr|oui|es|si|it|si|nl|ja"}  }

#define enum_no_V  0 
#define enum_yes_V  1
#define parPresMapRangeLAH LABEL "|en|pres. map dist.|de|akt. Ausbl.dist.|fr|Dist.suppr. act.|es|akt. Ausbl.dist.|it|dist. mappa att.|nl|act. afst. uitw.";
#define parCustTankMapLAH LABEL "|en|cust. tank map|de|Ausblendung|fr|Suppression|es|Ausblendung|it|Mappa cliente|nl|klant tank map";
#define parCustTankMapEL ENUMERATED {  { 0 ,"|en|inactive|de|inaktiv|fr|Inactif|es|inactivo|it|inattivato|nl|inactief"}, { 1 ,"|en|active|de|aktiv|fr|Actif|es|activo|it|attivato|nl|actief"}, { 2 ,"|en|delete|de|Lschen|fr|Effacer |es|borrar|it|cancella|nl|wissen"}  }

#define enum_inactive_V  0 
#define enum_active_tr_V  1 
#define enum_delete_V  2
#define parEchoQualityLAH LABEL "|en|echo quality|de|Echoqualitt|fr|Amplitude cho|es|Echoqualitt|it|Qualit eco|nl|echokwaliteit";
#define parEchoQualityU CONSTANT_UNIT "|en|dB";
#define parOffsetOfMeasuredLevelanceLAH HELP "|en|will be added to the\nmeasured level|de|wird zum gemessennen\nFllstand addiert|fr|sera additionne\nau niveau mesur|es|sera aadido\nal nivel medido|it|sara addizionata\nal livello misurato|nl|zal werd. toegevoegd\nan de gemeten waarde"; LABEL "|en|offset|de|Fllhhenkorrekt|fr|Correct. niveau|es|Fllhhenkorrekt|it|offset|nl|offset";
#define parOutputDampingLAH LABEL "|en|output damping|de|Integrationszeit|fr|Tps d'intgrat.|es|Integrationszeit|it|Tempo integraz.|nl|uitgangsdemping";
#define parOutputDampingU CONSTANT_UNIT "|en|s";
#define parBlockingDistanceLAH LABEL "|en|blocking dist.|de|Blockdistanz|fr|Distance blocage|es|Blockdistanz|it|Dist. di blocco|nl|blokafstand";
#define parCommAddressLAH LABEL "|en|commun. address|de|Kommun.Adresse|fr|Adresse commun.|es|Kommun.Adresse|it|Indirizzo strum.|nl|communicat.adres";
#define parPreamblesLAH LABEL "|en|no. of preambels|de|Prambelanzahl|fr|Nb prambules|es|Prambelanzahl|it|Introduzione|nl|aantal. inleid.";

#define enum_off_V  0 
#define enum_on_V  1

#define enum_standard_V  0 
#define enum_current_turn_down_V  1 
#define enum_fixed_current_V  2
#define parSimulationLAH LABEL "|en|simulation|de|Simulation|fr|Simulation|es|Simulation|it|simulazione|nl|simulatie";
#define parSimulationEL ENUMERATED {  { 0 ,"|en|sim. off|de|Sim. aus|fr|simul. inact.|es|sim, conectada|it|sim. disattiva|nl|sim. off"}, { 1 ,"|en|sim. level|de|Sim. Fllstand|fr|simul. Niveau|es|sim, nivel|it|sim. livello|nl|sim. level"}, { 2 ,"|en|sim. volume|de|Sim. Volumen|fr|simul. Volume|es|sim, volumen|it|sim. volume|nl|sim. volume"}}

#define enum_sim_off_V  0 
#define enum_sim_level_V  1 
#define enum_sim_volume_V  2 
#define enum_sim_current_V  3
#define parSimulationValueLevelLAH LABEL "|en|simulation value|de|Simulationswert|fr|Valeur simule|es|Simulationswert|it|Val. di simul.|nl|simulatiewaarde";
#define parSimulationValueVolumeLAH LABEL "|en|simulation value|de|Simulationswert|fr|Valeur simule|es|Simulationswert|it|Val. di simul.|nl|simulatiewaarde";
#define parCurrentOutputLAH LABEL "|en|output current|de|Ausgangsstrom|fr|Sortie courant|es|Ausgangsstrom|it|uscita corrente|nl|uitgangsstroom";
#define parCurrentOutputU CONSTANT_UNIT "|en|mA";
#define parMinMeasuredValueLAH LABEL "|en|min. meas. value|de|Min. Messwert|fr|Val. min. mesur.|es|Min. Messwert|it|min. val. misur.|nl|min. meetwaarde";
#define par4mAValueLAH LABEL "|en|4mA value|de|4mA Wert|fr|Valeur 4mA|es|4mA Wert|it|valore 4mA|nl|4mA waarde";
#define parMaxMeasuredValueLAH LABEL "|en|max. meas. value|de|Max. Messwert|fr|Val. max. mesur.|es|Max. Messwert|it|max. val. misur.|nl|max. meetwaarde";
#define par20mAValueLAH LABEL "|en|20mA value|de|20mA Wert|fr|Valeur 20mA|es|20mA Wert|it|valore 20mA|nl|20mA waarde";
#define parLanguageLAH LABEL "|en|language|de|Sprache|fr|Langue|es|Sprache|it|Lingua|nl|taal";
#define parLanguageEL ENUMERATED {  { 0 ,"|en|English"}, { 1 ,"|en|Deutsch"}, { 2 ,"|en|Franais"}, { 3 ,"|en|Espaol"}, { 4 ,"|en|Italiano"}, { 5 ,"|en|Nederlands"}, { 6 ,"|en|Japanese|de|Japanese|fr|Japanese|es|Japanese|it|Japanese|nl|Japanese"}  }

#define enum_English_V  0 
#define enum_Deutsch_V  1 
#define enum_Francais_V  2 
#define enum_Espagnol_V  3 
#define enum_Italiano_V  4 
#define enum_Nederlands_V  5 
#define enum_Katakana_V  6
#define parBackToHomeLAH LABEL "|en|back to home|de|Zur Startseite|fr|Retour affi val.|es|Zur Startseite|it|Vai a men princ|nl|Home";
#define parBackToHomeU CONSTANT_UNIT "|en|s";
#define parFormatDisplayDec16inchLAH LABEL "|en|format display|de|Anzeigeformat|fr|Format affichage|es|Anzeigeformat|it|formato display|nl|aanwijsformaat";
#define parFormatDisplayDec16inchEL ENUMERATED {  { 0 ,"|en|decimal|de|dezimal|fr|dcimal|es|decimal|it|decimale|nl|decimaal"}, { 1 ,"|en|ft-in-1/16''"}  }

#define enum_decimal_V  0 
#define enum_1_16_inch_V  1
#define parNoOfDecimalsUpTo3LAH LABEL "|en|no.of decimals|de|Nachkommast.|fr|Dcimales|es|Nachkommast.|it|decimali|nl|aantal decim.";
#define parNoOfDecimalsUpTo3EL ENUMERATED {  { 0 ,"|en|x"}, { 1 ,"|en|x.x"}, { 2 ,"|en|x.xx"}, { 3 ,"|en|x.xxx"}  }

#define enum_x_V  0 
#define enum_x_x_V  1 
#define enum_x_xx_V  2 
#define enum_x_xxx_V  3
#define parSeparationCharacterLAH LABEL "|en|sep. character|de|Trennungszeichen|fr|Signe sparation|es|Trennungszeichen|it|segni separaz.|nl|scheidingsteken";
#define parSeparationCharacterEL ENUMERATED {  { 0 ,"|en|."}, { 1 ,"|en|,"}  }

#define enum_point_V  0 
#define enum_comma_V  1
#define parDisplayTestLAH LABEL "|en|display test|de|Anzeigetest|fr|Test affichage|es|Anzeigetest|it|test display|nl|display test";
#define parDisplayTestEL ENUMERATED {  { 0 ,"|en|off|de|aus|fr|Inactif|es|desconectado|it|disattivato|nl|uit"}, { 1 ,"|en|on|de|an|fr|Actif|es|conectado|it|attivato|nl|aan"}  }

#define enum_off_V  0 
#define enum_on_V  1
#define parActualErrorLAH LABEL "|en|present error|de|aktueller Fehler|fr|Dfaut actuel|es|aktueller Fehler|it|errore attuale|nl|actuele fout";
#define parLastErrorLAH LABEL "|en|previous error|de|letzter Fehler|fr|Dernier dfaut|es|letzter Fehler|it|ultimo errore|nl|vorige fout";
#define parClearLastErrorLAH LABEL "|en|clear last error|de|Lsche let.Fehl.|fr|Eff. der. dfaut|es|Lsche let.Fehl.|it|canc.ult. err.|nl|wis laatste fout";
#define parClearLastErrorEL ENUMERATED {  { 0 ,"|en|keep|de|beibehalten|fr|Garder|es|mantener|it|mantieni|nl|houden"}, { 1 ,"|en|erase|de|lschen|fr|Effacer|es|borrar|it|cancella|nl|wissen"}  }

#define enum_keep_V  0 
#define enum_erase_V  1
#define parResetLAH HELP "|en|for reset code\nsee manual|de|Zur Codeeingabe\nsiehe Betriebsanl.|fr|pour code r..z.\nvoir mise en serv.|es|cdigo de borrado\nver manual|it|per codice reset\nvedi manuale|nl|voor resetcode\nzie handboek"; LABEL "|en|reset|de|Rcksetzen|fr|Remise  zro|es|Rcksetzen|it|reset|nl|reset";
#define parOperationCodeLAH LABEL "|en|unlock parameter|de|Freigabecode|fr|Code opration|es|Freigabecode|it|Modo operativo|nl|startcode";
#define parMeasuredDistanceLAH LABEL "|en|measured dist.|de|gemessene Dist.|fr|Distance mesure|es|gemessene Dist.|it|Distanza mis.|nl|meetafstand";
#define parMeasuredLevelLAH LABEL "|en|measured level|de|gemess. Fllst.|fr|Niveau mesur|es|gemess. Fllst.|it|Livello mis.|nl|gemeten niveau";
#define parApplicationParameterLAH LABEL "|en|application par.|de|Anwendungsparam.|fr|Para. applicat.|es|Anwendungsparam.|it|par. applicaz.|nl|toepassing par.";
#define parApplicationParameterEL ENUMERATED {  { 0 ,"|en|not modified|de|nicht gendert|fr|Non modifie|es|non modificato|it|non modificato|nl|niet verander."}, { 1 ,"|en|modified|de|gendert|fr|Modifie|es|modificato|it|modificato|nl|veranderet"}  }

#define enum_not_changed_V  0 
#define enum_changed_V  1
#define parTagNumber32LAH LABEL "|en|tag no.|de|Messstelle|fr|N Repre|es|Messstelle|it|Tag n|nl|tag nummer";
#define parProtSoftVersionStringLAH LABEL "|en|protocol+sw-no.|de|Protokoll+SW-Nr.|fr|Protoc. +nsw|es|Protokoll+SW-Nr.|it|protocol.+sw ver|nl|protoc.en SW.nr.";
#define parSerialNumberLAH LABEL "|en|serial no.|de|Seriennummer|fr|Numro de srie|es|Seriennummer|it|Num. di serie|nl|serienummer";
#define parDistanceUnit16LAH HELP "|en|unit for calculation\nof distance|de|Einheit zur Berech-\nnung der Distanz|fr|Unit pour calcul\nde distance|es|unidad de clculo\nde distancia|it|unit di calcolo \ndella distanza|nl|eenheid voor\nafstandsberekening"; LABEL "|en|distance unit|de|Lngeneinheit|fr|Unit longueur|es|Lngeneinheit|it|Unit distanza|nl|lengte-eenheid";



#define parDownloadModeLAH LABEL "|en|download mode|de|Download Mode|fr|Mode download|es|Download Mode|it|modo download|nl|download keuze";
#define parDownloadModeEL ENUMERATED {  { 0 ,"|en|parameter only|de|nur Parameter|fr|Seulem. param.|es|slo parmet.|it|solo parametro|nl|alleen param."}, { 1 ,"|en|param+cust.map|de|Param+Ausblen.|fr|Param.+ suppr.|es|par.+mapeado|it|param+map.cl.|nl|param.+select."}, { 2 ,"|en|mapping only|de|Ausblendung|fr|Suppression|es|slo mapeado|it|solo mappatura|nl|alleen select."}  }

#define enum_matrix_V  0 
#define enum_matrix_mapping_V  1 
#define enum_only_mapping_V  2
#define parAntennaExtensionLengthLAH HELP "|en|length FAR10 -\nfor FMR230 only|de|Lnge FAR10 -\nnur fr FMR230|fr|longueur FAR10 -\nuniquement FMR230|es|longitud de FAR10-\nslo para FMR230|it|lunghezza  FAR10 -\nsolo per FMR 230|nl|lengte FAR10 -\nalleen voor FMR230"; LABEL "|en|antenna extens.|de|Antenn.verlng|fr|extension anten.|es|Antenn.verlng|it|estens. Antenna|nl|antenne verleng.";
#define parServiceLevelLAH LABEL "|en|service level";
#define parCurrentAmplitudeLAH LABEL "|en|pres. amplitude";
#define parCurrentAmplitudeU CONSTANT_UNIT "|en|dB";
#define parAmplitudeOverSuppLAH LABEL "|en|ampl. over map.";
#define parAmplitudeOverSuppU CONSTANT_UNIT "|en|dB";
#define parAmplitudeOverFACLAH LABEL "|en|ampl. over FAC";
#define parAmplitudeOverFACU CONSTANT_UNIT "|en|dB";
#define parUnfilteredDistanceLAH LABEL "|en|unfilt. distance";
#define parCalcEdgeParameterLAH LABEL "|en|pres. edge param";
#define parCalcEdgeParameterU CONSTANT_UNIT "|en|dB";
#define parCurrentFirstEchoFactorLAH LABEL "|en|present FEF";
#define parCurrentFirstEchoFactorU CONSTANT_UNIT "|en|dB";
#define parDeviceNameLAH LABEL "|en|device name";
#define parOrderCodeLAH LABEL "|en|order code";
#define parMamFilterLengthLAH LABEL "|en|MAM filt. length";
#define parMamFilterBorderLAH LABEL "|en|MAM filt. border";
#define parDetectionWindowLAH LABEL "|en|detection window|de|Fensterung|fr|Fentre dtec.|es|Fensterung|it|finestra di ispz|nl|Detectie venster";
#define parDetectionWindowEL ENUMERATED {  { 0 ,"|en|off|de|aus|fr|Inactif|es|desconectado|it|disattivato|nl|uit"}, { 1 ,"|en|on|de|an|fr|Actif|es|conectado|it|attivato|nl|aan"}, { 2 ,"|en|reset|de|rcksetzen|fr|reset|es|borrar|it|reset|nl|reset"}  }

#define enum_off_V  0 
#define enum_on_V  1 
#define enum_reset_V  2
#define parFilterConstMinLAH LABEL "|en|min. low pass";
#define parFilterConstMinU CONSTANT_UNIT "|en|s";
#define parFilterConstMaxLAH LABEL "|en|max. low pass";
#define parFilterConstMaxU CONSTANT_UNIT "|en|s";
#define parInnovationFiltConstMaxLAH LABEL "|en|delta at min.";
#define parHkStatCountPosLAH LABEL "|en|env. stat. up";
#define parHkStatCountNegLAH LABEL "|en|env. stat. down";
#define parClipDistanceToEmptyLAH LABEL "|en|empty limiter";
#define parClipDistanceToEmptyEL ENUMERATED {  { 0 ,"|en|off|de|aus|fr|Inactif|es|desconectado|it|disattivato|nl|uit"}, { 1 ,"|en|on|de|an|fr|Actif|es|conectado|it|attivato|nl|aan"}  }

#define enum_off_V  0 
#define enum_on_V  1
#define parDelayTimerLAH LABEL "|en|delay timer";
#define parDelayTimerU CONSTANT_UNIT "|en|s";
#define parEchoFoundDelayLAH LABEL "|en|echo found delay";
#define parEchoFoundDelayU CONSTANT_UNIT "|en|s";
#define parEchoLostDelayLAH LABEL "|en|echo lost delay";
#define parEchoLostDelayU CONSTANT_UNIT "|en|s";
#define parJumpDelayBaseLAH LABEL "|en|min. jump delay";
#define parJumpDelayBaseU CONSTANT_UNIT "|en|s";
#define parJumpDelaySlopeLAH LABEL "|en|jump delay";
#define parJumpDelaySlopeU CONSTANT_UNIT "|en|mm/s";
#define parNoJumpWindowWithLAH LABEL "|en|echo window";
#define parWeightModeLAH LABEL "|en|FAC Mode";
#define parWeightModeEL ENUMERATED {  { 0 ,"|en|FMC"}, { 1 ,"|en|FMC rising"}, { 2 ,"|en|FAC"}, { 3 ,"|en|FAC rising"}  }

#define enum_FMC_V  0 
#define enum_FMC_rising_V  1 
#define enum_FAC_V  2 
#define enum_FAC_rising_V  3
#define parMergingEchoesLAH LABEL "|en|merging echoes";
#define parMergingEchoesEL ENUMERATED {  { 0 ,"|en|parablefit"}, { 1 ,"|en|merg. gravity"}, { 2 ,"|en|merging ratio"}, { 3 ,"|en|gravity center"}  }

#define enum_parabelfit_V  0 
#define enum_merginggravity_V  1 
#define enum_mergingratio_V  2 
#define enum_gravitycenter_V  3
#define parMergingWindowLAH LABEL "|en|merging window";
#define parMergingEchoDistLAH LABEL "|en|merg. echo dist";
#define parMergingRatioLAH LABEL "|en|merging ratio";
#define parMergingRatioU CONSTANT_UNIT "|en|%";
#define parRangeTankBottomDetectionLAH LABEL "|en|range TBD";
#define parLowPassFilterLAH LABEL "|en|low pass filter";
#define parLowPassFilterU CONSTANT_UNIT "|en|s";
#define parHystereseWidthLAH LABEL "|en|hysterese width";
#define parEchoLostRampUpLAH LABEL "|en|max. fill. speed";
#define parEchoLostRampUpU CONSTANT_UNIT "|en|mm/s";
#define parEchoLostRampDownLAH LABEL "|en|max. drain speed";
#define parEchoLostRampDownU CONSTANT_UNIT "|en|mm/s";
#define parUnfilteredDistanceRawLAH LABEL "|en|unfilt. dist.raw";
#define parFilterBreiteLAH LABEL "|en|env. smoothing";
#define parSawitzkiGolayLAH LABEL "|en|Savitzky Golay";
#define parFACRisingLAH LABEL "|en|FAC rising";
#define parFACRisingEL ENUMERATED {  { 0 ,"|en|off|de|aus|fr|Inactif|es|desconectado|it|disattivato|nl|uit"}, { 1 ,"|en|on|de|an|fr|Actif|es|conectado|it|attivato|nl|aan"}  }

#define enum_off_V  0 
#define enum_on_V  1
#define parEchoAdjustLAH LABEL "|en|echo adjust.";
#define parEchoAdjustEL ENUMERATED {  { 0 ,"|en|parablefit"}, { 1 ,"|en|gravity center"}  }

#define enum_parabelfit_V  0 
#define enum_gravitycenter_V  3
#define parGravityWindowLAH LABEL "|en|gravity window";
#define parEnvelopeEnergyLAH LABEL "|en|envel. energy";
#define parEnvelopeEnergyU CONSTANT_UNIT "|en|dB";
#define parMappingAdderLAH LABEL "|en|mapping adder";
#define parMappingAdderU CONSTANT_UNIT "|en|dB";
#define parMappingWidthLAH LABEL "|en|mapping scanrate";
#define parMappingAverageLAH LABEL "|en|mapping average";
#define parFactoryTdtLAH LABEL "|en|fact. map. valid";
#define parFactoryTdtEL ENUMERATED {  { 0 ,"|en|off|de|aus|fr|Inactif|es|desconectado|it|disattivato|nl|uit"}, { 1 ,"|en|on|de|an|fr|Actif|es|conectado|it|attivato|nl|aan"}, { 2 ,"|en|reset|de|rcksetzen|fr|reset|es|borrar|it|reset|nl|reset"}  }

#define enum_off_V  0 
#define enum_on_V  1 
#define enum_reset_V  2
#define parFacAdderLAH LABEL "|en|FAC adder";
#define parFacAdderU CONSTANT_UNIT "|en|dB";
#define parFACWidthLAH LABEL "|en|FAC scan rate";
#define parRangeFactoryMapLAH LABEL "|en|range fact. map";
#define parFactoryMappingValidLAH LABEL "|en|fact. map. valid";
#define parFactoryMappingValidEL ENUMERATED {  { 0 ,"|en|not active"}, { 1 ,"|en|active"}  }

#define enum_not_active_V  0 
#define enum_active_V  1
#define parCustomerMappingValidLAH LABEL "|en|cust. map. valid";
#define parCustomerMappingValidEL ENUMERATED {  { 0 ,"|en|not active"}, { 1 ,"|en|active"}  }

#define enum_not_active_V  0 
#define enum_active_V  1
#define parEdgeDetectionModeLAH LABEL "|en|edge detec. mode";
#define parEdgeDetectionModeEL ENUMERATED {  { 0 ,"|en|front of echo"}, { 1 ,"|en|behind echo"}, { 2 ,"|en|middle of echo"}  }

#define enum_echo_front_V  0 
#define enum_echo_back_V  1 
#define enum_echo_median_V  2
#define parEdgeParameterLAH LABEL "|en|edge parameter";
#define parEdgeParameterU CONSTANT_UNIT "|en|dB";
#define parFirstEchoFactorLAH LABEL "|en|first echo fact.";
#define parFirstEchoFactorU CONSTANT_UNIT "|en|dB";
#define parFefThresholdLAH LABEL "|en|FEF threshold";
#define parFefThresholdU CONSTANT_UNIT "|en|dB";
#define parFefNearFactorLAH LABEL "|en|FEF at near dist";
#define parFefNearFactorU CONSTANT_UNIT "|en|dB";
#define parFefDistanceNearLAH LABEL "|en|FEF dist. near";
#define parFefDistanceFarLAH LABEL "|en|FEF dist. far";
#define parFefEdgeLAH LABEL "|en|FEF edge";
#define parFefEdgeU CONSTANT_UNIT "|en|dB";
#define parMaxEchoSNLAH LABEL "|en|max.ampl.o.FAC";
#define parMaxEchoSNU CONSTANT_UNIT "|en|dB";
#define parDishBottomDetLAH LABEL "|en|Tank Bottom Det.";
#define parDishBottomDetEL ENUMERATED {  { 0 ,"|en|off|de|aus|fr|Inactif|es|desconectado|it|disattivato|nl|uit"}, { 1 ,"|en|on|de|an|fr|Actif|es|conectado|it|attivato|nl|aan"}  }

#define enum_off_V  0 
#define enum_on_V  1
#define parAmplLevelBottomDetLAH LABEL "|en|min. ampl. TBD";
#define parAmplLevelBottomDetU CONSTANT_UNIT "|en|dB";
#define parMinLevelBottomDetLAH LABEL "|en|max. level TBD";
#define parLevelSpeedLAH LABEL "|en|fill/drain speed";
#define parLevelSpeedU CONSTANT_UNIT "|en|mm/s";
#define parHfModulLAH LABEL "|en|HF module";
#define parHfModulEL ENUMERATED {  { 0 ,"|en|P III.3"}, { 1 ,"|en|P III.5"}  }

#define enum_26_GHz_80m_V  0
#define enum_26_GHz_liquid_V  1
#define parZeroDistanceLAH LABEL "|en|zero distance";
#define parAntennaTypeLAH LABEL "|en|antenna type";
#define parAntennaTypeEL ENUMERATED {  { 0 ,"|en|rod aerial"}, { 1 ,"|en|horn aerial"}, { 2 ,"|en|dish antenna"}, { 3 ,"|en|planar antenna"}  }

#define enum_rod_aerial_V  0 
#define enum_horn_aerial_V  1 
#define enum_dish_antenna_V  2 
#define enum_planar_antenna_V  3
#define parInactiveLengthLAH LABEL "|en|inactive length";
#define parTotalLengthLAH LABEL "|en|total length";
#define parAbsMaxMessDistLAH LABEL "|en|max meas dist";
#define parEditRangeMaxSampleDistLAH LABEL "|en|max sample dist.";
#define parPositionOfReferencePulseLAH LABEL "|en|pos. ref. pulse";
#define parPositionOfReferencePulseU CONSTANT_UNIT "|en|mm";
#define parAmplOfReferencePulseLAH LABEL "|en|ampl. ref. pulse";
#define parAmplOfReferencePulseU CONSTANT_UNIT "|en|dB";
#define parPlausibilityFunctionLAH LABEL "|en|Plausib.Function";
#define parPlausibilityFunctionEL ENUMERATED {  { 0 ,"|en|off|de|aus|fr|Inactif|es|desconectado|it|disattivato|nl|uit"}, { 1 ,"|en|on|de|an|fr|Actif|es|conectado|it|attivato|nl|aan"}  }

#define enum_off_V  0 
#define enum_on_V  1
#define parMaxDeltaPlausibilityFunctionLAH LABEL "|en|PF maximum delta";
#define parUpperAreaPlausibilityFunctionLAH LABEL "|en|PF upper area";
#define parWireTypeLAH LABEL "|en|wire type";
#define parWireTypeEL ENUMERATED {  { 0 ,"|en|2 wire"}, { 1 ,"|en|4 wire"}  }
#define enum_2wire_V  0 
#define enum_4wire_V  1
#define parDisplayVersionLAH LABEL "|en|display version";
#define parCalculatedCycleTimeLAH LABEL "|en|calc. cycle time";
#define parCalculatedCycleTimeU CONSTANT_UNIT "|en|ms";
#define parSwVersionLAH LABEL "|en|sw. vers. appl.";
#define parParamVersionLAH LABEL "|en|para. vers. appl";
#define parDAAdjust4mALAH LABEL "|en|D/A adjust 4mA";
#define parDAAdjust20mALAH LABEL "|en|D/A adjust 20mA";
#define parDeviceIDNumberLAH LABEL "|en|device ID number";
#define parDaaIndex1LAH LABEL "|en|debug index 1";
#define parDaaIndex2LAH LABEL "|en|debug index 2";
#define parDaaRdWrValueLAH LABEL "|en|debug value";
#define parErrorStateOfAlgorithmLAH LABEL "|en|err. state alg.";
#define parStateOfAlgorithmLAH LABEL "|en|state algorithm";
#define parDVPBasicSetup3_1U CONSTANT_UNIT "|en|in/s";


#define  DEFAULT_MANUFACTURER_ID        17
/* !Defines! ***************************************************************************/
/************************************************************************************************************/
/*                         OTHER DEFINES                                                                    */
/************************************************************************************************************/
#define HL     33999
#define WHG    33998
#define VS       33200
#define CUL      2457
#define SUL      33300
#define DUL      33123

#define  Val006 ((parOperationCode == 33999)||\
   (parOperationCode ==33998)||\
   (parOperationCode == 200)||\
   (parOperationCode == 300)||\
   (parOperationCode == 123))

#define ServiceValidity parOperationCode == HL || parOperationCode == WHG || parOperationCode == VS || parOperationCode == SUL || parOperationCode == DUL


#define Hnd026 (((parOperationCode==CUL)||(parOperationCode==SUL)||(parOperationCode==DUL))&&((parLevelUllageMode==enum_lvl_cust_unit_V)||(parLevelUllageMode==enum_ullage_CU_V)))
#define Hnd033 (((parOperationCode==CUL)||(parOperationCode==SUL)||(parOperationCode==DUL))&&((parLinearisation==enum_horizontal_cyl_V))&&((parLevelUllageMode==enum_lvl_cust_unit_V)||(parLevelUllageMode==enum_ullage_CU_V)))
#define Hnd032 (((parOperationCode==CUL)||(parOperationCode==SUL)||(parOperationCode==DUL))&&((parLinearisation==enum_linear_in_percent_V)||(parLinearisation==enum_horizontal_cyl_V)||(parLinearisation==enum_clear_table_V))&&((parLevelUllageMode==enum_lvl_cust_unit_V)||(parLevelUllageMode==enum_ullage_CU_V)))
#define Hnd030 (((parOperationCode==CUL)||(parOperationCode==SUL)||(parOperationCode==DUL))&&((parLinearisation==enum_manual_V)&&(parLevelUllageMode==enum_lvl_cust_unit_V))||((parLevelUllageMode==enum_ullage_CU_V)))
#define Hnd031 (((parOperationCode==CUL)||(parOperationCode==SUL)||(parOperationCode==DUL))&&((parLinearisation==enum_manual_V)||(parLinearisation==enum_semi_automatic_V))&&((parLevelUllageMode==enum_lvl_cust_unit_V)||(parLevelUllageMode==enum_ullage_CU_V)))
#define Hnd043 (((parOperationCode==CUL)||(parOperationCode==SUL)||(parOperationCode==DUL))&&(parCommAddress==0))
#define Hnd000 (Hnd011)
#define Hnd005 (Hnd012)
#define Hnd034 (parOperationCode==CUL||parOperationCode==SUL||parOperationCode==DUL)
#define Hnd090 (parOperationCode==DUL)
#define Hnd096 (parOperationCode==SUL||parOperationCode==DUL)
#define Hnd008 (parOperationMode==enum_level_overspill_V)

#define Val041 ((parCheckDistance==3)||(parCheckDistance==2))
#define Val039 ((parLinearisation==enum_horizontal_cyl_V)||(parLinearisation==enum_linear_in_percent_V))
#define Val034 ((parTankShape==enum_stilling_well_V&&parMediaType!=enum_solids_V)||(parTankShape==enum_bypass_V&&parMediaType!=enum_solids_V))
#define Val026 (parFormatDisplayDec16inch==enum_decimal_V)
#define Val040 (parLinearisation==enum_horizontal_cyl_V)
#define Val037 (parLinearisation==enum_semi_automatic_V)
#define Val027 (parMediaType==enum_liquidity_V)
#define Val028 (parMediaType==enum_solids_V)
#define Val036 (parReactionLostEcho==enum_ramp_in_percent_per_min_V)
#define Val046 (parSimulation==enum_sim_current_V)
#define Val044 (parSimulation==enum_sim_level_V)
#define Val045 (parSimulation==enum_sim_volume_V)




#define Unit_mm 1013
#define Unit_m 1010
#define Unit_inch 1010
#define Unit_ft 1018



/*****************************************************************************/ 
/*****************************************************************************/ 


VARIABLE parMeasuredValue
{
   parMeasuredValueLAH
   DEFAULT_VALUE 0; 
  CLASS COMPUTATION & DYNAMIC;
   HANDLING READ;
   TYPE  FLOAT
    {
        DISPLAY_FORMAT

        IF (parNoOfDecimalsUpTo3 == 0)
        {
            "9.0f";
        }
        ELSE
        {
            IF ( parNoOfDecimalsUpTo3 == 1 )
            {
                "9.1f";
            }
            ELSE
            {
                IF ( parNoOfDecimalsUpTo3 == 2 )
                {
                    "9.2f";
                }
                ELSE
                {
                    IF ( parNoOfDecimalsUpTo3 == 3 )
                    {
                        "9.3f";
                    }
                        ELSE
                       {
                        "9.3f";
                       }
                    }
                }
            }
        }
    }




/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE MEASVAR_LOWER_LIMIT {
 LABEL  "Internal" ;
 CLASS  LOCAL ; 
 TYPE  FLOAT  {
  DEFAULT_VALUE 0 ;
  INITIAL_VALUE 0 ;
 }
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE MEASVAR_UPPER_LIMIT {
 LABEL  "Internal" ;
 CLASS  LOCAL ; 
 TYPE  FLOAT  {
  DEFAULT_VALUE 100 ;
  INITIAL_VALUE 100 ;
 }
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE software_revision {
 LABEL  [software_revision] ;
 HELP  [field_device_software_revision_help] ;
 CLASS  DEVICE ; 
 HANDLING READ ;
 TYPE  UNSIGNED_INTEGER  {
  MAX_VALUE 253 ;
 }
        DEFAULT_VALUE 5;
        POST_READ_ACTIONS  { 
  PostReadSoftware_revision
 }
} 



/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE parShowAccess {
 LABEL  "|en|Access rights|de|Zugriff|fr|Droits d'accs" ;
 CLASS  LOCAL ; 
 HANDLING READ ;
        TYPE    ENUMERATED      {  DEFAULT_VALUE   1; 
 { 0, "|en|Locked|de|Verriegelt|fr|Verrouill"}, 
 { 1 ,"|en|Customer|de|Kunde|fr|Client"},
 { 2 ,"|en|Service (View only)|de|Service (nur Ansicht)|fr|Service (Consultation)"}, 
 { 3 ,"|en|Service|de|Service|fr|Service"},
 { 5, "|en|WHG|de|WHG|fr|WHG"},
 { 6, "|en|Debug unlock|de|Debug unlock|fr|Debug unlock"},
 { 7, "|en|Hard lock|de|Hard lock|fr|Hard lock"}
}

} 



/*****************************************************************************/ 
/*****************************************************************************/ 




/*****************************************************************************/ 
 VARIABLE TitleDisplayTest {
        LABEL   [TitleDisplayTest] ;
 CLASS  LOCAL ; 
 HANDLING READ ;
 TYPE  ENUMERATED         {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleDisplayTest] }
        }
} 
/*****************************************************************************/ 
 VARIABLE TitleSetUnit {
        LABEL   [TitleDisplayTest] ;
 CLASS  LOCAL ; 
 HANDLING READ ;
 TYPE  ENUMERATED         {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleDisplayTest] }
        }
} 

VARIABLE TitleBasicSetup {
 LABEL  [LabTitleBasicSetup] ;
 CLASS  LOCAL ; 
 HANDLING READ ;
 TYPE  ENUMERATED         {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleBasicSetup] }
        }
} 


/*****************************************************************************/ 
VARIABLE TitleServiceParameter {
 LABEL  [LabTitleProfibusParameters] ;
 CLASS  LOCAL ; 
 HANDLING READ ;
 TYPE  ENUMERATED         {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleServiceParameters] }
        }
} 

/*****************************************************************************/ 

VARIABLE TitleSafetySettings {
 LABEL  [LabTitleSafetySettings] ;
 CLASS  LOCAL ; 
 HANDLING READ ;
 TYPE  ENUMERATED         {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleSafetySettings] }
        }
} 

 VARIABLE parTagNumber32
 {

 HANDLING CUSTOMERLOCK
 parTagNumber32LAH
 CLASS CONTAINED;


 TYPE ASCII (32);
 DEFAULT_VALUE "-----------------------";

 }


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE TitleLinearisation {
 LABEL  [LabTitleLinearisation] ;
 CLASS  LOCAL ; 
 HANDLING READ ;
 TYPE  ENUMERATED         {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleLinearisation] }
        }
} 



/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE TitleExtendedCalibration {
 LABEL  [LabTitleExtendedCalibration] ;
 CLASS  LOCAL ; 
 HANDLING READ ;
 TYPE  ENUMERATED         {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleExtendedCalibration] }
        }
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE TitleProfibusParameter {
 LABEL  [LabTitleProfibusParameters] ;
 CLASS  LOCAL ; 
 HANDLING READ ;
 TYPE  ENUMERATED         {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleProfibusParameters] }
        }
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE TitleDisplay {
 LABEL  [LabTitleDisplay] ;
 CLASS  LOCAL ; 
 HANDLING READ ;
 TYPE  ENUMERATED         {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleDisplay] }
        }
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE TitleDiagnostics {
 LABEL  [LabTitleDiagnostics] ;
 CLASS  LOCAL ; 
 HANDLING READ ;
 TYPE  ENUMERATED         {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleDiagnostics] }
        }
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE TitleSystemParameter {
 LABEL  [LabTitleSystemParameter] ;
 CLASS  LOCAL ; 
 HANDLING READ ;
 TYPE  ENUMERATED         {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleSystemParameter] }
        }
} 


/*****************************************************************************/ 
/*****************************************************************************/ 


VARIABLE TitleSimulation {
        LABEL "|en|simulation|de|Simulation";
	CLASS 	LOCAL ;
	HANDLING  READ ;
	TYPE 	ENUMERATED	        {

                {       0,      [EnumTitleSimulation ] }
        }

}


VARIABLE TitleSetUnitToBus {
 LABEL  "|en|set unit to bus|de|Setze Einh. Out" ;
 CLASS  LOCAL ; 
 HANDLING READ ;
 TYPE  ENUMERATED         {
                DEFAULT_VALUE 0;
                {       0,      [EnumSetUnitToBus] }
        }
} 


/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE TitleDiagnosticsReset {
 LABEL  [LabTitleDiagnosticsReset] ;
 CLASS  LOCAL ; 
 HANDLING READ ;
 TYPE  ENUMERATED         {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleDiagnosticsReset] }
        }
} 



VARIABLE TitleOperationCode {
 LABEL  [LabTitleOperationCode] ;
 CLASS  LOCAL ; 
 HANDLING READ ;
 TYPE  ENUMERATED         {
                DEFAULT_VALUE 0;
                {       0,      [EnumTitleOperationCode] }
        }
} 





MENU Menu_Main_Specialist {
 LABEL  [main_menu] ;
 ITEMS { 
  Menu_File,
  Menu_S_Device,
  Menu_S_View,
  Menu_S_Options,
  Menu_Help
 } 
}

MENU OnlineDialog_SystemReset {
 LABEL  [Online_Reset] ;
 ITEMS { 
  parReset
 } 
}

MENU Menu_S_Device {
 LABEL  [menu_Device] ;
 ITEMS { 
  std_NodeAddress,
  SEPARATOR,
  std_LoadinDevice,
  std_LoadinPC,
  SEPARATOR,
  OnlineDialog_Profibus
  SEPARATOR,
  OnlineDialog_SystemReset,
  SEPARATOR,
  OnlineDialog_Simulation
  SEPARATOR,
  OnlineDialog_Adjust_BasicSetup,
  OnlineDialog_Adjust_SafetySettings,
  OnlineDialog_Adjust_Linearisation,
  OnlineDialog_Adjust_ExtendedCalibration,
  OnlineDialog_Adjust_Display,
  OnlineDialog_Adjust_Diagnostics,
  OnlineDialog_Adjust_SystemParam
  IF (ServiceValidity)
    { OnlineDialog_SERVICE_MENU}
   SEPARATOR,
  OnlineDialog_write_lock
 } 
}

MENU Page_SetUnitToBus {
	LABEL 	[Online_SetUnitToBus] ;
	ITEMS {
                setUnitToBus
	}

}
MENU Online_simulation_func_MENU
{
        LABEL "Analog Input Simulation";
	ITEMS
	{
                OnlineDialog_simulation_func1
        }
}


MENU Page_phys_ident_number
{
        LABEL  [menu_profibus_parameter];
	ITEMS
	{
                parPAIdentNumberSelector
        }
}


MENU OnlineDialog_Profibus
{
        LABEL  [menu_profibus_parameter];
	ITEMS
	{
                        Page_SetUnitToBus,
                        Page_phys_ident_number
                        Page_reset

        }
}



MENU Page_reset
{
   LABEL [menu_PROFIBUS_reset];
   ITEMS
   {
      Page_reset
   }

}

MENU OnlineDialog_Simulation {
 LABEL  [Online_Simulation] ;
 ITEMS { 
  parSimulation,
  parSimulationValueLevel,
  parSimulationValueVolume,
 } 
}


MENU OnlineDialog_Adjust_BasicSetup {
 LABEL  [Online_Adjust_BasicSetup] ;
 ITEMS { 
                parMediaType,           
                parTankShape,           
                parDielectricConstant,  
                parProcessCondition,    
                parVesselSilo           
                parDielectricConstantSolid,  /*VH03 solid*/
                parProcessConditionSolid,    
                parEmptyCalibration,    
                parFullCalibration,     
                parTubeDiameter         
                parMeasuredDistance,
                parCheckDistance,
                parSuppressionDistance,
                parStartMappingRecord,
}
}

MENU OnlineDialog_Adjust_SafetySettings {
 LABEL  [Online_Adjust_SafetySettings] ;
 ITEMS { 
        parReactionLostEcho
        parDelayTimeOnLostEcho
        parLevelWithinSafetyDistance
        parInSafetyDistance
        parAcknowledgeAlarm
        parOperationMode
 } 
}


MENU OnlineDialog_Adjust_Linearisation {
 LABEL  [Online_Adjust_Linearisation] ;
 ITEMS { 
		page_Linearisation_1_3,
		page_Linearisation_2_3,
		page_Linearisation_3_3
 } 
}

MENU   page_Linearisation_1_3 {
	LABEL 	[Online_Adjust_Linearisation_1_3] ;
	ITEMS { 
		parLevelUllageMode,
		parLinearisation
	} 
}

MENU   page_Linearisation_2_3 {
	LABEL 	[Online_Adjust_Linearisation_2_3] ;
	ITEMS { 
		parCylinderVessel,
		parCustomerUnit,
		parMaxVolume,
		parTableNumber,
		parInputLevelManual,
		parInputLevelHalfAutomatic,
		parInputVolume
	} 
}

MENU   page_Linearisation_3_3 {
	LABEL 	[Online_Adjust_Linearisation_3_3] ;
	ITEMS { 
		parLinearisation,
		parActualError
	} 
}

MENU OnlineDialog_Adjust_ExtendedCalibration {
 LABEL  "|en|extended calibr.|de|erweit. Abgleich|fr|Etalonnage tendu|es|calib. extendida|it|Altre calibr.|nl|uitgebreide kalib" ;
 ITEMS { 
                page_EXTENDED_CALIBRATION_COMMON,
                page_EXTENDED_CALIBRATION_MAPPING,
                page_EXTENDED_CALIBRATION_EXTENDED_MAPPING,

 } 
}
MENU page_EXTENDED_CALIBRATION_COMMON {
 LABEL  "|en|Common|de|Allgemein" ;
 ITEMS { 
                parEchoQuality,      
                parOffsetOfMeasuredLevel,
                parAntennaExtensionLength,
                parOutputDamping,
                parBlockingDistance
 } 
}
MENU page_EXTENDED_CALIBRATION_MAPPING {
        LABEL   "|en|mapping|de|Ausblendung" ;
 ITEMS { 
                parMeasuredDistance,
                parMeasuredValue,
                parCheckDistance,
                parSuppressionDistance,
                parStartMappingRecord,
 } 
}

MENU page_EXTENDED_CALIBRATION_EXTENDED_MAPPING {
        LABEL   "|en|extended mapping|de|erweiterte Ausblendung" ;
 ITEMS { 
                parPresMapRange,
                parCustTankMap
 } 
}


MENU OnlineDialog_Adjust_Display {
 LABEL  [Online_Adjust_Display] ;
 ITEMS { 
  parLanguage,
  parBackToHome,
  parFormatDisplayDec16inch,
  parNoOfDecimalsUpTo3,
  parSeparationCharacter,
  TitleDisplayTest(READ_ONLY)
 } 
}

MENU OnlineDialog_Adjust_Diagnostics {
 LABEL  [Online_Adjust_Diagnostics] ;
 ITEMS { 
                parActualError,
                parLastError,
  parClearLastError,
                TitleDiagnosticsReset,
                parShowAccess,
                TitleOperationCode,
                parOperationCode(READ_ONLY),
                parMeasuredDistance,
                parMeasuredLevel,
                parDetectionWindow,
                parApplicationParameter
        }
}

MENU OnlineDialog_Adjust_SystemParam {
 LABEL  [Online_Adjust_SystemParam] ;
 ITEMS { 
  parTagNumber32,
  parProtSoftVersionString,
  parSerialNumber,
parDistanceUnit16,
parDownloadMode
 } 
}
MENU OnlineDialog_SERVICE_MENU {
        LABEL   "|en|Service|de|Service|fr|Service|es|servicio|it|Service|nl|service" ;
        ITEMS { 
                        Page_service_lv_0,
                        Page_service_lv_1,
                        Page_service_lv_2,
                        Page_service_lv_3,
                        Page_service_lv_4,
                        Page_service_lv_5,
                        Page_service_lv_6,
                        Page_service_lv_7,
                        Page_service_lv_8,
        //KVP4
                        Page_service_lv_9,   
                        Page_service_lv_12,
                        Page_service_lv_13,
                        Page_service_lv_15
        } 

}

MENU Page_service_lv_0 {
    LABEL                   pardService0SubParamGroup
 ITEMS { 
  parAmplitudeOverSupp,
  parAmplitudeOverFAC,
  parUnfilteredDistance,
  parCalcEdgeParameter,
  parCurrentFirstEchoFactor,
  parDeviceName,
  parOrderCode
 } 
        VALIDITY IF(Val000){ TRUE; }
   ELSE
    { FALSE; }
        
}

MENU Page_service_lv_1 {
    LABEL                   pardService1SubParamGroup
 ITEMS { 
  parMamFilterLength,
  parMamFilterBorder,
  parFilterConstMin,                       /*VD1H3*/
  parFilterConstMax,                       /*VD1H4*/
  parInnovationFiltConstMax,               /*VD1H5*/
  parHystereseWidth,
  parEchoLostRampUp,
  parEchoLostRampDown,
  parUnfilteredDistanceRaw
 } 
  VALIDITY IF(ServiceValidity){ TRUE; }
     ELSE
  { FALSE; }
  
}

MENU Page_service_lv_2 {
    LABEL                   pardService2SubParamGroup
 ITEMS { 
        parFilterBreite,
        parSawitzkiGolay,
        parHkStatCountPos,
        parHkStatCountNeg,
        parMergingEchoes,
        parMergingWindow,
        parMergingEchoDist,
        parMergingRatio,
        parEnvelopeEnergy
 } 
        VALIDITY IF(ServiceValidity){ TRUE; }
   ELSE
    { FALSE; }
        
}

MENU Page_service_lv_3 {
    LABEL                   pardService3SubParamGroup
    ITEMS
    {
        parMappingAdder,
        parMappingWidthNew,
        parMappingAverage,
        parFactoryTdt,
        parFacAdder,
        parFACWidthNew,
        parRangeFactoryMap,
        parFactoryMappingValid,
        parCustomerMappingValid
    }
    VALIDITY IF(ServiceValidity){ TRUE; }
    ELSE
    { FALSE; }
    
}

MENU Page_service_lv_4 {
    LABEL                   pardService4SubParamGroup
    ITEMS
    {
        parEdgeDetectionMode,
        parEdgeParameter,
        parCalcEdgeParameter
    }
        VALIDITY IF(ServiceValidity){ TRUE; }
   ELSE
    { FALSE; }
        
}

MENU Page_service_lv_5 {
    LABEL                   pardService5SubParamGroup
    ITEMS
    {
        parFirstEchoFactor,
        parFefThreshold,
        parFefNearFactor,
        parFefDistanceNear,
        parFefDistanceFar,
        parFefEdge,
        parMaxEchoSN,
/*        parCurrentFirstEchoFactor*/
    }
        VALIDITY IF(ServiceValidity){ TRUE; }
   ELSE
    { FALSE; }
        
}

MENU Page_service_lv_6 {
    LABEL                   pardService6SubParamGroup
    ITEMS
    {
        parDishBottomDet,
        parAmplLevelBottomDet,
        parMinLevelBottomDet,
        parRangeTankBottomDetection,
        parClipDistanceToEmpty,
        parLevelSpeed
    }
   VALIDITY IF(ServiceValidity){ TRUE; }
   ELSE
    { FALSE; }
   
}

MENU Page_service_lv_7 {
        LABEL                   pardService7SubParamGroup
	ITEMS
    {
        parHfModul,
        parZeroDistance,
        parPositionOfReferencePulse,
        parAmplOfReferencePulse
    }
        VALIDITY IF(ServiceValidity){ TRUE; }
   ELSE
    { FALSE; }
        
}

MENU Page_service_lv_8 {
    LABEL pardService8SubParamGroup
    ITEMS
    {
        parAntennaType,
        parInactiveLength,
        parTotalLength,
        parAbsMaxMessDist,
        parEditRangeMaxSampleDist
    }
 
  VALIDITY IF(ServiceValidity){ TRUE; }
   ELSE
    { FALSE; }
  
}

//KVP4 Start
MENU Page_service_lv_9
{
        LABEL                   pardService9SubParamGroup
    ITEMS
    {
        parDelayTimer,
        parEchoFoundDelay,
        parEchoLostDelay,
        parJumpDelayBase,
        parJumpDelaySlope,
        parNoJumpWindowWith,
        parWeightMode
    }
    VALIDITY IF(ServiceValidity){ TRUE; }
    ELSE
           { FALSE; }
    
}
//KVP4 End

MENU Page_service_lv_12 {
    LABEL pardService12SubParamGroup
    ITEMS
    {
/*        parWireType,*/
        parDisplayVersion,
        parCalculatedCycleTime,
        parSwVersion,
        parParamVersion
    }
        VALIDITY IF(ServiceValidity){ TRUE; }
   ELSE
    { FALSE; }
        
}

MENU Page_service_lv_13 {
    LABEL                   pardService13SubParamGroup
    ITEMS
    {
/*        parDeviceIDNumber*/
    }
        VALIDITY IF(ServiceValidity){ TRUE; }
   ELSE
    { FALSE; }
        
}

MENU Page_service_lv_15 {
    LABEL                   pardService15SubParamGroup
    ITEMS
    {
        parDaaIndex1,
        parDaaIndex2,
        parDaaRdWrValue,
        parErrorStateOfAlgorithm,
        parStateOfAlgorithm
    }
        VALIDITY IF(ServiceValidity){ TRUE; }
   ELSE
    { FALSE; }
        
}

MENU OnlineDialog_write_lock {
 LABEL  [phys_write_locking] ;
 ACCESS OFFLINE;
 ITEMS { 
  page_phys_write_locking
 } 
}

MENU page_phys_write_locking {
 LABEL  [phys_write_locking_user] ;
 ITEMS { 
                parShowAccess,
                parOperationCode,
                CodeToDevice
 } 
}

METHOD CodeToDevice
{
        LABEL "|en|Transfer|de|bertragen";
        DEFINITION
        {

           updateParShowAccess();
           WriteCommand(write_parOperationCodeFFPAOnline);
        }

}



MENU Menu_S_View {
 LABEL  [menu_View] ;
 ITEMS { 
  OnlineWindow_display,
  OnlineWindow_yt,
  OnlineWindow_S_alarm_func1,
  OnlineWindow_diagnosis,
  SEPARATOR,
  std_Funktionsleiste,
  std_Statuszeile,
  SEPARATOR,
  std_Update
 } 
}

#include "\PA\SIPAST_Macros_300.inc"
#include "\PA\SIPASTPB_300.inc"
#include "\PA\SIPASTAI_300.inc"

MENU OnlineWindow_display {
	LABEL 	[menu_dialog_display_measure] ;
        ITEMS {
                Page_display_measure,
		Page_display_func1,
		Page_display_value
 } 
}

MENU   Page_display_measure {
	LABEL 	[menu_dialog_display_measure] ;
	ITEMS { 
                 BarVal_measuredValue
                 group_1
	} 
}

VARIABLE  parBarLowerRange {
	LABEL 	"Lower range" ;
	CLASS 	LOCAL ; 
	TYPE  FLOAT  {
		DEFAULT_VALUE	0.0 ;
	}
} 
MENU   BarVal_measuredValue {
	LABEL 	"|en|measured value|de|Messwert|fr|Valeur de mesure|es|Messwert|it|Valore di misura|nl|gemeten waarde" ;
	ITEMS { 
		parMeasuredValue,
		parBarLowerRange,
		parMaxVolume
	} 
}

MENU   group_1 {
	LABEL 	"" ;
	ITEMS { 
		Val_parMeasuredValue,
		Val_parMeasuredDistance,
		Val_parMeasuredLevel,
		SEPARATOR,
		Val_parEchoQuality,
		Val_parActualError
	} 
}

MENU   Val_parMeasuredValue {
	LABEL 	"|en|measured value|de|Messwert|fr|Valeur de mesure|es|Messwert|it|Valore di misura|nl|gemeten waarde" ;
	ITEMS { 
		parMeasuredValue
	} 
}

MENU   Val_parMeasuredDistance {
	LABEL 	"|en|measured dist.|de|gemessene Dist.|fr|distance mesuree|es|gemessene Dist.|it|Distanza mis.|nl|meetafstand" ;
	ITEMS { 
		parMeasuredDistance
	} 
}

MENU   Val_parMeasuredLevel {
	LABEL 	"|en|measured level|de|gemess. Fuellst.|fr|niveau mesure|es|gemess. Fuellst.|it|Livello mis.|nl|gemeten niveau" ;
	ITEMS { 
		parMeasuredLevel
	} 
}

MENU   Val_parEchoQuality {
	LABEL 	"|en|echo quality|de|Echoqualitaet|fr|Qualite echo|es|Echoqualitaet|it|Qualit eco|nl|echokwaliteit" ;
	ITEMS { 
		parEchoQuality
	} 
}

MENU   Val_parActualError {
	LABEL 	"|en|present error|de|aktueller Fehler|fr|defaut actuel|es|aktueller Fehler|it|errore attuale|nl|actuele fout" ;
	ITEMS { 
		parActualError
	} 
}

MENU   Page_display_value {
	LABEL 	"display value" ;
	ITEMS { 
		Val_parPADisplayValue
	} 
}

MENU   Val_parPADisplayValue {
	LABEL 	"display value" ;
	ITEMS { 
		parPADisplayValue
	} 
}

MENU   OnlineWindow_diagnosis {
	LABEL 	[menu_dialog_diagnosis] ;
	ITEMS { 
		Page_diagnosis_general,
		Page_diagnosis_phys_block,
		Page_diagnosis_func1
	} 
}

MENU   Page_diagnosis_general {
	LABEL 	[menu_dialog_general] ;
	ITEMS { 
		parTagNumber,
		phys_device_man_id,
		phys_device_id,
		phys_device_ser_num,
		phys_software_rev,
		phys_hardware_rev,
		phys_install_date,
		phys_diagnosis
	} 
}

MENU   Page_diagnosis_phys_block {
	LABEL 	[blk_block_object_PHYSICAL] ;
	ITEMS { 
		phys_blk_object,
		phys_blk_parent_class,
		phys_blk_class,
		phys_blk_dd_reference,
		phys_blk_dd_rev,
		phys_blk_profile,
		phys_blk_profile_rev,
		phys_st_rev,
		phys_actual_mode
	} 
}


/* !Matrix Menu! ***********************************************************************/
MENU Table_Main_Specialist {
 LABEL  DEFAULT_VALUE_phys_device_id ;
 ITEMS { 
  MenuMainMicroPilot_M,
  IF (Hnd011) {
        Tab_s_PA_Profil
  }
  IF (!(Hnd011)) {
        Tab_s_PA_Profil_RO
     }
 } 
}

MENU MenuMainMicroPilot_M {
 LABEL  [EH_Standard_View] ;
 ITEMS { 
                CALIBRATION,                     /*MENU*/
                SAFETY_SETTINGS,                 /*MENU*/
                LINEARISATION,                   /*MENU*/
                EXTENDED_CALIBRATION,            /*MENU*/
                PROFIBUS_MENU,
                DISPLAY,                         /*MENU*/
                OPERATING_PARAMETER,             /*MENU*/
                SYSTEM_PARAMETER,                
                IF (ServiceValidity)
                {SERVICE_MENU}
        } 
}

MENU PROFIBUS_MENU {
    LABEL grpProfibusDPGroupLabel;
    ITEMS {
                parPADeviceBusAddress,
                parPAIdentNumberSelector
                TitleSetUnitToBus
                parPAProfileRevision,
		parPAAIOutValue,
		parPAAIOutStatus,
		parPA2ndCyclicValue,
		parPASelectMainValue
                TitleSimulation(READ_ONLY)
    }

}

BLOCK transducer_block_1
{
	TYPE	TRANSDUCER;
	NUMBER	1;
}

VARIABLE  parPAProfileRevision {
	LABEL 	"Profile Version" ;
	CLASS 	CONTAINED ; 
	VALIDITY  TRUE ;
	HANDLING  READ ;
	TYPE  ASCII (16)  {
		DEFAULT_VALUE	"3.0" ;
	}
} 



VARIABLE parPADeviceBusAddress {
 CLASS CONTAINED & DYNAMIC;
 LABEL PADeviceBusAddressLabel;
 VALIDITY TRUE;
 HANDLING READ;
 TYPE UNSIGNED_INTEGER (1);

}

VARIABLE RBIdentNumberSelector {
 CLASS CONTAINED;
 DEFAULT_VALUE 1;
 LABEL PAIdentNumberSelectorLabel;
 VALIDITY TRUE;
 HANDLING CUSTOMERLOCK
 TYPE ENUMERATED (1) {
 ENUM_RBIdentNumberSelector
 }

}


VARIABLE parPAAIOutValue {
	LABEL 	"|en|out value|de|Out Wert" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  TRUE ;
	HANDLING  READ ;
	TYPE  FLOAT ;
} 



COMMAND read_parPAAIOutValue { 
	BLOCK 	transducer_block_1 ;
	INDEX 	61 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parPAAIOutValue
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE parPAAIOutStatus {
	LABEL 	"|en|out status|de|Out Status" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  TRUE ;
	HANDLING  READ ;
	TYPE  UNSIGNED_INTEGER(1) ;
} 



COMMAND read_parPAAIOutStatus { 
	BLOCK 	transducer_block_1 ;
	INDEX 	62 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parPAAIOutStatus
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE parPA2ndCyclicValue {
	LABEL 	"|en|2nd cyclic value|de|2. zykl. Wert" ;
	CLASS 	CONTAINED ; 
	VALIDITY  TRUE ;
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	  {
    DEFAULT_VALUE 0;
    { 0,  "|en|height/dist.|de|Hhe/Distanz"  }
  }
} 



COMMAND read_parPA2ndCyclicValue { 
	BLOCK 	transducer_block_1 ;
	INDEX 	65 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parPA2ndCyclicValue
		} 
	} 
} 

COMMAND write_parPA2ndCyclicValue { 
	BLOCK 	transducer_block_1 ;
	INDEX 	65 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parPA2ndCyclicValue
		} 
		REPLY {
		} 
	} 
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE parPASelectMainValue {
	LABEL 	"|en|select V0H0|de|Zuordnung Anzei." ;
	CLASS 	CONTAINED ; 
	VALIDITY  TRUE ;
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED(1)	        {
                {0,[enum_eh_meas]},
                {1,[enum_eh_display]}
        }
} 

/*****************************************************************************/ 
/*****************************************************************************/ 

VARIABLE parPADisplayValue {
        LABEL   "|en|Display value|de|eingel. Werte" ;
	CLASS 	DYNAMIC ; 
	VALIDITY  TRUE ;
	HANDLING  READ ;
	TYPE  FLOAT ;
} 

/*****************************************************************************/ 
/*****************************************************************************/ 


BLOCK physical_block
{
 TYPE PHYSICAL;
 NUMBER 1;

}


REDEFINE VARIABLE phys_hardware_rev
{
  DEFAULT_VALUE 01.00           ;


}
REDEFINE VARIABLE phys_st_rev
{
  DEFAULT_VALUE 41;
 }


VARIABLE phys_device_man_id
{
  DEFAULT_VALUE 17;
 CLASS CONTAINED;
 HANDLING READ;
 TYPE INTEGER (2);

}
VARIABLE phys_device_id
{
  DEFAULT_VALUE "MICROPILOT M";
 CLASS CONTAINED;
 HANDLING READ;
 TYPE ASCII (16);

}
VARIABLE phys_software_rev
{
 CLASS CONTAINED;
 HANDLING READ;
 TYPE ASCII (16);
  DEFAULT_VALUE "01.05.00        ";

}


MENU CALIBRATION {
   LABEL var_basic_setupParamGroup
   ITEMS { 
                TitleBasicSetup(READ_ONLY),
                parMeasuredDistance(READ_ONLY),
                parMeasuredValue(READ_ONLY),
                parMediaType,           /*VH01*/
                parTankShape,           /*VH02 liquid*/
                parDielectricConstant,  /*VH03 liquid*/
                parProcessCondition,    /*VH04 liquid*/
                parVesselSilo           /*VH02 solid*/
                parDielectricConstantSolid,  /*VH03 solid*/
                parProcessConditionSolid,    /*VH04 solid*/
                parEmptyCalibration,    /*VH05*/
                parFullCalibration,     /*VH06*/
                parTubeDiameter         /*VH07*/
                parMeasuredDistance,
                parCheckDistance(READ_ONLY),
                parSuppressionDistance(READ_ONLY),
                parStartMappingRecord(READ_ONLY),
        } 
}

MENU SAFETY_SETTINGS {
 LABEL  "|en|safety settings|de|Sicherheitseinst.|fr|Rglages scurit|es|ajustes de fb.|it|imp. sicurezza|nl|veiligheidsinst." ;
 ITEMS { 
                TitleSafetySettings(READ_ONLY),
		parOutputOnAlarm,
                parReactionLostEcho,        /*VH12*/
                parRampInPercentPerMin,     /*VH13*/
                parDelayTimeOnLostEcho,     /*VH14*/
                parLevelWithinSafetyDistance,   /*VH15*/
                parInSafetyDistance,        /*VH16*/
                parAcknowledgeAlarm,        /*VH17*/
                parOperationMode

        } 
}

MENU LINEARISATION {
 LABEL  "|en|linearisation|de|Linearisierung|fr|Linarisation|es|linearizacin|it|Linearizzazione|nl|linearisering" ;
 ITEMS { 
        TitleLinearisation(READ_ONLY),
        parLevelUllageMode(READ_ONLY),
        parLinearisation(READ_ONLY),
        parCustomerUnit(READ_ONLY),
        parTableNumber(READ_ONLY),
        parInputLevelManual(READ_ONLY),
        parInputLevelHalfAutomatic(READ_ONLY),
        parInputVolume(READ_ONLY),
        parMaxVolume(READ_ONLY),
        parCylinderVessel(READ_ONLY)

 } 
}

MENU EXTENDED_CALIBRATION {
 LABEL  "|en|extended calibr.|de|erweit. Abgleich|fr|Etalonnage tendu|es|calib. extendida|it|Altre calibr.|nl|uitgebreide kalib" ;
 ITEMS { 
  software_revision(HIDDEN),
  TitleExtendedCalibration(READ_ONLY),
  EXTENDED_CALIBRATION_COMMON,
  EXTENDED_CALIBRATION_MAPPING,
  EXTENDED_CALIBRATION_EXTENDED_MAPPING,

 } 
}
MENU EXTENDED_CALIBRATION_COMMON {
 LABEL  "|en|Common|de|Allgemein" ;
 ITEMS { 
  parEchoQuality(READ_ONLY), 
  parOffsetOfMeasuredLevel(READ_ONLY),
  parAntennaExtensionLength,
  parOutputDamping,
  parBlockingDistance,
 } 
}
MENU EXTENDED_CALIBRATION_MAPPING {
        LABEL   "|en|mapping|de|Ausblendung" ;
 ITEMS { 
  parMeasuredDistance(READ_ONLY),
  parMeasuredValue(READ_ONLY),
  parCheckDistance(READ_ONLY),
  parSuppressionDistance(READ_ONLY),
  parStartMappingRecord(READ_ONLY),
 } 
}

MENU EXTENDED_CALIBRATION_EXTENDED_MAPPING {
        LABEL   "|en|extended mapping|de|erweiterte Ausblendung" ;
 ITEMS { 
  parPresMapRange(READ_ONLY),
  parCustTankMap(READ_ONLY),
 } 
}



MENU DISPLAY {
 LABEL  "|en|display|de|Anzeige|fr|Affichage|es|visualizador|it|Indicatore|nl|display" ;
 ITEMS { 
        parLanguage,            
        parBackToHome,          
        parFormatDisplayDec16inch,    
        parNoOfDecimalsUpTo3,        
        parSeparationCharacter  
        TitleDisplayTest(READ_ONLY)
 } 
}

MENU OPERATING_PARAMETER {
 LABEL  "|en|diagnostics|de|Diagnose|fr|Diagnostic|es|diagnsticos|it|Param. operativi|nl|diagnose" ;
 ITEMS { 
  TitleDiagnostics(READ_ONLY),
  parActualError(READ_ONLY),
  parLastError(READ_ONLY),
  parClearLastError,
  TitleDiagnosticsReset(READ_ONLY),
  parShowAccess(READ_ONLY),
  TitleOperationCode(READ_ONLY),
  parOperationCode(READ_ONLY),
  parMeasuredDistance(READ_ONLY),
  parMeasuredLevel(READ_ONLY),
  parDetectionWindow(READ_ONLY)      
  parApplicationParameter(READ_ONLY) 

 } 
}

MENU SYSTEM_PARAMETER {
 LABEL  "|en|system parameters|de|System Parameter|fr|Paramtre systme|es|parm sistema|it|Param. di sistema|nl|systeemparameter" ;
 ITEMS { 
  TitleSystemParameter(READ_ONLY),
  parTagNumber32,               /*VHA1*/
  parProtSoftVersionString(READ_ONLY),
  parSerialNumber,
  parDistanceUnit16,
  parDownloadMode(READ_ONLY)
 } 
}

MENU SERVICE_MENU {
 LABEL  "|en|service|de|Service|fr|Service|es|servicio|it|Service|nl|service" ;
 ITEMS { 
  service_lv_0,
  service_lv_1,
  service_lv_2,
  service_lv_3,
  service_lv_4,
  service_lv_5,
  service_lv_6,
  service_lv_7,
  service_lv_8,
  service_lv_9, 
  service_lv_12,
  service_lv_13,
  service_lv_15
 } 
}

MENU service_lv_0 {
 LABEL  "|en|info|de|Info|fr|Info|es|Info|it|Info|nl|informatie" ;
 ITEMS { 
  parAmplitudeOverSupp(READ_ONLY),
  parAmplitudeOverFAC(READ_ONLY),
  parUnfilteredDistance(READ_ONLY),
  parCalcEdgeParameter(READ_ONLY),
/*  parCurrentFirstEchoFactor(READ_ONLY),*/
  parDeviceName(READ_ONLY),
  parOrderCode(READ_ONLY)
 } 
 VALIDITY IF(ServiceValidity){ TRUE; }
   ELSE
    { FALSE; }
 
}

MENU service_lv_1 {
 LABEL  "|en|distance" ;
 ITEMS { 
        parMamFilterLength(READ_ONLY),
        parMamFilterBorder(READ_ONLY),
        parFilterConstMin(READ_ONLY),                      
        parFilterConstMax(READ_ONLY),                      
        parInnovationFiltConstMax(READ_ONLY),              
        parHystereseWidth(READ_ONLY),
        parEchoLostRampUp(READ_ONLY),
        parEchoLostRampDown(READ_ONLY),
        parUnfilteredDistanceRaw(READ_ONLY)
 } 
 VALIDITY IF(ServiceValidity){ TRUE; }
   ELSE
    { FALSE; }
 
}

MENU service_lv_2 {
 LABEL  "|en|envelope" ;
 ITEMS { 
        parFilterBreite(READ_ONLY),
        parSawitzkiGolay(READ_ONLY),
        parHkStatCountPos(READ_ONLY),
        parHkStatCountNeg(READ_ONLY),
        parMergingEchoes(READ_ONLY),
        parMergingWindow(READ_ONLY),
        parMergingEchoDist(READ_ONLY),
        parMergingRatio(READ_ONLY),
        parEnvelopeEnergy(READ_ONLY)
 } 
 VALIDITY IF(ServiceValidity){ TRUE; }
   ELSE
    { FALSE; }
 
}

MENU service_lv_3 {
    LABEL                   pardService3SubParamGroup
    ITEMS
    {
        parMappingAdder(READ_ONLY),
        parMappingWidthNew(READ_ONLY),
        parMappingAverage(READ_ONLY),
        parFactoryTdt(READ_ONLY),
        parFacAdder(READ_ONLY),
        parFACWidthNew(READ_ONLY),
        parRangeFactoryMap(READ_ONLY),
        parFactoryMappingValid(READ_ONLY),
        parCustomerMappingValid(READ_ONLY)
    }
 VALIDITY IF(ServiceValidity){ TRUE; }
   ELSE
    { FALSE; }
 
}

MENU service_lv_4 {
    LABEL                   pardService4SubParamGroup
    ITEMS
    {
        parEdgeDetectionMode(READ_ONLY),
        parEdgeParameter(READ_ONLY),
        parCalcEdgeParameter(READ_ONLY)
    }
 VALIDITY IF(ServiceValidity){ TRUE; }
   ELSE
    { FALSE; }
 
}

MENU service_lv_5 {
    LABEL                   pardService5SubParamGroup
    ITEMS
    {
        parFirstEchoFactor(READ_ONLY),
        parFefThreshold(READ_ONLY),
        parFefNearFactor(READ_ONLY),
        parFefDistanceNear(READ_ONLY),
        parFefDistanceFar(READ_ONLY),
        parFefEdge(READ_ONLY),
        parMaxEchoSN(READ_ONLY),
/*        parCurrentFirstEchoFactor(READ_ONLY)*/
    }
    VALIDITY IF(ServiceValidity){ TRUE; }
      ELSE
    { FALSE; }
    
}

MENU service_lv_6 {
 LABEL  pardService6SubParamGroup
 ITEMS { 
        parDishBottomDet(READ_ONLY),
        parAmplLevelBottomDet(READ_ONLY),
        parMinLevelBottomDet(READ_ONLY),
        parRangeTankBottomDetection(READ_ONLY),
        parClipDistanceToEmpty(READ_ONLY),
        parLevelSpeed(READ_ONLY)
 } 
 VALIDITY IF(ServiceValidity){ TRUE; }
   ELSE
    { FALSE; }
 
}

MENU service_lv_7 {
    LABEL                   pardService7SubParamGroup
    ITEMS
    {
        parHfModul(READ_ONLY),
        parZeroDistance(READ_ONLY),
        parPositionOfReferencePulse(READ_ONLY),
        parAmplOfReferencePulse (READ_ONLY)
    }
 VALIDITY IF(ServiceValidity){ TRUE; }
   ELSE
    { FALSE; }
 
}

MENU service_lv_8 {
    LABEL                   pardService8SubParamGroup
    ITEMS
    {
        parAntennaType(READ_ONLY),
        parInactiveLength(READ_ONLY),
        parTotalLength(READ_ONLY),
        parAbsMaxMessDist(READ_ONLY),
        parEditRangeMaxSampleDist(READ_ONLY)
       
    }
 VALIDITY IF(ServiceValidity){ TRUE; }
   ELSE
    { FALSE; }
 
}

//KVP4 Start
MENU service_lv_9
{
        LABEL                   pardService9SubParamGroup
    ITEMS
    {
        parDelayTimer(READ_ONLY),
        parEchoFoundDelay(READ_ONLY),
        parEchoLostDelay(READ_ONLY),
        parJumpDelayBase(READ_ONLY),
        parJumpDelaySlope(READ_ONLY),
        parNoJumpWindowWith(READ_ONLY),
        parWeightMode(READ_ONLY)
    }
   VALIDITY IF(ServiceValidity){ TRUE; }
   ELSE
    { FALSE; }
   
}
//KVP4 End

MENU service_lv_12 {
        LABEL                   pardService12SubParamGroup
    ITEMS
    {
        parDisplayVersion(READ_ONLY),
        parCalculatedCycleTime(READ_ONLY),
        parSwVersion(READ_ONLY),
        parParamVersion(READ_ONLY)
    }
 VALIDITY IF(ServiceValidity){ TRUE; }
   ELSE
    { FALSE; }
 
}

MENU service_lv_13 {
    LABEL                   pardService13SubParamGroup
    ITEMS
    {
        parDeviceIDNumber(READ_ONLY)
    }
 VALIDITY IF(ServiceValidity){ TRUE; }
   ELSE
    { FALSE; }
 
}

MENU service_lv_15 {
        LABEL                   pardService15SubParamGroup
    ITEMS
    {
        parDaaIndex1(READ_ONLY),
        parDaaIndex2(READ_ONLY),
        parDaaRdWrValue(READ_ONLY),
        parErrorStateOfAlgorithm(READ_ONLY),
        parStateOfAlgorithm (READ_ONLY)
    }
 VALIDITY IF(ServiceValidity){ TRUE; }
   ELSE
    { FALSE; }
 
}

MENU Menu_Main_Maintenance {
 LABEL  [main_menu] ;
 ITEMS { 
  Menu_File,
  Menu_S_Device,
  Menu_S_View,
  Menu_S_Options,
  Menu_Help
 } 
}

MENU Table_Main_Maintenance {
 LABEL  DEFAULT_VALUE_phys_device_id ;
 ITEMS { 
  MenuMainMicroPilot_M,
  IF (Hnd011) {
        Tab_s_PA_Profil
  }
  IF (!(Hnd011)) {
        Tab_s_PA_Profil_RO
     }
 } 
}


/* !Methods! ***************************************************************************/



VARIABLE LockDownload
{
  LABEL   "LockDownload";
  HELP   "LockDownload";
  CLASS LOCAL;
   VALIDITY TRUE;
   HANDLING READ & WRITE;
   TYPE INTEGER;
   DEFAULT_VALUE 1;
}


METHOD Convert
{
 DEFINITION
 {
  float fact;
  if((preDistanceUnit == Unit_mm) && (parDistanceUnit16 == Unit_m)){
   fact = 0.001;
  }
  if((preDistanceUnit == Unit_mm) && (parDistanceUnit16 == Unit_ft)){
   fact = 0.003281;
  }
  if((preDistanceUnit == Unit_mm) && (parDistanceUnit16 == Unit_inch)){
   fact = 0.03937 ;
  }
  if((preDistanceUnit == Unit_m) && (parDistanceUnit16 == Unit_mm)){
   fact = 1000;
  }
  if((preDistanceUnit == Unit_m) && (parDistanceUnit16 == Unit_inch)){
   fact = 39.37 ;
  }
  if((preDistanceUnit == Unit_m) && (parDistanceUnit16 == Unit_ft)){
   fact = 3.28083 ;
  }
  if((preDistanceUnit == Unit_ft) && (parDistanceUnit16 == Unit_mm)){
   fact = 304.8;
  }
  if((preDistanceUnit == Unit_ft) && (parDistanceUnit16 == Unit_m)){
   fact = 0.3048 ;
  }
  if((preDistanceUnit == Unit_ft) && (parDistanceUnit16 == Unit_inch)){
   fact = 11.999976;
  }
  if((preDistanceUnit == Unit_inch) && (parDistanceUnit16 == Unit_m)){
   fact = 0.0254;
  }
  if((preDistanceUnit == Unit_inch) && (parDistanceUnit16 == Unit_mm)){
   fact = 25.4;
  }
  if((preDistanceUnit == Unit_inch) && (parDistanceUnit16 == Unit_ft)){
   fact = 0.083333;
  }
    
  if(fact!=0){
                        fassign(parEmptyCalibration,fvar_value(parEmptyCalibration)*fact);
                        fassign(parFullCalibration,fvar_value(parFullCalibration)*fact);
                        fassign(parLevelWithinSafetyDistanceance,fvar_value(parLevelWithinSafetyDistanceance)*fact);
                        fassign(parInputLevelManual,fvar_value(parInputLevelManual)*fact);
                        fassign(parOffsetOfMeasuredLevelance,fvar_value(parOffsetOfMeasuredLevelance)*fact);
                        fassign(parAntennaExtensionLength,fvar_value(parAntennaExtensionLength)*fact);
                        fassign(parBlockingDistance,fvar_value(parBlockingDistance)*fact);
                        fassign(parPresMapRange,fvar_value(parPresMapRange)*fact);      
                        fassign(parSuppressionDistance,fvar_value(parSuppressionDistance)*fact);        
                        fassign(parRangeFactoryMap,fvar_value(parRangeFactoryMap)*fact);        
                        fassign(parAbsMaxMessDistance,fvar_value(parAbsMaxMessDistance)*fact);  
                        fassign(parRangeFactoryMap, fvar_value(parRangeFactoryMap)*fact);

                        fassign(parCylinderVessel, fvar_value(parCylinderVessel)*fact);
                        fassign(parInputLevelHalfAutomaticmatic, fvar_value(parInputLevelHalfAutomaticmatic)*fact);
                        fassign(parSimulationValueLevel, fvar_value(parSimulationValueLevel)*fact);
                        fassign(parEditRangeMaxSampleDist, fvar_value(parEditRangeMaxSampleDist)*fact);
                }
 }
}

METHOD nonMetricToMetricUnits
{
        DEFINITION
        {
                fassign(parTubeDiameter, fvar_value(parTubeDiameter)*25.4);
                fassign(parUnfilteredDistance, fvar_value(parUnfilteredDistance)*25.4);
                fassign(parHystereseWidth, fvar_value(parHystereseWidth)*25.4);
                fassign(parEchoLostRampUp, fvar_value(parEchoLostRampUp)*25.4);
                fassign(parEchoLostRampDown, fvar_value(parEchoLostRampDown)*25.4);
                fassign(parUnfilteredDistanceRaw, fvar_value(parUnfilteredDistanceRaw)*25.4);
                fassign(parFefDistanceNear, fvar_value(parFefDistanceNear)*25.4);
                fassign(parFefDistanceFar, fvar_value(parFefDistanceFar)*25.4);
                fassign(parMinLevelBottomDet, fvar_value(parMinLevelBottomDet)*25.4);
                fassign(parLevelSpeed, fvar_value(parLevelSpeed)*25.4);
                fassign(parZeroDistance, fvar_value(parZeroDistance)*25.4);
                fassign(parInactiveLength, fvar_value(parInactiveLength)*25.4);
                fassign(parTotalLength, fvar_value(parTotalLength)*25.4);
                fassign(parPositionOfReferencePulse, fvar_value(parPositionOfReferencePulse)*25.4);

                fassign(parFACWidthNew, fvar_value(parFACWidthNew)*25.4);
                fassign(parInnovationFiltConstMax, fvar_value(parInnovationFiltConstMax)*25.4);
                fassign(parFilterBreite, fvar_value(parFilterBreite)*25.4);
                fassign(parMergingWindow, fvar_value(parMergingWindow)*25.4);
                fassign(parMergingEchoDist, fvar_value(parMergingEchoDist)*25.4);
                fassign(parMappingWidthNew, fvar_value(parMappingWidthNew)*25.4);
                fassign(parRangeTankBottomDetection, fvar_value(parRangeTankBottomDetection)*25.4);
                fassign(parNoJumpWindowWith, fvar_value(parNoJumpWindowWith)*25.4);
        }
}

METHOD metricToNonMetricUnits
{
        DEFINITION
        {
                fassign(parTubeDiameter, fvar_value(parTubeDiameter)/25.4);
                fassign(parUnfilteredDistance, fvar_value(parUnfilteredDistance)/25.4);
                fassign(parHystereseWidth, fvar_value(parHystereseWidth)/25.4);
                fassign(parEchoLostRampUp, fvar_value(parEchoLostRampUp)/25.4);
                fassign(parEchoLostRampDown, fvar_value(parEchoLostRampDown)/25.4);
                fassign(parUnfilteredDistanceRaw, fvar_value(parUnfilteredDistanceRaw)/25.4);
                fassign(parFefDistanceNear, fvar_value(parFefDistanceNear)/25.4);
                fassign(parFefDistanceFar, fvar_value(parFefDistanceFar)/25.4);
                fassign(parMinLevelBottomDet, fvar_value(parMinLevelBottomDet)/25.4);
                fassign(parLevelSpeed, fvar_value(parLevelSpeed)/25.4);
                fassign(parZeroDistance, fvar_value(parZeroDistance)/25.4);
                fassign(parInactiveLength, fvar_value(parInactiveLength)/25.4);
                fassign(parTotalLength, fvar_value(parTotalLength)/25.4);
                fassign(parPositionOfReferencePulse, fvar_value(parPositionOfReferencePulse)/25.4);

                fassign(parFACWidthNew, fvar_value(parFACWidthNew)/25.4);
                fassign(parInnovationFiltConstMax, fvar_value(parInnovationFiltConstMax)/25.4);
                fassign(parFilterBreite, fvar_value(parFilterBreite)/25.4);
                fassign(parMergingWindow, fvar_value(parMergingWindow)/25.4);
                fassign(parMergingEchoDist, fvar_value(parMergingEchoDist)/25.4);
                fassign(parMappingWidthNew, fvar_value(parMappingWidthNew)/25.4);
                fassign(parRangeTankBottomDetection, fvar_value(parRangeTankBottomDetection)/25.4);
                fassign(parNoJumpWindowWith, fvar_value(parNoJumpWindowWith)/25.4);
        }
}



METHOD uploadVariablesPreWriteActions
{
        LABEL "Download of the Operation Code before uploading the variables" ;
        DEFINITION
        {
              if (parShowAccess==0)
                {
                        ACKNOWLEDGE ([ack_no_access]);
                        local_abort = 1; 
                }
              if (parOperationCode==WHG)
                {
                        ACKNOWLEDGE ([ack_WHG]);
                        local_abort = 1; 
                }
                if (LockDownload==1)
                {
                        ACKNOWLEDGE([ack_no_upload]);
                        local_abort = 1; 
                }

/*                WriteCommand(write_parOperationCodeFFPAOnline);*/
        }
}


METHOD downloadVariablesPreReadActions
{
        LABEL "downloadVariablesPreReadActions" ;
        DEFINITION
        {
                LockDownload=1;
                ReadCommand(read_parDistanceUnit16);
                ReadCommand(read_parOperationCodeFFPAOnline);
                ReadCommand(read_parEditRangeMaxSampleDist);
                ReadCommand(read_parAbsMaxMessDist);
                ReadCommand(read_parTemperatureUnit);                
                ReadCommand(read_parCheckDistance);
                ReadCommand(read_parSuppressionDistance);
                ReadCommand(read_phys_software_rev);
            ReadCommand(id_phys_serial_num);

        }
}


METHOD downloadVariablesPostReadActions
{                                                       
 CLASS  INPUT;
 DEFINITION
 {
  int ret;
                char  szs[];
                LockDownload=0;
  }
}


METHOD Set_WHG
{
        DEFINITION
        {
               if (parOperationMode == enum_level_overspill_V)
                {
                   parSavedOperationCode=parOperationCode;
                   parOperationCode=WHG;
                }
                else if (parOperationMode== enum_standard_V)
                {
                   parOperationCode=parSavedOperationCode;
                }
        }
}

METHOD updateParShowAccess
{
        LABEL "|en|Transfer|de|bertragen";
        DEFINITION
        {
                parOperationCodeFFPAOnline = parOperationCode;
                switch (parOperationCode)
                {
                        case SERVICEUNLOCKCODE:
                        {
                                parShowAccess = 3;
                        }; break;
                        case CUSTOMERUNLOCKCODE:
                        {
                                parShowAccess = 1;
                        }; break;
                        case 33998:
                        {
                                parShowAccess = 5;
                        }; break;
                        case 33999:
                        {
                                parShowAccess = 7;
                        }; break;
                        case 33123:
                        {
                                parShowAccess = 6;
                        }; break;
                        default:
                        {
                                parShowAccess = 0;      // 0
                        }; break;
                }
                save_values();                
        }
}



METHOD std_CommWay
{
     LABEL          [menu_Device_CommWay];
     DEFINITION
     {
     }
}

MENU upload_variables { 
 LABEL "|en|Upload variables";
 PRE_WRITE_ACTIONS 
 {
    uploadVariablesPreWriteActions
 }

 ITEMS { 
              IF ((LockDownload!=1) && (parShowAccess!=0) && (parOperationCode!=WHG))
              {
		IF ( Hnd011 ) {
			func1_AI_pv_lower_range_value,
			func1_AI_out_lower_range_value,
			func1_AI_lo_lo_lim,
			phys_descriptor,
			func1_AI_pv_upper_range_value,
			func1_AI_out_upper_range_value,
			func1_AI_lo_lim,
			phys_message,
			func1_AI_out_unit,
			func1_AI_hi_lim,
			func1_AI_pv_ftime,
			func1_AI_hi_hi_lim,
			phys_install_date,
			func1_AI_out_decimal_point,
			func1_AI_alarm_hys,
			func1_AI_FSafeType,
			func1_AI_FSafeValue
		}
		IF ( Hnd000 ) { 
			phys_tag_desc
		}

                        IF (Hnd034)
                        {
                                parDistanceUnit16 
                                parMediaType
                                parDelayTimeOnLostEcho 
                                parLanguage,            
                                parTagNumber32 
                                parFormatDisplayDec16inch
                                parReactionLostEcho
                                parSimulation
                                parAcknowledgeAlarm
                                parLevelWithinSafetyDistance 
                                parInSafetyDistance 
                                parOutputDamping 
                                parBlockingDistance 
                                parBackToHome 
                                parClearLastError 
                                parAntennaExtensionLength 
                                parEmptyCalibration 
                                parFullCalibration 
                                IF (Val026)
                                { parNoOfDecimalsUpTo3
                                  parSeparationCharacter}
                                IF (Val027)
                                { 
                                  parTankShape
                                  parDielectricConstant
                                  parProcessCondition}
                                IF (Val028)
                                { parVesselSilo
                                  parDielectricConstantSolid
                                  parProcessConditionSolid}
                                parOutputOnAlarm,
                                IF (Val034)
                                { parTubeDiameter}
                                IF (Val035)
                                { parOutputAtError}
                                IF (Val036)
                                { parRampInPercentPerMin}
                                IF (Val044)
                                { parSimulationValueLevel}
                                IF (Val045)
                                { parSimulationValueVolume}
                      }

              }
        }
}


MENU download_variables { 
 LABEL [menu_load_to_PC] ; 
        POST_READ_ACTIONS {
                downloadVariablesPostReadActions
 }
 PRE_READ_ACTIONS {
  downloadVariablesPreReadActions
 }
 ITEMS {
                phys_tag_desc
                phys_descriptor
                phys_message
                parPAProfileRevision,
		parPASetUnitToBus,
                parAbsMaxMessDist,
                parPADeviceBusAddress,
                parPAIdentNumberSelector
		parPAAIOutValue,
		parPAAIOutStatus,
		parPA2ndCyclicValue,
		parPASelectMainValue
                parMeasuredValue ,
                parMediaType,
                parTankShape,
                parDielectricConstant,
                parProcessCondition,
                parVesselSilo,
                parDielectricConstantSolid,
                parProcessConditionSolid,
                parEmptyCalibration ,
                parFullCalibration ,
                parTubeDiameter ,
                parReactionLostEcho,
                parRampInPercentPerMin,
                parDelayTimeOnLostEcho,
                parLevelWithinSafetyDistance,
                parInSafetyDistance,
                parAcknowledgeAlarm,
                parOperationMode,
                parLevelUllageMode,
                parLinearisation,
                parCustomerUnit,
                parTableNumber,
                parInputLevelManual,
                parInputLevelHalfAutomatic,
                parInputVolume,
                parMaxVolume,
                parCylinderVessel,
                parCheckDistance,
                parSuppressionDistance,
                parStartMappingRecord,
                parPresMapRange,
                parCustTankMap,
                parEchoQuality,
                parOffsetOfMeasuredLevel,
                parOutputDamping,
                parBlockingDistance,
                parSimulation,
                parSimulationValueLevel,
                parSimulationValueVolume,
                parLanguage,
                parBackToHome,
                parFormatDisplayDec16inch,
                parNoOfDecimalsUpTo3,
                parSeparationCharacter,
                parAmplitudeOverSupp,
                parAmplitudeOverFAC,
                parUnfilteredDistance,
                parCalcEdgeParameter,
                parCurrentFirstEchoFactor,
                parDeviceName,
                parOrderCode,
                parMamFilterLength,
                parMamFilterBorder,
                parFilterConstMin,
                parFilterConstMax,
                parInnovationFiltConstMax,
                parHystereseWidth,
                parEchoLostRampUp,
                parEchoLostRampDown,
                parUnfilteredDistanceRaw,
                parFilterBreite,
                parSawitzkiGolay,
                parHkStatCountPos,
                parHkStatCountNeg,
                parMergingEchoes,
                parMergingWindow,
                parMergingEchoDist,
                parMergingRatio,
                parEnvelopeEnergy,
                parMappingAdder,
                parMappingWidthNew,
                parMappingAverage,
                parFactoryTdt,
                parFacAdder,
                parFACWidthNew,
                parRangeFactoryMap,
                parFactoryMappingValid,
                parCustomerMappingValid,
                parEdgeDetectionMode,
                parEdgeParameter,
                parCalcEdgeParameter,
                parFirstEchoFactor,
                parFefThreshold,
                parFefNearFactor,
                parFefDistanceNear,
                parFefDistanceFar,
                parFefEdge,
                parMaxEchoSN,
                parCurrentFirstEchoFactor,
                parDishBottomDet,
                parAmplLevelBottomDet,
                parMinLevelBottomDet,
                parRangeTankBottomDetection,
                parClipDistanceToEmpty,
                parOutputOnAlarm,
                parLevelSpeed,
                parHfModul,
                parZeroDistance,
                parPositionOfReferencePulse,
                parAmplOfReferencePulse,
                parAntennaType,
                parInactiveLength,
                parTotalLength,
                parEditRangeMaxSampleDist,
                parDelayTimer,
                parEchoFoundDelay,
                parEchoLostDelay,
                parJumpDelayBase,
                parJumpDelaySlope,
                parNoJumpWindowWith,
                parWeightMode,
                /*parWireType,*/
                parDisplayVersion,
                parCalculatedCycleTime,
                parSwVersion,
                parParamVersion,
                parDaaIndex1,
                parDaaIndex2,
                parDaaRdWrValue,
                parErrorStateOfAlgorithm,
                parStateOfAlgorithm,
                parActualError,
                parLastError,
                parClearLastError,
                parReset,
                parOperationCodeFFPAOnline,
                parMeasuredDistance,
                parMeasuredLevel,
                parDetectionWindow,
                parApplicationParameter,
                parTagNumber32,
                parProtSoftVersionString,
                parSerialNumber,
                parDistanceUnit16,
                parDownloadMode,
                parAntennaExtensionLength
                phys_device_man_id
                phys_device_ser_num
                phys_software_rev
                phys_hardware_rev
                phys_install_date
                phys_st_rev
                func1_AI_out_unit
                func1_AI_pv_lower_range_value
                func1_AI_pv_upper_range_value
                func1_AI_out_lower_range_value
                func1_AI_out_upper_range_value
                func1_AI_pv_ftime
                func1_AI_out_decimal_point
                func1_AI_lo_lo_lim
                func1_AI_lo_lim
                func1_AI_hi_lim
                func1_AI_hi_hi_lim
                func1_AI_alarm_hys
                func1_AI_FSafeType
                func1_AI_FSafeValue
                phys_device_certification

 }
}
/****************************************VH01****************************************/

VARIABLE parMediaType
{
   parMediaTypeLAH
   DEFAULT_VALUE 1;
   HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
   TYPE parMediaTypeEL
}

/****************************************VH65****************************************/

VARIABLE parNoOfDecimalsUpTo3
{
   DEFAULT_VALUE 2;
   parNoOfDecimalsUpTo3LAH
   HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
   TYPE parNoOfDecimalsUpTo3EL
   VALIDITY IF(Val026){TRUE;} ELSE {FALSE;}
   
}

VARIABLE parOperationCodeFFPAOnline {
	LABEL 	"|en|unlock parameter|de|Freigabecode|fr|code operation|es|Freigabecode|it|Modo operativo|nl|startcode" ;
        CLASS   CONTAINED; 
	TYPE  UNSIGNED_INTEGER (2)  {
                DISPLAY_FORMAT  "5.1u" ;                
                EDIT_FORMAT     "5.1u" ;                
                MIN_VALUE       0 ;             
                MAX_VALUE       40000 ;         
	}
        POST_READ_ACTIONS  { 
                updateParShowAccess
	}
} 


/****************************************VH94****************************************/

VARIABLE parOperationCode
{
   DEFAULT_VALUE 2457;
   parOperationCodeLAH
   CLASS LOCAL;
   HANDLING IF (Hnd008) {READ;} ELSE {READ & WRITE;}
   TYPE  UNSIGNED_INTEGER (2)
   {
      EDIT_FORMAT    "5u";
      DISPLAY_FORMAT "5u";
      MIN_VALUE       0;
      MAX_VALUE   33998;
   }

}

parSavedOperationCode LIKE VARIABLE parOperationCode
{ REDEFINE DEFAULT_VALUE 2457; }

/****************************************VH64****************************************/

VARIABLE parFormatDisplayDec16inch
{
   DEFAULT_VALUE  0;
   parFormatDisplayDec16inchLAH
    HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
   TYPE parFormatDisplayDec16inchEL 
}



/****************************************VH02liquid****************************************/

VARIABLE  parTankShape {
	LABEL 	"|en|tank shape|de|Tankgeometrie|fr|Forme reservoir|es|Tankgeometrie|it|Forma serbatoio|nl|Tankvorm" ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	VALIDITY IF (parMediaType==0)
                 { TRUE; }
             ELSE
                 { FALSE; }
	TYPE 	ENUMERATED	{
		{ 0 ,"|en|dome ceiling|de|Kloepperdeckel|fr|Toit bombe|es|techo bveda|it|tetto bombato|nl|dome plafond"},
		{ 20 ,"|en|horizontal cyl|de|zyl.liegend|fr|cyl. horizont.|es|cilind. horiz.|it|cilind. orizz.|nl|horizont. cyl."},
		{ 2 ,"|en|bypass|de|Bypass|fr|Bypass|es|bypass|it|bypass|nl|by-pass"},
		{ 3 ,"|en|stilling well|de|Schwallrohr|fr|Tube de mesure|es|tubo tranquil.|it|tubo di calma|nl|duikpyp"},
		{ 4 ,"|en|flat ceiling|de|Flachdeckel|fr|Toit plat|es|techo plano|it|tetto piatto|nl|vlak plafond"},
		{ 5 ,"|en|sphere|de|Kugeltank|fr|Spherique|es|esfera|it|sfera|nl|sferisch"}
}
} 


/****************************************VHXXSolid****************************************/

VARIABLE parVesselSilo
{
   DEFAULT_VALUE  0;
   parVesselSiloLAH
   HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
   TYPE parVesselSiloEL
   VALIDITY IF(Val028){TRUE;} ELSE {FALSE;}
   
}

/****************************************VH18****************************************/

VARIABLE parOperationMode
{
   DEFAULT_VALUE  0;
   parOperationModeLAH
   HANDLING CUSTOMERLOCK
   TYPE parOperationModeEL

 

}

/****************************************VH03liquid****************************************/

VARIABLE parDielectricConstant {
        LABEL "medium property|de|Medium Eigensch.|fr|charact.du prod|es|Medium Eigensch.|it|caratt.del prod.|nl|produktconstante" ;
        CLASS CONTAINED ;
		 VALIDITY IF (parMediaType==0)
                                { TRUE; }
                        ELSE
                                { FALSE; }

        HANDLING IF ((parOperationCode == 2457)|| (parOperationCode == 33300)|| (parOperationCode == 33123))
                                { READ&WRITE; }
                        ELSE
                                { READ; }
        TYPE ENUMERATED { { 0 ,"unknown|de|unbekannt|fr|inconnu|es|desconocido|it|sconosciuta|nl|onbekend"}, { 1 ,"DC:< 1.9"}, { 2 ,"DC:1.9 ... 4"}, { 3 ,"DC:4 ... 10"}, { 4 ,"DC:> 10"} }
}


/****************************************VH03solid****************************************/

VARIABLE parDielectricConstantSolid{
        LABEL "medium property|de|Medium Eigensch.|fr|charact.du prod|es|Medium Eigensch.|it|caratt.del prod.|nl|produktconstante" ;
        VALIDITY IF (parMediaType==1)
                                { TRUE; }
                        ELSE
                                { FALSE; }


		CLASS CONTAINED ;
        HANDLING IF ((parOperationCode == 2457)|| (parOperationCode == 33300)|| (parOperationCode == 33123))
                                { READ&WRITE; }
                        ELSE
                                { READ; }
TYPE ENUMERATED {  { 0 ,"|en|unknown|de|unbekannt|fr|Inconnu|es|desconocido|it|sconosciuto|nl|Onbekend"}, { 1 ,"|en|DC:1.6 ... 1.9|de|DK:1.6 ... 1.9|fr|CD:1.6 ... 1.9|es|DC:1.6 ... 1.9|it|DC:1.6 ... 1.9|nl|DC:1.6 ... 1.9"}, { 2 ,"|en|DC:1.9 ... 2.5|de|DK:1.9 ... 2.5|fr|CD:1.9 ... 2.5|es|DC:1.9 ... 2.5|it|DC:1.9 ... 2.5|nl|DC:1.9 ... 2.5"}, { 3 ,"|en|DC:2.5 ... 4|de|DK:2.5 ... 4|fr|CD:2.5 ... 4|es|DC:2.5 ... 4|it|DC:2.5 ... 4|nl|DC:2.5 ... 4"}, { 4 ,"|en|DC:4 ... 7|de|DK:4 ... 7|fr|CD:4 ... 7|es|DC:4 ... 7|it|DC:4 ... 7|nl|DC:4 ... 7"}, { 5 ,"|en|DC: > 7|de|DK: > 7|fr|CD: > 7|es|DC: > 7|it|DC: > 7|nl|DC: > 7"}  }        
}



/****************************************VH04liquid****************************************/

VARIABLE parProcessCondition {
        LABEL "process cond.|de|Messbedingungen|fr|Cond. process|es|Messbedingungen|it|condiz. Processo|nl|proces conditier" ;
        CLASS CONTAINED ;
		 VALIDITY IF (parMediaType==0)
                                { TRUE; }
                        ELSE
                                { FALSE; }

        HANDLING IF ((parOperationCode == 2457)|| (parOperationCode == 33300)|| (parOperationCode == 33123))
                                { READ&WRITE; }
                        ELSE
                                { READ; }
        TYPE ENUMERATED {
        { 0 ,"standard|de|Standard|fr|standard|es|estndar|it|standard|nl|standaard"},
        { 1 ,"calm surface|de|Oberfl. ruhig|fr|Surface calme|es|sup. calmada|it|superf.calma|nl|rustig"},
        { 2 ,"turb. surface|de|Oberfl.unruhig|fr|Surface agitee|es|sup. turbul.|it|superf.turbol.|nl|onrustig"},
        { 3 ,"add. agitator|de|zus. Ruehrwerk|fr|supp.Agitateur|es|adic. agitador|it|supp.agitatore|nl|plus roerwerk"},
        { 4 ,"fast change|de|schnelle aender|fr|Variat. rapide|es|camb. rpidos|it|cambiam.veloci|nl|snelle variat."},
        { 5 ,"test:no filter|de|Test:Filt. aus|fr|Test:pas filt.|es|test:no filtro|it|test:no filtro|nl|test:no filter"}
}
        
}

/****************************************VH04solid****************************************/

VARIABLE parProcessConditionSolid {
        LABEL "process cond.|de|Messbedingungen|fr|Cond. process|es|Messbedingungen|it|condiz. Processo|nl|proces conditier" ;
        VALIDITY IF (parMediaType==1)
                                { TRUE; }
                        ELSE
                                { FALSE; }


		CLASS CONTAINED ;
        HANDLING IF ((parOperationCode == 2457)|| (parOperationCode == 33300)|| (parOperationCode == 33123))
                                { READ&WRITE; }
                        ELSE
                                { READ; }

		TYPE ENUMERATED {  
{ 0 ,"|en|standard|de|Standard|fr|Standard|es|estndar|it|standard|nl|standaard"}, 
{ 1 ,"|en|fast change|de|schnelle nder|fr|Variat. rapide|es|camb. rpidos|it|cambiam.veloci|nl|snelle variat."}, 
{ 2 ,"|en|slow change|de|langsame nder|fr|Variat. lente|es|cambio lento|it|variaz lente|nl|langzame corr."}, 
{ 3 ,"|en|test:no filter|de|Test:Filt. aus|fr|Test:pas filt.|es|test:no filtro|it|test:no filtro|nl|test:no filter"} 
 }
        
}



/****************************************VH05****************************************/

VARIABLE parEmptyCalibration
{
   DEFAULT_VALUE  22;
   parEmptyCalibrationLAH
   HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
   TYPE FLOAT
      {
         EDIT_FORMAT "9.3f";
         DISPLAY_FORMAT "9.3f";
         MIN_VALUE 0.0;
         MAX_VALUE parAbsMaxMessDist;
      }
}

/****************************************VHA5****************************************/

VARIABLE parDistanceUnit16
{
   DEFAULT_VALUE  1010;
   parDistanceUnit16LAH
   HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
  TYPE    ENUMERATED(2)   { DEFAULT_VALUE 1010;  { 1010 ,"|en|m"}, { 1018 ,"|en|ft"}, { 1019 ,"|en|inch"}, { 1013 ,"|en|mm"}  }
}

/****************************************VH7/84***************************************/

VARIABLE parAbsMaxMessDist
{
   DEFAULT_VALUE  70.000;
   parAbsMaxMessDistLAH
   CLASS    COMPUTATION & DYNAMIC;
   HANDLING READ;
   TYPE  FLOAT
         {
            EDIT_FORMAT "9.3f";
            DISPLAY_FORMAT "9.3f";
         }
  /* */
}

/****************************************VH06****************************************/

VARIABLE parFullCalibration
{
   DEFAULT_VALUE  22;
   parFullCalibrationLAH
    HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
   TYPE     FLOAT
            {
               EDIT_FORMAT "9.3f";
               DISPLAY_FORMAT "9.3f";
               MIN_VALUE 0.0;
               MAX_VALUE parAbsMaxMessDist;
            }
}

/****************************************VH07****************************************/

VARIABLE parTubeDiameter
{
   DEFAULT_VALUE  204.425;
   parTubeDiameterLAH
    HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
   TYPE  FLOAT
         {
            EDIT_FORMAT "9.3f";
            DISPLAY_FORMAT "9.3f";
            MIN_VALUE
            SELECT (parDistanceUnit16)
            {
               CASE 1018 :    0.039;
               CASE 1010 :    1.000;
               CASE 1019 :    0.039;
               CASE 1010 :    1.000;
               DEFAULT:    204.425;
            }
            MAX_VALUE
            SELECT (parDistanceUnit16)
            {
               CASE 1018 :    393.701;
               CASE 1010 :  10000.000;
               CASE 1019 :    393.701;
               CASE 1010 :  10000.000;
               DEFAULT:     204.425;
            }
   }
   CONSTANT_UNIT  SELECT (parDistanceUnit16)
            {
            CASE 1018: "inch";
            CASE 1010:   "mm";
            CASE 1019: "inch";
            CASE 1010:   "mm";
            DEFAULT:   "mm";
            }
   
   VALIDITY IF(Val034){TRUE;} ELSE {FALSE;}
}

/****************************************VH10****************************************/


VARIABLE parReactionLostEcho
{
   DEFAULT_VALUE  239;
   parReactionLostEchoLAH
   HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
   TYPE    ENUMERATED      {  DEFAULT_VALUE 1; { 0 ,"|en|alarm|de|Alarm|fr|Alarme|es|alarma|it|allarme|nl|Alarm"}, { 1 ,"|en|hold|de|Halten|fr|Maintien|es|Mantener|it|Ultimo valore|nl|Hold"}, { 2 ,"|en|ramp %/min|de|Rampe %/min|fr|Rampe %/min|es|rampa %/min|it|rampa %/min|nl|Steilh. %/min"}  }
}

/****************************************VH13****************************************/

VARIABLE parRampInPercentPerMin
{
   DEFAULT_VALUE  0;
 parRampInPercentPerMinLAH
    HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
 parRampInPercentPerMinU
 TYPE  FLOAT
   {
    EDIT_FORMAT "10.3f";
    DISPLAY_FORMAT "10.3f";
    MIN_VALUE -999999.0;
    MAX_VALUE  999999.0;
   }
 VALIDITY IF(Val036){TRUE;} ELSE {FALSE;}
 
}

/****************************************VH14****************************************/

VARIABLE parDelayTimeOnLostEcho
{
   DEFAULT_VALUE  60;
 parDelayTimeOnLostEchoLAH
    HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
 parDelayTimeOnLostEchoU
 TYPE  UNSIGNED_INTEGER (2)
    {
     EDIT_FORMAT "5u";
     DISPLAY_FORMAT "5u";
     MIN_VALUE 0;
     MAX_VALUE    65535;
    }
}

/****************************************VH30****************************************/

VARIABLE parLevelUllageMode
{
   DEFAULT_VALUE  0;
 parLevelUllageModeLAH
 CLASS  COMPUTATION & DYNAMIC;
    HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
 TYPE parLevelUllageModeEL 
}

/****************************************VH31****************************************/

VARIABLE parLinearisation
{
   DEFAULT_VALUE  0;
 parLinearisationLAH
    HANDLING IF (Hnd026) {READ & WRITE;} ELSE {READ;}
 TYPE  parLinearisationEL
}   

/****************************************VH15****************************************/

VARIABLE parLevelWithinSafetyDistance
{
 parLevelWithinSafetyDistanceanceLAH
    HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
 TYPE   FLOAT
    {
     EDIT_FORMAT "9.3f";
     DISPLAY_FORMAT "9.3f";
     MIN_VALUE 0.0;
     DEFAULT_VALUE  0.100;
     MAX_VALUE parEditRangeMaxSampleDist;
    }
 VALIDITY IF(Val041){FALSE;} ELSE {TRUE;}
}

/****************************************VH16****************************************/

VARIABLE parInSafetyDistance
{
   DEFAULT_VALUE  1;
 parInSafetyDistanceLAH
    HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
 TYPE parInSafetyDistanceEL
}

/****************************************VH17****************************************/

VARIABLE parAcknowledgeAlarm
{
    DEFAULT_VALUE  0;
    parAcknowledgeAlarmLAH
    HANDLING CUSTOMERLOCK
    TYPE  parAcknowledgeAlarmEL
    POST_WRITE_ACTIONS {gotokeep}
}

/****************************************VH32****************************************/

VARIABLE parCustomerUnit
{
   DEFAULT_VALUE  1342;
 parCustomerUnitLAH
    HANDLING IF (Hnd026) {READ & WRITE;} ELSE {READ;}
	TYPE 	ENUMERATED(2)	        {	  DEFAULT_VALUE 1342;
                {1342,"%"},
                {1038,"l "},
                {1041,"hl"},
                {1034,"m"},
                {1035,"dm"},
                {1036,"cm"},
                {1043,"ft"},
                {1048,"us_gal"},
                {1049,"i_gal"},
                {1088,"kg"},
                {1092,"t"},
                {1094,"lb"},
                {1095,"ton"},
                {1010,"m"},
                {1018,"ft"},
                {1013,"mm"},
                {1019,"inch"},
                {1997, "none"}
}
}

/****************************************VH33****************************************/

VARIABLE parTableNumber
{
   DEFAULT_VALUE  1;
 parTableNumberLAH
 TYPE  UNSIGNED_INTEGER (1)
   {
    EDIT_FORMAT "2u";
    DISPLAY_FORMAT "2u";
    MIN_VALUE 1;
    MAX_VALUE 32;
   }
   
}

/****************************************VH34****************************************/

VARIABLE parInputLevelHalfAutomatic
{
   DEFAULT_VALUE  0;
 parInputLevelHalfAutomaticmaticLAH
 CLASS  COMPUTATION & DYNAMIC;
 HANDLING READ;
 TYPE    FLOAT
     {
      EDIT_FORMAT "9.3f";
      DISPLAY_FORMAT "9.3f";
     }
 VALIDITY IF(Val037){TRUE;} ELSE {FALSE;}
 
}

/****************************************VH35****************************************/

VARIABLE parInputLevelManual
{
   DEFAULT_VALUE  0;
 CLASS  COMPUTATION  & DYNAMIC;
 parInputLevelManualLAH
	HANDLING IF (Hnd030) {READ & WRITE;} ELSE {READ;}
 TYPE   FLOAT
    {
     EDIT_FORMAT "9.3f";
     DISPLAY_FORMAT "9.3f";
     MIN_VALUE 0.0;
     MAX_VALUE parAbsMaxMessDist;
	 DEFAULT_VALUE	0;
    }

	VALIDITY IF(Val037){FALSE;} ELSE {TRUE;}
 
}

/****************************************VH35****************************************/

VARIABLE parInputVolume
{
   DEFAULT_VALUE  0;
 CLASS  COMPUTATION & DYNAMIC;
 parInputVolumeLAH
    HANDLING IF (Hnd031) {READ & WRITE;} ELSE {READ;}
 TYPE  FLOAT
   {
    EDIT_FORMAT "10.3f";
    DISPLAY_FORMAT "10.3f";
    MIN_VALUE
    SELECT (parCustomerUnit)
     {
      CASE 1010: -999999.0*(1.0/1000.0);
      CASE 1018: -999999.0*(1.0/304.8);
      CASE 1019: -999999.0*(1.0/25.4);
      CASE 1010: -999999.0;
      DEFAULT: -999999.0;
     }    
    MAX_VALUE
    SELECT (parCustomerUnit)
     {
      CASE 1010: 999999.0*(1.0/1000.0);
      CASE 1018: 999999.0*(1.0/304.8);
      CASE 1019: 999999.0*(1.0/25.4);
      CASE 1010: 999999.0;
      DEFAULT: 999999.0;
     } 
   }
}

/****************************************VH36****************************************/

VARIABLE parMaxVolume
{
   DEFAULT_VALUE  100;
 parMaxVolumeLAH
    HANDLING IF (Hnd032) {READ & WRITE;} ELSE {READ;}
 TYPE  FLOAT
   {
    EDIT_FORMAT "10.3f";
    DISPLAY_FORMAT "10.3f";
    MIN_VALUE
    SELECT (parCustomerUnit)
     {
      CASE 1010: -999999.0*(1.0/1000.0);
      CASE 1018: -999999.0*(1.0/304.8);
      CASE 1019: -999999.0*(1.0/25.4);
      CASE 1010: -999999.0;
      DEFAULT: -999999.0;
     }    
    MAX_VALUE
    SELECT (parCustomerUnit)
     {
      CASE 1010: 999999.0*(1.0/1000.0);
      CASE 1018: 999999.0*(1.0/304.8);
      CASE 1019: 999999.0*(1.0/25.4);
      CASE 1010: 999999.0;
      DEFAULT: 999999.0;
     }    
   }
 VALIDITY IF(Val039){TRUE;} ELSE {FALSE;}
 
}

/****************************************VH37****************************************/

VARIABLE parCylinderVessel
{
   DEFAULT_VALUE  9000;
 parCylinderVesselLAH
    HANDLING IF (Hnd033) {READ & WRITE;} ELSE {READ;}
 TYPE   FLOAT
    {
     EDIT_FORMAT "8.3f";
     DISPLAY_FORMAT "8.3f";
     MIN_VALUE 0.0;
     MAX_VALUE parAbsMaxMessDist;
    }
 VALIDITY IF(Val040){TRUE;} ELSE {FALSE;}
 
}

/****************************************VH41****************************************/

VARIABLE parCheckDistance
{
   DEFAULT_VALUE  3;
 parCheckDistanceLAH
 HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
 TYPE  parCheckDistanceEL
}

/****************************************VH42****************************************/

VARIABLE parSuppressionDistance
{
   DEFAULT_VALUE  0;
 parSuppressionDistanceLAH
    HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
 TYPE   FLOAT
    {
     EDIT_FORMAT "9.3f";
     DISPLAY_FORMAT "9.3f";
     MIN_VALUE 0.0;
     MAX_VALUE parEditRangeMaxSampleDist;
    }
 VALIDITY IF(Val041){FALSE;} ELSE {TRUE;}
}

/****************************************VH43****************************************/

VARIABLE parStartMappingRecord
{
   DEFAULT_VALUE  0;
   parStartMappingRecordLAH
   HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
   TYPE  parStartMappingRecordEL
   VALIDITY IF(Val041){FALSE;} ELSE {TRUE;}
   

}

/****************************************VH44****************************************/

VARIABLE parPresMapRange
{
   DEFAULT_VALUE  3.000;
 parPresMapRangeLAH
 CLASS  COMPUTATION & DYNAMIC;
 HANDLING READ;
 TYPE   FLOAT
    {
     EDIT_FORMAT "9.3f";
     DISPLAY_FORMAT "9.3f";
    }
}

/****************************************VH45****************************************/

VARIABLE parCustTankMap
{
   DEFAULT_VALUE  0;
 parCustTankMapLAH
 HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
 TYPE  parCustTankMapEL
}

/****************************************VH46****************************************/

VARIABLE parEchoQuality
{
   DEFAULT_VALUE  0;
 parEchoQualityLAH
 CLASS  COMPUTATION & DYNAMIC;
 HANDLING READ;
 parEchoQualityU
 TYPE  UNSIGNED_INTEGER (1)
   {
    EDIT_FORMAT "3u";
    DISPLAY_FORMAT "3u";
   }
}

/****************************************VH47****************************************/

VARIABLE parOffsetOfMeasuredLevel
{
   DEFAULT_VALUE  0;
 parOffsetOfMeasuredLevelanceLAH
 HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
 TYPE  FLOAT
    {
     EDIT_FORMAT "10.3f";
     DISPLAY_FORMAT "10.3f";
        MIN_VALUE -(parAbsMaxMessDist);
     MAX_VALUE parAbsMaxMessDist;
    }
}

/****************************************VH48****************************************/

VARIABLE parOutputDamping
{
   DEFAULT_VALUE  15;
 parOutputDampingLAH
    HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
 parOutputDampingU
 TYPE  FLOAT
   {
    EDIT_FORMAT "7.1f";
    DISPLAY_FORMAT "7.1f";
    MIN_VALUE     0.0;
    MAX_VALUE 10000.0;
   }
}

/****************************************VH49****************************************/

VARIABLE parBlockingDistance
{

 parBlockingDistanceLAH
    HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
 TYPE   FLOAT
    {
     DEFAULT_VALUE  0.3;     
     EDIT_FORMAT "9.3f";
     DISPLAY_FORMAT "9.3f";
     MIN_VALUE 0.0;
     MAX_VALUE parEditRangeMaxSampleDist;
    }
}

/****************************************VH50****************************************/


VARIABLE parSimulation
{
   DEFAULT_VALUE  0;
 parSimulationLAH
    HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
 TYPE  parSimulationEL 
}

/****************************************VH56****************************************/

VARIABLE parSimulationValueLevel
{
   DEFAULT_VALUE  0;
 parSimulationValueLevelLAH
    HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
 TYPE  FLOAT
    {
     EDIT_FORMAT "9.2f";
     DISPLAY_FORMAT "9.2f";
   }
 VALIDITY IF(Val044){TRUE;} ELSE {FALSE;} 
}

/****************************************VH56****************************************/

VARIABLE parSimulationValueVolume
{
   DEFAULT_VALUE  0;
 parSimulationValueVolumeLAH
    HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
 TYPE  FLOAT
   {
    EDIT_FORMAT "9.3f";
    DISPLAY_FORMAT "9.3f";

   }
 VALIDITY IF(Val045){TRUE;} ELSE {FALSE;} 
}

/****************************************VH56****************************************/

/****************************************VH57****************************************/

VARIABLE parCurrentOutput
{
   DEFAULT_VALUE  22;
 parCurrentOutputLAH
 CLASS  COMPUTATION & DYNAMIC;
 HANDLING READ;
 parCurrentOutputU
 TYPE  FLOAT
   {
    EDIT_FORMAT "5.2f";
    DISPLAY_FORMAT "5.2f";
   }
}

/****************************************VH62****************************************/

VARIABLE parLanguage
{
   DEFAULT_VALUE  0;
 parLanguageLAH
 HANDLING CUSTOMERLOCK
 TYPE  parLanguageEL
}

/****************************************VH63****************************************/

VARIABLE parBackToHome
{
   DEFAULT_VALUE  900;
 parBackToHomeLAH
    HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
 parBackToHomeU
 TYPE  INTEGER (2)
   {
    EDIT_FORMAT "4i";
    DISPLAY_FORMAT "4i";
    MIN_VALUE    3;
    MAX_VALUE 9999;
   }
}

/****************************************VH66****************************************/

VARIABLE parSeparationCharacter
{
   DEFAULT_VALUE  0;
 parSeparationCharacterLAH
    HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
 TYPE parSeparationCharacterEL
 VALIDITY IF(Val026){TRUE;} ELSE {FALSE;}
 
}  

/************************************************************************************************************/
/*                         SERVICE VARIABLES            */
/************************************************************************************************************/

/*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*SERVICE_EBENE 0*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*/

/****************************************VH7/01***************************************/

VARIABLE parCurrentAmplitude
{
   DEFAULT_VALUE  0;
 parCurrentAmplitudeLAH
 CLASS  COMPUTATION & DYNAMIC;
 HANDLING READ;
 parCurrentAmplitudeU
 TYPE  INTEGER (1)
   {
    EDIT_FORMAT "3i";
    DISPLAY_FORMAT "3i";
   }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}

/****************************************VH7/02***************************************/

VARIABLE parAmplitudeOverSupp
{
   DEFAULT_VALUE  0;
 parAmplitudeOverSuppLAH
 CLASS  COMPUTATION & DYNAMIC;
 HANDLING READ;
 parAmplitudeOverSuppU
 TYPE  INTEGER (1)
   {
    EDIT_FORMAT "3i";
    DISPLAY_FORMAT "3i";
   }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}

/****************************************VH7/03***************************************/

VARIABLE parAmplitudeOverFAC
{
   DEFAULT_VALUE  0;
 parAmplitudeOverFACLAH
 CLASS  COMPUTATION & DYNAMIC;
 HANDLING READ;
 parAmplitudeOverFACU
 TYPE  INTEGER (1)
   {
    EDIT_FORMAT "4i";
    DISPLAY_FORMAT "4i";
   }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 

}

/****************************************VH7/04***************************************/

VARIABLE parUnfilteredDistance
{
   DEFAULT_VALUE  0;
 parUnfilteredDistanceLAH
 CLASS  COMPUTATION & DYNAMIC;
 HANDLING READ;
 TYPE  FLOAT
   {
    EDIT_FORMAT "8.2f";
    DISPLAY_FORMAT "8.2f";
   }
 CONSTANT_UNIT SELECT (parDistanceUnit16)
    {
     CASE 1018: "inch";
     CASE 1010:   "mm";
     CASE 1019: "inch";
     CASE 1010:   "mm";
     DEFAULT:   "mm";
    }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}

/****************************************VH7/05***************************************/

VARIABLE parCalcEdgeParameter
{
   DEFAULT_VALUE  0;
 parCalcEdgeParameterLAH
 CLASS  COMPUTATION & DYNAMIC;
 HANDLING READ;
 parCalcEdgeParameterU
 TYPE  UNSIGNED_INTEGER (1)
   {
    EDIT_FORMAT "4u";
    DISPLAY_FORMAT "4u";
   }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}

/****************************************VH7/06***************************************/

VARIABLE parCurrentFirstEchoFactor
{
   DEFAULT_VALUE 0;
 parCurrentFirstEchoFactorLAH
 CLASS  COMPUTATION & DYNAMIC;
 HANDLING READ;
 parCurrentFirstEchoFactorU
 TYPE  FLOAT
   {
    EDIT_FORMAT "5.1f";
    DISPLAY_FORMAT "5.1f";
   }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}

/****************************************VH7/08***************************************/

VARIABLE parDeviceName
{
   DEFAULT_VALUE  "FMR24x-25x";
 parDeviceNameLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE  ASCII (16);
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}
 
}

/****************************************VH7/09***************************************/

VARIABLE parOrderCode
{
   DEFAULT_VALUE  "";
 parOrderCodeLAH
     HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
     TYPE  ASCII (16);
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}
 
}

/*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*SERVICE_EBENE 1*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*/

/****************************************VH7/11***************************************/

VARIABLE parMamFilterLength
{
   DEFAULT_VALUE  20;
 parMamFilterLengthLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE  UNSIGNED_INTEGER (1)
   {
    EDIT_FORMAT "2u";
    DISPLAY_FORMAT "2u";
    MIN_VALUE 1;
    MAX_VALUE      32;
   }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}

/****************************************VH7/12***************************************/

VARIABLE parMamFilterBorder
{
   DEFAULT_VALUE  5;
 parMamFilterBorderLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE  UNSIGNED_INTEGER (1)
   {
    EDIT_FORMAT "2u";
    DISPLAY_FORMAT "2u";
    MIN_VALUE 0;
    MAX_VALUE 15;
   }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}


/****************************************VH7/16***************************************/

VARIABLE parHystereseWidth
{
   DEFAULT_VALUE  0;
 parHystereseWidthLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE  FLOAT
    {
     EDIT_FORMAT "8.3f";
     DISPLAY_FORMAT "8.3f";
     MIN_VALUE 0.0;
     MAX_VALUE
     SELECT (parDistanceUnit16)
     {
      CASE 1010: 1000.000;
      CASE 1019:   39.370;
      CASE 1010: 1000.000;
      CASE 1018:   39.370;
      DEFAULT: 1000.000;
     }
    }
 CONSTANT_UNIT SELECT (parDistanceUnit16)
    {
     CASE 1018: "inch";
     CASE 1010:   "mm";
     CASE 1019: "inch";
     CASE 1010:   "mm";
     DEFAULT:   "mm";
    }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 

}

/****************************************VH7/17***************************************/

VARIABLE parEchoLostRampUp
{
   DEFAULT_VALUE  0;
 parEchoLostRampUpLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE  FLOAT
    {
     EDIT_FORMAT "9.3f";
     DISPLAY_FORMAT "9.3f";
     MIN_VALUE 0.0;
     MAX_VALUE
            SELECT (parDistanceUnit16)
     {
         CASE 1010: 22000.000;
      CASE 1018: 866.14;
      CASE 1019: 866.14;
      CASE 1010: 22000.000;
      DEFAULT: 0.000;
     }
    }
 CONSTANT_UNIT SELECT (parDistanceUnit16)
    {
     CASE 1018: "inch/s";
     CASE 1010:   "mm/s";
     CASE 1019: "inch/s";
     CASE 1010:   "mm/s";
     DEFAULT:   "mm/s";
    }
   VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}   

}

/****************************************VH7/18***************************************/

VARIABLE parEchoLostRampDown
{
   DEFAULT_VALUE  0;
 parEchoLostRampDownLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE  FLOAT
    {
     EDIT_FORMAT "9.3f";
     DISPLAY_FORMAT "9.3f";
     MIN_VALUE 0.0;
     MAX_VALUE
            SELECT (parDistanceUnit16)
     {
         CASE 1010: 22000.000;
      CASE 1018: 866.14;
      CASE 1019: 866.14;
      CASE 1010: 22000.000;
      DEFAULT: 0.000;
     }
    }
 CONSTANT_UNIT SELECT (parDistanceUnit16)
    {
     
     CASE 1018: "inch/s";
     CASE 1010:   "mm/s";
     CASE 1019: "inch/s";
     CASE 1010:   "mm/s";
     DEFAULT:   "mm/s";
    }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}

/****************************************VH7/19***************************************/

VARIABLE parUnfilteredDistanceRaw
{
   DEFAULT_VALUE  0;
 parUnfilteredDistanceRawLAH
 CLASS  COMPUTATION & DYNAMIC;
 HANDLING READ;
 TYPE  FLOAT
   {
    EDIT_FORMAT "9.3f";
    DISPLAY_FORMAT "9.3f";
   }
 CONSTANT_UNIT SELECT (parDistanceUnit16)
    {
     CASE 1018: "inch";
     CASE 1010:   "mm";
     CASE 1019: "inch";
     CASE 1010:   "mm";
     DEFAULT:   "mm";
    }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}

/*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*SERVICE_EBENE 2*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*/


/****************************************VH7/21***************************************/

VARIABLE parFilterBreite
{
   DEFAULT_VALUE  0;
 parFilterBreiteLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE  FLOAT
   {
    EDIT_FORMAT "8.3f";
    DISPLAY_FORMAT "8.3f";
    MIN_VALUE       0.000;
    MAX_VALUE      5000.000;
   }
        CONSTANT_UNIT SELECT (parDistanceUnit16)
    {
     CASE 1018: "inch";
     CASE 1010:   "mm";
     CASE 1019: "inch";
     CASE 1010:   "mm";
     DEFAULT:   "mm";
    }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}

/****************************************VH7/22***************************************/

VARIABLE parSawitzkiGolay
{
   DEFAULT_VALUE  0;
 parSawitzkiGolayLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE  FLOAT
   {
    EDIT_FORMAT "8.3f";
    DISPLAY_FORMAT "8.3f";
    MIN_VALUE 0.000;
    MAX_VALUE     5000.000;
   }
    CONSTANT_UNIT SELECT (parDistanceUnit16)
    {
     CASE 1018: "inch";
     CASE 1010:   "mm";
     CASE 1019: "inch";
     CASE 1010:   "mm";
     DEFAULT:   "mm";
    }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}

/****************************************VH7/23***************************************/

VARIABLE parHkStatCountPos
{
   DEFAULT_VALUE  3;
 parHkStatCountPosLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE  UNSIGNED_INTEGER (1)
   {
    EDIT_FORMAT "3u";
    DISPLAY_FORMAT "3u";
    MIN_VALUE 0;
    MAX_VALUE     255;
   }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}

/****************************************VH7/24***************************************/

VARIABLE parHkStatCountNeg
{
   DEFAULT_VALUE  4;
 parHkStatCountNegLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE  UNSIGNED_INTEGER (1)
   {
    EDIT_FORMAT "3u";
    DISPLAY_FORMAT "3u";
    MIN_VALUE 0;
    MAX_VALUE     255;
   }
   VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}   
}

/****************************************VH7/25***************************************/

VARIABLE parFACRising
{

 parFACRisingLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE   parFACRisingEL      
   VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}
}

/****************************************VH7/26***************************************/

VARIABLE parEchoAdjust
{

 parEchoAdjustLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE   parFACRisingEL
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}
}

/****************************************VH7/27***************************************/

VARIABLE parGravityWindow
{

 parGravityWindowLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE  FLOAT
   {
    EDIT_FORMAT "8.3f";
    DISPLAY_FORMAT "8.3f";
    MIN_VALUE 0.000;
    MAX_VALUE     20000.000;
   }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}

/****************************************VH7/29***************************************/

VARIABLE parEnvelopeEnergy
{
   DEFAULT_VALUE  0;
 parEnvelopeEnergyLAH
 CLASS  COMPUTATION & DYNAMIC;
 HANDLING READ;
 parEnvelopeEnergyU
 TYPE  FLOAT
   {
    EDIT_FORMAT "9.3f";
    DISPLAY_FORMAT "9.3f";
   }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}

/*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*SERVICE_EBENE 3*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*/

/****************************************VH7/31***************************************/

VARIABLE parMappingAdder
{
   DEFAULT_VALUE  7;
 parMappingAdderLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
        parMappingAdderU
 TYPE  UNSIGNED_INTEGER (1)
   {
    EDIT_FORMAT "3u";
    DISPLAY_FORMAT "3u";
    MIN_VALUE 0;
    MAX_VALUE     255;
   }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}

/****************************************VH7/32***************************************/

VARIABLE parMappingWidthNew
{
   DEFAULT_VALUE  200;
 parMappingWidthLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE FLOAT
   {
    EDIT_FORMAT "8.3f";
    DISPLAY_FORMAT "8.3f";
    MIN_VALUE 0.0;
    MAX_VALUE   9999.0;
   }
   
 CONSTANT_UNIT SELECT (parDistanceUnit16)
    {
     CASE 1018: "inch";
     CASE 1010:   "mm";
     CASE 1019: "inch";
     CASE 1010:   "mm";
     DEFAULT:   "mm";
    }
        
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}

/****************************************VH7/33***************************************/

VARIABLE parMappingAverage
{
   DEFAULT_VALUE  6;
 parMappingAverageLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE  UNSIGNED_INTEGER (1)
   {
    EDIT_FORMAT "3u";
    DISPLAY_FORMAT "3u";
    MIN_VALUE 0;
    MAX_VALUE     255;
   }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}

/****************************************VH7/34***************************************/

VARIABLE parFactoryTdt
{
   DEFAULT_VALUE  0;
 parFactoryTdtLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE  parFactoryTdtEL
  VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}
}

/****************************************VH7/35***************************************/

VARIABLE parFacAdder
{
   DEFAULT_VALUE  8;
 parFacAdderLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 parFacAdderU
 TYPE  UNSIGNED_INTEGER (1)
   {
    EDIT_FORMAT "3u";
    DISPLAY_FORMAT "3u";
    MIN_VALUE 0;
    MAX_VALUE     255;
   }
  VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}  
}

/****************************************VH7/36***************************************/

VARIABLE parFACWidthNew
{
   DEFAULT_VALUE  1500;
 parFACWidthLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE FLOAT
         {
    EDIT_FORMAT "8.3f";
    DISPLAY_FORMAT "8.3f";
    MIN_VALUE 0.0;
    MAX_VALUE   9999.0;
   }
 CONSTANT_UNIT SELECT (parDistanceUnit16)
    {
     CASE 1018: "inch";
     CASE 1010:   "mm";
     CASE 1019: "inch";
     CASE 1010:   "mm";
     DEFAULT:   "mm";
    }
    VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}    
}


/****************************************VH7/37***************************************/

VARIABLE parRangeFactoryMap
{
   DEFAULT_VALUE  1;
 parRangeFactoryMapLAH
 CLASS  COMPUTATION & DYNAMIC;
 HANDLING READ;
 TYPE  FLOAT
   {
    EDIT_FORMAT "9.3f";
    DISPLAY_FORMAT "9.3f";
   }
    VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}    
}

/****************************************VH7/38***************************************/

VARIABLE parFactoryMappingValid
{
   DEFAULT_VALUE  1;
 parFactoryMappingValidLAH
 CLASS  COMPUTATION & DYNAMIC;
 HANDLING READ;
 TYPE  parFactoryMappingValidEL
    VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}    
}


/****************************************VH7/39***************************************/

VARIABLE parCustomerMappingValid
{
   DEFAULT_VALUE  1;
 parCustomerMappingValidLAH
 CLASS  COMPUTATION & DYNAMIC;
 HANDLING READ;
 TYPE  parCustomerMappingValidEL
    VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}    
}

/*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*SERVICE_EBENE 4*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*/

/****************************************VH7/41***************************************/

VARIABLE parEdgeDetectionMode
{
   DEFAULT_VALUE  0;
 parEdgeDetectionModeLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE  parEdgeDetectionModeEL
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}   

/****************************************VH7/42***************************************/

VARIABLE parEdgeParameter
{
   DEFAULT_VALUE  0;
 parEdgeParameterLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 parEdgeParameterU
 TYPE  UNSIGNED_INTEGER (1)
   {
    EDIT_FORMAT "3u";
    DISPLAY_FORMAT "3u";
    MIN_VALUE 0;
    MAX_VALUE     255;
   }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}

/****************************************VH7/49***************************************/

/* VARIABLE parCalcEdgeParameter already defined in VD0H5*/

/*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*SERVICE_EBENE 5*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*/

/****************************************VH7/51***************************************/

VARIABLE parFirstEchoFactor
{
   DEFAULT_VALUE  15;

 parFirstEchoFactorLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 parFirstEchoFactorU
 TYPE  UNSIGNED_INTEGER (1)
   {
    EDIT_FORMAT "3u";
    DISPLAY_FORMAT "3u";
    MIN_VALUE 0;
    MAX_VALUE     255;
   }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}


/****************************************VH7/52***************************************/

VARIABLE parFefThreshold
{
   DEFAULT_VALUE  72;
 parFefThresholdLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 parFefThresholdU
 TYPE  UNSIGNED_INTEGER (1)
   {
    EDIT_FORMAT "3u";
    DISPLAY_FORMAT "3u";
    MIN_VALUE 0;
    MAX_VALUE     255;
   }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}


/****************************************VH7/53***************************************/

VARIABLE parFefNearFactor
{
   DEFAULT_VALUE  0;
 parFefNearFactorLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 parFefNearFactorU
 TYPE  UNSIGNED_INTEGER (1)
   {
    EDIT_FORMAT "3u";
    DISPLAY_FORMAT "3u";
    MIN_VALUE 0;
    MAX_VALUE     255;
   }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}

/****************************************VH7/54***************************************/
       
VARIABLE parFefDistanceNear
{
   DEFAULT_VALUE  0;
 parFefDistanceNearLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE  FLOAT
   {
    EDIT_FORMAT "9.3f";
    DISPLAY_FORMAT "9.3f";
    MIN_VALUE   0.0;
    MAX_VALUE
            SELECT (parDistanceUnit16)
     { 
         CASE 1010: parAbsMaxMessDist*1000;
      CASE 1018: parAbsMaxMessDist*12;
      CASE 1019: parAbsMaxMessDist;
      CASE 1010: parAbsMaxMessDist;
      DEFAULT: parAbsMaxMessDist;
     }
   
   }
 CONSTANT_UNIT SELECT (parDistanceUnit16)
    {
     CASE 1018: "inch";
     CASE 1010:   "mm";
     CASE 1019: "inch";
     CASE 1010:   "mm";
     DEFAULT:   "mm";
    }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}


/****************************************VH7/55***************************************/

VARIABLE parFefDistanceFar
{
   DEFAULT_VALUE  0;
 parFefDistanceFarLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE  FLOAT
   {
    EDIT_FORMAT "9.3f";
    DISPLAY_FORMAT "9.3f";
    MIN_VALUE   0.000;
    MAX_VALUE
            SELECT (parDistanceUnit16)
     { 
         CASE 1010: parAbsMaxMessDist*1000;
      CASE 1018: parAbsMaxMessDist*12;
      CASE 1019: parAbsMaxMessDist;
      CASE 1010: parAbsMaxMessDist;
      DEFAULT: parAbsMaxMessDist;
     }
   }
 CONSTANT_UNIT SELECT (parDistanceUnit16)
    {
     CASE 1018: "inch";
     CASE 1010:   "mm";
     CASE 1019: "inch";
     CASE 1010:   "mm";
     DEFAULT:   "mm";
    }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}

/****************************************VH7/56***************************************/

VARIABLE parFefEdge
{
   DEFAULT_VALUE  0;
 parFefEdgeLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 parFefEdgeU
 TYPE  UNSIGNED_INTEGER (1)
   {
    EDIT_FORMAT "3u";
    DISPLAY_FORMAT "3u";
    MIN_VALUE 0;
    MAX_VALUE     255;
   }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}


/****************************************VH7/58***************************************/

VARIABLE parMaxEchoSN
{
   DEFAULT_VALUE  0;
 parMaxEchoSNLAH
 CLASS  COMPUTATION & DYNAMIC;
 HANDLING READ;
 parMaxEchoSNU
 TYPE  FLOAT
   {
    EDIT_FORMAT "5.2f";
    DISPLAY_FORMAT "5.2f";
   }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}


/****************************************VH7/59***************************************/

/* VARIABLE parCurrentFirstEchoFactor already defined in VD0H6*/

/*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*SERVICE_EBENE 6*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*/

/****************************************VH7/61***************************************/

VARIABLE parDishBottomDet
{
   DEFAULT_VALUE  1;

 parDishBottomDetLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE  parDishBottomDetEL
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}

/****************************************VH7/62***************************************/

VARIABLE parAmplLevelBottomDet
{
   DEFAULT_VALUE  10;
 parAmplLevelBottomDetLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 parAmplLevelBottomDetU
 TYPE  UNSIGNED_INTEGER (1)
   {
    EDIT_FORMAT "3u";
    DISPLAY_FORMAT "3u";
    MIN_VALUE 0;
    MAX_VALUE     255;
   }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}


/****************************************VH7/63***************************************/

VARIABLE parMinLevelBottomDet
{
   DEFAULT_VALUE  1000;
        parMinLevelBottomDetLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE  FLOAT
   {
    EDIT_FORMAT "9.3f";
    DISPLAY_FORMAT "9.3f";
    MIN_VALUE   0.0;
    MAX_VALUE
            SELECT (parDistanceUnit16)
     { 
         CASE 1010: parAbsMaxMessDist*1000;
      CASE 1018: parAbsMaxMessDist*12;
      CASE 1019: parAbsMaxMessDist;
      CASE 1010: parAbsMaxMessDist;
      DEFAULT: parAbsMaxMessDist;
     }
   }
 CONSTANT_UNIT SELECT (parDistanceUnit16)
    {
     CASE 1018: "inch";
     CASE 1010:   "mm";
     CASE 1019: "inch";
     CASE 1010:   "mm";
     DEFAULT:   "mm";
    }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}


/****************************************VH7/69***************************************/

VARIABLE parLevelSpeed
{
   DEFAULT_VALUE  0;
 parLevelSpeedLAH
 CLASS  COMPUTATION & DYNAMIC;
 HANDLING READ;
 TYPE  FLOAT
   {
    EDIT_FORMAT "9.3f";
    DISPLAY_FORMAT "9.3f";
   }
 CONSTANT_UNIT SELECT (parDistanceUnit16)
    {
     CASE 1018: "inch/s";
     CASE 1010:   "mm/s";
     CASE 1019: "inch/s";
     CASE 1010:   "mm/s";
     DEFAULT:   "mm";
    }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}


/*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*SERVICE_EBENE 7*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*/

/****************************************VH7/71***************************************/

VARIABLE parHfModul
{
   DEFAULT_VALUE  0;
 parHfModulLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE  parHfModulEL
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}


/****************************************VH7/72***************************************/

VARIABLE parZeroDistance
{
   DEFAULT_VALUE  700;
 parZeroDistanceLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE  FLOAT
   {
    EDIT_FORMAT "9.3f";
    DISPLAY_FORMAT "9.3f";
    MIN_VALUE   0.0;
    MAX_VALUE
     SELECT (parDistanceUnit16)
     {
      CASE 1018:  393.7;
      CASE 1010:  10000.000;
      CASE 1019:  393.7;
      CASE 1010:  10000.000;
      DEFAULT:   700.000;
     }
   }
 CONSTANT_UNIT SELECT (parDistanceUnit16)
    {
     CASE 1018: "inch";
     CASE 1010:   "mm";
     CASE 1019: "inch";
     CASE 1010:   "mm";
     DEFAULT:   "mm";
    }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}


/*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*SERVICE_EBENE 8*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*/

/****************************************VH7/81***************************************/

VARIABLE parAntennaType
{
   DEFAULT_VALUE  1;
 parAntennaTypeLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE  parAntennaTypeEL
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}


/****************************************VH7/82***************************************/

VARIABLE parInactiveLength
{
   DEFAULT_VALUE  0;
 parInactiveLengthLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE  FLOAT
   {
    EDIT_FORMAT "9.3f";
    DISPLAY_FORMAT "9.3f";
    MIN_VALUE
     SELECT (parDistanceUnit16)
     {
      CASE 1018:  -196.850;
      CASE 1010: -5000.000;
      CASE 1019:  -196.850;
      CASE 1010: -5000.000;
      DEFAULT:  0.0;
     }
    MAX_VALUE
     SELECT (parDistanceUnit16)
     {
      CASE 1018:   196.850;
      CASE 1010:  5000.000;
      CASE 1019:   196.850;
      CASE 1010:  5000.000;
      DEFAULT:  0.0;
     }
   }
 CONSTANT_UNIT SELECT (parDistanceUnit16)
    {
     CASE 1018: "inch";
     CASE 1010:   "mm";
     CASE 1019: "inch";
     CASE 1010:   "mm";
     DEFAULT:   "mm";
    }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}


/****************************************VH7/83***************************************/

VARIABLE parTotalLength
{
   DEFAULT_VALUE  500;
 parTotalLengthLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE  FLOAT
   {
    EDIT_FORMAT "9.3f";
    DISPLAY_FORMAT "9.3f";
    MIN_VALUE
     SELECT (parDistanceUnit16)
     {
      CASE 1018:  -196.850;
      CASE 1010: -5000.000;
      CASE 1019:  -196.850;
      CASE 1010: -5000.000;
      DEFAULT:   0.0;
     }
    MAX_VALUE
     SELECT (parDistanceUnit16)
     {
      CASE 1018:   196.850;
      CASE 1010:  5000.000;
      CASE 1019:   196.850;
      CASE 1010:  5000.000;
      DEFAULT:  0.0;
     }
   }
 CONSTANT_UNIT SELECT (parDistanceUnit16)
    {
     CASE 1018: "inch";
     CASE 1010:   "mm";
     CASE 1019: "inch";
     CASE 1010:   "mm";
     DEFAULT:   "mm";
    }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}

/****************************************VH7/88***************************************/

VARIABLE parPositionOfReferencePulse
{
   DEFAULT_VALUE  0;
 parPositionOfReferencePulseLAH
 CLASS  COMPUTATION & DYNAMIC;
 HANDLING READ;
 TYPE  FLOAT
   {
    EDIT_FORMAT "8.3f";
    DISPLAY_FORMAT "8.3f";
   }
 CONSTANT_UNIT SELECT (parDistanceUnit16)
    {
     CASE 1018: "inch";
     CASE 1010:   "mm";
     CASE 1019: "inch";
     CASE 1010:   "mm";
     DEFAULT:   "mm";
    }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}   

/****************************************VH7/89***************************************/

VARIABLE parAmplOfReferencePulse
{
   DEFAULT_VALUE  0;
 parAmplOfReferencePulseLAH
 CLASS  COMPUTATION & DYNAMIC;
 HANDLING READ;
 parAmplOfReferencePulseU
 TYPE  INTEGER (1)
   {
    EDIT_FORMAT "4i";
    DISPLAY_FORMAT "4i";
   }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}


/*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*SERVICE_EBENE 12*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*/

/****************************************VH7/C4***************************************/

/****************************************VH7/C5****************************************/

VARIABLE parDisplayVersion
{
 DEFAULT_VALUE "";

 parDisplayVersionLAH
 CLASS  COMPUTATION & DYNAMIC;
 HANDLING READ;
 TYPE  ASCII (32)  ;
VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}

/****************************************VH7/C6****************************************/

VARIABLE parCalculatedCycleTime
{
   DEFAULT_VALUE  1000;
 parCalculatedCycleTimeLAH
 CLASS  COMPUTATION & DYNAMIC;
 HANDLING READ;
 parCalculatedCycleTimeU
 TYPE  UNSIGNED_INTEGER (2);
    VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}    
}

/****************************************VH7/C8****************************************/

VARIABLE parSwVersion
{
   DEFAULT_VALUE  1202;
 parSwVersionLAH
 CLASS  COMPUTATION & DYNAMIC;
 HANDLING READ;
 TYPE  UNSIGNED_INTEGER (2);
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}

/****************************************VH7/C9****************************************/

VARIABLE parParamVersion
{
   DEFAULT_VALUE  23;
 parParamVersionLAH
 CLASS  COMPUTATION & DYNAMIC;
 HANDLING READ;
 TYPE  UNSIGNED_INTEGER (2);
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}

/*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*SERVICE_EBENE 13*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*/

/****************************************VH7/D1****************************************/

VARIABLE parDAAdjust4mA
{
   DEFAULT_VALUE  83;
 parDAAdjust4mALAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
 TYPE  UNSIGNED_INTEGER (2)
   {
    EDIT_FORMAT "5u";
    DISPLAY_FORMAT "5u";
    MIN_VALUE     0;
    MAX_VALUE     65535;
   }
 VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;} 
}

/****************************************VH7/D2****************************************/


/****************************************VH7/D3****************************************/

VARIABLE parDeviceIDNumber
{
   DEFAULT_VALUE  0;
   parDeviceIDNumberLAH
   HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
   TYPE  UNSIGNED_INTEGER (4)
         {
            EDIT_FORMAT "9u";
            DISPLAY_FORMAT "9u";                
            MIN_VALUE   0;                
            MAX_VALUE   16777215;
         }  
}

/*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*SERVICE_EBENE 15*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*/

/****************************************VH7/F1****************************************/

VARIABLE parDaaIndex1
{
   DEFAULT_VALUE  160;
   parDaaIndex1LAH
   HANDLING IF (Hnd090) {READ & WRITE;} ELSE {READ;}
   TYPE  UNSIGNED_INTEGER (1)
         {
            EDIT_FORMAT "3u";
            DISPLAY_FORMAT "3u";
            MIN_VALUE     0;
            MAX_VALUE     255;
         }
   VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}   
}

/****************************************VH7/F2****************************************/

VARIABLE parDaaIndex2
{
   DEFAULT_VALUE  0;
   parDaaIndex2LAH
   HANDLING IF (Hnd090) {READ & WRITE;} ELSE {READ;}
   TYPE  UNSIGNED_INTEGER (1)
         {
            EDIT_FORMAT "3u";
            DISPLAY_FORMAT "3u";
            MIN_VALUE     0;
            MAX_VALUE     255;
         }
   VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}   
}   

/****************************************VH7/F3****************************************/

VARIABLE parDaaRdWrValue
{
   DEFAULT_VALUE  0;
   parDaaRdWrValueLAH
   HANDLING IF (Hnd090) {READ & WRITE;} ELSE {READ;}
   TYPE  FLOAT
         {
            EDIT_FORMAT "11.3f";
            DISPLAY_FORMAT "11.3f";
            MIN_VALUE     -9999999.0;
            MAX_VALUE      9999999.0;
         }
   VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}   
}

/****************************************VH7/F7****************************************/

VARIABLE parErrorStateOfAlgorithm
{
   DEFAULT_VALUE  0;
   parErrorStateOfAlgorithmLAH
   CLASS    COMPUTATION & DYNAMIC;
   HANDLING READ;
   TYPE     UNSIGNED_INTEGER (4);
   VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}   
}


/****************************************VH7/F8****************************************/

VARIABLE parStateOfAlgorithm
{
   DEFAULT_VALUE  0;
   parStateOfAlgorithmLAH
   CLASS    COMPUTATION & DYNAMIC;
   HANDLING READ;
   TYPE     UNSIGNED_INTEGER (4);
   VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}   
}


/****************************************VH90****************************************/

VARIABLE parActualError
{
   DEFAULT_VALUE  "";
   HELP    [sys_error_code_help] ;
   parActualErrorLAH
   CLASS    COMPUTATION & DYNAMIC;
   HANDLING READ;
   TYPE     parErrorEnumList
}

/****************************************VH91****************************************/

VARIABLE parLastError
{
   DEFAULT_VALUE  "";
   HELP    [sys_error_code_help] ;
   parLastErrorLAH
   CLASS    COMPUTATION & DYNAMIC;
   HANDLING READ;
   TYPE  UNSIGNED_INTEGER (2)
         {
            EDIT_FORMAT "3u";
            DISPLAY_FORMAT "3u";
         }
}

/****************************************VH92****************************************/

VARIABLE parClearLastError
{
   DEFAULT_VALUE  0;
   parClearLastErrorLAH
   HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
   TYPE  parClearLastErrorEL
   POST_WRITE_ACTIONS {gotokeep}
}

/****************************************VH93****************************************/

VARIABLE parReset
{
   DEFAULT_VALUE  0;
   parResetLAH
   HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
   TYPE  UNSIGNED_INTEGER (2)
         {
            EDIT_FORMAT    "5u";
            DISPLAY_FORMAT "5u";
            MIN_VALUE     0;
            MAX_VALUE       65535;
         }
    POST_WRITE_ACTIONS {delayafterReset}
}

/****************************************VH95****************************************/

VARIABLE parMeasuredDistance
{
   DEFAULT_VALUE  0;
   parMeasuredDistanceLAH
   CLASS    COMPUTATION & DYNAMIC;
   HANDLING READ;
   TYPE  FLOAT
         {
            EDIT_FORMAT "6.3f";
            DISPLAY_FORMAT "6.3f";
         }
}

/****************************************VH96****************************************/

VARIABLE parMeasuredLevel 
{

   parMeasuredLevelLAH
   DEFAULT_VALUE 0;
   CLASS       COMPUTATION & DYNAMIC;
   HANDLING READ;
   TYPE  FLOAT
         {
            EDIT_FORMAT "6.3f";
            DISPLAY_FORMAT "6.3f";
         }
}

/****************************************VH98****************************************/

VARIABLE parApplicationParameter
{
   DEFAULT_VALUE  0;
   parApplicationParameterLAH
   CLASS       COMPUTATION & DYNAMIC;
   HANDLING READ;
   TYPE  parApplicationParameterEL
}

/****************************************VHA0****************************************/


/****************************************VHA2****************************************/

VARIABLE parProtSoftVersionString
{
   DEFAULT_VALUE  "V01.05.00 (PA)";
   parProtSoftVersionStringLAH
   HANDLING READ;
   TYPE  ASCII (16);
}

/****************************************VHA4****************************************/

VARIABLE parSerialNumber
{
   DEFAULT_VALUE  " ";
   parSerialNumberLAH
   HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
   TYPE  ASCII (16);
}

/****************************************VHA8****************************************/

VARIABLE parDownloadMode
{
   DEFAULT_VALUE  0;
   parDownloadModeLAH
   HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
   TYPE parDownloadModeEL
}

/****************************************VH58****************************************/


/****************************************VH59****************************************/

/****************************************VH7/88***************************************/

VARIABLE parEditRangeMaxSampleDist
{
   DEFAULT_VALUE  70.000;
   parEditRangeMaxSampleDistLAH
   CLASS COMPUTATION & DYNAMIC;
   HANDLING READ;
   TYPE  FLOAT
         {
            EDIT_FORMAT "9.3f";
            DISPLAY_FORMAT "9.3f";
         }
   VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}   
}
     
/****************************************VHA9***************************************/

VARIABLE parAntennaExtensionLength
{
   DEFAULT_VALUE  0;
   parAntennaExtensionLengthLAH
   HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
   TYPE        FLOAT
         {
            EDIT_FORMAT "9.3f";
            DISPLAY_FORMAT "9.3f";
            MIN_VALUE 0.0;
            MAX_VALUE
            SELECT (parDistanceUnit16)
            {
               CASE 1018 :  5000.0*(1.0/304.8);
               CASE 1010 :  5000.0*(1.0/1000.0);
               CASE 1019 :  5000.0*(1.0/25.4);
               CASE 1010 :  5000.0;
               DEFAULT:   5000.0*(1.0/1000.0);
            }
         }
} 

/****************************************VHA7***************************************/

VARIABLE parDetectionWindow
{
   DEFAULT_VALUE  1;
   parDetectionWindowLAH
   HANDLING IF (Hnd034) {READ & WRITE;} ELSE {READ;}
   TYPE parDetectionWindowEL
}


/****************************************VH7/13****************************************/

VARIABLE parFilterConstMin
{
   DEFAULT_VALUE  15;
   parFilterConstMinLAH
   HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
   parFilterConstMinU
   TYPE  FLOAT
         {
            EDIT_FORMAT "7.1f";
            DISPLAY_FORMAT "7.1f";
            MIN_VALUE     0.0;
            MAX_VALUE     10000.0;
}
   VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}   
}   

/****************************************VH7/14****************************************/

VARIABLE parFilterConstMax
{
   DEFAULT_VALUE  60;
   parFilterConstMaxLAH
   HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
   parFilterConstMaxU
   TYPE  FLOAT
         {
            EDIT_FORMAT "7.1f";
            DISPLAY_FORMAT "7.1f";
            MIN_VALUE     0.0;
            MAX_VALUE     10000.0;
         }
   VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}   
}


/****************************************VH7/15****************************************/

VARIABLE parInnovationFiltConstMax
{
   DEFAULT_VALUE  10;
   parInnovationFiltConstMaxLAH
   HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
   TYPE  FLOAT
         {
            EDIT_FORMAT "9.3f";
            DISPLAY_FORMAT "9.3f";
            MIN_VALUE     0.0;
            MAX_VALUE
            SELECT (parDistanceUnit16)
            {
               CASE 1018 :  393.7;
               CASE 1010 :  10000.000;
               CASE 1019 :  393.7;
               CASE 1010 :  10000.000;
               DEFAULT:   2.000;
            }
         }
   CONSTANT_UNIT  SELECT (parDistanceUnit16)
         {
            CASE 1018: "inch";
            CASE 1010:   "mm";
            CASE 1019: "inch";
            CASE 1010:   "mm";
            DEFAULT:   "mm";
         }
   VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}   
}


/****************************************VHA7***************************************/

VARIABLE parMergingEchoes
{
   DEFAULT_VALUE  0;
   parMergingEchoesLAH
   HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
   TYPE parMergingEchoesEL
}


/****************************************VH7/26****************************************/

VARIABLE parMergingWindow
{
   DEFAULT_VALUE  3000;
   parMergingWindowLAH
   HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
   TYPE  FLOAT
         {
            EDIT_FORMAT "9.3f";
            DISPLAY_FORMAT "9.3f";
            MIN_VALUE     0.0;
            MAX_VALUE
            SELECT (parDistanceUnit16)
            {
               CASE 1018:  787.4;
               CASE 1010:  20000.000;
               CASE 1019:  787.4;
               CASE 1010:  20000.000;
               DEFAULT:  3000.000;
            }
         }
   CONSTANT_UNIT  SELECT (parDistanceUnit16)
            {
               CASE 1018: "inch";
               CASE 1010:   "mm";
               CASE 1019: "inch";
               CASE 1010:   "mm";
               DEFAULT:   "mm";
            }
   VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}   
}

/****************************************VH7/27****************************************/

VARIABLE parMergingEchoDist
{
   DEFAULT_VALUE  1500;
   parMergingEchoDistLAH
   HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
   TYPE  FLOAT
         {
            EDIT_FORMAT "9.3f";
            DISPLAY_FORMAT "9.3f";
            MIN_VALUE     0.0;
            MAX_VALUE
            SELECT (parDistanceUnit16)
            {
               CASE 1018 :  393.7;
               CASE 1010 :  10000.000;
               CASE 1019 :  393.7;
               CASE 1010 :  10000.000;
               DEFAULT:   1500.000;
            }
         }
   CONSTANT_UNIT  SELECT (parDistanceUnit16)
         {
            CASE 1018: "inch";
            CASE 1010:   "mm";
            CASE 1019: "inch";
            CASE 1010:   "mm";
            DEFAULT:   "mm";
         }
   VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}   
}

/****************************************VH7/28****************************************/

VARIABLE parMergingRatio
{
   DEFAULT_VALUE  40;
   parMergingRatioLAH
   HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
   parMergingRatioU
   TYPE  UNSIGNED_INTEGER (1)
         {
            EDIT_FORMAT    "3u";
            DISPLAY_FORMAT "3u";
            MIN_VALUE     0;
            MAX_VALUE       100;
         }
   VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}   
} 

/****************************************VH7/64****************************************/

VARIABLE parRangeTankBottomDetection
{
   DEFAULT_VALUE  3000;
   parRangeTankBottomDetectionLAH
   HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
   TYPE  FLOAT
         {
            EDIT_FORMAT "9.3f";
            DISPLAY_FORMAT "9.3f";
            MIN_VALUE     0.0;
            MAX_VALUE
            SELECT (parDistanceUnit16)
            {
               CASE 1018 :  1574.8;
               CASE 1010 :  40000.000;
               CASE 1019 :  1574.8;
               CASE 1010 :  40000.000;
               DEFAULT:   3000.000;
            }
         }
   CONSTANT_UNIT SELECT (parDistanceUnit16)
            {
               CASE 1018: "inch";
               CASE 1010:   "mm";
               CASE 1019: "inch";
               CASE 1010:   "mm";
               DEFAULT:   "mm";
            }
   VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}   
}

/****************************************VH7/68***************************************/

VARIABLE parClipDistanceToEmpty
{
   DEFAULT_VALUE  1;
   parClipDistanceToEmptyLAH
   HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
   TYPE parClipDistanceToEmptyEL
   VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}   
}


/****************************************VH7/28****************************************/

VARIABLE parDelayTimer
{
   DEFAULT_VALUE  0;
   parDelayTimerLAH
   HANDLING READ;
   parDelayTimerU
   TYPE  UNSIGNED_INTEGER (2)
         {
            EDIT_FORMAT    "5u";
            DISPLAY_FORMAT "5u";
         }
   VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}
  
} 

/****************************************VH7/94****************************************/

VARIABLE parEchoFoundDelay
{
   DEFAULT_VALUE  10;
   parEchoFoundDelayLAH
   HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
   parEchoFoundDelayU
   TYPE  UNSIGNED_INTEGER (2)
         {
            EDIT_FORMAT    "5u";
            DISPLAY_FORMAT "5u";
            MIN_VALUE       0;
            MAX_VALUE       65535;
         }
   VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}
   
}

/****************************************VH7/95****************************************/

VARIABLE parEchoLostDelay
{
   DEFAULT_VALUE  60;
   parEchoLostDelayLAH
   HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
   parEchoLostDelayU
   TYPE  UNSIGNED_INTEGER (2)
         {
            EDIT_FORMAT    "5u";
            DISPLAY_FORMAT "5u";
            MIN_VALUE       0;
            MAX_VALUE       65535;
         }
   VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}
   
}

/****************************************VH7/96****************************************/

VARIABLE parJumpDelayBase
{
   DEFAULT_VALUE  600;
   parJumpDelayBaseLAH
   HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
   parJumpDelayBaseU
   TYPE  UNSIGNED_INTEGER (2)
         {
            EDIT_FORMAT    "5u";
            DISPLAY_FORMAT "5u";
            MIN_VALUE       0;
            MAX_VALUE       65535;
         }
   VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}
   
}

/****************************************VH7/97****************************************/

VARIABLE parJumpDelaySlope
{
   DEFAULT_VALUE  0;
   parJumpDelaySlopeLAH
   HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
   TYPE  FLOAT
         {
            EDIT_FORMAT "8.3f";
            DISPLAY_FORMAT "8.3f";
            MIN_VALUE     0.0;
            MAX_VALUE
            SELECT (parDistanceUnit16)
            {
               CASE 1018 :  2.580;
               CASE 1010 :  65.535;
               CASE 1019 :  2.580;
               CASE 1010 :  65.535;
               DEFAULT:   1.000;
            }
         }
   CONSTANT_UNIT  SELECT (parDistanceUnit16)
            {
               CASE 1018: "inch/s";
               CASE 1010:   "mm/s";
               CASE 1019: "inch/s";
               CASE 1010:   "mm/s";
               DEFAULT:   "mm/s";
            }
   VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}
   
}

/****************************************VH7/98****************************************/

VARIABLE parNoJumpWindowWith
{
   DEFAULT_VALUE  2000;
    parNoJumpWindowWithLAH
    HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
    TYPE  FLOAT
         {
            EDIT_FORMAT "9.3f";
            DISPLAY_FORMAT "9.3f";
            MIN_VALUE     0.0;
            MAX_VALUE
            SELECT (parDistanceUnit16)
            {
               CASE 1018 :  393.7;
               CASE 1010 :  10000.0;
               CASE 1019 :  393.7;
               CASE 1010 :  10000.0;
               DEFAULT:   1.000;
            }
         }
   CONSTANT_UNIT SELECT (parDistanceUnit16)
            {
               CASE 1018: "inch";
               CASE 1010:   "mm";
               CASE 1019: "inch";
               CASE 1010:   "mm";
               DEFAULT:   "mm";
            }
   VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}
}

/****************************************VH7/98****************************************/

VARIABLE parWeightMode
{
   DEFAULT_VALUE  1;
   parWeightModeLAH
   HANDLING IF (Hnd096) {READ & WRITE;} ELSE {READ;}
   TYPE parWeightModeEL
   VALIDITY IF(ServiceValidity){TRUE;} ELSE {FALSE;}
}

/* neue Parameter fr Version 010400 */
/*
parDetectionWindow
parFilterConstMin VD1H3
parFilterConstMax VD1H4
parInnovationFiltConstMax  VD1H5
parHkStatCountPos VD2H3
parHkStatCountNeg VD2H4 
parMergingEchoes  VD2H5
parMergingWindow  VD2H6
parMergingEchoDist  VD2H7
parMergingRatio  VD2H8
parRangeTankBottomDetection VD6H4
parClipDistanceToEmpty  VD6H8
parDelayTimer  VD9H3
parEchoFoundDelay VD9H4
parEchoLostDelay  VD9H5
parJumpDelayBase  VD9H6
parJumpDelaySlope VD9H7
parNoJumpWindowWith  VD9H8
parWeightMode  VD9H9
*/      

/************************************************************************************************************/
/*                                              UNITS                                                       */
/************************************************************************************************************/


UNIT parCustomerUnit_relation
{
   parCustomerUnit:
      func1_AI_out_value      
      parMeasuredValue,
      parInputVolume,
      parMaxVolume,
      parSimulationValueVolume,
}


UNIT parDistanceUnit16_relation
{
   parDistanceUnit16:
      parEmptyCalibration,
      parFullCalibration,
      parLevelWithinSafetyDistance,
      parInputLevelHalfAutomatic,
      parInputLevelManual,
      parCylinderVessel,
      parSuppressionDistance,
      parPresMapRange,
      parOffsetOfMeasuredLevel,
      parBlockingDistance,
      parSimulationValueLevel,
      parMeasuredDistance,
      parMeasuredLevel,
      parRangeFactoryMap,
      parAbsMaxMessDist,
      parEditRangeMaxSampleDist,
      parAntennaExtensionLength
      func1_AI_lo_lo_lim
      func1_AI_lo_lim
      func1_AI_hi_lim
      func1_AI_hi_hi_lim
      func1_AI_alarm_hys
      func1_AI_out_lower_range_value
      func1_AI_out_upper_range_value

}



COMMAND read_index_parameter
{
   NUMBER      172 ;
   OPERATION   READ ;
   TRANSACTION {
               REQUEST
               {
                  variable_array_index(INFO,INDEX )
               }
                  REPLY
               {
                  response_code ,
                  device_status ,
                  variable_array_index(INFO,INDEX ) ,
                  variable_array_val[variable_array_index]
               }
               }

               RESPONSE_CODES
               {
                  0, SUCCESS,          [no_command_specific_errors];
                  2, DATA_ENTRY_ERROR, [invalid_selection];
                  5, MISC_ERROR,       [too_few_data_bytes_recieved];
                  6, MISC_WARNING,     [xmtr_specific_command_error];
               }
}

COMMAND write_index_parameter
{
   NUMBER      173 ;
   OPERATION   WRITE ;
   TRANSACTION {
               REQUEST
               {
               
                  variable_array_index( INFO,INDEX ) ,
                  variable_array_val[variable_array_index]
               }
               REPLY
               {
                  response_code,
                  device_status,
                  variable_array_index(INFO,INDEX ),
                  variable_array_val[variable_array_index]
               }
            }
            
            RESPONSE_CODES
            {
                0, SUCCESS,          [no_command_specific_errors];
                2, DATA_ENTRY_ERROR, [invalid_selection];
                3, DATA_ENTRY_ERROR, [passed_parameter_too_large];
                4, DATA_ENTRY_ERROR, [passed_parameter_too_small];
                5, MISC_ERROR,       [too_few_data_bytes_recieved];
                7, MODE_ERROR,       [in_write_protect_mode];
                8, MISC_WARNING,     "Set to nearest possible value";
                9, DATA_ENTRY_ERROR, "Invalid value selection";
               16, MODE_ERROR,       [access_restricted];
            }
}


METHOD Reset_Config_changed_Flag
{
   LABEL  "Reset Configuration Changed Flag" ;
   DEFINITION  {
                  ACKNOWLEDGE ("Do you want to reset the 'Config Changed Flag' ?");
                  send_command(38);
               }
}

METHOD Restart_Device
{
   LABEL  "Restart Device" ;
   DEFINITION  {
                        ACKNOWLEDGE ("Attention !   Device will be restarted !\n \n \n Loss of information possible !");
                        send_command(42);
               }
}


METHOD gotokeep
{
  LABEL "gotokeep";
  DEFINITION
    { 
        int value;
        value = 0;
        isetval (value);
    }
}


#define SEND_TO_DEVICE(x) \
 LABEL "SEND_TO_DEVICE"; \
  CLASS COMPUTATION; \
  DEFINITION \
  { \
        IGNORE_ALL_DEVICE_STATUS(); \
        XMTR_IGNORE_ALL_RESPONSE_CODES(); \
        XMTR_IGNORE_ALL_DEVICE_STATUS(); \
        iassign(variable_array_index, x); \
        send_command(173); \
        IGNORE_ALL_RESPONSE_CODES(); \
        IGNORE_ALL_DEVICE_STATUS(); \
        XMTR_IGNORE_ALL_RESPONSE_CODES(); \
        XMTR_IGNORE_ALL_DEVICE_STATUS(); \
    }


METHOD send_Reset   
 {
   SEND_TO_DEVICE(35)
 }

METHOD send_OperationCode   
 { 
   SEND_TO_DEVICE(0)
 }

METHOD send_OperationMode   
 {
   SEND_TO_DEVICE(46) 
 }  

METHOD send_StartMappingRecord   
 {
   SEND_TO_DEVICE(110)
 }

#define READ_FROM_DEVICE(x) \
 LABEL "SEND_TO_DEVICE"; \
  CLASS COMPUTATION; \
  DEFINITION \
  { \
        IGNORE_ALL_DEVICE_STATUS(); \
        XMTR_IGNORE_ALL_RESPONSE_CODES(); \
        XMTR_IGNORE_ALL_DEVICE_STATUS(); \
        iassign(variable_array_index, x); \
        send_command(172); \
        IGNORE_ALL_RESPONSE_CODES(); \
        IGNORE_ALL_DEVICE_STATUS(); \
        XMTR_IGNORE_ALL_RESPONSE_CODES(); \
        XMTR_IGNORE_ALL_DEVICE_STATUS(); \
    }

METHOD read_SuppressionDistance   
 {
   READ_FROM_DEVICE(82)
 }



METHOD read_CheckDistance   
 {
   READ_FROM_DEVICE(244)
 }

METHOD read_EmptyCalibration   
 {
   READ_FROM_DEVICE(45)
 }

METHOD read_FullCalibration   
 {
   READ_FROM_DEVICE(62)
 }

METHOD read_AbsMaxMessDist 
 {
   READ_FROM_DEVICE(85)
 }


METHOD delayafterchange
{
  LABEL "delayafterchange";
  DEFINITION
    { 
        char prompt[60];
        int delay_time;
        delay_time = 5;
        DELAY(delay_time, "After changing this parameter the device is refreshing, please wait some time before further editing.");
    }
}


METHOD delaystartmapping
{
  LABEL "delaystartmapping";
  DEFINITION
    { 
        char prompt[60];
        int delay_time;
        delay_time = 11;
        DELAY(delay_time, "Recording of mapping - please wait.");
    }
}

METHOD delayafterReset
{
  LABEL "delayafterReset";
  DEFINITION
    { 
        char prompt[60];
        int delay_time;
        delay_time = 5;
        DELAY(delay_time, "After Reset the device is refreshing, please wait some time before further editing.");
    }
}

MENU Tab_s_PA_Profil {
	LABEL 	[menu_table_sensor_level_radar] ;
	ITEMS { 
		Tab_s_ident,
		Tab_s_input,
		Tab_s_output,
		Tab_s_certificates
	} 
}

MENU Tab_s_ident {
	LABEL 	[menu_ident] ;
	ITEMS { 
		Tab_s_ident_opunit,
		Tab_s_ident_device
	} 
}

MENU Tab_s_ident_opunit {
	LABEL 	[menu_ident_opunit] ;
	ITEMS { 
		phys_tag_desc,
		phys_descriptor,
		phys_message
	} 
}

MENU Tab_s_ident_device {
	LABEL 	[menu_ident_device] ;
	ITEMS { 
		phys_device_man_id,
		phys_device_ser_num,
		phys_software_rev,
		phys_hardware_rev,
		phys_install_date,
		phys_st_rev
	} 
}

MENU Tab_s_input {
	LABEL 	[menu_input] ;
	ITEMS { 
		Tab_s_input_measwindow
	} 
}

MENU Tab_s_input_measwindow {
	LABEL 	[menu_input_measwindow] ;
	ITEMS { 
		func1_AI_pv_lower_range_value,
		func1_AI_pv_upper_range_value
	} 
}

MENU Tab_s_output {
	LABEL 	[menu_output] ;
	ITEMS { 
		Tab_s_output_signal,
		Tab_s_output_limits,
		Tab_s_func1_FSafe
	} 
}

MENU Tab_s_output_signal {
	LABEL 	[menu_output_signal] ;
	ITEMS { 
		func1_AI_out_lower_range_value,
		func1_AI_out_upper_range_value,
                parDistanceUnit16,
		func1_AI_pv_ftime,
		func1_AI_out_decimal_point
	} 
}

MENU Tab_s_output_limits {
	LABEL 	[menu_output_limits] ;
	ITEMS { 
		func1_AI_lo_lo_lim,
		func1_AI_lo_lim,
		func1_AI_hi_lim,
		func1_AI_hi_hi_lim,
		func1_AI_alarm_hys
	} 
}

MENU Tab_s_func1_FSafe {
	LABEL 	[menu_fail_safe] ;
	ITEMS { 
		func1_AI_FSafeType,
		func1_AI_FSafeValue
	} 
}

MENU Tab_s_certificates {
	LABEL 	[menu_certificates] ;
	ITEMS { 
		phys_device_certification
	} 
}

MENU Tab_s_PA_Profil_RO {
	LABEL 	[menu_table_sensor_level_radar] ;
	ITEMS { 
		Tab_s_ident_RO,
		Tab_s_input_RO,
		Tab_s_output_RO,
		Tab_s_certificates_RO
	} 
}

MENU Tab_s_ident_RO {
	LABEL 	[menu_ident] ;
	ITEMS { 
		Tab_s_ident_opunit_RO,
		Tab_s_ident_device_RO
	} 
}

MENU Tab_s_ident_opunit_RO {
	LABEL 	[menu_ident_opunit] ;
	ITEMS { 
		phys_tag_desc,
		phys_descriptor(READ_ONLY),
		phys_message(READ_ONLY)
	} 
}

MENU Tab_s_ident_device_RO {
	LABEL 	[menu_ident_device] ;
	ITEMS { 
		phys_device_man_id(READ_ONLY),
		phys_device_ser_num(READ_ONLY),
		phys_software_rev(READ_ONLY),
		phys_hardware_rev(READ_ONLY),
		phys_install_date(READ_ONLY),
		phys_st_rev(READ_ONLY)
	} 
}

MENU Tab_s_input_RO {
	LABEL 	[menu_input] ;
	ITEMS { 
		Tab_s_input_measwindow_RO
	} 
}

MENU Tab_s_input_measwindow_RO {
	LABEL 	[menu_input_measwindow] ;
	ITEMS { 
		func1_AI_pv_lower_range_value(READ_ONLY),
		func1_AI_pv_upper_range_value(READ_ONLY)
	} 
}

MENU Tab_s_output_RO {
	LABEL 	[menu_output] ;
	ITEMS { 
		Tab_s_output_signal_RO,
		Tab_s_output_limits_RO,
		Tab_s_func1_FSafe_RO
	} 
}

MENU Tab_s_output_signal_RO {
	LABEL 	[menu_output_signal] ;
	ITEMS { 
		func1_AI_out_lower_range_value(READ_ONLY),
		func1_AI_out_upper_range_value(READ_ONLY),
                parDistanceUnit16(READ_ONLY),
		func1_AI_pv_ftime(READ_ONLY),
		func1_AI_out_decimal_point(READ_ONLY)
	} 
}

MENU Tab_s_output_limits_RO {
	LABEL 	[menu_output_limits] ;
	ITEMS { 
		func1_AI_lo_lo_lim(READ_ONLY),
		func1_AI_lo_lim(READ_ONLY),
		func1_AI_hi_lim(READ_ONLY),
		func1_AI_hi_hi_lim(READ_ONLY),
		func1_AI_alarm_hys(READ_ONLY)
	} 
}

MENU Tab_s_func1_FSafe_RO {
	LABEL 	[menu_fail_safe] ;
	ITEMS { 
		func1_AI_FSafeType(READ_ONLY),
		func1_AI_FSafeValue(READ_ONLY)
	} 
}

MENU Tab_s_certificates_RO {
	LABEL 	[menu_certificates] ;
	ITEMS { 
		phys_device_certification(READ_ONLY)
	} 
}


REDEFINE VARIABLE func1_AI_pv_upper_range_value
{
  DEFAULT_VALUE 100;


}


REDEFINE VARIABLE func1_AI_out_upper_range_value
{
  DEFAULT_VALUE 100;


}
REDEFINE VARIABLE func1_AI_out_unit
{
  DEFAULT_VALUE 0;


}
REDEFINE VARIABLE func1_AI_pv_ftime
{
  DEFAULT_VALUE 0;


}
REDEFINE VARIABLE func1_AI_out_decimal_point
{
  DEFAULT_VALUE 127;
}
REDEFINE VARIABLE func1_AI_alarm_hys
{
  DEFAULT_VALUE 0.5;
}
REDEFINE VARIABLE func1_AI_FSafeType
{
  DEFAULT_VALUE 1;


}


REDEFINE VARIABLE phys_device_certification
{


}

REDEFINE VARIABLE func1_AI_out_lower_range_value
{
  DEFAULT_VALUE 0;


}

REDEFINE VARIABLE func1_AI_FSafeType
{


}

REDEFINE VARIABLE func1_AI_st_rev
{
  DEFAULT_VALUE 0; HANDLING CUSTOMERLOCK}

REDEFINE VARIABLE func1_AI_out_unit
{ HANDLING CUSTOMERLOCK}

REDEFINE VARIABLE func1_AI_out_unit_text
{
  DEFAULT_VALUE "-               "; HANDLING CUSTOMERLOCK}

REDEFINE VARIABLE func1_AI_pv_ftime
{ HANDLING CUSTOMERLOCK}

REDEFINE VARIABLE func1_AI_batch_id
{
  DEFAULT_VALUE 0; HANDLING CUSTOMERLOCK}

REDEFINE VARIABLE func1_AI_batch_unit
{
  DEFAULT_VALUE 0; HANDLING CUSTOMERLOCK}

REDEFINE VARIABLE func1_AI_batch_operation
{
  DEFAULT_VALUE 0; HANDLING CUSTOMERLOCK}

REDEFINE VARIABLE func1_AI_batch_phase
{
  DEFAULT_VALUE 0; HANDLING CUSTOMERLOCK}

REDEFINE VARIABLE func1_AI_pv_lower_range_value
{
  DEFAULT_VALUE 0; HANDLING CUSTOMERLOCK}

REDEFINE VARIABLE func1_AI_pv_upper_range_value
{ HANDLING CUSTOMERLOCK}

REDEFINE VARIABLE func1_AI_out_lower_range_value
{ HANDLING CUSTOMERLOCK}

REDEFINE VARIABLE func1_AI_out_upper_range_value
{ HANDLING CUSTOMERLOCK}

REDEFINE VARIABLE func1_AI_lo_lo_lim
{ HANDLING CUSTOMERLOCK}

REDEFINE VARIABLE func1_AI_lo_lim
{ HANDLING CUSTOMERLOCK}

REDEFINE VARIABLE func1_AI_hi_lim
{ HANDLING CUSTOMERLOCK}

REDEFINE VARIABLE func1_AI_hi_hi_lim
{ HANDLING CUSTOMERLOCK}

REDEFINE VARIABLE func1_AI_alarm_hys
{ HANDLING CUSTOMERLOCK}

REDEFINE VARIABLE func1_AI_FSafeType
{ HANDLING CUSTOMERLOCK}

REDEFINE VARIABLE func1_AI_FSafeValue
{
  DEFAULT_VALUE 0; HANDLING CUSTOMERLOCK}

REDEFINE VARIABLE func1_AI_out_decimal_point
{ HANDLING CUSTOMERLOCK}

COMMAND read_parMediaType
{
	SLOT 1;
	INDEX 139;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parMediaType
		}
	}
}


COMMAND write_parMediaType
{
	SLOT 1;
	INDEX 139;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parMediaType
		}
		REPLY
		{
		}
	}
}

COMMAND read_parTankShape { 
	BLOCK 	transducer_block_1 ;
	INDEX 	10 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parTankShape
		} 
	} 
} 

COMMAND write_parTankShape { 
	BLOCK 	transducer_block_1 ;
	INDEX 	10 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parTankShape
		} 
		REPLY {
		} 
	} 
} 

COMMAND read_parDielectricConstant {
        BLOCK transducer_block_1 ;
        INDEX 11 ;


        OPERATION READ ;
        TRANSACTION {
                REQUEST {
                }
                REPLY {
                        parDielectricConstant
                }
        }
}

COMMAND write_parDielectricConstant {
        BLOCK transducer_block_1 ;
        INDEX 11 ;
        OPERATION WRITE ;
        TRANSACTION {
                REQUEST {
                        parDielectricConstant
                }
                REPLY {
                }
        }
}


COMMAND read_parDielectricConstantSolid {
        BLOCK transducer_block_1 ;
        INDEX 36 ;


        OPERATION READ ;
        TRANSACTION {
                REQUEST {
                }
                REPLY {
                        parDielectricConstantSolid 
                }
        }
}

COMMAND write_parDielectricConstantSolid {
        BLOCK transducer_block_1 ;
        INDEX 36 ;
        OPERATION WRITE ;
        TRANSACTION {
                REQUEST {
                        parDielectricConstantSolid
                }
                REPLY {
                }
        }
}


COMMAND read_parProcessCondition {
        BLOCK transducer_block_1 ;
        INDEX 12 ;
        OPERATION READ ;
        TRANSACTION {



                REQUEST {
                }
                REPLY {
                        parProcessCondition
                }

        }
}

COMMAND write_parProcessCondition {
        BLOCK transducer_block_1 ;


        INDEX 12 ;
        OPERATION WRITE ;
        TRANSACTION {
                REQUEST {
                        parProcessCondition
                }
                REPLY {
                }
        }
}

COMMAND read_parProcessConditionSolid {
        BLOCK transducer_block_1 ;
        INDEX 37 ;
        OPERATION READ ;
        TRANSACTION {



                REQUEST {
                }
                REPLY {
                        parProcessConditionSolid 
                }

        }
}

COMMAND write_parProcessConditionSolid {
        BLOCK transducer_block_1 ;
        INDEX 37 ;
        OPERATION WRITE ;
        TRANSACTION {
                REQUEST {
                        parProcessConditionSolid
                }
                REPLY {
                }
        }
}

COMMAND read_parEmptyCalibration
{
	SLOT 1;
	INDEX 143;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parEmptyCalibration
		}
	}
}


COMMAND write_parEmptyCalibration
{
	SLOT 1;
	INDEX 143;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parEmptyCalibration
		}
		REPLY
		{
		}
	}
}

COMMAND read_parFullCalibration
{
	SLOT 1;
	INDEX 144;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parFullCalibration
		}
	}
}


COMMAND write_parFullCalibration
{
	SLOT 1;
	INDEX 144;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parFullCalibration
		}
		REPLY
		{
		}
	}
}

COMMAND read_parTubeDiameter
{
	SLOT 1;
	INDEX 145;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parTubeDiameter
		}
	}
}


COMMAND write_parTubeDiameter
{
	SLOT 1;
	INDEX 145;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parTubeDiameter
		}
		REPLY
		{
		}
	}
}

COMMAND read_parVesselSilo
{
	SLOT 1;
	INDEX 165;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parVesselSilo
		}
	}
}


COMMAND write_parVesselSilo
{
	SLOT 1;
	INDEX 165;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parVesselSilo
		}
		REPLY
		{
		}
	}
}

COMMAND read_parMediumConditionSolid
{
	SLOT 1;
	INDEX 166;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parMediumConditionSolid
		}
	}
}


COMMAND write_parMediumConditionSolid
{
	SLOT 1;
	INDEX 166;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parMediumConditionSolid
		}
		REPLY
		{
		}
	}
}

VARIABLE  parOutputOnAlarm {
	LABEL 	"|en|output on alarm|de|Ausg. b. Alarm|fr|Sortie si alarme|es|Ausg. b. Alarm|it|Comp. in allarme|nl|uitg. bij alarm" ;
	CLASS 	CONTAINED ; 
	HANDLING  IF (Hnd000)
				{ READ&WRITE; }
			ELSE
				{ READ; }
	TYPE 	ENUMERATED	{  	 DEFAULT_VALUE 1;
        {0, "MIN"},
        {1, "MAX"}, 
        {2, "hold"}     
}
} 

COMMAND read_parOutputOnAlarm
{
	SLOT 1;
	INDEX 148;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parOutputOnAlarm
		}
	}
}


COMMAND write_parOutputOnAlarm
{
	SLOT 1;
	INDEX 148;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parOutputOnAlarm
		}
		REPLY
		{
		}
	}
}

COMMAND read_parReactionLostEcho
{
	SLOT 1;
	INDEX 150;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parReactionLostEcho
		}
	}
}


COMMAND write_parReactionLostEcho
{
	SLOT 1;
	INDEX 150;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parReactionLostEcho
		}
		REPLY
		{
		}
	}
}

COMMAND read_parRampInPercentPerMin
{
	SLOT 1;
	INDEX 151;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parRampInPercentPerMin
		}
	}
}


COMMAND write_parRampInPercentPerMin
{
	SLOT 1;
	INDEX 151;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parRampInPercentPerMin
		}
		REPLY
		{
		}
	}
}

COMMAND read_parDelayTimeOnLostEcho
{
	SLOT 1;
	INDEX 152;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parDelayTimeOnLostEcho
		}
	}
}


COMMAND write_parDelayTimeOnLostEcho
{
	SLOT 1;
	INDEX 152;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parDelayTimeOnLostEcho
		}
		REPLY
		{
		}
	}
}

COMMAND read_parLevelWithinSafetyDistance
{
	SLOT 1;
	INDEX 153;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parLevelWithinSafetyDistance
		}
	}
}


COMMAND write_parLevelWithinSafetyDistance
{
	SLOT 1;
	INDEX 153;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parLevelWithinSafetyDistance
		}
		REPLY
		{
		}
	}
}

COMMAND read_parInSafetyDistance
{
	SLOT 1;
	INDEX 154;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parInSafetyDistance
		}
	}
}


COMMAND write_parInSafetyDistance
{
	SLOT 1;
	INDEX 154;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parInSafetyDistance
		}
		REPLY
		{
		}
	}
}

COMMAND read_parAcknowledgeAlarm
{
	SLOT 1;
	INDEX 155;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parAcknowledgeAlarm
		}
	}
}


COMMAND write_parAcknowledgeAlarm
{
	SLOT 1;
	INDEX 155;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parAcknowledgeAlarm
		}
		REPLY
		{
		}
	}
}

COMMAND read_parOperationMode
{
	SLOT 1;
	INDEX 156;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parOperationMode
		}
	}
}


COMMAND write_parOperationMode
{
	SLOT 1;
	INDEX 156;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parOperationMode
		}
		REPLY
		{
		}
	}
}

COMMAND read_parLevelUllageMode
{
	SLOT 1;
	INDEX 168;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parLevelUllageMode
		}
	}
}


COMMAND write_parLevelUllageMode
{
	SLOT 1;
	INDEX 168;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parLevelUllageMode
		}
		REPLY
		{
		}
	}
}

COMMAND read_parLinearisation
{
	SLOT 1;
	INDEX 169;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parLinearisation
		}
	}
}


COMMAND write_parLinearisation
{
	SLOT 1;
	INDEX 169;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parLinearisation
		}
		REPLY
		{
		}
	}
}

COMMAND read_parTableNumber
{
	SLOT 1;
	INDEX 171;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parTableNumber
		}
	}
}


COMMAND write_parTableNumber
{
	SLOT 1;
	INDEX 171;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parTableNumber
		}
		REPLY
		{
		}
	}
}

COMMAND read_parInputLevelHalfAutomatic
{
	SLOT 1;
	INDEX 248;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parInputLevelHalfAutomatic
		}
	}
}


COMMAND write_parInputLevelHalfAutomatic
{
	SLOT 1;
	INDEX 248;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parInputLevelHalfAutomatic
		}
		REPLY
		{
		}
	}
}

COMMAND read_parInputLevelManual
{
	SLOT 1;
	INDEX 249;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parInputLevelManual
		}
	}
}


COMMAND write_parInputLevelManual
{
	SLOT 1;
	INDEX 249;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parInputLevelManual
		}
		REPLY
		{
		}
	}
}

COMMAND read_parInputVolume
{
	SLOT 1;
	INDEX 173;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parInputVolume
		}
	}
}


COMMAND write_parInputVolume
{
	SLOT 1;
	INDEX 173;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parInputVolume
		}
		REPLY
		{
		}
	}
}

COMMAND read_parMaxVolume
{
	SLOT 1;
	INDEX 174;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parMaxVolume
		}
	}
}


COMMAND write_parMaxVolume
{
	SLOT 1;
	INDEX 174;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parMaxVolume
		}
		REPLY
		{
		}
	}
}

COMMAND read_parCylinderVessel
{
	SLOT 1;
	INDEX 175;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parCylinderVessel
		}
	}
}


COMMAND write_parCylinderVessel
{
	SLOT 1;
	INDEX 175;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parCylinderVessel
		}
		REPLY
		{
		}
	}
}

COMMAND read_parMappingSelectExtended
{
	SLOT 1;
	INDEX 178;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parMappingSelectExtended
		}
	}
}


COMMAND write_parMappingSelectExtended
{
	SLOT 1;
	INDEX 178;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parMappingSelectExtended
		}
		REPLY
		{
		}
	}
}

COMMAND read_parCheckDistance
{
	SLOT 1;
	INDEX 179;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parCheckDistance
		}
	}
}


COMMAND write_parCheckDistance
{
	SLOT 1;
	INDEX 179;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parCheckDistance
		}
		REPLY
		{
		}
	}
}

COMMAND read_parSuppressionDistance
{
	SLOT 1;
	INDEX 180;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parSuppressionDistance
		}
	}
}


COMMAND write_parSuppressionDistance
{
	SLOT 1;
	INDEX 180;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parSuppressionDistance
		}
		REPLY
		{
		}
	}
}

COMMAND read_parStartMappingRecord
{
	SLOT 1;
	INDEX 181;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parStartMappingRecord
		}
	}
}


COMMAND write_parStartMappingRecord
{
	SLOT 1;
	INDEX 181;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parStartMappingRecord
		}
		REPLY
		{
		}
	}
}

COMMAND read_parPresMapRange
{
	SLOT 1;
	INDEX 182;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parPresMapRange
		}
	}
}


COMMAND write_parPresMapRange
{
	SLOT 1;
	INDEX 182;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parPresMapRange
		}
		REPLY
		{
		}
	}
}

COMMAND read_parCustTankMap
{
	SLOT 1;
	INDEX 183;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parCustTankMap
		}
	}
}


COMMAND write_parCustTankMap
{
	SLOT 1;
	INDEX 183;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parCustTankMap
		}
		REPLY
		{
		}
	}
}

COMMAND read_parEchoQuality
{
	BLOCK 	transducer_block_1 ;
	INDEX 	54 ;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
                        parEchoQuality
		}
	}
}


COMMAND write_parEchoQuality
{
	BLOCK 	transducer_block_1 ;
	INDEX 	54 ;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
                        parEchoQuality
		}
		REPLY
		{
		}
	}
}

COMMAND read_parOffsetOfMeasuredLevel
{
	SLOT 1;
	INDEX 185;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parOffsetOfMeasuredLevel
		}
	}
}


COMMAND write_parOffsetOfMeasuredLevel
{
	SLOT 1;
	INDEX 185;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parOffsetOfMeasuredLevel
		}
		REPLY
		{
		}
	}
}

COMMAND read_parOutputDamping
{
	SLOT 1;
	INDEX 186;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parOutputDamping
		}
	}
}


COMMAND write_parOutputDamping
{
	SLOT 1;
	INDEX 186;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parOutputDamping
		}
		REPLY
		{
		}
	}
}

COMMAND read_parBlockingDistance
{
	SLOT 1;
	INDEX 187;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parBlockingDistance
		}
	}
}


COMMAND write_parBlockingDistance
{
	SLOT 1;
	INDEX 187;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parBlockingDistance
		}
		REPLY
		{
		}
	}
}



COMMAND write_parPADeviceBusAddress
{
	SLOT 1;
	INDEX 188;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parPADeviceBusAddress
		}
		REPLY
		{
		}
	}
}

COMMAND read_parPAIdentNumberSelector
{
BLOCK   transducer_block_1 ;
INDEX   59 ;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parPAIdentNumberSelector
		}
	}
}


COMMAND write_parPAIdentNumberSelector
{
BLOCK   transducer_block_1 ;
INDEX   59 ;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parPAIdentNumberSelector
		}
		REPLY
		{
		}
	}
}

VARIABLE  parPASetUnitToBus {
	LABEL 	"|en|set unit to bus|de|Setze Einh. Out" ;
	CLASS 	CONTAINED ; 
	VALIDITY  TRUE ;
	HANDLING  READ & WRITE ;
	TYPE 	ENUMERATED (1)	{ DEFAULT_VALUE 0; {0,"|en|confirm|de|besttigen"}}
} 


COMMAND read_parPASetUnitToBus
{
	BLOCK 	transducer_block_1 ;
	INDEX 	60 ;
        OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parPASetUnitToBus
		}
	}
}


COMMAND write_parPASetUnitToBus
{
	BLOCK 	transducer_block_1 ;
	INDEX 	60 ;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parPASetUnitToBus
		}
		REPLY
		{
		}
	}
}

COMMAND read_parSimulation
{
	SLOT 1;
	INDEX 193;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parSimulation
		}
	}
}


COMMAND write_parSimulation
{
	SLOT 1;
	INDEX 193;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parSimulation
		}
		REPLY
		{
		}
	}
}

COMMAND read_parSimulationValueLevel
{
	SLOT 1;
	INDEX 250;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parSimulationValueLevel
		}
	}
}


COMMAND write_parSimulationValueLevel
{
	SLOT 1;
	INDEX 250;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parSimulationValueLevel
		}
		REPLY
		{
		}
	}
}

COMMAND read_parSimulationValueVolume
{
	SLOT 1;
	INDEX 251;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parSimulationValueVolume
		}
	}
}


COMMAND write_parSimulationValueVolume
{
	SLOT 1;
	INDEX 251;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parSimulationValueVolume
		}
		REPLY
		{
		}
	}
}

COMMAND read_parPA2ndCycValHeightDist
{
	SLOT 1;
	INDEX 195;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parPA2ndCycValHeightDist
		}
	}
}


COMMAND write_parPA2ndCycValHeightDist
{
	SLOT 1;
	INDEX 195;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parPA2ndCycValHeightDist
		}
		REPLY
		{
		}
	}
}

COMMAND read_parPASelectMainValue
{
	SLOT 1;
	INDEX 196;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parPASelectMainValue
		}
	}
}


COMMAND write_parPASelectMainValue
{
	SLOT 1;
	INDEX 196;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parPASelectMainValue
		}
		REPLY
		{
		}
	}
}

COMMAND read_parPADisplayValue
{
	SLOT 1;
	INDEX 197;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parPADisplayValue
		}
	}
}


COMMAND write_parPADisplayValue
{
	SLOT 1;
	INDEX 197;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parPADisplayValue
		}
		REPLY
		{
		}
	}
}

COMMAND read_parContrastDisplay
{
	SLOT 1;
	INDEX 199;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parContrastDisplay
		}
	}
}


COMMAND write_parContrastDisplay
{
	SLOT 1;
	INDEX 199;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parContrastDisplay
		}
		REPLY
		{
		}
	}
}

COMMAND read_parLanguage
{
	SLOT 1;
	INDEX 200;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
                        parLanguage
		}
	}
}


COMMAND write_parLanguage
{
	SLOT 1;
	INDEX 200;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
                        parLanguage
		}
		REPLY
		{
		}
	}
}

COMMAND read_parFormatDisplayDec16inch
{
	SLOT 1;
	INDEX 202;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parFormatDisplayDec16inch
		}
	}
}


COMMAND write_parFormatDisplayDec16inch
{
	SLOT 1;
	INDEX 202;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parFormatDisplayDec16inch
		}
		REPLY
		{
		}
	}
}

COMMAND read_parNoOfDecimalsUpTo3
{
	SLOT 1;
	INDEX 203;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parNoOfDecimalsUpTo3
		}
	}
}


COMMAND write_parNoOfDecimalsUpTo3
{
	SLOT 1;
	INDEX 203;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parNoOfDecimalsUpTo3
		}
		REPLY
		{
		}
	}
}

COMMAND read_parSeparationCharacter
{
	SLOT 1;
	INDEX 204;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parSeparationCharacter
		}
	}
}


COMMAND write_parSeparationCharacter
{
	SLOT 1;
	INDEX 204;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parSeparationCharacter
		}
		REPLY
		{
		}
	}
}

COMMAND read_parDisplayTest
{
	SLOT 1;
	INDEX 205;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parDisplayTest
		}
	}
}


COMMAND write_parDisplayTest
{
	SLOT 1;
	INDEX 205;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parDisplayTest
		}
		REPLY
		{
		}
	}
}

COMMAND read_parActualError
{
	SLOT 1;
	INDEX 228;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parActualError
		}
	}
}


COMMAND write_parActualError
{
	SLOT 1;
	INDEX 228;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parActualError
		}
		REPLY
		{
		}
	}
}

COMMAND read_parLastError
{
	SLOT 1;
	INDEX 229;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parLastError
		}
	}
}


COMMAND write_parLastError
{
	SLOT 1;
	INDEX 229;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parLastError
		}
		REPLY
		{
		}
	}
}

COMMAND read_parClearLastError
{
	SLOT 1;
	INDEX 230;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parClearLastError
		}
	}
}


COMMAND write_parClearLastError
{
	SLOT 1;
	INDEX 230;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parClearLastError
		}
		REPLY
		{
		}
	}
}

COMMAND read_parReset
{
	SLOT 1;
	INDEX 231;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parReset
		}
	}
}


COMMAND write_parReset
{
	SLOT 1;
	INDEX 231;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parReset
		}
		REPLY
		{
		}
	}
}

COMMAND read_parOperationCodeFFPAOnline
{
	BLOCK 	transducer_block_1 ;
	INDEX 	102 ;
        OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
                        parOperationCodeFFPAOnline
		}
	}
}


COMMAND write_parOperationCodeFFPAOnline
{
	BLOCK 	transducer_block_1 ;
	INDEX 	102 ;
        OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
                        parOperationCodeFFPAOnline
		}
		REPLY
		{
		}
	}
}

COMMAND read_parMeasuredDistance
{
	SLOT 1;
	INDEX 233;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parMeasuredDistance
		}
	}
}


COMMAND write_parMeasuredDistance
{
	SLOT 1;
	INDEX 233;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parMeasuredDistance
		}
		REPLY
		{
		}
	}
}

COMMAND read_parMeasuredLevel
{
	SLOT 1;
	INDEX 234;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parMeasuredLevel
		}
	}
}


COMMAND write_parMeasuredLevel
{
	SLOT 1;
	INDEX 234;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parMeasuredLevel
		}
		REPLY
		{
		}
	}
}

COMMAND read_parDetectionWindow
{
	SLOT 1;
	INDEX 235;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parDetectionWindow
		}
	}
}


COMMAND write_parDetectionWindow
{
	SLOT 1;
	INDEX 235;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parDetectionWindow
		}
		REPLY
		{
		}
	}
}

COMMAND read_parApplicationParameter
{
	SLOT 1;
	INDEX 236;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parApplicationParameter
		}
	}
}


COMMAND write_parApplicationParameter
{
	SLOT 1;
	INDEX 236;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parApplicationParameter
		}
		REPLY
		{
		}
	}
}

COMMAND read_parTagNumber32
{
	BLOCK 	transducer_block_1 ;
	INDEX 	108 ;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parTagNumber32
		}
	}
}


COMMAND write_parTagNumber32
{
	BLOCK 	transducer_block_1 ;
	INDEX 	108 ;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parTagNumber32
		}
		REPLY
		{
		}
	}
}

COMMAND read_parPAProfileRevision
{
	SLOT 	1 ;
	INDEX 	113 ;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parPAProfileRevision
		}
	}
}


COMMAND write_parPAProfileRevision
{
	SLOT 1;
	INDEX 239;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parPAProfileRevision
		}
		REPLY
		{
		}
	}
}

COMMAND read_parProtSoftVersionString
{
	SLOT 1;
	INDEX 240;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parProtSoftVersionString
		}
	}
}


COMMAND write_parProtSoftVersionString
{
	SLOT 1;
	INDEX 240;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parProtSoftVersionString
		}
		REPLY
		{
		}
	}
}

COMMAND read_parSerialNumber
{
	SLOT 1;
	INDEX 242;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parSerialNumber
		}
	}
}


COMMAND write_parSerialNumber
{
	SLOT 1;
	INDEX 242;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parSerialNumber
		}
		REPLY
		{
		}
	}
}

COMMAND read_parDistanceUnit16
{
	SLOT 1;
	INDEX 243;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parDistanceUnit16
		}
	}
}


COMMAND write_parDistanceUnit16
{
	SLOT 1;
	INDEX 243;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parDistanceUnit16
		}
		REPLY
		{
		}
	}
}

COMMAND read_parDownloadMode
{
	SLOT 1;
	INDEX 246;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parDownloadMode
		}
	}
}


COMMAND write_parDownloadMode
{
	SLOT 1;
	INDEX 246;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parDownloadMode
		}
		REPLY
		{
		}
	}
}

COMMAND read_parAntennaExtensionLength
{
	SLOT 1;
	INDEX 247;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parAntennaExtensionLength
		}
	}
}


COMMAND write_parAntennaExtensionLength
{
	SLOT 1;
	INDEX 247;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parAntennaExtensionLength
		}
		REPLY
		{
		}
	}
}

COMMAND read_parServiceLevelFMR2XX
{
	SLOT 1;
	INDEX 208;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parServiceLevelFMR2XX
		}
	}
}


COMMAND write_parServiceLevelFMR2XX
{
	SLOT 1;
	INDEX 208;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parServiceLevelFMR2XX
		}
		REPLY
		{
		}
	}
}

COMMAND read_parActualAmplitude
{
	SLOT 2;
	INDEX 0;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parActualAmplitude
		}
	}
}


COMMAND write_parActualAmplitude
{
	SLOT 2;
	INDEX 0;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parActualAmplitude
		}
		REPLY
		{
		}
	}
}

COMMAND read_parAmplitudeOverSupp
{
	SLOT 2;
	INDEX 1;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
                        parAmplitudeOverSupp
		}
	}
}


COMMAND write_parAmplitudeOverSupp
{
	SLOT 2;
	INDEX 1;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
                        parAmplitudeOverSupp
		}
		REPLY
		{
		}
	}
}

COMMAND read_parAmplitudeOverFAC
{
	SLOT 2;
	INDEX 2;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parAmplitudeOverFAC
		}
	}
}


COMMAND write_parAmplitudeOverFAC
{
	SLOT 2;
	INDEX 2;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parAmplitudeOverFAC
		}
		REPLY
		{
		}
	}
}

COMMAND read_parUnfilteredDistance
{
	SLOT 2;
	INDEX 3;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parUnfilteredDistance
		}
	}
}


COMMAND write_parUnfilteredDistance
{
	SLOT 2;
	INDEX 3;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parUnfilteredDistance
		}
		REPLY
		{
		}
	}
}

COMMAND read_parCalcEdgeParameter
{
	SLOT 2;
	INDEX 4;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parCalcEdgeParameter
		}
	}
}


COMMAND write_parCalcEdgeParameter
{
	SLOT 2;
	INDEX 4;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parCalcEdgeParameter
		}
		REPLY
		{
		}
	}
}

COMMAND read_parActFirstEchoFactor
{
	SLOT 2;
	INDEX 5;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parActFirstEchoFactor
		}
	}
}


COMMAND write_parActFirstEchoFactor
{
	SLOT 2;
	INDEX 5;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parActFirstEchoFactor
		}
		REPLY
		{
		}
	}
}

COMMAND read_parDeviceName
{
	SLOT 2;
	INDEX 7;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parDeviceName
		}
	}
}


COMMAND write_parDeviceName
{
	SLOT 2;
	INDEX 7;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parDeviceName
		}
		REPLY
		{
		}
	}
}

COMMAND read_parDeviceNameNotEditable16
{
	SLOT 1;
	INDEX 76;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parDeviceNameNotEditable16
		}
	}
}


COMMAND write_parDeviceNameNotEditable16
{
	SLOT 1;
	INDEX 76;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parDeviceNameNotEditable16
		}
		REPLY
		{
		}
	}
}

COMMAND read_parDeviceNameNotEditable8
{
	SLOT 1;
	INDEX 76;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parDeviceNameNotEditable8
		}
	}
}


COMMAND write_parDeviceNameNotEditable8
{
	SLOT 1;
	INDEX 76;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parDeviceNameNotEditable8
		}
		REPLY
		{
		}
	}
}

COMMAND read_parOrderCode
{
	SLOT 2;
	INDEX 8;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parOrderCode
		}
	}
}


COMMAND write_parOrderCode
{
	SLOT 2;
	INDEX 8;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parOrderCode
		}
		REPLY
		{
		}
	}
}

COMMAND read_parMamFilterLength
{
	SLOT 2;
	INDEX 9;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
                        parMamFilterLength
		}
	}
}


COMMAND write_parMamFilterLength
{
	SLOT 2;
	INDEX 9;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
                        parMamFilterLength
		}
		REPLY
		{
		}
	}
}

COMMAND read_parMamFilterBorder
{
	SLOT 2;
	INDEX 10;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
                        parMamFilterBorder
		}
	}
}


COMMAND write_parMamFilterBorder
{
	SLOT 2;
	INDEX 10;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
                        parMamFilterBorder
		}
		REPLY
		{
		}
	}
}

COMMAND read_parFilterConstMin
{
	SLOT 2;
	INDEX 11;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parFilterConstMin
		}
	}
}


COMMAND write_parFilterConstMin
{
	SLOT 2;
	INDEX 11;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parFilterConstMin
		}
		REPLY
		{
		}
	}
}

COMMAND read_parFilterConstMax
{
	SLOT 2;
	INDEX 12;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parFilterConstMax
		}
	}
}


COMMAND write_parFilterConstMax
{
	SLOT 2;
	INDEX 12;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parFilterConstMax
		}
		REPLY
		{
		}
	}
}

COMMAND read_parInnovationFiltConstMax
{
	SLOT 2;
	INDEX 13;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parInnovationFiltConstMax
		}
	}
}


COMMAND write_parInnovationFiltConstMax
{
	SLOT 2;
	INDEX 13;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parInnovationFiltConstMax
		}
		REPLY
		{
		}
	}
}

COMMAND read_parHystereseWidth
{
	SLOT 2;
	INDEX 14;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parHystereseWidth
		}
	}
}


COMMAND write_parHystereseWidth
{
	SLOT 2;
	INDEX 14;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parHystereseWidth
		}
		REPLY
		{
		}
	}
}

COMMAND read_parEchoLostRampUp
{
	SLOT 2;
	INDEX 15;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parEchoLostRampUp
		}
	}
}


COMMAND write_parEchoLostRampUp
{
	SLOT 2;
	INDEX 15;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parEchoLostRampUp
		}
		REPLY
		{
		}
	}
}

COMMAND read_parEchoLostRampDown
{
	SLOT 2;
	INDEX 16;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parEchoLostRampDown
		}
	}
}


COMMAND write_parEchoLostRampDown
{
	SLOT 2;
	INDEX 16;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parEchoLostRampDown
		}
		REPLY
		{
		}
	}
}

COMMAND read_parUnfilteredDistanceRaw
{
	SLOT 2;
	INDEX 17;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parUnfilteredDistanceRaw
		}
	}
}


COMMAND write_parUnfilteredDistanceRaw
{
	SLOT 2;
	INDEX 17;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parUnfilteredDistanceRaw
		}
		REPLY
		{
		}
	}
}

COMMAND read_parEnvSmoothingDistance
{
	SLOT 2;
	INDEX 18;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parEnvSmoothingDistance
		}
	}
}


COMMAND write_parEnvSmoothingDistance
{
	SLOT 2;
	INDEX 18;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parEnvSmoothingDistance
		}
		REPLY
		{
		}
	}
}

COMMAND read_parSawitzkiGolay
{
	SLOT 2;
	INDEX 19;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parSawitzkiGolay
		}
	}
}


COMMAND write_parSawitzkiGolay
{
	SLOT 2;
	INDEX 19;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parSawitzkiGolay
		}
		REPLY
		{
		}
	}
}

COMMAND read_parHkStatCountPos
{
	SLOT 2;
	INDEX 20;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parHkStatCountPos
		}
	}
}


COMMAND write_parHkStatCountPos
{
	SLOT 2;
	INDEX 20;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parHkStatCountPos
		}
		REPLY
		{
		}
	}
}

COMMAND read_parHkStatCountNeg
{
	SLOT 2;
	INDEX 21;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parHkStatCountNeg
		}
	}
}


COMMAND write_parHkStatCountNeg
{
	SLOT 2;
	INDEX 21;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parHkStatCountNeg
		}
		REPLY
		{
		}
	}
}

COMMAND read_parMergingEchoes
{
	SLOT 2;
	INDEX 22;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parMergingEchoes
		}
	}
}


COMMAND write_parMergingEchoes
{
	SLOT 2;
	INDEX 22;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parMergingEchoes
		}
		REPLY
		{
		}
	}
}

COMMAND read_parMergingWindow
{
	SLOT 2;
	INDEX 23;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parMergingWindow
		}
	}
}


COMMAND write_parMergingWindow
{
	SLOT 2;
	INDEX 23;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parMergingWindow
		}
		REPLY
		{
		}
	}
}

COMMAND read_parMergingEchoDist
{
	SLOT 2;
	INDEX 24;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parMergingEchoDist
		}
	}
}


COMMAND write_parMergingEchoDist
{
	SLOT 2;
	INDEX 24;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parMergingEchoDist
		}
		REPLY
		{
		}
	}
}

COMMAND read_parMergingRatio
{
	SLOT 2;
	INDEX 25;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parMergingRatio
		}
	}
}


COMMAND write_parMergingRatio
{
	SLOT 2;
	INDEX 25;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parMergingRatio
		}
		REPLY
		{
		}
	}
}

COMMAND read_parMappingAdder
{
	SLOT 2;
	INDEX 27;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parMappingAdder
		}
	}
}


COMMAND write_parMappingAdder
{
	SLOT 2;
	INDEX 27;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parMappingAdder
		}
		REPLY
		{
		}
	}
}

COMMAND read_parMappingWidthNew
{
	SLOT 2;
	INDEX 28;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
                        parMappingWidthNew
		}
	}
}


COMMAND write_parMappingWidthNew
{
	SLOT 2;
	INDEX 28;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
                        parMappingWidthNew
		}
		REPLY
		{
		}
	}
}

COMMAND read_parMappingAverage
{
	SLOT 2;
	INDEX 29;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parMappingAverage
		}
	}
}


COMMAND write_parMappingAverage
{
	SLOT 2;
	INDEX 29;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parMappingAverage
		}
		REPLY
		{
		}
	}
}

COMMAND read_parFactoryTdt
{
	SLOT 2;
	INDEX 30;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parFactoryTdt
		}
	}
}


COMMAND write_parFactoryTdt
{
	SLOT 2;
	INDEX 30;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parFactoryTdt
		}
		REPLY
		{
		}
	}
}

COMMAND read_parFacAdder
{
	SLOT 2;
	INDEX 31;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parFacAdder
		}
	}
}


COMMAND write_parFacAdder
{
	SLOT 2;
	INDEX 31;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parFacAdder
		}
		REPLY
		{
		}
	}
}

COMMAND read_parFACWidthNew
{
	SLOT 2;
	INDEX 32;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
                        parFACWidthNew
		}
	}
}


COMMAND write_parFACWidthNew
{
	SLOT 2;
	INDEX 32;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
                        parFACWidthNew
		}
		REPLY
		{
		}
	}
}

COMMAND read_parRangeFactoryMap
{
	SLOT 2;
	INDEX 33;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parRangeFactoryMap
		}
	}
}


COMMAND write_parRangeFactoryMap
{
	SLOT 2;
	INDEX 33;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parRangeFactoryMap
		}
		REPLY
		{
		}
	}
}

COMMAND read_parFactoryMappingValid
{
	SLOT 2;
	INDEX 34;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parFactoryMappingValid
		}
	}
}


COMMAND write_parFactoryMappingValid
{
	SLOT 2;
	INDEX 34;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parFactoryMappingValid
		}
		REPLY
		{
		}
	}
}

COMMAND read_parCustomerMappingValid
{
	SLOT 2;
	INDEX 35;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parCustomerMappingValid
		}
	}
}


COMMAND write_parCustomerMappingValid
{
	SLOT 2;
	INDEX 35;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parCustomerMappingValid
		}
		REPLY
		{
		}
	}
}

COMMAND read_parEdgeDetectionMode
{
	SLOT 2;
	INDEX 36;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parEdgeDetectionMode
		}
	}
}


COMMAND write_parEdgeDetectionMode
{
	SLOT 2;
	INDEX 36;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parEdgeDetectionMode
		}
		REPLY
		{
		}
	}
}

COMMAND read_parEdgeParameter
{
	SLOT 2;
	INDEX 37;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parEdgeParameter
		}
	}
}


COMMAND write_parEdgeParameter
{
	SLOT 2;
	INDEX 37;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parEdgeParameter
		}
		REPLY
		{
		}
	}
}

COMMAND read_parCalcEdgeParameterCopy
{
	SLOT 2;
	INDEX 44;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parCalcEdgeParameterCopy
		}
	}
}


COMMAND write_parCalcEdgeParameterCopy
{
	SLOT 2;
	INDEX 44;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parCalcEdgeParameterCopy
		}
		REPLY
		{
		}
	}
}

COMMAND read_parFirstEchoFactor
{
	SLOT 2;
	INDEX 45;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parFirstEchoFactor
		}
	}
}


COMMAND write_parFirstEchoFactor
{
	SLOT 2;
	INDEX 45;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parFirstEchoFactor
		}
		REPLY
		{
		}
	}
}

COMMAND read_parFefThreshold
{
	SLOT 2;
	INDEX 46;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parFefThreshold
		}
	}
}


COMMAND write_parFefThreshold
{
	SLOT 2;
	INDEX 46;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parFefThreshold
		}
		REPLY
		{
		}
	}
}

COMMAND read_parFefNearFactor
{
	SLOT 2;
	INDEX 47;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parFefNearFactor
		}
	}
}


COMMAND write_parFefNearFactor
{
	SLOT 2;
	INDEX 47;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parFefNearFactor
		}
		REPLY
		{
		}
	}
}

COMMAND read_parFefDistanceNear
{
	SLOT 2;
	INDEX 48;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parFefDistanceNear
		}
	}
}


COMMAND write_parFefDistanceNear
{
	SLOT 2;
	INDEX 48;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parFefDistanceNear
		}
		REPLY
		{
		}
	}
}

COMMAND read_parFefDistanceFar
{
	SLOT 2;
	INDEX 49;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parFefDistanceFar
		}
	}
}


COMMAND write_parFefDistanceFar
{
	SLOT 2;
	INDEX 49;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parFefDistanceFar
		}
		REPLY
		{
		}
	}
}

COMMAND read_parFefEdge
{
	SLOT 2;
	INDEX 50;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parFefEdge
		}
	}
}


COMMAND write_parFefEdge
{
	SLOT 2;
	INDEX 50;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parFefEdge
		}
		REPLY
		{
		}
	}
}

COMMAND read_parMaxEchoSN
{
	SLOT 2;
	INDEX 52;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parMaxEchoSN
		}
	}
}


COMMAND write_parMaxEchoSN
{
	SLOT 2;
	INDEX 52;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parMaxEchoSN
		}
		REPLY
		{
		}
	}
}

COMMAND read_parDishBottomDet
{
	SLOT 2;
	INDEX 54;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
                        parDishBottomDet
		}
	}
}


COMMAND write_parDishBottomDet
{
	SLOT 2;
	INDEX 54;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
                        parDishBottomDet
		}
		REPLY
		{
		}
	}
}

COMMAND read_parAmplLevelBottomDet
{
	SLOT 2;
	INDEX 55;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
                        parAmplLevelBottomDet
		}
	}
}


COMMAND write_parAmplLevelBottomDet
{
	SLOT 2;
	INDEX 55;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
                        parAmplLevelBottomDet
		}
		REPLY
		{
		}
	}
}

COMMAND read_parMinLevelBottomDet
{
	SLOT 2;
	INDEX 56;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
                        parMinLevelBottomDet
		}
	}
}


COMMAND write_parMinLevelBottomDet
{
	SLOT 2;
	INDEX 56;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
                        parMinLevelBottomDet
		}
		REPLY
		{
		}
	}
}

COMMAND read_parRangeTankBottomDetection
{
	SLOT 2;
	INDEX 57;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parRangeTankBottomDetection
		}
	}
}


COMMAND write_parRangeTankBottomDetection
{
	SLOT 2;
	INDEX 57;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parRangeTankBottomDetection
		}
		REPLY
		{
		}
	}
}

COMMAND read_parClipDistanceToEmpty
{
	SLOT 2;
	INDEX 61;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parClipDistanceToEmpty
		}
	}
}


COMMAND write_parClipDistanceToEmpty
{
	SLOT 2;
	INDEX 61;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parClipDistanceToEmpty
		}
		REPLY
		{
		}
	}
}

COMMAND read_parHfModul
{
	SLOT 2;
	INDEX 63;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
                        parHfModul
		}
	}
}


COMMAND write_parHfModul
{
	SLOT 2;
	INDEX 63;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
                        parHfModul
		}
		REPLY
		{
		}
	}
}

COMMAND read_parActualMicroFactorHidden
{
	SLOT 2;
	INDEX 69;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parActualMicroFactorHidden
		}
	}
}


COMMAND write_parActualMicroFactorHidden
{
	SLOT 2;
	INDEX 69;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parActualMicroFactorHidden
		}
		REPLY
		{
		}
	}
}

COMMAND read_parPositionOfReferencePulse
{
	SLOT 2;
	INDEX 70;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parPositionOfReferencePulse
		}
	}
}


COMMAND write_parPositionOfReferencePulse
{
	SLOT 2;
	INDEX 70;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parPositionOfReferencePulse
		}
		REPLY
		{
		}
	}
}

COMMAND read_parAmplOfReferencePulse
{
	SLOT 2;
	INDEX 71;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
                        parAmplOfReferencePulse
		}
	}
}


COMMAND write_parAmplOfReferencePulse
{
	SLOT 2;
	INDEX 71;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
                        parAmplOfReferencePulse
		}
		REPLY
		{
		}
	}
}

COMMAND read_parInactiveLength
{
	SLOT 2;
	INDEX 73;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parInactiveLength
		}
	}
}


COMMAND write_parInactiveLength
{
	SLOT 2;
	INDEX 73;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parInactiveLength
		}
		REPLY
		{
		}
	}
}

COMMAND read_parTotalLength
{
	SLOT 2;
	INDEX 74;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parTotalLength
		}
	}
}


COMMAND write_parTotalLength
{
	SLOT 2;
	INDEX 74;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parTotalLength
		}
		REPLY
		{
		}
	}
}

COMMAND read_parAbsMaxMessDist
{
	SLOT 2;
	INDEX 75;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parAbsMaxMessDist
		}
	}
}


COMMAND write_parAbsMaxMessDist
{
	SLOT 2;
	INDEX 75;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parAbsMaxMessDist
		}
		REPLY
		{
		}
	}
}

COMMAND read_parEditRangeMaxSampleDist
{
	SLOT 2;
	INDEX 79;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parEditRangeMaxSampleDist
		}
	}
}


COMMAND write_parEditRangeMaxSampleDist
{
	SLOT 2;
	INDEX 79;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parEditRangeMaxSampleDist
		}
		REPLY
		{
		}
	}
}

COMMAND read_parDelayTimer
{
	SLOT 2;
	INDEX 83;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parDelayTimer
		}
	}
}


COMMAND write_parDelayTimer
{
	SLOT 2;
	INDEX 83;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parDelayTimer
		}
		REPLY
		{
		}
	}
}

COMMAND read_parEchoFoundDelay
{
	SLOT 2;
	INDEX 84;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parEchoFoundDelay
		}
	}
}


COMMAND write_parEchoFoundDelay
{
	SLOT 2;
	INDEX 84;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parEchoFoundDelay
		}
		REPLY
		{
		}
	}
}

COMMAND read_parEchoLostDelay
{
	SLOT 2;
	INDEX 85;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parEchoLostDelay
		}
	}
}


COMMAND write_parEchoLostDelay
{
	SLOT 2;
	INDEX 85;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parEchoLostDelay
		}
		REPLY
		{
		}
	}
}

COMMAND read_parJumpDelayBase
{
	SLOT 2;
	INDEX 86;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parJumpDelayBase
		}
	}
}


COMMAND write_parJumpDelayBase
{
	SLOT 2;
	INDEX 86;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parJumpDelayBase
		}
		REPLY
		{
		}
	}
}

COMMAND read_parJumpDelaySlope
{
	SLOT 2;
	INDEX 87;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parJumpDelaySlope
		}
	}
}


COMMAND write_parJumpDelaySlope
{
	SLOT 2;
	INDEX 87;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parJumpDelaySlope
		}
		REPLY
		{
		}
	}
}

COMMAND read_parNoJumpWindowWith
{
	SLOT 2;
	INDEX 88;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parNoJumpWindowWith
		}
	}
}


COMMAND write_parNoJumpWindowWith
{
	SLOT 2;
	INDEX 88;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parNoJumpWindowWith
		}
		REPLY
		{
		}
	}
}

COMMAND read_parWeightMode
{
	SLOT 2;
	INDEX 89;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parWeightMode
		}
	}
}


COMMAND write_parWeightMode
{
	SLOT 2;
	INDEX 89;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parWeightMode
		}
		REPLY
		{
		}
	}
}

COMMAND read_parCalculatedCycleTime
{
	SLOT 2;
	INDEX 113;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parCalculatedCycleTime
		}
	}
}


COMMAND write_parCalculatedCycleTime
{
	SLOT 2;
	INDEX 113;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parCalculatedCycleTime
		}
		REPLY
		{
		}
	}
}

COMMAND read_parBuildNumber
{
	SLOT 2;
	INDEX 115;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parBuildNumber
		}
	}
}


COMMAND write_parBuildNumber
{
	SLOT 2;
	INDEX 115;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parBuildNumber
		}
		REPLY
		{
		}
	}
}

COMMAND read_parParamVersion
{
	SLOT 2;
	INDEX 116;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parParamVersion
		}
	}
}


COMMAND write_parParamVersion
{
	SLOT 2;
	INDEX 116;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parParamVersion
		}
		REPLY
		{
		}
	}
}

COMMAND read_parDaaIndex1
{
	SLOT 2;
	INDEX 135;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parDaaIndex1
		}
	}
}


COMMAND write_parDaaIndex1
{
	SLOT 2;
	INDEX 135;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parDaaIndex1
		}
		REPLY
		{
		}
	}
}

COMMAND read_parDaaIndex2
{
	SLOT 2;
	INDEX 136;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parDaaIndex2
		}
	}
}


COMMAND write_parDaaIndex2
{
	SLOT 2;
	INDEX 136;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parDaaIndex2
		}
		REPLY
		{
		}
	}
}

COMMAND read_parDaaRdWrValue
{
	SLOT 2;
	INDEX 137;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parDaaRdWrValue
		}
	}
}


COMMAND write_parDaaRdWrValue
{
	SLOT 2;
	INDEX 137;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parDaaRdWrValue
		}
		REPLY
		{
		}
	}
}

COMMAND read_parErrorStateOfAlgorithm
{
	SLOT 2;
	INDEX 141;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parErrorStateOfAlgorithm
		}
	}
}


COMMAND write_parErrorStateOfAlgorithm
{
	SLOT 2;
	INDEX 141;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parErrorStateOfAlgorithm
		}
		REPLY
		{
		}
	}
}

COMMAND read_parStateOfAlgorithm
{
	SLOT 2;
	INDEX 142;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parStateOfAlgorithm
		}
	}
}


COMMAND write_parStateOfAlgorithm
{
	SLOT 2;
	INDEX 142;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parStateOfAlgorithm
		}
		REPLY
		{
		}
	}
}

COMMAND read_parPADisplayValueRecord
{
	SLOT 1;
	INDEX 111;
	OPERATION READ;
	TRANSACTION
	{
		REQUEST
		{
		}
		REPLY
		{
			parPADisplayValueRecord
		}
	}
}


COMMAND write_parPADisplayValueRecord
{
	SLOT 1;
	INDEX 111;
	OPERATION WRITE;
	TRANSACTION
	{
		REQUEST
		{
			parPADisplayValueRecord
		}
		REPLY
		{
		}
	}
}

COMMAND read_parPADeviceBusAddress { 
	BLOCK 	transducer_block_1 ;
	INDEX 	58 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parPADeviceBusAddress
		} 
	} 
} 

COMMAND read_parMeasuredValue {
 SLOT 1;
 INDEX 138;
 OPERATION READ;
 TRANSACTION {
   REQUEST {}
   REPLY {
    parMeasuredValue
   }
 }

}
COMMAND write_parMeasuredValue {
 SLOT 1;
 INDEX 138;
 OPERATION WRITE;
 TRANSACTION {
   REQUEST {
    parMeasuredValue
   }
   REPLY {}
 }

}

COMMAND read_parSwVersion { 
	SLOT 	2 ;
	INDEX 	115 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parSwVersion
		} 
	} 
} 
COMMAND read_parDisplayVersion { 
	SLOT 	2 ;
	INDEX 	112 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parDisplayVersion
		} 
	} 
} 
COMMAND read_parAntennaType { 
	SLOT 	2 ;
	INDEX 	72 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parAntennaType
		} 
	} 
} 

COMMAND write_parAntennaType { 
	SLOT 	2 ;
	INDEX 	72 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parAntennaType
		} 
		REPLY {
		} 
	} 
} 
COMMAND read_parZeroDistance { 
	SLOT 	2 ;
	INDEX 	64 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parZeroDistance
		} 
	} 
} 

COMMAND write_parZeroDistance { 
	SLOT 	2 ;
	INDEX 	64 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parZeroDistance
		} 
		REPLY {
		} 
	} 
} 
COMMAND read_parLevelSpeed { 
	SLOT 	2 ;
	INDEX 	62 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parLevelSpeed
		} 
	} 
} 
COMMAND read_parEnvelopeEnergy { 
	SLOT 	2 ;
	INDEX 	26 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parEnvelopeEnergy
		} 
	} 
} 

COMMAND read_parFilterBreite { 
	SLOT 	2 ;
	INDEX 	19 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parFilterBreite
		} 
	} 
} 

COMMAND write_parFilterBreite { 
	SLOT 	2 ;
	INDEX 	19 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parFilterBreite
		} 
		REPLY {
		} 
	} 
} 
COMMAND read_parCurrentAmplitude { 
	SLOT 	2 ;
	INDEX 	0 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parCurrentAmplitude
		} 
	} 
} 

COMMAND read_parBackToHome { 
	BLOCK 	transducer_block_1 ;
	INDEX 	71 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parBackToHome
		} 
	} 
} 

COMMAND write_parBackToHome { 
	BLOCK 	transducer_block_1 ;
	INDEX 	71 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parBackToHome
		} 
		REPLY {
		} 
	} 
} 
COMMAND read_parCustomerUnit { 
	BLOCK 	transducer_block_1 ;
	INDEX 	40 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parCustomerUnit
		} 
	} 
} 

COMMAND write_parCustomerUnit { 
	BLOCK 	transducer_block_1 ;
	INDEX 	40 ;
	OPERATION 	WRITE ; 
	TRANSACTION {
		REQUEST {
			parCustomerUnit
		} 
		REPLY {
		} 
	} 
} 

METHOD setUnitToBus
{
        LABEL "|en|set unit to bus|de|Setze Einh. Out";
        DEFINITION
        {
                WriteCommand(write_parPASetUnitToBus);
        }
}


VARIABLE  parPAIdentNumberSelector {
	LABEL 	"|en|ident number|de|Ident. Nr." ;
	CLASS 	CONTAINED ; 
	VALIDITY  TRUE ;
        HANDLING CUSTOMERLOCK
        TYPE    ENUMERATED(1)           {
		   DEFAULT_VALUE 1;
                {0,[phys_ident_number_PROFILE]},
                {1,[phys_ident_number_MANUFACURER]}
        }
} 


COMMAND read_parCurrentFirstEchoFactor { 
	SLOT 	2 ;
	INDEX 	5 ;
	OPERATION 	READ ; 
	TRANSACTION {
		REQUEST {
		} 
		REPLY {
			parCurrentFirstEchoFactor
		} 
	} 
} 

REDEFINE VARIABLE phys_tag_desc
{
 HANDLING CUSTOMERLOCK
}


REDEFINE VARIABLE phys_descriptor
{
 HANDLING CUSTOMERLOCK
}

REDEFINE VARIABLE phys_message
{
 HANDLING CUSTOMERLOCK
}


